const fs = require('fs');
const exec = require('child_process').exec;


function execute(command, callback){
    exec(command, function(error, stdout, stderr){ callback(stdout); });
}

function createVersionJs(version, time) {
    return function (branchName) {
        const { excludedBranches, versionMinor, versionMajor, versionMiddle } = version;
        const versionName = excludedBranches.includes(branchName.trim()) ? `"${versionMinor}_${branchName.trim()}"` : `${versionMinor}`;
        let fileContent =
            `// !!! Don't edit this file it is generated by script "pre-build.js", any changes will be overwritten.
export const currentVersion = () => {
return { versionMajor: ${versionMajor},versionMiddle: ${versionMiddle},versionMinor: ${versionName},
date: "${time.getMonth() + 1}.${time.getDate()}.${time.getFullYear()}",
time: "${time.getHours()}:${time.getMinutes()}:${time.getSeconds()}"};};
`;
        fs.writeFileSync("./src/js/common/version.js", fileContent);
    }
}

function createVersionJson(version, time) {
    return function () {
        const { versionMinor, versionMajor, versionMiddle } = version;
        let fileContent =
            `{
    "version": "v${versionMajor}.${versionMiddle}.${versionMinor}",
    "date": "${time.getMonth() + 1}.${time.getDate()}.${time.getFullYear()}",
    "time": "${time.getHours()}:${time.getMinutes()}:${time.getSeconds()}"
}
`;
        fs.writeFileSync("./version.json", fileContent);
    }
}

function getVersionOptions(data) {
    const package_json = JSON.parse(data);
    const version = package_json.version.split(".");
    const versionMajor = version[0];
    const versionMiddle = version[1];
    const versionMinor = version[2]; // todo fix it: we expect minor version(npm version patch)
    const excludedBranches = ['test_ci'];
    
    return { excludedBranches, versionMinor, versionMajor, versionMiddle };
}

const saveVersion = () => {
    if (fs.existsSync('./package.json')) {
        fs.readFile('./package.json', 'utf8', async function (err, data) {
            if (err) throw err;
            if (data) {
                const time = new Date();
                const versionOptions = getVersionOptions(data);
                
                await execute("git symbolic-ref --short HEAD\n", createVersionJs(versionOptions, time));
                await execute("git symbolic-ref --short HEAD\n", createVersionJson(versionOptions, time));
            } else {
                throw ("Couldn't read package.json wrong format?");
            }
        });
    } else {
        throw ("Couldn't find package.json.");
    }
};

saveVersion();
