import React, { Suspense } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { Redirect, Route, Router, Switch } from 'react-router-dom';
import Loading from 'components/Loading';
import { getCurrentUserScope, getDefaultPageForScope } from 'common/scopes';
import { NO_PROJECTS_AVAILABLE } from 'common/ui-labels';
import allPages from '../pages';


function Pages(props) {
    return props.pages.map(route => (
        <Route
            key={route.path}
            path={route.path}
            component={allPages[route.path]}
        />
    ));
}

function Content(props) {
    const getRedirectPath = () => {
        const { access: { currentRole } } = props;
        const currentScope = getCurrentUserScope(currentRole);
        
        return getDefaultPageForScope(currentScope);
    };
    
    return (
        <Router history={props.history}>
            <Switch>
                <Route
                    path="/loading"
                    render={renderProps => (
                        <Loading access={props.access} dispatch={props.dispatch} {...renderProps} />)}
                />
            
                <Suspense fallback={<Loading />}>
                    <Pages pages={props.pages} />
                </Suspense>
            
                <Redirect from="*" to={getRedirectPath()} />
            </Switch>
            {!props.access.currentRole && <div className="RPP-Text">{NO_PROJECTS_AVAILABLE}</div>}
        </Router>
    );
}

Content.propTypes = {
    pathname: PropTypes.string,
    dispatch: PropTypes.func,
    pages: PropTypes.arrayOf(PropTypes.shape()),
    access: PropTypes.shape(),
    history: PropTypes.shape(),
};

Content.defaultProps = {
    pathname: '',
    dispatch: () => { },
    pages: [{}],
    access: {},
    history: {},
};

const mapStateToProps = (state) => {
    const { access } = state.user;
    const { pages } = state.user.scope;
    const { pathname } = state.router.location;
    
    return { pages, pathname, access };
};

export default connect(mapStateToProps)(Content);

