import React, { Component } from 'react';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';

import DashboardToggle from './DashboardToggle';
import { dashboardChangeWidgets } from 'stores/actions/index';


class DashboardTogglesContainer extends Component {
    static propTypes = {
        dispatch: PropTypes.func,
        widgets: PropTypes.arrayOf(PropTypes.object),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        widgets: [{}],
    };

    onToggle = (widget) => {
        this.resetWidgetsUIState();
        this.props.dispatch(dashboardChangeWidgets({
            ...widget,
            active: !widget.active,
            isExpanded: false,
        }));
    };

    resetWidgetsUIState = () => {
        this.props.widgets.forEach((widget) => {
            this.props.dispatch(dashboardChangeWidgets({
                ...widget,
                isExpanded: false,
            }));
        });
    };
    
    render() {
        return (
            <div className="Dashboard-Toggles">
                {
                    this.props.widgets.map(widget => (
                        <DashboardToggle
                            key={widget.name}
                            dataCy={`dashboard-toggle-${widget.name.toLowerCase()}`}
                            {...widget}
                            onToggle={this.onToggle.bind(this, widget)}
                        />
                    ))
                }
            </div>
        );
    }
}

const mapStateToProps = state => ({
    widgets: state.dashboard.widgets,
});

export default connect(mapStateToProps)(DashboardTogglesContainer);
