import React, { Component } from 'react';
import PropTypes from 'prop-types';

const withLocalPaging = WrappedComponent => (
    class extends Component {
        static propTypes = {
            tableData: PropTypes.arrayOf(PropTypes.shape()),
        };

        static defaultProps = {
            tableData: [],
        };

        constructor(props) {
            super(props);
            this.state = {
                sizePerPage: 10,
                currentPage: 1,
            };
        }

        shouldComponentUpdate(nextProps, nextState) {
            return (nextProps.tableData.length !== this.props.tableData.length)
                || (nextState.sizePerPage !== this.state.sizePerPage)
                || (nextState.currentPage !== this.state.currentPage);
        }

        _onPageChange = (currentPage, sizePerPage) => {
            const isPageNotChanged = this.state.sizePerPage === sizePerPage;
            if (isPageNotChanged) {
                this.setState({
                    currentPage,
                    sizePerPage,
                });
            }
        };

        _onSizePerPageList = (sizePerPage) => {
            const firstLinePositionInAllList = (this.state.sizePerPage * (this.state.currentPage - 1)) + 1;
            const currentPage = Math.floor(firstLinePositionInAllList / sizePerPage) + 1;
            this.setState({
                currentPage,
                sizePerPage,
            });
        };

        render() {
            return (
                <WrappedComponent
                    sizePerPage={this.state.sizePerPage}
                    currentPage={this.state.currentPage}
                    onSizePerPageList={this._onSizePerPageList}
                    onPageChange={this._onPageChange}
                    tableData={this.props.tableData}
                />
            );
        }
    });

export default withLocalPaging;
