import React, { Component } from 'react';
import PropTypes from 'prop-types';

const needShowError = props => !!props.error;
const needShowProgress = props => props.status > 0 && props.status !== 100 && props.chartConfig === null && !needShowError(props);
const needShowMessage = props => props.status === 0 && !needShowError(props);
const needShowChart = props => props.status === 100 && props.chartConfig !== null && !needShowError(props);

const withReport = WrappedComponent => (
    class extends Component {
        static propTypes = {
            status: PropTypes.number,
            chartConfig: PropTypes.shape({}),
            error: PropTypes.shape({}),
        };
    
        static defaultProps = {
            status: 0,
            chartConfig: {},
            error: null,
        };
    
        constructor(props) {
            super(props);
            this.state = {
                showChart: false,
                showProgress: false,
                showMessage: true,
                showError: false,
                firstUpdate: false,
            };
            this.setTimeout = null;
        }
    
        static getDerivedStateFromProps(props, state) {
            const showProgress = needShowProgress(props);
            const showChart = needShowChart(props);
            const showMessage = needShowMessage(props);
            const showError = needShowError(props);
            
            if (!state.firstUpdate && (state.showProgress !== showProgress || state.showChart !== showChart ||
                state.showMessage !== showMessage || state.showError !== showError)) {
                return {
                    firstUpdate: true,
                    showProgress,
                    showMessage,
                    showChart,
                    showError,
                };
            }
            return null;
        }
        
        componentDidUpdate() {
            const showProgress = needShowProgress(this.props);
            const showChart = needShowChart(this.props);
            const showMessage = needShowMessage(this.props);
            const showError = needShowError(this.props);
            
            if (this.props.status === 100 && this.state.showProgress) {
                this.setTimeout = setTimeout(() => {
                    this.setState({
                        showProgress: false,
                        showMessage,
                        showChart,
                        showError,
                    });
                }, 500);
            } else if (this.state.showProgress !== showProgress || this.state.showChart !== showChart) {
                this.setState({
                    showProgress,
                    showMessage,
                    showError,
                    showChart,
                });
            }
        }
        
        componentWillUnmount() {
            if (this.setTimeout) {
                clearTimeout(this.setTimeout);
            }
        }
        
        render() {
            return (
                <WrappedComponent
                    showChart={this.state.showChart}
                    showProgress={this.state.showProgress}
                    showMessage={this.state.showMessage}
                    {...this.props}
                />
            );
        }
    });

export default withReport;
