import React, { Fragment, useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import * as api from 'api';
import { getCurrentVersion } from 'utils/utils';
import { FOOTER } from 'common/ui-labels';


const RedpointVersion = props => (
    <div>
        <div className="Footer-Copyright">
        &#9400;{' '}{FOOTER.COPYRIGHT_FUNC(props.version.formattedDate)}
        </div>
        |
        <div className="Footer-Version">
            {FOOTER.VERSION} {props.version.rppVersion}
        </div>
    </div>
);

RedpointVersion.propTypes = {
    version: PropTypes.shape({
        formattedDate: PropTypes.string,
        rppVersion: PropTypes.string,
    }),
};

RedpointVersion.defaultProps = {
    version: {
        formattedDate: '',
        rppVersion: '',
    },
};

const CustomVersion = () => {
    const [customVersion, setCustomVersion] = useState(null);
    
    useEffect(() => {
        api.getVersion().then((version) => {
            setCustomVersion(version.custom_product_attributes || null);
        });
    }, []);
    
    if (!customVersion) {
        return <Fragment />;
    }
    return (
        <div>
            <div className="Footer-Copyright">
                {customVersion.name}
            </div>
            |
            <div className="Footer-Version">
                {FOOTER.VERSION} {customVersion.version}
            </div>
        </div>
    );
};

const LoginFooter = (props) => {
    const rppVersion = getCurrentVersion();
    return (
        <div className="RPP-Footer" style={props.style}>
            <RedpointVersion version={rppVersion} />
            <CustomVersion />
        </div>
    );
};

LoginFooter.propTypes = {
    style: PropTypes.shape(),
};

LoginFooter.defaultProps = {
    style: {},
};

export default LoginFooter;
