import React, { PureComponent } from 'react';
import { injectIntl } from 'react-intl';
import PropTypes from 'prop-types';
import { NAVBAR } from 'common/ui-labels';


class CollapseSidebarButton extends PureComponent {
    static propTypes = {
        intl: PropTypes.shape({
            formatMessage: PropTypes.func,
        }),
        isSidebarCollapsed: PropTypes.bool,
        collapseSidebar: PropTypes.func,
    };

    static defaultProps = {
        intl: {
            formatMessage: () => {},
        },
        isSidebarCollapsed: false,
        collapseSidebar: () => {},
    };

    render() {
        const { intl, collapseSidebar, isSidebarCollapsed } = this.props;

        return (
            <div className="toggle-sidebar">
                <button
                    className="toggle-sidebar-button unstyled-button"
                    data-id="toggle-sidebar-button"
                    data-collapsed={isSidebarCollapsed}
                    onClick={collapseSidebar}
                    title={isSidebarCollapsed ? NAVBAR.EXPAND(intl) : ''}
                >
                    <span className="small-row-block">
                        <i className="fa fa-angle-double-left" />
                    </span>
                    <span className="collapse-sidebar-text">
                        {NAVBAR.COLLAPSE(intl)}
                    </span>
                </button>
            </div>
        );
    }
}

export default injectIntl(CollapseSidebarButton);
