import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import { isCurrentPageDashboardPage } from 'components/NavBar/navBarHelpers';
import DashboardTogglesContainer from 'components/DashboardTogglesContainer';


export default function DashboardSubmenu(props) {
    const { item, id } = props;
    
    if (!item.expandable || item.submenu || !isCurrentPageDashboardPage(item.to)) {
        return null;
    }
    return (
        <Fragment>
            <input
                type="checkbox"
                name="radio"
                id={`menu_bar${id}`}
                className="submenu-toggle"
                defaultChecked={props.getNavBarMenuOpenCloseStatus(item.to)}
                onChange={(e) => {
                    props.setNavBarMenuOpenCloseStatus(item.to, e.target.checked);
                }}
            />
            <label className="dropdown-menu-arrow" htmlFor={`menu_bar${id}`}>
                <i className="fa fa-sort-down" />
            </label>
            <div className="expandable">
                <DashboardTogglesContainer />
            </div>
        </Fragment>
    );
}

DashboardSubmenu.propTypes = {
    item: PropTypes.shape({
        to: PropTypes.string,
        submenu: PropTypes.arrayOf(PropTypes.shape({})),
    }),
    id: PropTypes.number,
    getNavBarMenuOpenCloseStatus: PropTypes.func,
    setNavBarMenuOpenCloseStatus: PropTypes.func,
};

DashboardSubmenu.defaultProps = {
    item: {
        to: '',
        submenu: [],
    },
    id: 0,
    getNavBarMenuOpenCloseStatus: () => {
    },
    setNavBarMenuOpenCloseStatus: () => {
    },
};
