import { ROUTES } from 'common/constants';

export const getCompanyColor = (company, editingCompanyParams, isCorrectModalOpen) => {
    if (editingCompanyParams && isCorrectModalOpen) {
        return editingCompanyParams.color;
    } else if (company) {
        return company.color;
    }

    return '';
};

export const isMenuOpened = (path, currentPathname) => {
    const topLevelPage = currentPathname.split('/', 2)[1];
    return path.includes(topLevelPage);
};

export const isCurrentPageSitePage = (currentPathname) => {
    const topLevelPage = currentPathname.split('/', 2)[1];
    const sitePage = ROUTES.SITE_ROUTE.split('/', 2)[1];
    return sitePage.includes(topLevelPage);
};

export const isCurrentPageDashboardPage = (currentPathname) => {
    const topLevelPage = currentPathname.split('/', 2)[1];
    const sitePage = ROUTES.DASHBOARD_ROUTE.split('/', 2)[1];
    return sitePage.includes(topLevelPage);
};

export const clearSelectionUserMenuItemButtons = () => {
    const userMenuItemButtons = document.querySelectorAll('.user-menu-item-button');
    userMenuItemButtons.forEach(button => button.classList.remove('selected'));
};

export const getContrastHoverTextColor = (mainColorObj, cssVariables) => {
    const { defaultTextColor, contrastTextColor } = cssVariables;

    // relative luminance the relative brightness of any point in a colorspace,
    // normalized to 0 for darkest black and 1 for lightest white
    // https://www.w3.org/TR/WCAG20/#relativeluminancedef
    const relativeLuminance = Math.round(mainColorObj.luminosity());

    return (relativeLuminance) ? defaultTextColor : contrastTextColor;
};

export const resetCssVariables = (rootStyle, initialCssVariables) => {
    Object.entries(initialCssVariables).forEach(([variableName, variableValue]) =>
        rootStyle.setProperty(`--${variableName}`, variableValue));
};

export const getTitleText = (title, intl) => ((typeof title === 'function') ? title(intl) : title);

const isCurrentPageOpened = (currentPathname, path) => currentPathname.includes(path);

export const getMenuItemClassName = (currentPathname, path) =>
    `menu-item${isCurrentPageOpened(currentPathname, path) ? ' menu-item-selected' : ''}`;

export const getSubMenuItemClassName = (currentPathname, path) =>
    `submenu-item${isCurrentPageOpened(currentPathname, path) ? ' submenu-item-selected' : ''}`;

