import React from 'react';
import PropTypes from 'prop-types';
import { TIMELINE_ACTIONS, COMPONENTS } from 'common/ui-labels';
import { durationHumanize } from 'utils/timeUtils';


function getTypeText(type) {
    switch (type) {
        case 'active': {
            return TIMELINE_ACTIONS.ACTIVE;
        }
        case 'idle': {
            return TIMELINE_ACTIONS.IDLE;
        }
        case 'unresponsive': {
            return TIMELINE_ACTIONS.UNRESPONSIVE;
        }
        default: {
            return TIMELINE_ACTIONS.UNASSIGNED;
        }
    }
}

function ToolTip(props) {
    if (!props.action) {
        return null;
    }
    const duration = durationHumanize(props.action.duration);

    return (
        <div className="tooltip" style={{ top: props.pos.y, left: props.pos.x }}>
            <div className="text-ellipsis"><b>{props.name}</b></div>
            <div className="row">
                <div className="col-md-4 col-sm-4"><b>{COMPONENTS.FIELDS.COMMON.STATUS}:</b></div>
                <div className="col-md-8 col-sm-8 text-capitalize">{getTypeText(props.action.type)}</div>
            </div>
            <div className="row">
                <div className="col-md-4 col-sm-4"><b>{COMPONENTS.FIELDS.SITE.FROM}:</b></div>
                <div className="col-md-8 col-sm-8">{props.action.from}</div>
            </div>
            <div className="row">
                <div className="col-md-4 col-sm-4"><b>{COMPONENTS.FIELDS.SITE.TO}:</b></div>
                <div className="col-md-8 col-sm-8">{props.action.to}</div>
            </div>
            <div className="row">
                <div className="col-md-4 col-sm-4"><b>{COMPONENTS.FIELDS.SITE.DURATION}:</b></div>
                <div className="col-md-8 col-sm-8">{duration}</div>
            </div>
        </div>);
}

ToolTip.propTypes = {
    name: PropTypes.string,
    action: PropTypes.shape({
        from: PropTypes.string,
        to: PropTypes.string,
        duration: PropTypes.number,
        type: PropTypes.string,
    }),
    pos: PropTypes.shape({
        x: PropTypes.number,
        y: PropTypes.number,
    }),
};

ToolTip.defaultProps = {
    name: '',
    action: {
        from: '',
        to: '',
        duration: 0,
        type: '',
    },
    pos: null,
};

export default ToolTip;
