import React, { useState } from 'react';
import PropTypes from 'prop-types';
import ToolTip from './ToolTip';


function getElementStyle(timelineWidth, timelineDuration, action) {
    const width = timelineWidth * ((action.duration) / timelineDuration);
    let backgroundColor = 'white';
    if (action.type === 'active') {
        backgroundColor = '#2ECC40';
    } else if (action.type === 'idle') {
        backgroundColor = 'rgba(255,65,54,0.89)';
    } else if (action.type === 'unresponsive') {
        backgroundColor = 'rgba(141,138,138,0.89)';
    }
    
    return { width, backgroundColor };
}

function Index(props) {
    const [showToolTip, setShowToolTip] = useState(false);
    const [pos, setPos] = useState(null);
    const [action, setAction] = useState(null);

    const handleMouseOver = (e) => { e.preventDefault(); setShowToolTip(true); };
    const handleMouseOut = (e) => { e.preventDefault(); setShowToolTip(false); };
    const handleMouseMove = (e, timeFrame) => {
        e.preventDefault();
        const { parentWrapperHtmlEL } = props;

        const bound = parentWrapperHtmlEL.getBoundingClientRect();
        const parentWrapperHeight = parentWrapperHtmlEL.clientHeight;

        const x = (e.clientX > bound.right - 250) ? e.clientX - (200 + 30) : e.clientX;
        const y = (e.clientY > parentWrapperHeight - 108) ? e.clientY - (108 + 20) : e.clientY + 20;

        setPos({ x, y });
        setAction(timeFrame);
    };

    const { width, to, from, name, timeline } = props;

    const timelineWidth = width || 500;
    const timelineDuration = to - from;

    return (
        <div className="timeline" style={{ width: '100%' }}>
            {timeline.map((timeFrame, index) => (
                <div
                    key={index}
                    className="timeline-element"
                    data-status={timeFrame.type || 'none'}
                    style={getElementStyle(timelineWidth, timelineDuration, timeFrame, from)}
                    onMouseOver={handleMouseOver}
                    onMouseOut={handleMouseOut}
                    onMouseMove={(e) => { handleMouseMove(e, timeFrame); }}
                />
            ))}
            {showToolTip && <ToolTip pos={pos} action={action} name={name} />}
        </div>
    );
}

Index.propTypes = {
    width: PropTypes.number,
    from: PropTypes.number,
    to: PropTypes.number,
    name: PropTypes.string,
    timeline: PropTypes.arrayOf(PropTypes.shape({
        from: PropTypes.string,
        to: PropTypes.string,
        type: PropTypes.string,
    })),
    parentWrapperHtmlEL: PropTypes.shape({}),
};

Index.defaultProps = {
    width: 500,
    from: 0,
    to: 0,
    name: '',
    timeline: [],
    parentWrapperHtmlEL: {},
};

export default Index;
