import { ImageOverlay } from 'react-leaflet';

function rotateImageOverlay(url, bounds, options) {
    return new L.RotateImageOverlay(url, bounds, options);
}

L.RotateImageOverlay = L.ImageOverlay.extend({
    options: {
        rotation: 0,
    },

    _animateZoom(e) {
        L.ImageOverlay.prototype._animateZoom.call(this, e);
        const img = this._image;
        img.style[L.DomUtil.TRANSFORM] += ` rotate(${this.options.rotation}deg)`;
        L.ImageOverlay.prototype.bringToBack.call(this);
    },

    _reset() {
        L.ImageOverlay.prototype._reset.call(this);
        const img = this._image;
        img.style[L.DomUtil.TRANSFORM] += ` rotate(${this.options.rotation}deg)`;
        L.ImageOverlay.prototype.bringToBack.call(this);
    },
});

export default class extends ImageOverlay {
    constructor(props) {
        super(props);
        this._leafletEvents = this.extractLeafletEvents(props);
        this.leafletElement = rotateImageOverlay(props.url, props.bounds, Object.assign({}, props));
    }

    componentDidMount() {
        this.leafletElement = rotateImageOverlay(this.props.url, this.props.bounds, Object.assign({}, this.props));
        this.layerContainer.addLayer(this.leafletElement);
    }

    componentDidUpdate(prevProps) {
        if (this.props.url !== prevProps.url) {
            if (this.leafletElement) {
                this.layerContainer.removeLayer(this.leafletElement);
            }
            this.leafletElement = rotateImageOverlay(this.props.url, this.props.bounds, Object.assign({}, this.props));
            this.layerContainer.addLayer(this.leafletElement);
        }

        if (this.props.opacity !== prevProps.opacity) {
            this.leafletElement.setOpacity(this.props.opacity);
        }
    }
}
