import React from 'react';
import PropTypes from 'prop-types';
import { injectIntl } from 'react-intl';
import { LayerGroup, Popup } from 'react-leaflet';
import { changeSpaghettiViewMode } from 'stores/actions';
import { SITE_ANALYTICS_LABELS } from 'common/ui-labels';


class LeafletSpaghettiMarkers extends LayerGroup {
    static propTypes = {
        marker: PropTypes.shape({}),
    };
    
    static defaultProps = {
        marker: null,
    };

    render() {
        const { marker, dispatch, intl } = this.props;
        
        if (!marker) {
            return null;
        }

        return (
            <Popup
                className="spaghetti-marker"
                position={marker.pos}
                onClose={() => {
                    dispatch(changeSpaghettiViewMode({ marker: null }));
                }}
            >
                <div>
                    <div className="RPP-BlockHeader">
                        <h4
                            className="RPP-BlockBtnTitle title-popup text-center"
                            style={{ color: marker.color }}
                            title={marker.trackableName}
                        >
                            {marker.trackableName}
                        </h4>
                    </div>
                    <div className="RPP-PopUpRowsWrapper">
                        <div className="popup-row row">
                            <div className="col-md-4 popup-field-label text-left">{SITE_ANALYTICS_LABELS.TIME(intl)}:</div>
                            <div className="col-md-8 popup-field-value text-right">
                                {marker.time}
                            </div>
                        </div>
                        <div className="popup-row row">
                            <div className="col-md-4 popup-field-label text-left">{SITE_ANALYTICS_LABELS.DISTANCE(intl)}</div>
                            <div className="col-md-8 popup-field-value text-right">
                                {marker.distance}
                            </div>
                        </div>
                    </div>
                </div>
            </Popup>

        );
    }
}

export default injectIntl(LeafletSpaghettiMarkers);
