import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import { PopUpWrapper } from 'components/leaflet/PopUpWrapper';
import { convertMillimetersToMeters } from 'utils/formatters';


export function VertexPopup(props) {
    if (!props.show) {
        return (<Fragment />);
    }
    return (
        <PopUpWrapper
            position={props.position}
            onClose={() => {
                props.onClose();
            }}
            className="RPP-BlockBody-Small"
        >
            <div className="RPP-BlockBody-Wrapper" style={{ textAlign: 'center' }}>
                <div className="RPP-BlockHeader">
                    <button
                        type="button"
                        className="RPP-BtnPopUp"
                        onClick={() => { props.onClose(); }}
                    >
                        <i className="fa fa-times" />
                    </button>
                </div>
                <div className="RPP-BlockHeader-Bold">Point: {props.index}</div>
                <div className="RPP-PopUpRowsWrapper">
                    <span>X: {convertMillimetersToMeters(props.data.x)} m</span>
                    <span style={{ marginLeft: '5px', marginRight: '5px' }}>|</span>
                    <span>Y: {convertMillimetersToMeters(props.data.y)} m</span>
                </div>
            </div>
        </PopUpWrapper>);
}

VertexPopup.propTypes = {
    position: PropTypes.shape({}),
    onClose: PropTypes.func,
    index: PropTypes.number,
    show: PropTypes.bool,
    data: PropTypes.shape({
        x: PropTypes.number,
        y: PropTypes.number,
    }),
};

VertexPopup.defaultProps = {
    position: {},
    onClose: () => {},
    show: false,
    index: 0,
    data: {
        x: 0,
        y: 0,
    },
};
