import React from 'react';
import PropTypes from 'prop-types';
import { Field } from 'redux-form';
import { COMPONENTS, DEFAULT_VALUES } from '../../common';
import RenderTextArea from './RenderTextArea';

const CustomInfoFieldWithPadding = ({ placeholder, firstColumnWidth = 4, dataId, customInfoLength, paddingLeft = null }) => (
    <div className="Form-Line row">
        {paddingLeft && <div className={`Form-Label col-md-${paddingLeft}`} /> }
        <div className={`Form-Label col-md-${firstColumnWidth}`}>
            {COMPONENTS.FIELDS.COMMON.CUSTOM_INFO} <br />
            { customInfoLength }/{ DEFAULT_VALUES.CUSTOM_INFO_LIMIT }
        </div>
        <div className={`col-md-${12 - paddingLeft - firstColumnWidth}`}>
            <Field
                name="custom_info"
                dataId={dataId}
                component={RenderTextArea}
                rows="5"
                maxLength={256}
                onKeyPress={(e) => {
                    if (e.key === 'Enter') {
                        e.preventDefault();
                    }
                }}
                placeholder={placeholder}
            />
        </div>
    </div>
);

CustomInfoFieldWithPadding.propTypes = {
    placeholder: PropTypes.string,
    firstColumnWidth: PropTypes.number,
    dataId: PropTypes.string,
    customInfoLength: PropTypes.number,
    paddingLeft: PropTypes.number,
};
CustomInfoFieldWithPadding.defaultProps = {
    firstColumnWidth: 4,
    placeholder: '',
    dataId: '',
    customInfoLength: 0,
    paddingLeft: null,
};

export { CustomInfoFieldWithPadding };
