import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import Select from 'react-select';


const MultiSelectComponent = (props) => {
    const {
        dataId, options, disabled, placeholder, noResultsText, simpleValue, filterOptions, scrollMenuIntoView,
        meta: { touched, error }, input: { value, onChange, onBlur },
    } = props;

    const onMenuOpen = () => {
        if (scrollMenuIntoView) {
            const selectedEl = document.getElementsByClassName('Select-menu-outer')[0];
            setTimeout(() => {
                if (selectedEl) {
                    selectedEl.scrollIntoView({ behavior: 'smooth', block: 'end', inline: 'nearest' });
                }
            }, 300);
        }
    };

    return (
        <Fragment>
            <Select
                filterOptions={filterOptions}
                simpleValue={simpleValue}
                options={options}
                inputProps={{ 'data-id': dataId }}
                className="menu-outer-top"
                multi
                placeholder={placeholder}
                disabled={disabled}
                onChange={onChange}
                onOpen={onMenuOpen}
                value={value}
                noResultsText={noResultsText}
                onBlur={() => onBlur(value)}
            />
            {touched && error && <span className="error">{error}</span>}
        </Fragment>
    );
};

MultiSelectComponent.propTypes = {
    options: PropTypes.arrayOf(PropTypes.shape({
        value: PropTypes.string,
        label: PropTypes.string,
    })),
    disabled: PropTypes.bool,
    placeholder: PropTypes.string,
    dataId: PropTypes.string,
    noResultsText: PropTypes.shape(),
    simpleValue: PropTypes.bool,
    filterOptions: PropTypes.any, // boolean to enable default filtering or function to filter the options array ([options], filterString, [values])
    input: PropTypes.shape({
        value: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.shape()), PropTypes.string]),
        onChange: PropTypes.func,
        onBlur: PropTypes.func,
    }),
    meta: PropTypes.shape({
        touched: PropTypes.bool,
        error: PropTypes.oneOfType([PropTypes.shape({}), PropTypes.string]),
    }),
    scrollMenuIntoView: PropTypes.bool,
};

MultiSelectComponent.defaultProps = {
    options: [],
    disabled: false,
    placeholder: '',
    dataId: '',
    noResultsText: null,
    simpleValue: false,
    filterOptions: true,
    input: {
        value: '',
        onChange: () => {},
        onBlur: () => {},
    },
    meta: {
        touched: false,
        error: '',
    },
    scrollMenuIntoView: false,
};

export default MultiSelectComponent;
