import React from 'react';
import PropTypes from 'prop-types';

import { alarmLevelStyle } from '../../utils/index';

const RenderSelectSeverityField = ({ input, meta: { touched, error }, children, disabled, dataId, dataCy }) => (
    <div>
        <select
            {...input}
            disabled={disabled}
            style={alarmLevelStyle(input.value)}
            data-id={dataId}
            data-cy={dataCy}
        >
            {children}
        </select>
        {touched && error && <span className="error">{error}</span>}
    </div>
);

RenderSelectSeverityField.propTypes = {
    maxValue: PropTypes.number,
    minValue: PropTypes.number,
    step: PropTypes.number,
    disabled: PropTypes.bool,
    children: PropTypes.oneOfType([
        PropTypes.arrayOf(PropTypes.node),
        PropTypes.node,
    ]),
    input: PropTypes.shape({
        onChange: PropTypes.func,
        value: PropTypes.number,
    }),
    meta: PropTypes.shape({
        touched: PropTypes.bool,
        error: PropTypes.string,
    }),
    dataId: PropTypes.string,
    dataCy: PropTypes.string,
};

RenderSelectSeverityField.defaultProps = {
    maxValue: 0,
    minValue: 0,
    step: 0,
    disabled: false,
    children: [],
    input: {
        onChange: () => {

        },
        value: 0,
    },
    meta: {
        touched: false,
        error: '',
    },
    dataId: '',
    dataCy: '',
};

export default RenderSelectSeverityField;
