import React, { Fragment } from 'react';
import _Has from 'lodash/has';
import PropTypes from 'prop-types';
import DurationInputMask from 'react-duration-input-mask';
import { DURATION_FIELD_DESCRIPTION } from 'common';

const RenderSimpleTimeDurationField = (props) => {
    const {
        input,
        meta: { error, warning },
        className,
        defaultValue,
        disabled,
        fieldDescription = DURATION_FIELD_DESCRIPTION.FULL_FORMAT,
    } = props;
    const isDefaultValue = _Has(input, 'value.value') || !input || !input.value;

    return (
        <Fragment>
            <DurationInputMask
                className={className}
                defaultValue={defaultValue}
                handleBlur={(parsedValue) => {
                    input.onChange(parsedValue);
                }}
                value={(isDefaultValue) ? defaultValue : input.value}
                disabled={disabled}
            />
            <div style={{ fontSize: '10px' }}>
                {fieldDescription}
            </div>
            {((error && <span className="error">{error}</span>)
                || (warning && <span className="warning"><span>{warning}</span></span>)
            )}
        </Fragment>
    );
};

RenderSimpleTimeDurationField.propTypes = {
    input: PropTypes.shape({
        value: PropTypes.oneOfType([PropTypes.shape(), PropTypes.number, PropTypes.string]),
        onChange: PropTypes.func,
        onBlur: PropTypes.func,
    }),
    meta: PropTypes.shape({
        warning: PropTypes.string,
        error: PropTypes.string,
    }),
    defaultValue: PropTypes.number,
    disabled: PropTypes.bool,
    className: PropTypes.string,
};

RenderSimpleTimeDurationField.defaultProps = {
    input: {},
    meta: {
        warning: '',
        error: '',
    },
    defaultValue: 0,
    disabled: false,
    className: '',
};


export default RenderSimpleTimeDurationField;
