import React, { useState } from 'react';
import { Map, LayersControl, Polygon } from 'react-leaflet';
import PropTypes from 'prop-types';

import LeafletFloorplan from '../../../components/leaflet/LeafletFloorplan';
import { DEFAULT_VALUES, ZONE_DETAILS_MODAL } from '../../../common';
import { MAP_BOUNDS } from '../../../utils';

const { Overlay } = LayersControl;

function FloorplansAll(props) {
    const { floorplansList, selectedFloorplan, zone, selectFloorplan, unSelectFloorplan, leafletClass, mapStyle, intl } = props;
    const [dblClickCalled, setDblClickCalled] = useState(false);
    if (selectedFloorplan) {
        return null;
    }
    return (
        <div
            className="Zone-Details-Body"
            style={{ height: '57vh' }}
        >
            {floorplansList.map(floorplan => (
                <div
                    key={floorplan.uid}
                    className={leafletClass}
                    title={ZONE_DETAILS_MODAL.DOUBLE_CLICK_EXPAND(intl)}
                    onMouseOver={(e) => {
                        e.currentTarget.style.borderColor = 'red';
                        e.currentTarget.style.borderWidth = '2px';
                    }}
                    onMouseLeave={(e) => {
                        e.currentTarget.style.borderColor = 'gray';
                        e.currentTarget.style.borderWidth = '1px';
                    }}
                    onClick={() => {
                        setTimeout(() => {
                            if (!dblClickCalled) {
                                selectedFloorplan ? unSelectFloorplan() : selectFloorplan(floorplan);
                            }
                            setDblClickCalled(false);
                        }, 200);
                    }}
                    onDoubleClick={() => {
                        setDblClickCalled(true);
                        selectedFloorplan ? unSelectFloorplan() : selectFloorplan(floorplan);
                    }}
                >

                    <Map
                        center={[0, 0]}
                        className="zone-modal"
                        bounds={MAP_BOUNDS({}, floorplan)}
                        style={mapStyle}
                        minZoom={DEFAULT_VALUES.MAP_ZOOM.MIN}
                        maxZoom={DEFAULT_VALUES.MAP_ZOOM.MAX}
                        doubleClickZoom={false}
                        zoom={DEFAULT_VALUES.MAP_ZOOM.DEFAULT_MODAl}
                    >
                        <LayersControl position="topright">
                            <Overlay checked name="Floorplan">
                                <LeafletFloorplan floorplan={floorplan} />
                            </Overlay>
                            <Overlay checked name="Zones">
                                <Polygon
                                    opacity={zone.dashOpacity}
                                    fillOpacity={0.2}
                                    fillColor={zone.fillColor}
                                    color={zone.dashColor}
                                    weight={zone.dashWeight}
                                    dashArray={zone.dashArray}
                                    positions={zone.positions}
                                />
                            </Overlay>
                        </LayersControl>
                    </Map>

                </div>))}
        </div>
    );
}

FloorplansAll.propTypes = {
    floorplansList: PropTypes.arrayOf(PropTypes.shape({})),
    selectedFloorplan: PropTypes.bool,
    zone: PropTypes.shape({}),
    selectFloorplan: PropTypes.func,
    unSelectFloorplan: PropTypes.func,
    leafletClass: PropTypes.string,
    mapStyle: PropTypes.shape({}),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

FloorplansAll.defaultProps = {
    floorplansList: [],
    selectedFloorplan: false,
    zone: {},
    selectFloorplan: () => {},
    unSelectFloorplan: () => {},
    leafletClass: '',
    mapStyle: {},
    intl: {
        formatMessage: () => {
        },
    },
};

export default FloorplansAll;
