import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import { Field, FieldArray } from 'redux-form';
import { SCHEDULE_FORM, COMPONENTS } from 'common';
import RenderInputTypeNumber from '../../RenderInputTypeNumber';


const renderHourMinutes = ({ hourName, minuteName }) => ({ readOnly }) => (
    <div className="d-inline-block">
        <div className="Schedule-Mask">
            <Field
                component={RenderInputTypeNumber}
                min="00"
                max="24"
                step="1"
                name={hourName}
                dataCy={hourName}
                readOnly={readOnly}
            />
            <div className="d-inline-block">:</div>
            <Field
                component={RenderInputTypeNumber}
                name={minuteName}
                dataCy={minuteName}
                min="00"
                max="59"
                step="1"
                readOnly={readOnly}
            />
        </div>
    </div>
);

const renderActivePeriodField = ({ timeFieldFrom, timeFieldTo }) => ({ readOnly, meta: { error } }) => (
    <div>
        <FieldArray
            name="timeFrom"
            component={timeFieldFrom}
            readOnly={readOnly}
        />
        <div className="d-inline-block" style={{ margin: '0 10px 0 10px' }}>
            -
        </div>
        <FieldArray
            name="timeTo"
            component={timeFieldTo}
            readOnly={readOnly}
        />
        {error && <div className="error">{error}</div>}
    </div>
);

const timeFieldFrom = renderHourMinutes({ hourName: 'fromHour', minuteName: 'fromMinute' });
const timeFieldTo = renderHourMinutes({ hourName: 'toHour', minuteName: 'toMinute' });
const activePeriod = renderActivePeriodField({ timeFieldFrom, timeFieldTo });


function ScheduleForm(props) {
    const { active24, activated = false, show } = props;
    if (!show) {
        return (<Fragment />);
    }
    return (
        <div className="Form-Line RPP-Group-advanced">
            <h4 className="RPP-Group-advanced-border-title">{SCHEDULE_FORM.ACTIVITY_SCHEDULE}</h4>

            <div className="Form-Line row" style={{ opacity: activated ? 1 : 0.6 }}>
                <div
                    className="Form-Label col-md-4"
                    style={{ fontSize: '1.1em' }}
                >
                    {SCHEDULE_FORM.CHECKBOX}
                </div>
                <div
                    className="col-md-8 text-left"
                    data-id="zone-add-configuration-active"
                    data-cy="zone-add-configuration-active24"
                >
                    <Field
                        name="active24"
                        component="input"
                        props={{ disabled: !activated }}
                        type="checkbox"
                    />
                </div>
            </div>

            <div className="Form-Line row" style={{ opacity: active24 || !activated ? 0.6 : 1 }}>
                <div
                    className="Form-Label col-md-4"
                    style={{ fontSize: '1.1em' }}
                >
                    {COMPONENTS.FIELDS.ZONE.ACTIVE_PERIOD}
                </div>
                <div className="col-md-8 text-left">
                    <div className="Zone-Edit-Schedule">
                        <FieldArray
                            name="activePeriod"
                            component={activePeriod}
                            readOnly={active24 || !activated}
                        />
                    </div>
                </div>
            </div>

        </div>
    );
}

ScheduleForm.propTypes = {
    active24: PropTypes.bool,
    activated: PropTypes.bool,
    show: PropTypes.bool,
};

ScheduleForm.defaultProps = {
    active24: false,
    activated: false,
    show: true,
};

export default ScheduleForm;
