import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import { Field } from 'redux-form';

import { SITE_ZONES_TABLE } from '../../../../common';
import RenderSelectSeverityField from '../../RenderSelectSeverityField';
import { alarmLevelStyle } from '../../../../utils';


function SeverityOptions(props) {
    const { show, isZoneTypeSelected, isInformationZone, intl } = props;
    if (!show) {
        return (<Fragment />);
    }
    return (
        <div className="Form-Line row" style={{ opacity: isInformationZone ? '0.65' : '1' }}>
            <div className="Form-Label col-md-6">
                {SITE_ZONES_TABLE.TEXT.SEVERITY_FUNC(intl)} *
            </div>
            <div className="col-md-6">
                <Field
                    className="form-control input-sm "
                    name="zone_alarm_level"
                    style={{ fontSize: '14px' }}
                    props={{ disabled: !isZoneTypeSelected || isInformationZone }}
                    dataId="zone-add-configuration-severity"
                    component={RenderSelectSeverityField}
                >
                    <option value={1} style={alarmLevelStyle(1)}>1</option>
                    <option value={2} style={alarmLevelStyle(2)}>2</option>
                    <option value={3} style={alarmLevelStyle(3)}>3</option>
                    <option value={4} style={alarmLevelStyle(4)}>4</option>
                </Field>
            </div>
        </div>
    );
}

SeverityOptions.propTypes = {
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    isInformationZone: PropTypes.bool,
    isZoneTypeSelected: PropTypes.bool,
    show: PropTypes.bool,
};

SeverityOptions.defaultProps = {
    intl: {
        formatMessage: () => {},
    },
    isInformationZone: true,
    isZoneTypeSelected: true,
    show: true,
};

export default SeverityOptions;
