import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import VertexOption from 'modals/zone/ZoneCoordinatesEnterModal/VertexOption';
import { addZoneVertexCoordinate } from 'stores/actions/siteViewZoneEditCoordinatesActions';
import { convertMillimetersToMeters } from 'utils/formatters';


function ZoneVertices(props) {
    return props.vertices.map((vertex, index) => (
        <VertexOption
            key={index}
            index={index + 1}
            x={convertMillimetersToMeters(vertex.x)}
            y={convertMillimetersToMeters(vertex.y)}
            addVertex={props.addVertex}
            removeVertex={() => {}}
            sublocation={props.sublocation}
        />
    ));
}

ZoneVertices.propTypes = {
    vertices: PropTypes.arrayOf(PropTypes.shape({})),
    withLabels: PropTypes.bool,
    addVertex: PropTypes.func,
    sublocation: PropTypes.shape({
        offset_x: PropTypes.number,
        offset_y: PropTypes.number,
        uid: PropTypes.string,
    }),
}

ZoneVertices.defaultProps = {
    vertices: [],
    withLabels: false,
    addVertex: () => {},
    sublocation: {
        offset_x: 0,
        offset_y: 0,
        uid: '',
    },
}


function ZoneGeometryOptions(props) {
    if (!props.show) return null;

    return (
        <div className="Form-Line RPP-Group-advanced">
            <h4 className="RPP-Group-advanced-border-title">Edit coordinates</h4>
            <div className="Form-Line padding-l-lg">
                <ZoneVertices
                    vertices={props.changedGeometry.length > 0 ? props.changedGeometry : props.zoneGeometry}
                    sublocation={props.sublocation}
                    addVertex={props.addVertex}
                />
            </div>
        </div>
    );
}

const mapDispatchToProps = (dispatch) => ({
    addVertex: (position) => {
        dispatch(addZoneVertexCoordinate(position));
    },
});

export default connect(null, mapDispatchToProps)(ZoneGeometryOptions)

ZoneGeometryOptions.propTypes = {
    zoneGeometry: PropTypes.arrayOf(PropTypes.shape({})),
    changedGeometry: PropTypes.arrayOf(PropTypes.shape({})),
    sublocation: PropTypes.shape({}),
};

ZoneGeometryOptions.defaultProps = {
    zoneGeometry: [],
    changedGeometry: [],
    sublocation: {},
};
