import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import PropTypes from 'prop-types';

import { NAME_OF_FORMS, COMPONENTS, ASSIGN_LOW_LATENCY_LINK_VALIDATION_MODAL } from '../../common';
import {
    createTrackableAssociations,
    closeAssignLowLatencyLinkValidateModal,
    closeTagAssignModal,
} from '../../stores/actions';

let AssignLatencyLinkValidateForm = (props) => {
    const {
        close, save, className, macAddress,
    } = props;
    return (
        <form className={className}>
            <div style={{ fontSize: '1.3em', marginTop: '10px' }} data-id="trackable-collision-validate-message">
                {ASSIGN_LOW_LATENCY_LINK_VALIDATION_MODAL.TEXT(macAddress)}
                <br />
                Would you like to save your association anyway?
            </div>
            <div className="Form-Buttons row text-right">
                <button type="button" data-id="trackable-validate-save" onClick={save}>{COMPONENTS.BUTTONS.SAVE}</button>
                <button type="button" data-id="trackable-validate-cancel" onClick={close}>{COMPONENTS.BUTTONS.CLOSE}</button>
            </div>
        </form>
    );
};

AssignLatencyLinkValidateForm.propTypes = {
    close: PropTypes.func,
    save: PropTypes.func,
    className: PropTypes.string,
    macAddress: PropTypes.string,
};

AssignLatencyLinkValidateForm.defaultProps = {
    close: () => {
    },
    save: () => {
    },
    className: '',
    macAddress: '',
};

AssignLatencyLinkValidateForm = reduxForm({
    form: NAME_OF_FORMS.TRACKABLE_LOW_LATENCY_LINK_VALIDATE,
})(AssignLatencyLinkValidateForm);

class AssignLowLatencyLinkValidationModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        assignLowLatencyLinkValidation: PropTypes.shape({
            params: PropTypes.shape(),
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        assignLowLatencyLinkValidation: {
            params: {},
        },
        style: {},
    };
    
    close = () => {
        this.props.dispatch(closeAssignLowLatencyLinkValidateModal());
        this.props.dispatch(closeTagAssignModal());
    };
    
    save = () => {
        const { params } = this.props.assignLowLatencyLinkValidation;
        if (params && params.mac_address && params.trackable_uid) {
            this.props.dispatch(createTrackableAssociations({
                mac_address: params.mac_address,
                trackable_uid: params.trackable_uid,
            }));
        } else {
            console.warn('assignLowLatencyLinkValidation. need to specify params.mac_address, params.trackable_uid');
        }
        this.props.dispatch(closeAssignLowLatencyLinkValidateModal());
        this.props.dispatch(closeTagAssignModal());
    };
    
    render() {
        const { style, assignLowLatencyLinkValidation } = this.props;
        const params = assignLowLatencyLinkValidation.params || {};
        const title = ASSIGN_LOW_LATENCY_LINK_VALIDATION_MODAL.TITLE;
        
        return (
            <Modal
                contentLabel="assignLowLatencyLinkValidation"
                isOpen={assignLowLatencyLinkValidation.open}
                onRequestClose={this.close}
                style={style}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header2" data-id="trackable-collision-validation-title">
                        {title}
                    </span>
                    <AssignLatencyLinkValidateForm
                        macAddress={params.mac_address}
                        className="Modal-Form"
                        close={this.close}
                        save={this.save}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    assignLowLatencyLinkValidation: state.modals.assignModals.assignLowLatencyLinkValidation,
});

export default connect(mapStateToProps)(AssignLowLatencyLinkValidationModal);
