import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { Field, reduxForm } from 'redux-form';
import { injectIntl } from 'react-intl';
import { NAME_OF_FORMS, AUTH_MODAL, COMPONENTS } from '../../common';
import { closeForgotPassword, restoreUserPassword, changeParamsOfForgotPassword } from '../../stores/actions';

import RenderField from '../../components/modals/RenderField';

const renderField = RenderField(4, 8);

let ForgotPasswordForm = (props) => {
    const {
        close, submit, className, message, success, intl,
    } = props;
    
    return (
        <form className={className}>
            <div className="Form-Line Form-Line-Reset row">
                <Field
                    className="Form-Input"
                    name="email"
                    dataId="forgot-password"
                    component={renderField}
                    label={COMPONENTS.FIELDS.USER.EMAIL_ADDRESS_FUNC(intl)}
                    type="text"
                    placeholder="Email"
                />
            </div>
            
            <span style={{
                color: success ? 'green' : 'red',
                marginTop: '10px',
                marginLeft: '0',
                display: 'inline-block',
                position: 'absolute',
            }}
            >
                {message}
            </span>
            
            <div className="Form-Buttons btn-reset-password" style={{ marginTop: '40px' }}>
                {success ?
                    <button type="button" data-id="forgot-password-ok" onClick={close}>{COMPONENTS.BUTTONS.OK}</button>
                    :
                    <div>
                        <button
                            type="button"
                            data-id="forgot-password-send"
                            onClick={submit}
                        >
                            {AUTH_MODAL.FORGOT_PASSWORD_MODAL.BUTTON_SEND}
                        </button>
                        <button
                            type="button"
                            data-id="forgot-password-cancel"
                            onClick={close}
                        >
                            {COMPONENTS.BUTTONS.CANCEL}
                        </button>
                    </div>}
            </div>
        </form>
    );
};

ForgotPasswordForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    message: PropTypes.string,
    success: PropTypes.bool,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

ForgotPasswordForm.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    message: '',
    className: '',
    success: false,
    intl: {
        formatMessage: () => {
        },
    },
};

ForgotPasswordForm = reduxForm({
    form: NAME_OF_FORMS.FORGOT_PASSWORD,
})(ForgotPasswordForm);

const mapStateToForm = state => ({
    initialValues: state.modals.authModals.forgotPassword,
    success: state.modals.authModals.forgotPassword.success,
    message: state.modals.authModals.forgotPassword.message || '',
});
ForgotPasswordForm = connect(mapStateToForm)(injectIntl(ForgotPasswordForm));

class ForgotPasswordModal extends React.PureComponent {
    static propTypes = {
        dispatch: PropTypes.func,
        intl: PropTypes.shape({
            formatMessage: PropTypes.func,
        }),
        forgotPassword: PropTypes.shape(),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        forgotPassword: {},
        dispatch: () => {
        },
        intl: {
            formatMessage: () => {
            },
        },
        style: {},
    };
    
    close = () => {
        this.props.dispatch(closeForgotPassword());
    };
    
    submit = (values) => {
        this.props.dispatch(restoreUserPassword(values.email))
            .then((res) => {
                if (res) {
                    this.props.dispatch(changeParamsOfForgotPassword({
                        success: true,
                        message: AUTH_MODAL.FORGOT_PASSWORD_MODAL.MESSAGE_OK_FUNC(this.props.intl),
                    }));
                } else {
                    this.props.dispatch(changeParamsOfForgotPassword({
                        success: false,
                        message: AUTH_MODAL.FORGOT_PASSWORD_MODAL.MESSAGE_FAIL_FUNC(this.props.intl),
                    }));
                }
            });
    };
    
    render() {
        const { forgotPassword, style } = this.props;
        
        return (
            <Modal
                contentLabel="EditProfile"
                isOpen={forgotPassword.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header">
                        {COMPONENTS.FIELDS.USER.RESET_PASSWORD}
                    </span>
                    
                    <ForgotPasswordForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    forgotPassword: state.modals.authModals.forgotPassword,
});

export default connect(mapStateToProps)(injectIntl(ForgotPasswordModal));
