import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { AUTH_MODAL, COMPONENTS } from 'common';
import { closeProjectDeletionPopupModal } from 'stores/actions/modalActions/authActions';
import { userLogout, userLogoutFromProjectSystemAdmin } from 'stores/actions/userActions';
import LocationStore from 'stores/LocationStore';
import { makeCopy } from 'utils/simpleUtils';


class ProjectDeletionPopupModal extends React.PureComponent {
    static propTypes = {
        dispatch: PropTypes.func,
        projectDeletionPopup: PropTypes.shape({
            open: PropTypes.bool,
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        projectDeletionPopup: {
            open: false,
        },
        style: {},
    };
    
    submit = () => {
        this.props.dispatch(closeProjectDeletionPopupModal());
        if (LocationStore.isCompanyAdminAsProjectSystemAdmin()) {
            this.props.dispatch(userLogoutFromProjectSystemAdmin());
        } else {
            this.props.dispatch(userLogout());
        }
    };
    
    render() {
        const { projectDeletionPopup } = this.props;
        
        const style = makeCopy(this.props.style);
        style.content.width = '400px';
        
        return (
            <Modal
                contentLabel="ProjectDeletionPopup"
                isOpen={projectDeletionPopup.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <div className="Modal-Header">
                        {AUTH_MODAL.PROJECT_DELETION_POPUP_MODAL.HEADER}
                    </div>
                    
                    <div className="Modal-Text">
                        {AUTH_MODAL.PROJECT_DELETION_POPUP_MODAL.TEXT}
                    </div>
                    
                    <form className="Modal-Form Form-Line" onSubmit={this.submit}>
                        <button
                            type="submit"
                            data-id="project-deletion-popup-continue"
                        >
                            {COMPONENTS.BUTTONS.CONTINUE}
                        </button>
                    </form>
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    projectDeletionPopup: state.modals.authModals.projectDeletionPopup,
});

export default connect(mapStateToProps)(ProjectDeletionPopupModal);
