import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { openChangePassword, closeRecommendToChangePassword } from 'stores/actions';
import { AUTH_MODAL, COMPONENTS } from 'common/ui-labels';


class RecommendToChangePasswordModal extends React.PureComponent {
    static propTypes = {
        dispatch: PropTypes.func,
        recommendToChangePassword: PropTypes.shape({
            open: PropTypes.bool,
            user: PropTypes.shape(),
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        recommendToChangePassword: {
            open: false,
            user: {},
        },
        style: {},
    };
    
    close = () => {
        this.props.dispatch(closeRecommendToChangePassword());
    };
    
    submit = (event) => {
        event.preventDefault();
        
        this.props.dispatch(openChangePassword({
            uid: this.props.recommendToChangePassword.user.uid,
            email: this.props.recommendToChangePassword.user.email,
            token: this.props.recommendToChangePassword.user.token,
        }));
        
        this.close();
    };
    
    render() {
        const { recommendToChangePassword, style } = this.props;
        
        return (
            <Modal
                contentLabel="Welcome"
                isOpen={recommendToChangePassword.open}
                shouldCloseOnOverlayClick={false}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <div className="Modal-Header">
                        {AUTH_MODAL.RECOMEND_TO_CHANGE_PASSWORD_MODAL.HEADER}
                    </div>
                    
                    <div className="Modal-Text">
                        {AUTH_MODAL.RECOMEND_TO_CHANGE_PASSWORD_MODAL.TEXT}
                    </div>
                    
                    <form className="Modal-Form Form-Line" onSubmit={this.submit}>
                        <button
                            type="submit"
                            className="Form-ChangePassword"
                            data-id="change-password-change"
                        >{COMPONENTS.BUTTONS.CHANGE_PASSWORD}
                        </button>
                        
                        <div className="Form-Buttons">
                            <button
                                onClick={this.close}
                                data-id="change-password-cancel"
                            >
                                {COMPONENTS.BUTTONS.CANCEL}
                            </button>
                        </div>
                    </form>
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    recommendToChangePassword: state.modals.authModals.recommendToChangePassword,
});

export default connect(mapStateToProps)(RecommendToChangePasswordModal);
