import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';

import { AUTH_MODAL, STORAGE_KEY, COMPONENTS } from 'common';
import { openChangePassword, closeWelcomeModal } from 'stores/actions/modalActions/authActions';
import { makeCopy } from 'utils/simpleUtils';
import { LocationStoreMethods } from 'utils/browserStorage';


class WelcomeModal extends React.PureComponent {
    static propTypes = {
        dispatch: PropTypes.func,
        welcome: PropTypes.shape({
            open: PropTypes.bool,
            user: PropTypes.shape(),
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        welcome: {
            open: false,
            user: {},
        },
        style: {},
    };
    
    close = () => {
        this.props.dispatch(closeWelcomeModal());
        const user = this.props.welcome.user;

        LocationStoreMethods.setToLocalStorage(STORAGE_KEY.FORCE_TO_CHANGE_PASSWORD, user.uid, user.email, null);
    };
    
    submit = (event) => {
        event.preventDefault();
        const user = this.props.welcome.user;

        this.props.dispatch(openChangePassword({
            uid: user.uid,
            email: user.email,
            token: this.props.welcome.user.token,
            force: true,
        }));

        this.props.dispatch(closeWelcomeModal());
    };
    
    render() {
        const { welcome } = this.props;
        
        const style = makeCopy(this.props.style);
        style.content.width = '400px';
        
        return (
            <Modal
                contentLabel="Welcome"
                isOpen={welcome.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <div className="Modal-Header">
                        {AUTH_MODAL.WELCOME_MODAL.HEADER}
                    </div>
                    
                    <div className="Modal-Header2">
                        {AUTH_MODAL.WELCOME_MODAL.HEADER2}
                    </div>

                    <form className="Modal-Form Form-Line" onSubmit={this.submit}>
                        <button
                            type="submit"
                            className="Form-ChangePassword"
                            data-id="welcome-change-password"
                        >
                            {COMPONENTS.BUTTONS.CHANGE_PASSWORD}
                        </button>
                        
                        <div className="Form-Buttons">
                            <button
                                data-id="welcome-cancel"
                                type="button"
                                onClick={this.close}
                            >
                                {COMPONENTS.BUTTONS.CANCEL}
                            </button>
                        </div>
                    </form>
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    welcome: state.modals.authModals.welcome,
});

export default connect(mapStateToProps)(WelcomeModal);
