import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { Field, reduxForm } from 'redux-form';
import { injectIntl } from 'react-intl';
import PropTypes from 'prop-types';
import _isEmpty from 'lodash/isEmpty';

import { closeAuditDownloadModal } from 'stores/actions';
import { NAME_OF_FORMS, AUDIT_DOWNLOAD_MODAL, COMPONENTS } from 'common';
import * as api from 'api';
import { errorHandlerGetRequest } from 'stores/actions/errorHandlerActions';
import RenderRangePicker from 'components/modals/RenderRangePicker';


const validate = values => ({
    from_to: _isEmpty(values.from_to) ? COMPONENTS.VALIDATION.REQUIRED : undefined,
});

let AuditDownloadForm = (props) => {
    const { close, className, invalid, handleSubmit, intl } = props;

    return (
        <form className={className} onSubmit={handleSubmit}>
            <div className="Form-Line row">
                <div className="col-md-12 text-center" data-id="site-analytics-interval-from">
                    <div className="DatePicker-From">
                        <Field
                            name="from_to"
                            component={RenderRangePicker}
                            placeholder={[
                                AUDIT_DOWNLOAD_MODAL.RANGE_PICKER.FROM(intl),
                                AUDIT_DOWNLOAD_MODAL.RANGE_PICKER.TO(intl),
                            ]}
                            style={{ width: '100%' }}
                        />
                    </div>
                </div>
                <div className="Form-Buttons col-md-12 text-right">
                    <button type="submit" data-cy="site-analytics-download" disabled={invalid}>{AUDIT_DOWNLOAD_MODAL.BUTTONS.DOWNLOAD}</button>
                    <button type="button" data-cy="site-analytics-cancel" onClick={close}>{COMPONENTS.BUTTONS.CANCEL}</button>
                </div>
            </div>
        </form>
    );
};

AuditDownloadForm.propTypes = {
    handleSubmit: PropTypes.func,
    close: PropTypes.func,
    invalid: PropTypes.bool,
    className: PropTypes.string,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

AuditDownloadForm.defaultProps = {
    handleSubmit: () => {
    },
    close: () => {
    },
    invalid: true,
    className: '',
    intl: {
        formatMessage: () => {},
    },
};

AuditDownloadForm = reduxForm({
    form: NAME_OF_FORMS.AUDIT_DOWNLOAD,
    validate,
})(AuditDownloadForm);

const mapStateToForm = (state) => {
    const initialValues = {};
    return {
        initialValues,
        formState: state.form,
    };
};

AuditDownloadForm = connect(mapStateToForm)(injectIntl(AuditDownloadForm));

class AuditDownloadModal extends React.PureComponent {
    static propTypes = {
        dispatch: PropTypes.func,
        style: PropTypes.shape({}),
        company_uid: PropTypes.string,
        auditDownloadModal: PropTypes.shape({
            open: PropTypes.bool,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        company_uid: null,
        auditDownloadModal: PropTypes.shape({
            open: false,
        }),
        style: {},
    };

    onClose = () => {
        this.props.dispatch(closeAuditDownloadModal());
    };

    onSubmit = (submitData) => {
        const { company_uid } = this.props;
        const { from_to } = submitData;

        if (from_to[0] && from_to[1]) {
            const from = from_to[0].toDate().getTime();
            const to = from_to[1].toDate().getTime();
    
            api.downloadAudit({ from, to, company_uid })
                .catch((err) => {
                    errorHandlerGetRequest(err, this.props.dispatch);
                });
        }

        this.onClose();
    };

    render() {
        const { open } = this.props.auditDownloadModal;

        return (
            <Modal
                contentLabel="DatePicker"
                isOpen={open}
                onRequestClose={this.close}
                style={this.props.style}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header">{AUDIT_DOWNLOAD_MODAL.HEADER}</span>
                    <AuditDownloadForm
                        className="Modal-Form Form-Line"
                        close={this.onClose}
                        onSubmit={this.onSubmit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    company_uid: state.appContext.company ? state.appContext.company.uid : null,
    auditDownloadModal: state.modals.commonModals.auditDownloadModal,
});

export default connect(mapStateToProps)(injectIntl(AuditDownloadModal));
