import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import PropTypes from 'prop-types';
import { closeCommonMessageModal } from 'stores/actions';
import { DEFAULT_VALUES, NAME_OF_FORMS } from 'common/constants';
import { COMPONENTS } from 'common/ui-labels';


let CommonMessageModalForm = (props) => {
    const { className, status, message, close } = props;

    let messageStyle = {};
    if (status === DEFAULT_VALUES.SUCCESS_STATUS) {
        messageStyle = { color: 'green' };
    } else if (status === DEFAULT_VALUES.UNSUCCESS_STATUS) {
        messageStyle = { color: 'red' };
    } else if (status === DEFAULT_VALUES.WARNING_STATUS) {
        messageStyle = { color: 'orange' };
    }
    
    return (
        <form className={className}>
            <div className="Form-DeleteTitle" style={messageStyle}>
                { message }
            </div>
            <div className="Form-Buttons text-right">
                <button type="button" data-id="error-modal-close" onClick={close}>{COMPONENTS.BUTTONS.OK}</button>
            </div>
        </form>
    );
};
CommonMessageModalForm.propTypes = {
    close: PropTypes.func,
    className: PropTypes.string,
    message: PropTypes.shape({}),
    status: PropTypes.string,
};
CommonMessageModalForm.defaultProps = {
    close: () => {},
    className: '',
    message: {},
    status: '',
};

CommonMessageModalForm = reduxForm({
    form: NAME_OF_FORMS.COMMON_MESSAGE,
})(CommonMessageModalForm);

class CommonMessageModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        commonMessageModal: PropTypes.shape({
            open: PropTypes.bool,
            message: PropTypes.shape({}),
            title: PropTypes.shape({}),
            status: PropTypes.string,
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => { },
        commonMessageModal: {
            open: false,
            title: null,
            message: null,
            status: '',
        },
        style: {},
    };
    
    close = () => {
        this.props.dispatch(closeCommonMessageModal());
    };
    
    render() {
        const { style, commonMessageModal } = this.props;

        return (
            <Modal
                contentLabel="commonMessageModal"
                isOpen={commonMessageModal.open}
                onRequestClose={this.close}
                shouldCloseOnOverlayClick={false}
                style={style}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header2" style={{ fontSize: '1.4em' }} data-id="error-modal">
                        {commonMessageModal.title}
                    </span>
                    <CommonMessageModalForm
                        className="Modal-Form"
                        message={commonMessageModal.message}
                        status={commonMessageModal.status}
                        close={this.close}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    commonMessageModal: state.modals.commonModals.commonMessageModal,
});

export default connect(mapStateToProps)(CommonMessageModal);
