import React, { Component } from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { Field, reduxForm } from 'redux-form';
import { injectIntl } from 'react-intl';
import RenderField from 'components/modals/RenderField';
import RenderInputField from 'components/modals/RenderInputField';
import { NAME_OF_FORMS } from 'common/constants';
import { closeCompanyEditModalCompanyScope, editCompany, createCompany, stopLiveMode, startLiveMode } from 'stores/actions';
import { COMPANY_EDIT_MODAL, COMPONENTS } from 'common/ui-labels';


const validate = (values) => {
    const errors = {};

    if (!values.name) {
        errors.name = COMPONENTS.VALIDATION.REQUIRED;
    } else if (values.name.length < 3) {
        errors.name = COMPONENTS.VALIDATION.MIN_LENGTH_FUNC(3);
    }

    return errors;
};

const renderField = RenderField(4, 8);
const renderInputField = RenderInputField();

let CompanyEditForm = (props) => {
    const {
        close, submit, className, invalid, formState, intl, submitSucceeded,
    } = props;
    
    let tag_allocation;
    const companyEditForm = formState[NAME_OF_FORMS.COMPANY_EDIT];
    
    if (companyEditForm && companyEditForm.values) {
        tag_allocation = companyEditForm.values.tag_allocation;
    } else {
        tag_allocation = false;
    }
    
    return (
        <form className={className}>
            <div className="Form-Line row">
                <Field
                    className="Form-Input"
                    name="name"
                    dataId="company-edit-name"
                    component={renderField}
                    label={COMPANY_EDIT_MODAL.FORM.LABEL_COMPANY_NAME_FUNC(intl)}
                    type="text"
                />
            </div>
            
            <div className="Form-Line row">
                <div
                    htmlFor="companyColor"
                    className="Form-Label col-md-4"
                >
                    {COMPANY_EDIT_MODAL.FORM.COMPANY_COLOR}
                </div>
                <div className="col-md-8" data-id="company-edit-color">
                    <Field
                        name="color"
                        className="Form-Input"
                        component={renderInputField}
                        type="color"
                    />
                </div>
            </div>
            
            <div className="Form-Line row">
                <div
                    htmlFor="address"
                    className="Form-Label col-md-4"
                >
                    {COMPANY_EDIT_MODAL.FORM.ADDRESS}
                </div>
                <div className="col-md-8" data-id="company-edit-address">
                    <Field
                        className="Form-Input"
                        name="address"
                        component="textarea"
                        type="text"
                        style={{ height: '150px' }}
                    />
                </div>
            </div>
            
            <div className="Form-Line row">
                <div
                    htmlFor="website"
                    className="Form-Label col-md-4"
                >
                    {COMPONENTS.FIELDS.COMPANY.WEBSITE}
                </div>
                <div className="col-md-8" data-id="company-edit-website">
                    <Field
                        name="website"
                        className="Form-Input input"
                        component="input"
                        type="text"
                    />
                </div>
            </div>
            
            <div className="Form-Line row">
                <div htmlFor="phone" className="Form-Label col-md-4">{COMPONENTS.FIELDS.USER.PHONE}</div>
                <div className="col-md-8" data-id="company-edit-phone">
                    <Field
                        name="phone"
                        className="Form-Input input"
                        component="input"
                        type="text"
                    />
                </div>
            </div>
            
            <div style={{ textAlign: 'center', marginTop: '15px', display: 'none' }} data-id="company-edit-allocation">
                <Field
                    name="tag_allocation"
                    component="input"
                    type="checkbox"
                    checked={tag_allocation}
                />
                <span
                    style={{ marginLeft: '10px' }}
                >
                    {COMPANY_EDIT_MODAL.FORM.ALLOW_AUTO_TAG_ALLOCATION}
                </span>
            </div>
            
            <div className="Form-Buttons">
                <button
                    type="button"
                    onClick={submit}
                    disabled={invalid || submitSucceeded}
                    data-id="company-edit-save"
                >
                    {COMPONENTS.BUTTONS.SAVE}
                </button>
                <button type="button" data-id="company-edit-cancel" onClick={close}>{COMPONENTS.BUTTONS.CANCEL}</button>
            </div>
        </form>
    );
};

CompanyEditForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    invalid: PropTypes.bool,
    formState: PropTypes.shape(),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    submitSucceeded: PropTypes.bool,
};

CompanyEditForm.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    invalid: false,
    className: '',
    formState: {},
    intl: {
        formatMessage: () => {
        },
    },
    submitSucceeded: false,
};

CompanyEditForm = reduxForm({
    form: NAME_OF_FORMS.COMPANY_EDIT,
    validate,
})(CompanyEditForm);

const mapStateToForm = state => ({
    initialValues: state.modals.companyModals.companyEdit.params,
    formState: state.form,
});
CompanyEditForm = connect(mapStateToForm)(injectIntl(CompanyEditForm));


class CompanyEditModalCompanyScope extends Component {
    static propTypes = {
        dispatch: PropTypes.func,
        companyEdit: PropTypes.shape({
            openCompanyScope: PropTypes.bool,
            params: PropTypes.shape({
                uid: PropTypes.string,
                name: PropTypes.string,
            }),
        }),
        projectScope: PropTypes.shape({}),
        style: PropTypes.shape({}),
    };
    
    static defaultProps = {
        dispatch: () => {},
        companyEdit: {
            openCompanyScope: false,
            params: null,
        },
        projectScope: null,
        style: {},
    };

    componentDidUpdate(prevProps) {
        const openInProjectScope = this.props.projectScope && this.props.companyEdit.openCompanyScope;
        const closeInProjectScope = this.props.projectScope && !this.props.companyEdit.openCompanyScope;

        if (openInProjectScope && !prevProps.companyEdit.openCompanyScope) {
            this.props.dispatch(stopLiveMode());
        } else if (closeInProjectScope && prevProps.companyEdit.openCompanyScope) {
            this.props.dispatch(startLiveMode());
        }
    }

    close = () => {
        this.props.dispatch(closeCompanyEditModalCompanyScope());
    };
    
    submit = (values) => {
        if (this.props.companyEdit.params && this.props.companyEdit.params.uid) {
            this.props.dispatch(editCompany(values));
        } else {
            this.props.dispatch(createCompany(values));
        }
        this.props.dispatch(closeCompanyEditModalCompanyScope());
    };
    
    render() {
        const { style, companyEdit } = this.props;
        const title = companyEdit.params && companyEdit.params.uid
            ? companyEdit.params.name
            : COMPANY_EDIT_MODAL.TITLE_ADD_NEW;
        
        return (
            <Modal
                contentLabel="companyEdit"
                isOpen={companyEdit.openCompanyScope}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header">
                        {title}
                    </span>
                    <CompanyEditForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}


const mapStateToProps = state => ({
    companyEdit: state.modals.companyModals.companyEdit,
    projectScope: state.appContext.project,
});

export default connect(mapStateToProps)(CompanyEditModalCompanyScope);
