import React from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';

import { TRACKABLE_OR_TRACKABLES_SELECTED, COMPONENTS } from 'common/ui-labels';
import { NAME_OF_FORMS, GROUP_DETACH_MODAL } from '../../common';
import { getAdminPageSelectedGroup } from '../../utils';
import { closeGroupDetachModal, detachGroup } from '../../stores/actions';


let GroupDetachForm = (props) => {
    const { close, submit, className, detachedTrackables } = props;
    const { params } = props.groupDetach;
    const group = params.group;
    const isBatchDelete = Array.isArray(detachedTrackables);

    const message = (isBatchDelete)
        ? GROUP_DETACH_MODAL.FORM.TITLE.MULTI_FUNC(group && group.name)
        : GROUP_DETACH_MODAL.FORM.TITLE.SINGLE_FUNC(detachedTrackables.name, group && group.name);

    return (
        <form className={className}>
            {
                isBatchDelete && <div className="Form-Confirmation info-text" data-id="group-delete-message">
                    { TRACKABLE_OR_TRACKABLES_SELECTED(<b>{detachedTrackables.length}</b>) }
                </div>
            }
            <div className="Form-DeleteTitle confirmation" data-id="group-detach-confirmation">
                {message}
            </div>
            <div className="Form-Buttons">
                <button data-id="group-detach-detach" type="button" onClick={submit}>{COMPONENTS.BUTTONS.DELETE}</button>
                <button data-id="group-detach-cancel" type="button" onClick={close}>{COMPONENTS.BUTTONS.CANCEL}</button>
            </div>
        </form>
    );
};

GroupDetachForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    detachedTrackables: PropTypes.oneOfType([PropTypes.shape(), PropTypes.array]),
    groupDetach: PropTypes.shape({
        params: PropTypes.shape({
            group: PropTypes.shape({
                name: PropTypes.string,
            }),
        }),
    }),
};

GroupDetachForm.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    className: '',
    groupDetach: {
        params: {
            group: {
                name: '',
            },
        },
    },
    detachedTrackables: [{}],
};

GroupDetachForm = reduxForm({
    form: NAME_OF_FORMS.COMPANY_DELETE,
})(GroupDetachForm);

const mapStateToForm = state => ({
    groupDetach: state.modals.groupModals.groupDetach,
    detachedTrackables: state.modals.groupModals.groupDetach.params ? state.modals.groupModals.groupDetach.params.row : '',
});
GroupDetachForm = connect(mapStateToForm)(GroupDetachForm);


class GroupDetachModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        selectedGroup: PropTypes.shape({}),
        groupDetach: PropTypes.shape({
            params: PropTypes.shape({
                row: PropTypes.oneOfType([
                    PropTypes.shape({
                        mac_address: PropTypes.string,
                        uid: PropTypes.string,
                        groups: PropTypes.arrayOf(PropTypes.string),
                    }),
                    PropTypes.arrayOf(PropTypes.shape({
                        mac_address: PropTypes.string,
                        uid: PropTypes.string,
                        groups: PropTypes.arrayOf(PropTypes.string),
                    })),
                ]),
            }),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({
            overlay: PropTypes.object,
            content: PropTypes.object,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        selectedGroup: {},
        groupDetach: {
            params: {
                row: {
                    mac_address: '',
                    uid: '',
                    groups: [],
                },
            },
            open: false,
        },
        style: {
            overlay: {},
            content: {},
        },
    };
    
    close = () => {
        this.props.dispatch(closeGroupDetachModal());
    };
    
    submit = () => {
        const { groupDetach, selectedGroup, dispatch } = this.props;
        dispatch(detachGroup({ modalProps: groupDetach.params, selectedGroup }));
    };
    
    render() {
        const { style } = this.props;
        return (
            <Modal
                contentLabel="groupDetach"
                isOpen={this.props.groupDetach.open}
                onRequestClose={this.close}
                style={style}
            >
                <div className="RPP-Modal">
                    <GroupDetachForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    selectedGroup: getAdminPageSelectedGroup(state),
    groupDetach: state.modals.groupModals.groupDetach,
});

export default connect(mapStateToProps)(GroupDetachModal);
