import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import { injectIntl } from 'react-intl';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';

import { NAME_OF_FORMS } from 'common/constants';
import { GROUP_DETAILS_MODAL, GROUP_TRACKABLE_COMMON_FIELD, COMPONENTS } from 'common/ui-labels';
import { closeGroupDetailsModal } from 'stores/actions/modalActions/groupModalActions';

export const colorWidthFormatter = (color = 'white', width = '22px', margin = 'auto') => {
    const style = {
        backgroundColor: color,
        width,
        height: '20px',
        margin,
    };
    return (<div style={style} />);
};

let GroupDetailsForm = (props) => {
    const {
        close, params, className,
    } = props;
    const custom_info = params.custom_info;

    const sensorSpecialCasesKeys = Object.keys(params.sensorSpecialCases || {});
    return (
        <form className={className}>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{GROUP_DETAILS_MODAL.FORM.NAME}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="group-details-name">{params.name}</div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.COMMON.COLOR}</div>
                <div
                    className="Form-Value col-md-8"
                    data-id="group-details-color"
                >
                    {colorWidthFormatter(params.color, '100%', 'left')}
                </div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{GROUP_DETAILS_MODAL.FORM.TRACKABLE_COUNT}</div>
                <div className="Form-Value col-md-8" data-id="group-details-trackable-count">{params.trackable_count}</div>
            </div>
            
            {params.user_params && params.user_params.customParams &&
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{GROUP_DETAILS_MODAL.FORM.CUSTOM_PARAMETERS}</div>
                <div
                    className="Form-Value col-md-8 multiple-lines-ellipsis"
                    data-id="group-details-params"
                    data-cy="group-user-params"
                >
                    {params.user_params && params.user_params.customParams}
                </div>
            </div>}

            {sensorSpecialCasesKeys.length > 0 &&
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.NODE.ADVANCED_SENSOR_INTEGRATION_PARAMETER}</div>
                <div className="Form-Value col-md-8">
                    {sensorSpecialCasesKeys.map((x, key) => (
                        <span key={key}>{x}: { params.sensorSpecialCases[x]
                            ? GROUP_TRACKABLE_COMMON_FIELD.SENSOR_CONFIG_ENABLED
                            : GROUP_TRACKABLE_COMMON_FIELD.SENSOR_CONFIG_DISABLED}
                        </span>
                    ))}
                </div>
            </div>
            }
            <Fragment key="zones">
                {((params.inclusionsForZones && params.inclusionsForZones.length) || (params.exclusionsForZones && params.exclusionsForZones.length))
                    ? (
                        <div className="Form-Line row">
                            <div className="Form-Label col-md-4">{GROUP_TRACKABLE_COMMON_FIELD.ZONE_CONFIGURATION}</div>
                            <div className="Form-Value col-md-8" />
                        </div>
                    ) : ''
                }
                {params.inclusionsForZones && params.inclusionsForZones.length ?
                    <div className="Form-Line row">
                        <div className="Form-Label col-md-4 grey-text">{GROUP_TRACKABLE_COMMON_FIELD.ZONE_INCLUSIONS}</div>
                        <div className="Form-Value col-md-8 grey-text">{params.inclusionsForZones.join(', ')}</div>
                    </div> : ''
                }
                {params.exclusionsForZones && params.exclusionsForZones.length ?
                    <div className="Form-Line row">
                        <div className="Form-Label col-md-4 grey-text">{GROUP_TRACKABLE_COMMON_FIELD.ZONE_EXCLUSIONS}</div>
                        <div className="Form-Value col-md-8 grey-text">{params.exclusionsForZones.join(', ')}</div>
                    </div> : ''
                }
            </Fragment>
            {custom_info &&
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.COMMON.CUSTOM_INFO}</div>
                <div
                    className="Form-Value col-md-8 multiple-lines-ellipsis"
                    data-id="group-details-params"
                    data-cy="group-detail-custom-info"
                >
                    <textarea value={custom_info} readOnly className="RPP-Group-advanced-TextArea" />
                </div>
            </div>}

            <div className="Form-Buttons OneBtn">
                <button type="button" data-id="group-details-close" onClick={close}>{COMPONENTS.BUTTONS.CLOSE}</button>
            </div>
        </form>
    );
};

GroupDetailsForm.propTypes = {
    close: PropTypes.func,
    className: PropTypes.string,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    params: PropTypes.shape({
        name: PropTypes.string,
        trackable_count: PropTypes.number,
        user_params: PropTypes.shape({
            customParams: PropTypes.string,
        }),
        color: PropTypes.string,
        custom_info: PropTypes.string,
        exclusionsForZones: PropTypes.arrayOf(PropTypes.string),
        inclusionsForZones: PropTypes.arrayOf(PropTypes.string),
        sensorSpecialCases: PropTypes.shape({}),
    }),
};

GroupDetailsForm.defaultProps = {
    close: () => {
    },
    className: '',
    intl: {
        formatMessage: () => {
        },
    },
    params: {
        name: '',
        trackable_count: 0,
        user_params: {
            customParams: '',
        },
        color: '',
        custom_info: '',
        exclusionsForZones: [],
        inclusionsForZones: [],
        sensorSpecialCases: {},
    },
};

GroupDetailsForm = reduxForm({
    form: NAME_OF_FORMS.GROUP_DETAILS,
})(injectIntl(GroupDetailsForm));


class GroupDetailsModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        groupDetails: PropTypes.shape({
            params: PropTypes.shape({
                mac_address: PropTypes.string,
                name: PropTypes.string,
            }),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({
            overlay: PropTypes.shape({}),
            content: PropTypes.shape({}),
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        groupDetails: {
            params: {
                mac_address: '',
                name: '',
            },
            open: false,
        },
        style: {
            overlay: {},
            content: {},
        },
    };
    
    close = () => {
        this.props.dispatch(closeGroupDetailsModal());
    };
    
    render() {
        const { style } = this.props;
        style.content.width = '650px';

        return (
            <Modal
                contentLabel="groupDetails"
                isOpen={this.props.groupDetails.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis">
                        {COMPONENTS.FIELDS.COMMON.VIEW_INFORMATION_FUNC(this.props.groupDetails.params ? this.props.groupDetails.params.name : '')}
                    </span>
                    <GroupDetailsForm
                        className="Modal-Form"
                        close={this.close}
                        params={this.props.groupDetails.params}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    groupDetails: state.modals.groupModals.groupDetails,
});

export default connect(mapStateToProps)(GroupDetailsModal);
