import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import { injectIntl } from 'react-intl';
import PropTypes from 'prop-types';

import { NAME_OF_FORMS, SEND_NEW_ROUTE, MESSAGE_SUCCESS_SEND } from '../../common';
import { closeMessageSuccessSend, clearMessage } from '../../stores/actions';
import { timeFormatter, isMacsEqual } from '../../utils';

import Trackable from '../../stores/classes/Trackable';

let MessageSuccessSendForm = (props) => {
    const {
        close, className, recipient, message,
    } = props;
    
    return (
        <form className={className}>
            <span className="Form-Confirmation">
                {MESSAGE_SUCCESS_SEND.TEXT(message, recipient, timeFormatter(new Date()))}
            </span>
            <div className="Form-Buttons">
                <button data-id="message-success-ok" type="button" onClick={close}>Ok</button>
            </div>
        </form>
    );
};

MessageSuccessSendForm.propTypes = {
    close: PropTypes.func,
    className: PropTypes.string,
    recipient: PropTypes.string,
    message: PropTypes.string,
};

MessageSuccessSendForm.defaultProps = {
    close: () => {
    },
    className: '',
    recipient: '',
    message: '',
};

MessageSuccessSendForm = reduxForm({
    form: NAME_OF_FORMS.MESSAGE_SUCCESS_SEND,
})(MessageSuccessSendForm);

const getRecipientNames = (recipient, trackables, intl) => {
    if (SEND_NEW_ROUTE) {
        return recipient && recipient.length === 1 ? trackables.find(x => x.uid === recipient[0]) : { name: MESSAGE_SUCCESS_SEND.TAGS_COUNT(intl, recipient.length) };
    }
    return recipient ? trackables.find(x => x.node && isMacsEqual(x.node.mac_address, recipient)) : null; // ??
};

const mapStateToForm = (state, { intl }) => {
    const trackables = Trackable.getAllTrackablesArray(state);
    const { recipient, recipients, message } = state.modals.messageModals.messageSuccessSend;
    
    const recipientNames = getRecipientNames(recipient, trackables, intl);
    const recipientAll = recipients ? MESSAGE_SUCCESS_SEND.TAGS_COUNT(intl, recipients.length) : null;
    return {
        recipient: (recipientNames && recipientNames.name) || recipientAll,
        message,
    };
};

MessageSuccessSendForm = injectIntl(connect(mapStateToForm)(MessageSuccessSendForm));

class MessageSuccessSendModal extends React.Component {
    close = () => {
        this.props.dispatch(clearMessage());
        this.props.dispatch(closeMessageSuccessSend());
    };
    
    render() {
        const title = MESSAGE_SUCCESS_SEND.TITLE;
        const { style } = this.props;
        
        return (
            <Modal
                contentLabel="nodeError"
                isOpen={this.props.messageSuccessSend.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header">
                        {title}
                    </span>
                    <MessageSuccessSendForm
                        className="Modal-Form"
                        close={this.close}
                    />
                </div>
            </Modal>
        );
    }
}
MessageSuccessSendModal.propTypes = {
    dispatch: PropTypes.func,
    messageSuccessSend: PropTypes.shape({
        open: PropTypes.bool,
    }),
    style: PropTypes.shape(),
};

MessageSuccessSendModal.defaultProps = {
    dispatch: () => {
    },
    messageSuccessSend: {
        open: false,
    },
    style: {},
};

const mapStateToProps = state => ({
    messageSuccessSend: state.modals.messageModals.messageSuccessSend,
});

export default connect(mapStateToProps)(MessageSuccessSendModal);
