import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { Field, reduxForm, SubmissionError, touch } from 'redux-form';
import PropTypes from 'prop-types';
import _Get from 'lodash/get';

import { makeCopy, isMacValid } from 'utils/simpleUtils';
import SaveButtons from 'components/modals/SaveButtons';

import { NAME_OF_FORMS, NODE_MODAL, HTTP_STATUS, COMPONENTS } from '../../common';
import {
    closeAddNodeModal,
    addNode,
} from '../../stores/actions';
import RenderMacField from '../../components/modals/RenderMacField';

const validate = (values, props) => {
    const errors = {};
    if (!values.manualEntry) {
        props.dispatch(touch(NAME_OF_FORMS.NODE_ADD, 'manualEntry'));
        errors.manualEntry = COMPONENTS.VALIDATION.REQUIRED;
    } else if (!isMacValid(values.manualEntry.replace(/_/g, '0'))) {
        errors.manualEntry = NODE_MODAL.NODE_ADD.MAC_ADDRESS_CLAIM;
    }

    return errors;
};

let NodeAddForm = (props) => {
    const {
        close, className, formState, submit,
    } = props;
    const nodeAddForm = formState[NAME_OF_FORMS.NODE_ADD];
    const { manualEntry } = (nodeAddForm && nodeAddForm.values) || {};

    return (
        <form className={className} onSubmit={(e) => { e.preventDefault(); }}>
            <div className="Form-Line">
                <div className="row">
                    <div className="Form-Label col-md-4">
                        {COMPONENTS.FIELDS.NODE.MAC_ADDRESS}
                    </div>
                    <div className="col-md-8" data-id="node-add-input">
                        <Field
                            className="Form-Input"
                            name="manualEntry"
                            component={RenderMacField}
                            data-cy="node-add-input"
                            label="ManualEntry"
                            style={{ color: 'grey' }}
                        />
                    </div>
                </div>
            </div>
            <SaveButtons
                submit={submit}
                close={close}
                disabled={!manualEntry || !isMacValid(manualEntry.replace(/_/g, ''))}
                dataId="node-add"
            />
        </form>
    );
};

NodeAddForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    formState: PropTypes.shape({
    }),
};

NodeAddForm.defaultProps = {
    close: () => {},
    submit: () => {},
    className: '',
    formState: {},
};

NodeAddForm = reduxForm({
    form: NAME_OF_FORMS.NODE_ADD,
    validate,
})(NodeAddForm);

const mapStateToForm = state => ({
    initialValues: {
        manualEntry: 'E4-95-6E-A_-__-__',
    },
    formState: state.form,
});

NodeAddForm = connect(mapStateToForm)(NodeAddForm);

class NodeAddModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        nodeAdd: PropTypes.shape({
            params: PropTypes.object,
            open: PropTypes.bool,
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        nodeAdd: {
            params: {},
            open: false,
        },
        style: {},
    };

    close = () => {
        this.props.dispatch(closeAddNodeModal());
    };

    submit = (values) => {
        const mac_address = values.manualEntry.replace(/-|\s/g, '');
        const node = { mac_address };

        return this.props.dispatch(addNode(node)).then((result) => {
            const status = _Get(result, 'response.status');
            if (status === HTTP_STATUS.UNPROCESSABLE) {
                throw new SubmissionError({ manualEntry: NODE_MODAL.NODE_ERROR_CREATE_MODAL.EXISTING_MAC });
            }

            this.close();
        });
    };

    render() {
        const { style } = this.props;

        const customStyle = makeCopy(style);
        customStyle.content.width = 430;

        return (
            <Modal
                contentLabel="nodeAdd"
                isOpen={this.props.nodeAdd.open}
                onRequestClose={this.close}
                style={customStyle}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header">
                        {NODE_MODAL.TITLES.CREATE_NEW_TAG}
                    </span>
                    <NodeAddForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    nodeAdd: state.modals.nodeModals.nodeAdd,
});

export default connect(mapStateToProps)(NodeAddModal);
