import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import PropTypes from 'prop-types';

import { NAME_OF_FORMS, NODE_MODAL, COMPONENTS } from 'common';
import { makeCopy } from 'utils/simpleUtils';
import { closeImportNodeModal, closeErrorNodeImportModal, importValidMacAddresses } from 'stores/actions';


let NodeErrorImportForm = (props) => {
    const { close, goBack, importValid, className, nodeImportError, parsedData, column } = props;
    const { invalid, valid, duplicate } = nodeImportError.data || {};

    const invalidData = (invalid || []).map(item => (item && item.toUpperCase()));
    const validData = makeCopy((valid || [])).map(item => (item && item.toUpperCase()));
    const duplicateData = (duplicate || []).map(item => (item && item.toUpperCase()));
    
    const messages = [];
    const records = parsedData.map((record) => {
        const findValidIndex = validData.indexOf(record[column] && record[column].toUpperCase());
        if (findValidIndex !== -1) {
            validData.splice(findValidIndex, findValidIndex + 1);
            return null;
        }
        return record;
    });
    
    records.forEach((data, index) => {
        if (data && invalidData.indexOf(data[column].toUpperCase()) !== -1) {
            messages.push(NODE_MODAL.NODE_ERROR_IMPORT_MODAL.INVALID_MAC_FUNC(index + 1));
        } else if (data && duplicateData.indexOf(data[column].toUpperCase()) !== -1) {
            messages.push(NODE_MODAL.NODE_ERROR_IMPORT_MODAL.DUPLICATE_MAC_FUNC(index + 1));
        }
    });

    return (
        <form className={className}>
            <div className="Form-Line" style={{ maxHeight: '300px', overflowY: 'auto' }}>
                {
                    messages.map((message, index) => (
                        <div key={index} className="node-error-message-box">
                            {message}
                        </div>))
                }
            </div>
            <div className="Form-Buttons">
                <button
                    type="button"
                    data-id="node-error-import-back"
                    onClick={goBack}
                >
                    {COMPONENTS.BUTTONS.GO_BACK}
                </button>
                <button
                    data-id="node-error-import-valid"
                    type="button"
                    style={{ width: '200px' }}
                    onClick={importValid}
                >
                    {NODE_MODAL.NODE_ERROR_IMPORT_MODAL.BUTTON_IMPORT_VALID}
                </button>
                <button
                    type="button"
                    data-id="node-error-import-cancel"
                    onClick={close}
                >
                    {COMPONENTS.BUTTONS.CANCEL}
                </button>
            </div>
        </form>
    );
};

NodeErrorImportForm.propTypes = {
    close: PropTypes.func,
    goBack: PropTypes.func,
    importValid: PropTypes.func,
    className: PropTypes.string,
    nodeImportError: PropTypes.shape({
        data: PropTypes.shape({
            valid: PropTypes.array,
            invalid: PropTypes.array,
            duplicate: PropTypes.array,
        }),
    }),
    parsedData: PropTypes.arrayOf(PropTypes.array),
    column: PropTypes.number,
};

NodeErrorImportForm.defaultProps = {
    close: () => {
    },
    goBack: () => {
    },
    importValid: () => {
    },
    className: '',
    nodeImportError: {
        data: {
            valid: [],
            invalid: [],
            duplicate: [],
        },
    },
    parsedData: [],
    column: 0,
};

NodeErrorImportForm = reduxForm({
    form: NAME_OF_FORMS.NODE_IMPORT_ERROR,
})(NodeErrorImportForm);

const mapStateToForm = state => ({
    nodeImportError: state.modals.nodeModals.nodeImportError,
    parsedData: state.modals.nodeModals.nodeImport.parseData || [],
    column: state.modals.nodeModals.nodeImport.column,
});

NodeErrorImportForm = connect(mapStateToForm)(NodeErrorImportForm);

class NodeErrorImportModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        style: PropTypes.shape({
            overlay: PropTypes.object,
            content: PropTypes.object,
        }),
        nodeImportError: PropTypes.shape({
            data: PropTypes.shape({
                valid: PropTypes.array,
                invalid: PropTypes.array,
                duplicate: PropTypes.array,
            }),
        }),
        parsedData: PropTypes.arrayOf(PropTypes.array),
        column: PropTypes.number,
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        style: {
            overlay: {},
            content: {},
        },
        nodeImportError: {
            data: {
                valid: [],
                invalid: [],
                duplicate: [],
            },
        },
        parsedData: [],
        column: 0,
    };
    
    close = () => {
        this.props.dispatch(closeErrorNodeImportModal());
        this.props.dispatch(closeImportNodeModal());
    };
    
    goBack = () => {
        this.props.dispatch(closeErrorNodeImportModal());
    };
    
    importValid = () => {
        const validData = this.props.nodeImportError.data.valid;
        this.props.dispatch(importValidMacAddresses(validData));
        this.props.dispatch(closeErrorNodeImportModal());
    };
    
    createDownloadCsv = ({ invalid, duplicate }, parsedData, column) => {
        let csv = 'Line,mac_address,error_type\n';
        const invalidData = invalid.map((mac, index) => ([index, mac, 'invalid format']));
        const duplicateData = duplicate.map((mac, index) => ([index, mac, 'duplicate entry']));
        const data = [...invalidData, ...duplicateData];
        
        parsedData.forEach((row, index) => {
            data.forEach((invalidRow) => {
                if (invalidRow[1] === row[column]) {
                    invalidRow[0] = index + 1;
                }
            });
        });
        
        data.forEach((row) => {
            csv += row.join(',');
            csv += '\n';
        });
        const hiddenElement = document.createElement('a');
        hiddenElement.href = `data:text/csv;charset=utf-8,${encodeURI(csv)}`;
        hiddenElement.target = '_blank';
        hiddenElement.download = 'error_list.csv';
        hiddenElement.click();
    };
    
    render() {
        const title = NODE_MODAL.NODE_ERROR_IMPORT_MODAL.ERROR_FOUND;
        const {
            style, nodeImportError, parsedData, column,
        } = this.props;
        
        return (
            <Modal
                contentLabel="nodeError"
                isOpen={nodeImportError.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <div className="row">
                        <div className="col-md-6 Modal-Header" data-id="node-error-import-title">
                            {title}
                        </div>
                        <div className="col-md-6 Modal-Buttons text-right">
                            <button onClick={() => {
                                this.createDownloadCsv(nodeImportError.data, parsedData, column);
                            }}
                            >
                                {NODE_MODAL.NODE_ERROR_IMPORT_MODAL.EXPORT_ERROR_BUTTON}
                            </button>
                        </div>
                    </div>
                    <NodeErrorImportForm
                        className="Modal-Form"
                        goBack={this.goBack}
                        importValid={this.importValid}
                        close={this.close}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    nodeImportError: state.modals.nodeModals.nodeImportError,
    parsedData: state.modals.nodeModals.nodeImport.parseData,
    column: state.modals.nodeModals.nodeImport.column,
});

export default connect(mapStateToProps)(NodeErrorImportModal);
