import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { injectIntl } from 'react-intl';
import { connect } from 'react-redux';
import { Field, reduxForm } from 'redux-form';

import { makeCopy } from 'utils/simpleUtils';
import { NAME_OF_FORMS, DEFAULT_VALUES, NODE_MODAL, COMPONENTS } from '../../common';

import RenderSelectField from '../../components/modals/RenderSelectField';

import {
    closeImportNodeModal,
    closeNodeImportCheckOneModal,
    setMacColumnInParseData,
    openNodeImportCheckTwoModal,
} from '../../stores/actions';

let NodeImportCheckOneForm = (props) => {
    const {
        close, submit, className, initialValues, intl, back,
    } = props;
    const parseData = props.parsedData[0] || [];
    
    parseData.forEach((column, index) => {
        if (column.length === DEFAULT_VALUES.MAC_ADDRESS_LENGTH || column === 'MAC_ADDRESS') {
            initialValues.column = index;
        }
    });
    
    return (
        <form className={className}>
            <div className="Form-Line row">
                <div className="Form-Label col-md-5">
                    {COMPONENTS.FIELDS.NODE.MAC_ADDRESS} :
                </div>
                <div className="Form-Value-Bold col-md-7">
                    <Field
                        className="form-control input-sm "
                        name="column"
                        dataId="node-import-check"
                        style={{ fontSize: '14px' }}
                        component={RenderSelectField}
                    >
                        {parseData.map((column, index) => (
                            <option
                                key={index}
                                value={index}
                            >{NODE_MODAL.NODE_IMPORT_CHECK_MODAL.COLUMN(intl)} {index + 1}
                            </option>))}
                    </Field>
                </div>
            </div>
            <div className="Form-Buttons OneBtn">
                <button type="button" data-id="node-import-check-two-back" onClick={back}>
                    {COMPONENTS.BUTTONS.GO_BACK}
                </button>
                <button type="button" data-id="node-import-check-import" onClick={submit}>
                    {COMPONENTS.BUTTONS.IMPORT}
                </button>
                <button type="button" data-id="node-import-check-cancel" onClick={close}>
                    {COMPONENTS.BUTTONS.CANCEL}
                </button>
            </div>
        </form>
    );
};
NodeImportCheckOneForm = reduxForm({
    form: NAME_OF_FORMS.NODE_IMPORT_CHECK_ONE,
})(NodeImportCheckOneForm);

NodeImportCheckOneForm.propTypes = {
    close: PropTypes.func,
    back: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    initialValues: PropTypes.shape(),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    parsedData: PropTypes.arrayOf(PropTypes.array),
};

NodeImportCheckOneForm.defaultProps = {
    close: () => {
    },
    back: () => {
    },
    submit: () => {
    },
    className: '',
    initialValues: {},
    intl: {
        formatMessage: () => {
        },
    },
    parsedData: [],
};

const mapStateToForm = state => ({
    initialValues: { column: 0 },
    parsedData: state.modals.nodeModals.nodeImport.parseData ? state.modals.nodeModals.nodeImport.parseData : [],
});

NodeImportCheckOneForm = connect(mapStateToForm)(injectIntl(NodeImportCheckOneForm));

class NodeImportCheckOneModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        style: PropTypes.shape({}),
        nodeDetails: PropTypes.shape({
            open: PropTypes.bool,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {},
        style: {},
        nodeDetails: {
            open: false,
        },
    };

    submit = (data) => {
        this.props.dispatch(setMacColumnInParseData(Number(data.column)));
        this.props.dispatch(closeNodeImportCheckOneModal());
        this.props.dispatch(openNodeImportCheckTwoModal());
    };
    
    close = () => {
        this.props.dispatch(closeNodeImportCheckOneModal());
        this.props.dispatch(closeImportNodeModal());
    };

    back = () => {
        this.props.dispatch(closeNodeImportCheckOneModal());
    };
    
    render() {
        const { style } = this.props;

        const customStyle = makeCopy(style);
        customStyle.content.width = 430;

        return (
            <Modal
                contentLabel="projectDetails"
                isOpen={this.props.nodeDetails.open}
                onRequestClose={this.close}
                style={customStyle}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header">
                        {NODE_MODAL.NODE_IMPORT_CHECK_MODAL.CHECK_IMPORT}
                    </span>
                    <NodeImportCheckOneForm
                        className="Modal-Form"
                        close={this.close}
                        back={this.back}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    nodeDetails: state.modals.nodeModals.nodeImportCheckOne,
});

export default connect(mapStateToProps)(NodeImportCheckOneModal);
