import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import Papa from 'papaparse';
import PropTypes from 'prop-types';

import { makeCopy } from 'utils/simpleUtils';

import { NAME_OF_FORMS, NODE_MODAL, COMPONENTS } from '../../common';
import {
    closeImportNodeModal,
    readCSVImportNodeModal,
    clearCSVImportNodeModal,
    openNodeImportCheckOneModal,
    setParsedData,
} from '../../stores/actions';

let NodeImportForm = (props) => {
    const {
        close, className, downloadCSV, importCSVToServer, csvFile,
    } = props;

    return (
        <form className={className}>
            <div className="Form-Line row">
                <div className="col-md-12 text-right">
                    <label className="input">
                        {csvFile.name || NODE_MODAL.NODE_ADD.CHOOSE_FILE}
                        <span style={{ display: 'none' }} data-id="node-add-download">
                            <input
                                data-cy="node-import-file"
                                type="file"
                                onChange={(e) => {
                                    downloadCSV(e);
                                }}
                            />
                        </span>
                    </label>
                </div>
            </div>
            <div className="Form-Buttons">
                <button
                    type="button"
                    disabled={!csvFile}
                    data-id="node-import-button-import"
                    onClick={() => importCSVToServer(csvFile)}
                >
                    {COMPONENTS.BUTTONS.IMPORT}
                </button>
                <button
                    type="button"
                    data-id="node-import-button-cancel"
                    onClick={close}
                >
                    {COMPONENTS.BUTTONS.CANCEL}
                </button>
            </div>
        </form>
    );
};

NodeImportForm.propTypes = {
    className: PropTypes.string,
    close: PropTypes.func,
    downloadCSV: PropTypes.func,
    importCSVToServer: PropTypes.func,
    csvFile: PropTypes.shape({
        name: PropTypes.string,
    }),
};

NodeImportForm.defaultProps = {
    className: '',
    close: () => {},
    downloadCSV: () => {},
    importCSVToServer: () => {},
    csvFile: {
        name: '',
    },
};

NodeImportForm = reduxForm({
    form: NAME_OF_FORMS.NODE_IMPORT,
})(NodeImportForm);

const mapStateToForm = state => ({
    csvFile: state.modals.nodeModals.nodeImport.csvFile,
});

NodeImportForm = connect(mapStateToForm)(NodeImportForm);

class NodeImportModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        nodeImport: PropTypes.shape({
            params: PropTypes.object,
            open: PropTypes.bool,
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        nodeImport: {
            params: {},
            open: false,
        },
        style: {},
    };
    
    onCSVImport = () => {
        this.props.dispatch(openNodeImportCheckOneModal());
    };
    
    onDownloadCSV = (e) => {
        const files = e.target.files;
        const file = files[0];
        this.props.dispatch(readCSVImportNodeModal(file));
        const same = this;
        const config = {
            delimiter: ',',
            newline: '',
            quoteChar: '"',
            header: false,
            dynamicTyping: false,
            preview: 0,
            encoding: '',
            worker: false,
            comments: false,
            complete(results) {
                if (results.data) {
                    const parsedData = results.data.filter(record => (!!record && !!record[0]));
                    same.props.dispatch(setParsedData(parsedData));
                }
            },
            error: undefined,
            download: false,
            skipEmptyLines: false,
            chunk: undefined,
            fastMode: undefined,
            beforeFirstChunk: undefined,
            withCredentials: undefined,
        };
        Papa.parse(file, config);
    };

    close = () => {
        this.props.dispatch(closeImportNodeModal());
        this.props.dispatch(clearCSVImportNodeModal());
    };
    
    render() {
        const { style, nodeImport: { open: isOpen } } = this.props;

        const customStyle = makeCopy(style);
        customStyle.content.width = 600;

        return (
            <Modal
                contentLabel="nodeImport"
                isOpen={isOpen}
                onRequestClose={this.close}
                style={customStyle}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header">
                        {NODE_MODAL.TITLES.IMPORT_TAGS_FROM_CSV}
                    </span>
                    <NodeImportForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                        downloadCSV={this.onDownloadCSV}
                        importCSVToServer={this.onCSVImport}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = (state) => {
    const { nodeImport } = state.modals.nodeModals;
    return { nodeImport };
};

export default connect(mapStateToProps)(NodeImportModal);
