import React from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';

import { NAME_OF_FORMS, NODE_MODAL, COMPONENTS } from '../../common';
import { closeImportNodeModal, closeSuccessNodeImportModal } from '../../stores/actions';

let NodeSuccessImportForm = (props) => {
    const { close, nodeImportSuccess, className } = props;
    const message = nodeImportSuccess.data.valid.length;
    return (
        <form className={className}>
            <div className="row">
                <div className="col-md-1" />
                <div className="Form-Confirmation col-md-11" data-id="node-success-import-message">
                    {message} {NODE_MODAL.NODE_SUCCESS_IMPORT_MODAL.TAGS_IMPORTED}
                </div>
            </div>
            <div className="Form-Buttons">
                <button type="button" data-id="node-success-import-ok" onClick={close}>{COMPONENTS.BUTTONS.OK}</button>
            </div>
        </form>
    );
};

NodeSuccessImportForm.propTypes = {
    close: PropTypes.func,
    className: PropTypes.string,
    nodeImportSuccess: PropTypes.shape({
        data: PropTypes.object,
    }),
};

NodeSuccessImportForm.defaultProps = {
    close: () => {},
    className: '',
    nodeImportSuccess: {
        data: {},
    },
};

NodeSuccessImportForm = reduxForm({
    form: NAME_OF_FORMS.NODE_IMPORT_SUCCESS,
})(NodeSuccessImportForm);

const mapStateToForm = state => ({
    nodeImportSuccess: state.modals.nodeModals.nodeImportSuccess,
});

NodeSuccessImportForm = connect(mapStateToForm)(NodeSuccessImportForm);

class NodeSuccessImportModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        style: PropTypes.shape({}),
        nodeImportSuccess: PropTypes.shape({
            open: PropTypes.bool,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {},
        style: {},
        nodeImportSuccess: {
            open: false,
        },
    };
    close = () => {
        this.props.dispatch(closeSuccessNodeImportModal());
        this.props.dispatch(closeImportNodeModal());
    };
    
    render() {
        const title = NODE_MODAL.NODE_SUCCESS_IMPORT_MODAL.TITLE;
        const { style } = this.props;
        
        return (
            <Modal
                contentLabel="nodeError"
                isOpen={this.props.nodeImportSuccess.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header" data-id="node-success-import-title">
                        {title}
                    </span>
                    <NodeSuccessImportForm
                        className="Modal-Form"
                        close={this.close}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    nodeImportSuccess: state.modals.nodeModals.nodeImportSuccess,
});

export default connect(mapStateToProps)(NodeSuccessImportModal);
