import React from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';

import { NAME_OF_FORMS, PROJECT_MODALS, COMPONENTS } from '../../common';
import { formatTimeZoneOffset, getTimeZones } from './../../utils';
import { closeProjectDetailsModal } from '../../stores/actions';


let ProjectDetailsForm = (props) => {
    const { close, params, className } = props;
    const timezones = getTimeZones();
    const projectTZ = timezones.find(timezone => timezone === params.timezone);

    return (
        <form className={className}>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.COMMON.NAME}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="project-details-name">{params.name}</div>
            </div>
            
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{PROJECT_MODALS.DETAIL_MODAL.FORM.TIME_ZONE}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="project-details-timezone">{projectTZ ? formatTimeZoneOffset(projectTZ) : ''}</div>
            </div>
            
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{PROJECT_MODALS.DETAIL_MODAL.FORM.MANAGER}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="project-details-manager">{params.manager}</div>
            </div>
            
            <div className="Form-Buttons OneBtn">
                <button type="button" data-id="project-details-close" onClick={close}>{COMPONENTS.BUTTONS.CLOSE}</button>
            </div>
        </form>
    );
};

ProjectDetailsForm.propTypes = {
    close: PropTypes.func,
    className: PropTypes.string,
    params: PropTypes.shape({
        name: PropTypes.string,
        manager: PropTypes.string,
    }),
};

ProjectDetailsForm.defaultProps = {
    close: () => {
    },
    className: '',
    params: {
        name: '',
        manager: '',
    },
};

ProjectDetailsForm = reduxForm({
    form: NAME_OF_FORMS.PROJECT_DETAILS,
})(ProjectDetailsForm);


class ProjectDetailsModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        projectDetails: PropTypes.shape({
            params: PropTypes.shape({
                uid: PropTypes.string,
                name: PropTypes.string,
            }),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({}),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        projectDetails: {
            params: {
                uid: '',
                name: '',
            },
            open: false,
        },
        style: {},
    };
    
    close = () => {
        this.props.dispatch(closeProjectDetailsModal());
    };
    
    render() {
        const { style } = this.props;
        return (
            <Modal
                contentLabel="projectDetails"
                isOpen={this.props.projectDetails.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis">
                        {COMPONENTS.FIELDS.COMMON.VIEW_INFORMATION_FUNC(this.props.projectDetails.params ? this.props.projectDetails.params.name : '')}
                    </span>
                    <ProjectDetailsForm
                        className="Modal-Form"
                        close={this.close}
                        params={this.props.projectDetails.params}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    projectDetails: state.modals.projectModals.projectDetails,
});

export default connect(mapStateToProps)(ProjectDetailsModal);
