import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import { NAME_OF_FORMS } from 'common/constants';
import { SHIFTS_MODAL } from 'common/ui-labels';
import { closeShiftDeleteModal, locationShiftDelete, clearAdminPageSelectedItems } from 'stores/actions';
import DeleteButtons from 'components/modals/DeleteButtons';


let ShiftDeleteForm = (props) => {
    const { close, handleSubmit, className, shiftsToDelete, submitted } = props;
    const isBatchDelete = Array.isArray(shiftsToDelete);
    const message = (isBatchDelete) ? SHIFTS_MODAL.DELETE.DELETE_SELECTED_SHIFTS : SHIFTS_MODAL.DELETE.DELETE_SHIFT(shiftsToDelete.name);

    return (
        <form className={className}>
            {
                isBatchDelete && <div className="Form-Confirmation info-text" data-id="shift-delete-message">
                    { SHIFTS_MODAL.DELETE.NUMBER_OF_SHIFTS_SELECTED(<b>{shiftsToDelete.length}</b>) }
                </div>
            }
            <div className="Form-DeleteTitle confirmation" data-id="shift-delete-confirmation">
                {message}
            </div>
    
            <DeleteButtons submit={handleSubmit} close={close} submitted={submitted} dataId="shift" />
        </form>
    );
};

ShiftDeleteForm.propTypes = {
    close: PropTypes.func,
    handleSubmit: PropTypes.func,
    className: PropTypes.string,
    submitted: PropTypes.bool,
    shiftsToDelete: PropTypes.oneOfType([
        PropTypes.shape({
            name: PropTypes.string,
            uid: PropTypes.string,
        }),
        PropTypes.array,
    ]),
};

ShiftDeleteForm.defaultProps = {
    handleSubmit: () => { },
    close: () => { },
    className: '',
    submitted: false,
    shiftsToDelete: {
        name: '',
        uid: '',
    },
};

ShiftDeleteForm = reduxForm({
    form: NAME_OF_FORMS.SHIFT_DELETE,
})(ShiftDeleteForm);


class ShiftDeleteModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        shiftDelete: PropTypes.shape({
            open: PropTypes.bool,
            params: PropTypes.oneOfType([
                PropTypes.shape({ name: PropTypes.string }),
                PropTypes.arrayOf(PropTypes.shape()),
            ]),
        }),
        style: PropTypes.shape(),
        locations: PropTypes.arrayOf(PropTypes.shape({})),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        shiftDelete: {
            open: false,
            params: {
                name: '',
            },
        },
        style: {},
        locations: [],
    };
    
    constructor(props) {
        super(props);
        this.state = {
            submitted: false,
        };
    }
    
    close = () => {
        this.props.dispatch(closeShiftDeleteModal());
    };

    clearSelectedItems = () => {
        this.props.dispatch(clearAdminPageSelectedItems());
    };

    deleteShift = (uids, locations) => {
        this.props.dispatch(locationShiftDelete({ uids, locations }));
    };

    submit = () => {
        this.setState({ submitted: true });
        const { params } = this.props.shiftDelete;
        const isBatchDelete = Array.isArray(params);
        const uids = [];
        let locations = [];
        if (isBatchDelete) {
            const shiftUids = params.map((shift) => {
                const location = this.props.locations.find(loc => loc.uid === shift.location_uid);
                const alreadyAdded = locations.find(loc => loc.uid === shift.location_uid);
                if (location && !alreadyAdded) {
                    locations.push(location);
                }
                return shift.uid;
            });
            uids.push(...shiftUids);
        } else {
            uids.push(this.props.shiftDelete.params.uid);
            locations = [this.props.locations.find(loc => loc.uid === this.props.shiftDelete.params.location_uid)];
        }
        
        this.deleteShift(uids, locations);
        this.clearSelectedItems();
        this.close();
    };
    
    render() {
        const { style, shiftDelete } = this.props;

        return (
            <Modal
                contentLabel="shiftDelete"
                isOpen={shiftDelete.open}
                shouldCloseOnOverlayClick={false}
                onAfterClose={() => {
                    this.setState({ submitted: false });
                }}
                onRequestClose={this.close}
                style={style}
            >
                <div className="RPP-Modal">
                    <ShiftDeleteForm
                        className="Modal-Form"
                        submitted={this.state.submitted}
                        close={this.close}
                        onSubmit={this.submit}
                        shiftsToDelete={shiftDelete.params}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    shiftDelete: state.modals.shiftModals.shiftDelete,
    locations: state.entities.locations,
});

export default connect(mapStateToProps)(ShiftDeleteModal);
