import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import { injectIntl } from 'react-intl';

import { NAME_OF_FORMS } from 'common/constants';
import { COMPONENTS, SHIFTS_MODAL } from 'common/ui-labels';
import { closeShiftDetailsModal } from 'stores/actions';
import { convertNumbersToWeekDays } from 'utils/formatters';

let ShiftDetailsForm = (props) => {
    const { close, params, className, intl } = props;
    return (
        <form className={className}>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{SHIFTS_MODAL.DETAIL.SHIFT_NAME}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="shift-details-name">
                    {params.name}
                </div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{SHIFTS_MODAL.DETAIL.LOCATION_NAME}</div>
                <div
                    className="Form-Value col-md-8 multiple-lines-ellipsis"
                    data-id="shift-details-name"
                    data-cy="shift-details-location-name"
                >
                    {params.location_name}
                </div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.SHIFT.WEEKDAYS}</div>
                <div
                    className="Form-Value col-md-8 multiple-lines-ellipsis"
                    data-id="shift-details-name"
                    data-cy="shift-details-weekdays"
                >
                    {params.weekdays && convertNumbersToWeekDays(params.weekdays, intl).join(', ')}
                </div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{SHIFTS_MODAL.DETAIL.START_TIME}</div>
                <div
                    className="Form-Value col-md-8 multiple-lines-ellipsis"
                    data-id="shift-details-name"
                    data-cy="shift-details-start-time"
                >
                    {params.start_time && params.start_time.format('HH:mm')}
                </div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{SHIFTS_MODAL.DETAIL.END_TIME}</div>
                <div
                    className="Form-Value col-md-8 multiple-lines-ellipsis"
                    data-id="shift-details-name"
                    data-cy="shift-details-end-time"
                >
                    {params.end_time && params.end_time.format('HH:mm')}
                </div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{SHIFTS_MODAL.EXPECTED_PERSON}</div>
                <div
                    className="Form-Value col-md-8 multiple-lines-ellipsis"
                    data-id="shift-details-name"
                    data-cy="shift-details-expected-person"
                >
                    {params.expected_person || SHIFTS_MODAL.DETAIL.NOT_SPECIFIED}
                </div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{SHIFTS_MODAL.EXPECTED_VEHICLE}</div>
                <div
                    className="Form-Value col-md-8 multiple-lines-ellipsis"
                    data-id="shift-details-name"
                    data-cy="shift-details-expected-vehicle"
                >
                    {params.expected_vehicles || SHIFTS_MODAL.DETAIL.NOT_SPECIFIED}
                </div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{SHIFTS_MODAL.EXPECTED_OTHERS}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="shift-details-expected-others" >
                    {params.expected_others || SHIFTS_MODAL.DETAIL.NOT_SPECIFIED}
                </div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.COMMON.ACTIVE}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="shift-details-active">
                    {params.active ? COMPONENTS.FIELDS.COMMON.ACTIVE : COMPONENTS.FIELDS.COMMON.STATUS_INACTIVE}
                </div>
            </div>
            <div className="Form-Buttons OneBtn">
                <button type="button" data-id="shift-details-close" onClick={close}>{COMPONENTS.BUTTONS.CLOSE}</button>
            </div>
        </form>
    );
};

ShiftDetailsForm.propTypes = {
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    close: PropTypes.func,
    className: PropTypes.string,
    params: PropTypes.shape({
        name: PropTypes.string,
        website: PropTypes.string,
        phone: PropTypes.string,
    }),
};

ShiftDetailsForm.defaultProps = {
    intl: {
        formatMessage: () => {
        },
    },
    close: () => {
    },
    className: '',
    params: {
        name: '',
        website: '',
        phone: '',
    },
};

ShiftDetailsForm = reduxForm({
    form: NAME_OF_FORMS.COMPANY_DETAILS,
})(injectIntl(ShiftDetailsForm));


class ShiftDetailsModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        shiftDetails: PropTypes.shape({
            open: PropTypes.bool,
            params: PropTypes.shape({
                name: PropTypes.string,
            }),
        }),
        style: PropTypes.shape(),
    };

    static defaultProps = {
        dispatch: () => {
        },
        shiftDetails: {
            open: false,
            params: {
                name: '',
            },
        },
        style: {},
    };

    close = () => {
        this.props.dispatch(closeShiftDetailsModal());
    };

    render() {
        const { style, shiftDetails } = this.props;

        const name = shiftDetails.params && shiftDetails.params.name;
        return (
            <Modal
                contentLabel="shiftDetails"
                isOpen={shiftDetails.open}
                onRequestClose={this.close}
                style={style}
            >

                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis">
                        {COMPONENTS.FIELDS.COMMON.VIEW_INFORMATION_FUNC(name)}
                    </span>
                    <ShiftDetailsForm
                        className="Modal-Form"
                        close={this.close}
                        params={shiftDetails.params}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    shiftDetails: state.modals.shiftModals.shiftDetails,
});

export default connect(mapStateToProps)(ShiftDetailsModal);
