import React from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import { NAME_OF_FORMS } from 'common/constants';
import { SUBSCRIBER_DELETE_MODAL } from 'common/ui-labels';
import { closeSubscriberDeleteModal, deleteSubscriber } from 'stores/actions';
import DeleteButtons from 'components/modals/DeleteButtons';


let SubscriberDeleteForm = (props) => {
    const { close, submit, className, initialValues, submitted } = props;

    const isBatchDelete = Array.isArray(initialValues);

    const message = (isBatchDelete)
        ? SUBSCRIBER_DELETE_MODAL.TITLE_MULTI
        : SUBSCRIBER_DELETE_MODAL.TITLE_FUNC(initialValues.name);
    
    return (
        <form className={className}>
            {
                isBatchDelete && <div className="Form-Confirmation info-text" data-id="subscribers-delete-message">
                    { SUBSCRIBER_DELETE_MODAL.NUMBER_OF_SUBSCRIBERS_SELECTED(<b>{initialValues.length}</b>) }
                </div>
            }
            <div className="Form-DeleteTitle confirmation" data-id="subscribers-delete-confirmation">
                { message }
            </div>
    
            <DeleteButtons submit={submit} close={close} submitted={submitted} dataId="subscribers" />
        </form>
    );
};

SubscriberDeleteForm = reduxForm({
    form: NAME_OF_FORMS.SUBSCRIPTION_DELETE,
})(SubscriberDeleteForm);

SubscriberDeleteForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    submitted: PropTypes.bool,
    initialValues: PropTypes.oneOfType([
        PropTypes.shape({
            uid: PropTypes.string,
            name: PropTypes.string,
        }),
        PropTypes.array,
    ]),
    className: PropTypes.string,
};

SubscriberDeleteForm.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    submitted: false,
    initialValues: {
        uid: '',
        name: '',
    },
    className: '',
};

const mapStateToForm = state => ({
    initialValues: state.modals.subscriberModals.subscriberDelete.params,
});

SubscriberDeleteForm = connect(mapStateToForm)(SubscriberDeleteForm);

class SubscriberDeleteModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        subscriberDelete: PropTypes.shape({
            params: PropTypes.oneOfType([
                PropTypes.shape({
                    uid: PropTypes.string,
                    name: PropTypes.string,
                }),
                PropTypes.arrayOf(PropTypes.shape({
                    uid: PropTypes.string,
                })),
            ]),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({}),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        subscriberDelete: {
            params: {
                uid: '',
                name: '',
            },
            open: false,
        },
        style: {},
    };
    
    constructor(props) {
        super(props);
        this.state = {
            submitted: false,
        };
    }

    close = () => {
        this.props.dispatch(closeSubscriberDeleteModal());
    };
    
    submit = () => {
        this.setState({ submitted: true });
        if (this.props.subscriberDelete.params.uid) {
            this.props.dispatch(deleteSubscriber({ uid: this.props.subscriberDelete.params.uid }));
        } else {
            this.props.subscriberDelete.params.forEach((subscriber) => {
                this.props.dispatch(deleteSubscriber({ uid: subscriber.uid }));
            });
        }
        
        this.props.dispatch(closeSubscriberDeleteModal());
    };
    
    render() {
        const { style } = this.props;

        return (
            <Modal
                contentLabel="subscriberDelete"
                isOpen={this.props.subscriberDelete.open}
                shouldCloseOnOverlayClick={false}
                onAfterClose={() => {
                    this.setState({ submitted: false });
                }}
                onRequestClose={this.close}
                style={style}
            >
                <div className="RPP-Modal">
                    <SubscriberDeleteForm
                        className="Modal-Form"
                        submitted={this.state.submitted}
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    subscriberDelete: state.modals.subscriberModals.subscriberDelete,
});

export default connect(mapStateToProps)(SubscriberDeleteModal);
