import React from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import { closeSubscriberDetailsModal } from 'stores/actions';
import { NAME_OF_FORMS, COMPONENTS, NAMES_OF_TABS } from 'common';


let SubscriberDetailsForm = (props) => {
    const { close, params, className } = props;
    return (
        <form className={className}>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.SUBSCRIBER.SUBSCRIBER_NAME}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="subscribers-details-name">{params.name}</div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{NAMES_OF_TABS.NOTIFICATIONS}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="subscribers-details-notifications">
                    {params.notificationList.map(x => <span key={x}>{x}<br /></span>)}
                </div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.USER.EMAIL_ADDRESS}</div>
                <div className="Form-Value col-md-8 multiple-lines-ellipsis" data-id="subscribers-details-email">{params.email}</div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.USER.PHONE_NUMBER}</div>
                <div className="Form-Value col-md-8" data-id="subscribers-details-phone">{params.phone}</div>
            </div>
            <div className="Form-Buttons OneBtn">
                <button type="button" data-id="subscribers-details-cancel" onClick={close}>{COMPONENTS.BUTTONS.CLOSE}</button>
            </div>
        </form>
    );
};

SubscriberDetailsForm.propTypes = {
    close: PropTypes.func,
    className: PropTypes.string,
    params: PropTypes.shape({
        name: PropTypes.string,
        email: PropTypes.string,
        phone: PropTypes.string,
        notificationList: PropTypes.arrayOf(PropTypes.string),
    }),
};

SubscriberDetailsForm.defaultProps = {
    close: () => {
    },
    className: '',
    params: {
        name: '',
        manager: '',
        phone: '',
        notificationList: [],
    },
};

SubscriberDetailsForm = reduxForm({
    form: NAME_OF_FORMS.SUBSCRIPTION_DETAILS,
})(SubscriberDetailsForm);

const mapStateToForm = (state) => {
    const params = state.modals.subscriberModals.subscriberDetails.params || {};
    const { notifications } = state.entities;
    
    if (params.notifications) {
        params.notificationList = params.notifications.map((uid) => {
            const notification = notifications.find(x => x.uid === uid);
            if (notification) {
                return notification.name;
            }
            
            return null;
        }).filter(x => x);
    }
    
    return {
        params,
    };
};

SubscriberDetailsForm = connect(mapStateToForm)(SubscriberDetailsForm);

class SubscriberDetailsModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        subscriberDetails: PropTypes.shape({
            params: PropTypes.shape({
                uid: PropTypes.string,
                name: PropTypes.string,
            }),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({}),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        subscriberDetails: {
            params: {
                uid: '',
                name: '',
            },
            open: false,
        },
        style: {},
    };
    
    close = () => {
        this.props.dispatch(closeSubscriberDetailsModal());
    };
    
    render() {
        const { style, subscriberDetails } = this.props;
        
        const title = COMPONENTS.FIELDS.COMMON.VIEW_INFORMATION_FUNC(subscriberDetails.params ? subscriberDetails.params.name : '');
        
        return (
            <Modal
                contentLabel="subscriberDetails"
                isOpen={this.props.subscriberDetails.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis" data-id="subscribers-details-title">
                        {title}
                    </span>
                    <SubscriberDetailsForm className="Modal-Form" close={this.close} />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    subscriberDetails: state.modals.subscriberModals.subscriberDetails,
});

export default connect(mapStateToProps)(SubscriberDetailsModal);
