import React from 'react';
import { reduxForm, Field, arrayRemove, arrayPush } from 'redux-form';
import { COMPONENTS, NAME_OF_FORMS, TRACKABLE_MODAL } from 'common';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { injectIntl } from 'react-intl';
import { onMouseDownScrollPrevent } from 'utils/htmlUtils';
import { toUpperCase } from 'utils/utils';
import { Node } from 'stores/classes/Selectors';
import Trackable from 'stores/classes/Trackable';
import SelectComponent from 'components/modals/SelectComponent';
import { bulkAssignAddTrackable, bulkAssignRemoveTrackable, bulkAssignUpdateTrackable, bulkAssignUpdateTag } from 'stores/actions';
import { Spinner } from 'components/Spinner';

let TrackableBulkAssignForm = (props) => {
    const {
        assignedItems, className, close, dispatch, invalid, selectedMacAddressMap, nodes, savedCount, submit,
        selectedTrackableMap, trackables, saving, savingError,
    } = props;
    const disabledAddBtn = saving
        || assignedItems.length >= trackables.length
        || assignedItems.length >= nodes.length
        || assignedItems.find((item) => !item.trackable_uid);
    const disableRemoveBtn = assignedItems.length <= 2;

    const onAddButtonClick = () => {
        dispatch(bulkAssignAddTrackable());
        dispatch(arrayPush(NAME_OF_FORMS.TRACKABLE_BULK_ASSIGN, 'assignedItems', {
            trackable_uid: null,
            mac_address: null,
        }));
    };

    return (
        <form className={className}>
            <div style={{ overflowY: 'auto', overflowX: 'hidden', maxHeight: '60vh', paddingRight: '10px' }} onMouseDown={onMouseDownScrollPrevent}>
                <div className="Form-Line row">
                    <div className="col-sm-1" />
                    <div className="col-sm-6 RPP-align-text-center">{TRACKABLE_MODAL.BULK_ASSIGN.TRACKABLES}</div>
                    <div className="col-sm-5 RPP-align-text-center">{TRACKABLE_MODAL.BULK_ASSIGN.NODES}</div>
                </div>
                {(assignedItems || []).map((item, index) => (
                    <div className="Form-Line row" key={`div-${index}`}>
                        <div className="col-sm-1">
                            <button
                                data-id={`trackable-bulk-assign-modal-remove-item-${index}`}
                                key={`remove-${index}`}
                                className={`unstyled-button ${disableRemoveBtn ? 'disabled' : ''}`}
                                style={{ paddingTop: '3px', paddingLeft: '5px' }}
                                disabled={disableRemoveBtn || saving}
                                onClick={(e) => {
                                    e.preventDefault();
                                    dispatch(bulkAssignRemoveTrackable(index));
                                    dispatch(arrayRemove(NAME_OF_FORMS.TRACKABLE_BULK_ASSIGN, 'assignedItems', index));
                                }}
                            >
                                <i className="fa fa-times fa-2x table-action-icon" />
                            </button>
                        </div>
                        <div className="col-sm-6" data-id={`trackable-bulk-assign-modal-trackable-item-${index}`}>
                            <Field
                                name={`assignedItems.${index}.trackable_uid`}
                                simpleValue
                                clearable
                                isDisabled={saving}
                                component={SelectComponent}
                                onChange={(e, trackable_uid) => {
                                    dispatch(bulkAssignUpdateTrackable({ trackable_uid, index }));
                                }}
                                options={trackables.filter((tko) => !selectedTrackableMap[tko.uid] || item.trackable_uid === tko.uid)}
                            />
                        </div>
                        <div
                            className="col-sm-5"
                            data-id={`trackable-bulk-assign-modal-mac-address-item-${index}`}
                        >
                            <Field
                                name={`assignedItems.${index}.mac_address`}
                                simpleValue
                                clearable
                                isDisabled={saving}
                                component={SelectComponent}
                                onChange={(e, mac_address) => {
                                    dispatch(bulkAssignUpdateTag({ index, mac_address }));
                                }}
                                options={nodes.filter((node) => !selectedMacAddressMap[toUpperCase(node.mac_address)]
                                    || toUpperCase(item.mac_address) === toUpperCase(node.mac_address))}
                            />
                        </div>
                    </div>
                ))}

                <div className="Form-Line row">
                    <div className="col-md-12">
                        <button
                            className="unstyled-button"
                            data-id="trackable-bulk-assign-modal-add-button table-action-icon"
                            style={{ paddingLeft: '7px' }}
                            onClick={onAddButtonClick}
                            disabled={disabledAddBtn}
                        >
                            <i className="fa fa-plus fa-2x" />
                        </button>
                    </div>
                </div>
                <div className="Form-Line row">
                    <div className="col-md-12">
                        <span style={{ paddingLeft: '7px', color: 'green', display: savingError ? 'block' : 'none' }}>
                            {TRACKABLE_MODAL.BULK_ASSIGN.STATUSES.CREATED_ASSOCIATIONS(savedCount)}
                        </span>
                    </div>
                </div>
            </div>

            <div className="Form-Buttons">
                <button
                    type="button"
                    data-id="trackable-bulk-assign-modal-save-button"
                    disabled={invalid || saving}
                    onClick={submit}
                >
                    {COMPONENTS.BUTTONS.SAVE}
                    <Spinner
                        style={{ marginLeft: '10px' }}
                        show={saving}
                    />
                </button>
                <button
                    type="button"
                    data-id="trackable-bulk-assign-modal-cancel-button"
                    onClick={close}
                    disabled={saving}
                >
                    {COMPONENTS.BUTTONS.CANCEL}
                </button>
            </div>
        </form>
    );
};

TrackableBulkAssignForm.propTypes = {
    assignedItems: PropTypes.arrayOf(PropTypes.shape({})),
    className: PropTypes.string,
    close: PropTypes.func,
    dispatch: PropTypes.func,
    idxMacAddressMap: PropTypes.shape({}),
    idxTrackableMap: PropTypes.shape({}),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    invalid: PropTypes.bool,
    macAddressMap: PropTypes.shape({}),
    nodes: PropTypes.arrayOf(PropTypes.shape({})),
    savedCount: PropTypes.number,
    submit: PropTypes.func,
    saving: PropTypes.bool,
    savingError: PropTypes.bool,
    trackableMap: PropTypes.shape({}),
    selectedMacAddressMap: PropTypes.shape({}),
    selectedTrackableMap: PropTypes.shape({}),
    trackables: PropTypes.arrayOf(PropTypes.shape({})),
};

TrackableBulkAssignForm.defaultProps = {
    assignedItems: [],
    className: '',
    close: () => {},
    dispatch: () => {},
    idxMacAddressMap: {},
    idxTrackableMap: {},
    intl: {
        formatMessage: () => {},
    },
    invalid: false,
    macAddressMap: {},
    nodes: [],
    savedCount: 0,
    submit: () => {},
    saving: false,
    savingError: false,
    trackableMap: {},
    selectedMacAddressMap: {},
    selectedTrackableMap: {},
    trackables: [],
};

const validate = (values, props) => {
    const errors = {};
    if (!values.assignedItems || values.assignedItems.length < 2) {
        return { _error: 'Invalid number of associations. The minimal number is equal to 2.' };
    }
    if (values && values.assignedItems) {
        errors.assignedItems = values.assignedItems.map((item) => {
            const e = {};
            if (!item.trackable_uid) { e.trackable_uid = COMPONENTS.VALIDATION.REQUIRED_FUNC(props.intl); }
            if (!item.mac_address) { e.mac_address = COMPONENTS.VALIDATION.REQUIRED_FUNC(props.intl); }
            return e;
        });
    }
    return errors;
};

TrackableBulkAssignForm = reduxForm({
    form: NAME_OF_FORMS.TRACKABLE_BULK_ASSIGN,
    validate,
})(TrackableBulkAssignForm);

const mapStateToForm = (state) => {
    const project = state.appContext.project;

    const {
        assignedItems, idxMacAddressMap, idxTrackableMap, selectedMacAddressMap, savedCount, saving, selectedTrackableMap, savingError,
    } = state.modals.trackableModals.trackableBulkAssign;

    const trackables = Trackable.getNotAssociatedTrackables(state).map((trackable) => trackable.formattedTrackablesAddUidName());
    const nodes = Node.getNotAssociatedNode(state, project);

    const initialValues = {
        assignedItems,
    };

    return {
        assignedItems,
        idxMacAddressMap,
        idxTrackableMap,
        initialValues,
        selectedMacAddressMap,
        nodes,
        savedCount,
        saving,
        savingError,
        selectedTrackableMap,
        trackables,
    };
};

TrackableBulkAssignForm = connect(mapStateToForm)(injectIntl(TrackableBulkAssignForm));

export { TrackableBulkAssignForm };
