import React from 'react';
import PropTypes from 'prop-types';
import { change, Field } from 'redux-form';
import { NAME_OF_FORMS, TRACKABLE_CATEGORY } from 'common/constants';
import { COMPONENTS, DB_NAMES, TRACKABLE_MODAL } from 'common/ui-labels';
import RenderTooltipHelper from 'components/RenderTooltipHelper';
import SelectComponent from 'components/modals/SelectComponent';
import { isAssetTag } from 'utils/utils';

function getCategoryOptions(intl) {
    return [
        {value: TRACKABLE_CATEGORY.PERSON, label: DB_NAMES.PERSON(intl)},
        {value: TRACKABLE_CATEGORY.VEHICLE, label: DB_NAMES.VEHICLE(intl)},
        {value: TRACKABLE_CATEGORY.ASSET, label: DB_NAMES.ASSET(intl)},
        {value: TRACKABLE_CATEGORY.UNSPECIFIED, label: DB_NAMES.UNSPECIFIED(intl)},
    ];
}

export function CategoryForm({ dispatch, category_checkbox, intl, category }) {
    const options = getCategoryOptions(intl);
    return (
        <section>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4" data-id="trackable-bulk-edit-category-checkbox-text">
                    {TRACKABLE_MODAL.EDIT.FORM.TRACKABLE_CATEGORY_FUNC(intl)}
                    <RenderTooltipHelper
                        tooltipText={TRACKABLE_MODAL.EDIT.FORM.TRACKABLE_CATEGORY_HELP_FUNC(intl)}
                        placement="bottom"
                    />
                </div>

                <div className="col-md-1" data-id="trackable-bulk-edit-category-checkbox">
                    <Field
                        onChange={(e, newVal) => {
                            if (!newVal) {
                                dispatch(change(NAME_OF_FORMS.TRACKABLE_BULK_EDIT, 'buffer_checkbox', false));
                                dispatch(change(NAME_OF_FORMS.TRACKABLE_BULK_EDIT, 'pws_checkbox', false));
                            }
                        }}
                        name="category_checkbox"
                        id="category_checkbox"
                        component="input"
                        type="checkbox"
                        style={{ width: '19px', height: '19px' }}
                    />
                </div>
            </div>
            <div className="Form-Line row" style={{ textAlign: 'center', marginTop: '15px', display: category_checkbox ? 'block' : 'none' }}>
                <div className="Form-Label col-md-4" />
                <div className="col-md-8" data-id="trackable-bulk-edit-category">
                    <Field
                        onChange={(e, newVal) => {
                            if (category !== newVal) {
                                dispatch(change(NAME_OF_FORMS.TRACKABLE_BULK_EDIT, 'role', ''));
                            }
                            if (isAssetTag(newVal)) {
                                dispatch(change(NAME_OF_FORMS.TRACKABLE_BULK_EDIT, 'buffer_checkbox', false));
                                dispatch(change(NAME_OF_FORMS.TRACKABLE_BULK_EDIT, 'pws_checkbox', false));
                            }
                        }}
                        clearable={false}
                        className="Form-Input"
                        name="category"
                        component={SelectComponent}
                        simpleValue
                        placeholder={COMPONENTS.SELECT_COMPONENT_PLACEHOLDER(intl)}
                        noResultsText={COMPONENTS.SELECT_COMPONENT_NO_RESULTS_TEXT}
                        options={options}
                    />
                </div>
            </div>
        </section>
    );
}

CategoryForm.propTypes = {
    category_checkbox: PropTypes.bool,
    category: PropTypes.string,
    dispatch: PropTypes.func,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
}

CategoryForm.defaultProps = {
    category_checkbox: false,
    category: '',
    dispatch: () => {},
    intl: {
        formatMessage: () => {},
    },
}
