import React from 'react';
import PropTypes from 'prop-types';
import { change, Field } from 'redux-form';
import RenderTextArea from 'components/modals/RenderTextArea';
import { NAME_OF_FORMS } from 'common/constants';
import { COMMON_LABELS } from 'common/ui-labels';

export function CustomInfoForm({ custom_info, dispatch, custom_info_checkbox, intl }) {
    return (
        <section>
            <div className="Form-Line row" style={{ textAlign: 'center', marginTop: '15px' }}>
                <div className="Form-Label col-md-4" style={{ fontSize: '1.2em' }}>{COMMON_LABELS.CUSTOM_INFO}</div>
                <div className="col-md-6 text-left" data-id="zone-add-configuration-active">
                    <Field
                        name="custom_info_checkbox"
                        component="input"
                        type="checkbox"
                        onChange={() => {
                            if (custom_info === undefined) {
                                dispatch(change(NAME_OF_FORMS.ZONE_BULK_EDIT_ADMIN_PAGE, 'custom_info', ''));
                            }
                        }}
                    />
                </div>
            </div>
            <div className="Form-Line row" style={{ textAlign: 'center', marginTop: '15px', display: custom_info_checkbox ? 'block' : 'none' }}>
                <div className="Form-Label col-md-4" style={{ fontSize: '1.2em', marginTop: '-20px' }}>{(custom_info || '').length}/120</div>
                <div className="col-md-8">
                    <Field
                        name="custom_info"
                        dataId="custom_info_id"
                        component={RenderTextArea}
                        rows="5"
                        maxLength={256}
                        onKeyPress={(e) => {
                            if (e.key === 'Enter') {
                                e.preventDefault();
                            }
                        }}
                        placeholder={COMMON_LABELS.ENTER_INFO_FUNC(intl)}
                    />
                </div>
            </div>
        </section>
    );
}

CustomInfoForm.propTypes = {
    custom_info: PropTypes.string,
    dispatch: PropTypes.func,
    custom_info_checkbox: PropTypes.bool,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
}

CustomInfoForm.defaultProps = {
    custom_info: '',
    dispatch: () => {},
    custom_info_checkbox: false,
    intl: {
        formatMessage: () => {},
    },
}
