import React from 'react';
import PropTypes from 'prop-types';

import { DEFAULT_VALUES } from 'common';

class CoverageAnnouncerWidget extends React.Component {
    componentDidMount() {
        const {
            uiSetting, angle, distance, distance_max,
        } = this.props;

        this.drawCoverageAnnouncer(uiSetting, angle, distance, distance_max);
    }

    drawCoverageAnnouncer = () => {
        const {
            uiSetting: { id, size, fillColor },
            angle,
            distance,
            distance_max,
        } = this.props;

        const adjustDistance = distance > 0 ? distance : 0;

        const canvas = document.getElementById(id);
        if (canvas) {
            const widget_half_size = size / 2;
            const ctx = canvas.getContext('2d');
            const strokewidth = parseInt((widget_half_size * adjustDistance) / distance_max);
            const degrees = angle;
            const radians = degrees * (Math.PI / 180);
            ctx.save();
            ctx.clearRect(0, 0, size, size);
            ctx.lineWidth = strokewidth;
            ctx.beginPath();
            ctx.translate(widget_half_size, widget_half_size);
            ctx.rotate(-radians / 2);
            const radius = strokewidth / 2;
            ctx.arc(0, 0, radius, 0, radians);
            ctx.strokeStyle = fillColor;
            ctx.stroke();
            ctx.restore();
        }
    };

    render() {
        const { uiSetting: { id, size }, angle, distance, distance_max } = this.props;

        this.drawCoverageAnnouncer(this.props.uiSetting, angle, distance, distance_max);

        return (
            <div
                className="coverageAnnouncerWrapper"
                style={{ width: size, height: size }}
            >
                <canvas
                    className="pull-left"
                    id={id}
                    width={size}
                    height={size}
                />
                <span className="coverageAnnouncerImage">
                    <i className="fa fa-truck" />
                </span>
            </div>
        );
    }
}

CoverageAnnouncerWidget.propTypes = {
    uiSetting: PropTypes.shape({
        id: PropTypes.string,
        fillColor: PropTypes.string,
        size: PropTypes.number,
    }),
    angle: PropTypes.number,
    distance: PropTypes.number,
    distance_max: PropTypes.number,
};

CoverageAnnouncerWidget.defaultProps = {
    uiSetting: {
        id: 'coverageAnnouncer',
        fillColor: 'lightBlue',
        size: 100,
    },
    distance: DEFAULT_VALUES.LLL_COVERAGE_DISTANCE,
    angle: DEFAULT_VALUES.LLL_COVERAGE_ANGLE,
    distance_max: DEFAULT_VALUES.LLL_DISTANCE_MAX,
};

export { CoverageAnnouncerWidget };
