import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import PropTypes from 'prop-types';
import { NAME_OF_FORMS, TRACKABLE_BULK_EDIT, COMPONENTS } from 'common';
import { closeTrackableBulkEditWarningModal, bulkEditTrackable } from 'stores/actions';

let TrackableBulkEditWarningForm = (props) => {
    const { close, save, className } = props;
    return (
        <form className={className}>
            <div style={{ fontSize: '1.3em', marginTop: '10px' }} data-id="trackable-collision-validate-message">{TRACKABLE_BULK_EDIT.WARNING}</div>
            <div className="Form-Buttons">
                <button type="button" data-id="trackable-validate-save" onClick={save}>{COMPONENTS.BUTTONS.SAVE}</button>
                <button type="button" data-id="trackable-validate-cancel" onClick={close}>{COMPONENTS.BUTTONS.CANCEL}</button>
            </div>
        </form>
    );
};

TrackableBulkEditWarningForm.propTypes = {
    close: PropTypes.func,
    save: PropTypes.func,
    className: PropTypes.string,
};

TrackableBulkEditWarningForm.defaultProps = {
    close: () => {},
    save: () => {},
    className: '',
};

TrackableBulkEditWarningForm = reduxForm({
    form: NAME_OF_FORMS.TRACKABLE_BULK_EDIT_WARNING,
})(TrackableBulkEditWarningForm);

class TrackableBulkEditWarningModal extends React.Component {
    close = () => {
        this.props.dispatch(closeTrackableBulkEditWarningModal());
    };
    
    save = () => {
        this.props.dispatch(bulkEditTrackable(this.props.trackableBulkEditWarning.params));
        this.props.dispatch(closeTrackableBulkEditWarningModal());
    };
    
    render() {
        const { style, trackableBulkEditWarning } = this.props;
        
        return (
            <Modal
                contentLabel="trackableLowLatencyLinkValidation"
                isOpen={trackableBulkEditWarning.open}
                shouldCloseOnOverlayClick={false}
                onRequestClose={this.close}
                style={style}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header2" data-id="trackable-collision-validation-title">
                        {TRACKABLE_BULK_EDIT.WARNING_TITLE}
                    </span>
                    <TrackableBulkEditWarningForm
                        className="Modal-Form"
                        close={this.close}
                        save={this.save}
                    />
                </div>
            </Modal>
        );
    }
}
TrackableBulkEditWarningModal.propTypes = {
    dispatch: PropTypes.func,
    trackableBulkEditWarning: PropTypes.shape({
        open: PropTypes.bool,
        params: PropTypes.shape({}),
    }),
    style: PropTypes.shape({}),
};

TrackableBulkEditWarningModal.defaultProps = {
    dispatch: () => { },
    trackableBulkEditWarning: {},
    style: {},
};

const mapStateToProps = (state) => ({
    trackableBulkEditWarning: state.modals.trackableModals.trackableBulkEditWarning,
});

export default connect(mapStateToProps)(TrackableBulkEditWarningModal);
