import React, { Fragment } from 'react';
import { Field, change } from 'redux-form';
import PropTypes from 'prop-types';
import 'react-select/dist/react-select.css';
import { NAME_OF_FORMS, TRACKABLE_MODAL, COMPONENTS, POS_UPDATE_INTERVAL, DISABLED_FIELD_TEXT, TRACKABLE_CATEGORY } from 'common';
import { checkboxClick, saveStationaryPosition, saveTrackablePositionFromState } from 'stores/actions';
import { preventInputNotNumber, filterSelectBoxOptions } from 'utils/utils';
import { lengthToDegree } from 'utils/simpleUtils';
import { formatDbNameToHumanReadable } from 'utils/htmlUtils';
import SelectComponent from 'components/modals/SelectComponent';
import RenderBox from 'components/modals/RenderBox';
import RenderCheckbox from 'components/modals/RenderCheckbox';
import RenderTooltipHelper from 'components/RenderTooltipHelper';
import RenderSimpleTimeDurationField from 'components/modals/RenderSimpleTimeDurationField';
import { renderReducedField, renderPosField, getNoneOptionForUpdateInterval, getUpdateIntervalValues } from './trackableModalUtils';


function updateStationary(dispatch, e, uid, selectedArea, trackableCategory, clearRoleField) {
    const stationaryChecked = e.target.checked;
    dispatch(change(NAME_OF_FORMS.TRACKABLE_EDIT, 'role', ''));

    dispatch(checkboxClick({ stationary: stationaryChecked }));

    const positionUpdateInterval = stationaryChecked
        ? getNoneOptionForUpdateInterval(trackableCategory)
        : getUpdateIntervalValues().default;
    dispatch(change(
        NAME_OF_FORMS.TRACKABLE_EDIT,
        'position_update_interval',
        positionUpdateInterval,
    ));
    dispatch(saveTrackablePositionFromState({ trackableUid: uid, sublocationUid: selectedArea }));
    clearRoleField();
}

const advancedOptionsSection = ({
    dispatch,
    isAdvancedOptions,
    posReportInterval,
    intl,
    siteList,
    areaList,
    selectedArea,
    selectedSite,
    showMapClickTrackableEditModal,
    showMap,
    areaAutoSelection,
    isStationary,
    uid,
    isCategoryAsset,
    isStationaryDisabled,
    hideStationary,
    trackableCategory,
    clearRoleField,
}) => (
    <section>
        <div className="Form-Line row" style={{ marginTop: '2px' }}>
            <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.NODE.ADVANCED}</div>
            <div className="col-md-1 Custom-Rotated-Checkbox" data-id="trackable-edit-advanced">
                <Field
                    onChange={(e) => {
                        dispatch(checkboxClick({ advanced_options: e.target.checked }));
                    }}
                    name="advanced_options"
                    id="advanced_options"
                    component={RenderBox}
                    dataCy="advanced-options-checkbox"
                    type="checkbox"
                    style={{ width: '19px', height: '19px' }}
                />
            </div>
            <div
                className="col-md-7"
            />
        </div>
        <section style={{ display: isAdvancedOptions ? 'block' : 'none' }}>
            <Fragment key="default-height">
                <div className="Form-Line row" data-id="trackable-edit-default-height" style={{ marginTop: '2px' }}>
                    <Field
                        type="text"
                        onChange={(e) => {
                            preventInputNotNumber(e);
                            dispatch(checkboxClick({}));
                        }}
                        className="Form-Input"
                        name="defaultHeight"
                        dataCy="defaultHeight"
                        component={renderReducedField}
                        masked={false}
                        label={
                            isStationary
                                ? `${TRACKABLE_MODAL.EDIT.FORM.DEFAULT_HEIGHT_FUNC(intl)}*`
                                : TRACKABLE_MODAL.EDIT.FORM.DEFAULT_HEIGHT_FUNC(intl)
                        }
                    />
                </div>
            </Fragment>
            {hideStationary || <Fragment key="stationary_checkbox">
                <div className="Form-Line row">
                    <div className="Form-Label col-md-4">{COMPONENTS.FIELDS.NODE.STATIONARY}</div>
                    <div className="col-md-1">
                        <Field
                            onChange={e => updateStationary(dispatch, e, uid, selectedArea, trackableCategory, clearRoleField)}
                            name="stationary"
                            dataId="trackable-edit-stationary"
                            disabled={isStationaryDisabled}
                            component={RenderCheckbox}
                            title={
                                isStationaryDisabled
                                    ? DISABLED_FIELD_TEXT.STATIONARY_UNSUPPORTED_4_CATEGORY(intl, formatDbNameToHumanReadable(intl, trackableCategory))
                                    : ''
                            }
                        />
                    </div>
                    <div className="col-md-7" />
                </div>
            </Fragment>}
            <Fragment key="update_interval">
                <div className="Form-Line row" style={{ opacity: isStationary ? 0.6 : 1 }}>
                    <div htmlFor="name" className="Form-Label col-md-4">
                        {TRACKABLE_MODAL.EDIT.FORM.UPDATE_INTERVAL_FUNC(intl)}
                        <RenderTooltipHelper
                            tooltipText={TRACKABLE_MODAL.EDIT.FORM.UPDATE_INTERVAL_HELP_FUNC(intl)}
                        />
                    </div>
                    <div className="col-md-6" data-id="trackable-edit-position-update">
                        {
                            isCategoryAsset
                                ? <Field
                                    type="text"
                                    className="input"
                                    name="position_update_interval"
                                    component={RenderSimpleTimeDurationField}
                                    defaultValue={POS_UPDATE_INTERVAL.MIN}
                                    disabled={isStationary}
                                />
                                : <Field
                                    onChange={() => {
                                        dispatch(checkboxClick({}));
                                    }}
                                    clearable={false}
                                    className="Form-Input"
                                    name="position_update_interval"
                                    placeholder={COMPONENTS.SELECT_COMPONENT_PLACEHOLDER(intl)}
                                    noResultsText={COMPONENTS.SELECT_COMPONENT_NO_RESULTS_TEXT}
                                    options={posReportInterval}
                                    isDisabled={isStationary}
                                    component={SelectComponent}
                                />
                        }
                    </div>
                </div>
            </Fragment>
            {
                isStationary
                && (
                    <section>
                        <Fragment key="site_select">
                            <div className="Form-Line row">
                                <div htmlFor="name" className="Form-Label col-md-4">
                                    {COMPONENTS.FIELDS.SITE.SITE_FUNC(intl)}
                                </div>
                                <div className="col-md-6" data-id="trackable-edit-site">
                                    <Field
                                        onChange={(e, next) => {
                                            const currentSiteUid = next;
                                            areaAutoSelection(currentSiteUid);
                                        }}
                                        className="Form-Input"
                                        name="site"
                                        simpleValue
                                        clearable={false}
                                        placeholder={COMPONENTS.SELECT_COMPONENT_PLACEHOLDER(intl)}
                                        noResultsText={COMPONENTS.SELECT_COMPONENT_NO_RESULTS_TEXT}
                                        options={siteList}
                                        filterOptions={filterSelectBoxOptions}
                                        component={SelectComponent}
                                    />
                                </div>
                            </div>
                        </Fragment>
                        <Fragment key="button_map">
                            <div className="Form-Line row">
                                <div htmlFor="name" className="Form-Label col-md-4">
                                    {COMPONENTS.FIELDS.SITE.AREA_FUNC(intl)} *
                                </div>
                                <div className="col-md-6" data-id="trackable-edit-area">
                                    <Field
                                        onChange={() => {}}
                                        className="Form-Input"
                                        name="area"
                                        simpleValue
                                        clearable={false}
                                        placeholder={COMPONENTS.SELECT_COMPONENT_PLACEHOLDER(intl)}
                                        noResultsText={COMPONENTS.SELECT_COMPONENT_NO_RESULTS_TEXT}
                                        isDisabled={!selectedSite}
                                        options={areaList}
                                        filterOptions={filterSelectBoxOptions}
                                        component={SelectComponent}
                                    />
                                </div>
                                <div className="col-md-2">
                                    <button
                                        type="button"
                                        onClick={() => { dispatch(showMapClickTrackableEditModal()); }}
                                        data-id="trackable-edit-show-map"
                                        className="pull-right hover-button"
                                        disabled={!selectedArea}
                                    >
                                        {TRACKABLE_MODAL.EDIT.FORM.MAP}
                                        <i
                                            className={`fa fa-chevron-right show-map-icon${showMap ? ' rotate' : ''}`}
                                        />
                                    </button>
                                </div>
                            </div>
                        </Fragment>
                        <Fragment key="pos_x_y">
                            <div className="Form-Line row">
                                <div htmlFor="name" className="Form-Label col-md-4">
                                    {TRACKABLE_MODAL.EDIT.FORM.POSITION_COORDINATES}
                                </div>
                                <div className="col-md-6">
                                    <Field
                                        className="Form-Input"
                                        dataId="trackable-edit-pos-x"
                                        name="pos_x"
                                        component={renderPosField}
                                        label="x*"
                                        type="text"
                                        disabled={!selectedSite}
                                        onChange={(e) => {
                                            const inputNumber = preventInputNotNumber(e);
                                            const lng = lengthToDegree(inputNumber) * 10;
                                            dispatch(saveStationaryPosition({ stationaryPosition: { lng } }));
                                        }}
                                    />
                                    <Field
                                        className="Form-Input"
                                        dataId="trackable-edit-pos-y"
                                        name="pos_y"
                                        component={renderPosField}
                                        label="y*"
                                        type="text"
                                        disabled={!selectedSite}
                                        onChange={(e) => {
                                            const inputNumber = preventInputNotNumber(e);
                                            const lat = lengthToDegree(inputNumber) * 10;
                                            dispatch(saveStationaryPosition({ stationaryPosition: { lat } }));
                                        }}
                                    />
                                </div>
                            </div>
                        </Fragment>
                    </section>
                )
            }
        </section>
    </section>
);

advancedOptionsSection.propTypes = {
    dispatch: PropTypes.func,
    isAdvancedOptions: PropTypes.bool,
    isStationary: PropTypes.bool,
    hideStationary: PropTypes.bool,
    isStationaryDisabled: PropTypes.bool,
    isCategoryAsset: PropTypes.bool,
    trackableCategory: PropTypes.string,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    siteList: PropTypes.arrayOf(PropTypes.shape()),
    areaList: PropTypes.arrayOf(PropTypes.shape()),
    selectedArea: PropTypes.string,
    selectedSite: PropTypes.string,
    showMapClickTrackableEditModal: PropTypes.func,
    showMap: PropTypes.bool,
    posReportInterval: PropTypes.arrayOf(PropTypes.shape({
        value: PropTypes.number,
        label: PropTypes.string,
        type: PropTypes.string,
    })),
    areaAutoSelection: PropTypes.func,
    clearRoleField: PropTypes.func,
    uid: PropTypes.string,
};

advancedOptionsSection.defaultProps = {
    dispatch: () => { },
    isAdvancedOptions: false,
    isStationary: false,
    hideStationary: false,
    isStationaryDisabled: false,
    isCategoryAsset: false,
    trackableCategory: TRACKABLE_CATEGORY.UNSPECIFIED,
    intl: {
        formatMessage: () => {},
    },
    siteList: [],
    areaList: [],
    selectedArea: '',
    selectedSite: '',
    showMapClickTrackableEditModal: () => {},
    showMap: false,
    posReportInterval: [],
    areaAutoSelection: () => {},
    clearRoleField: () => {},
    uid: '',
};

export default advancedOptionsSection;
