import React from 'react';
import { Field } from 'redux-form';
import PropTypes from 'prop-types';

import 'react-select/dist/react-select.css';

import { COMPONENTS, TRACKABLE_MODAL } from 'common';
import { sortByField, isAssetTag, filterSelectBoxOptions, preventInputNotNumber } from 'utils';
import { checkboxClick } from 'stores/actions';
import store from '../../../stores/LocationStore';

import { renderField } from './trackableModalUtils';
import MultiSelectComponent from '../../../components/modals/MultiSelectComponent';

const renderBufferSection = ({
    dispatch,
    isBufferSelected,
    uid,
    intl,
    trackableCategory,
}) => {
    const trackables = store.getTrackables().reduce((r, tko) => {
        if (tko.uid !== uid) { r.push(tko.addValueLabelToValue()); }
        return r;
    }, []);
    const groups = store.getGroups().map(group => group.addValueLabelToValue());
    const options = sortByField([...trackables, ...groups], 'name');
    return (
        <section>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4">{TRACKABLE_MODAL.BUFFER}</div>
                <div className="col-md-1" data-id="trackable-edit-buffer">
                    <Field
                        onChange={(e) => {
                            dispatch(checkboxClick({ buffer: e.target.checked }));
                        }}
                        name="buffer"
                        props={{ disabled: isAssetTag(trackableCategory) || !trackableCategory, 'data-cy': 'trackable-edit-buffer' }}
                        id="buffer"
                        component="input"
                        type="checkbox"
                        style={{ width: '19px', height: '19px' }}
                    />
                </div>
            </div>
            <div
                className="Form-Line row"
                style={{ display: isBufferSelected ? 'block' : 'none' }}
                data-id="trackable-edit-buffer-radius"
            >
                <Field
                    type="text"
                    onChange={(e) => {
                        preventInputNotNumber(e);
                        dispatch(checkboxClick({}));
                    }}
                    data-cy="trackable-edit-buffer-radius"
                    className="Form-Input"
                    name="buffer_radius"
                    component={renderField}
                    masked={false}
                    label={TRACKABLE_MODAL.EDIT.FORM.BUFFER_RADIUS_FUNC(intl)}
                />
            </div>
            <div className="Form-Line row" style={{ display: isBufferSelected ? 'block' : 'none' }}>
                <div className="Form-Label col-md-4">{TRACKABLE_MODAL.EDIT.FORM.BUFFER_ACTIVE}</div>
                <div className="col-md-1" data-id="trackable-edit-active-buffer">
                    <Field
                        onChange={() => {
                            dispatch(checkboxClick({}));
                        }}
                        name="active_buffer"
                        data-cy="trackable-edit-active-buffer"
                        id="active_buffer"
                        component="input"
                        type="checkbox"
                        style={{ width: '19px', height: '19px' }} // todo: extract style to class, duplicate
                    />
                </div>
            </div>
            <div className="Form-Line row" style={{ display: isBufferSelected ? 'block' : 'none' }}>
                <div
                    className="Form-Label col-md-4"
                    style={{ fontWeight: 'bold' }}
                >
                    {TRACKABLE_MODAL.EDIT.FORM.BUFFER_EXCEPTIONS}
                </div>
                <div className="col-md-8" data-id="trackable-edit-zones">
                    <Field
                        name="trackables_and_groups"
                        type="text"
                        data-cy="trackable-edit-buffer-trackables-and-groups"
                        label="Objective"
                        placeholder={COMPONENTS.SELECT_COMPONENT_PLACEHOLDER(intl)}
                        options={options}
                        filterOptions={filterSelectBoxOptions}
                        noResultsText={COMPONENTS.SELECT_COMPONENT_NO_RESULTS_TEXT}
                        component={MultiSelectComponent}
                        scrollMenuIntoView
                    />
                </div>
            </div>
        </section>
    );
};

renderBufferSection.propTypes = {
    dispatch: PropTypes.func,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    isBufferSelected: PropTypes.bool,
    uid: PropTypes.string,
    trackableCategory: PropTypes.string,
};

renderBufferSection.defaultProps = {
    dispatch: () => {
    },
    intl: {
        formatMessage: () => {},
    },
    isBufferSelected: false,
    uid: '',
    trackableCategory: '',
};

export default renderBufferSection;
