import Modal from 'react-modal';
import React from 'react';
import PropTypes from 'prop-types';
import _Has from 'lodash/has';
import { connect } from 'react-redux';
import 'react-select/dist/react-select.css';

import { TRACKABLE_MODAL, NAME_OF_FORMS } from 'common';
import { sortByField, macToUpperCase } from 'utils';
import { makeCopy } from 'utils/simpleUtils';
import { closeTrackableEditModal, selectFloorPlan, unSelectFloorplan, createEditTrackable } from 'stores/actions';
import { Floorplan, Sublocation } from 'stores/classes';
import NotificationMessage from 'components/NotificationMessage';

import TrackableEditForm from './TrackableEditForm';
import { getParsedTrackable } from './trackableModalUtils';


class TrackableEditModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        trackableEdit: PropTypes.shape(),
        style: PropTypes.shape(),
        floorplans: PropTypes.arrayOf(PropTypes.shape()),
        formState: PropTypes.shape(),
        sublocations: PropTypes.arrayOf(PropTypes.shape()),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        trackableEdit: {},
        style: {},
        floorplans: [{}],
        formState: {},
        sublocations: [],
    };
    
    close = () => {
        this.props.dispatch(closeTrackableEditModal());
    };

    floorplanSelect = (floorplan) => {
        this.props.dispatch(selectFloorPlan(floorplan));
    };

    floorplanUnSelect = () => {
        this.props.dispatch(unSelectFloorplan());
    };

    submit = (trackableValues) => {
        this.props.dispatch(createEditTrackable({ trackableValues, trackableEdit: this.props.trackableEdit }));
    };

    isMapVisible = (showMap, stationary) => this.props.trackableEdit.showMap && stationary;

    render() {
        const {
            style, floorplans, sublocations, trackableEdit, formState,
        } = this.props;
        const { showMap, stationaryLeafletPosition } = trackableEdit;

        const title = (trackableEdit.params && trackableEdit.params.uid)
            ? trackableEdit.params.name : TRACKABLE_MODAL.EDIT.ADD_NEW;
        const node = trackableEdit && trackableEdit.params ? trackableEdit.params.node : {};

        const stationary = _Has(formState, 'values.stationary') && formState.values.stationary;

        const _isMapVisible = this.isMapVisible(showMap, stationary);

        const style2 = makeCopy(style);
        style2.content.width = _isMapVisible ? '75%' : 750;
        style2.content.top = '50%';
        style2.content.maxHeight = '100%';

        const project_uid = trackableEdit.params && trackableEdit.params.project_uid;

        const findSublocationByProjectUid = (projectUid) => sublocations.filter((sublocation) => sublocation.project_uid === projectUid);

        const relatedSublocations = findSublocationByProjectUid(project_uid);
        const sublocation_uid = relatedSublocations && relatedSublocations.length > 0 && relatedSublocations[0].uid;

        return (
            <Modal
                contentLabel="trackableEdit"
                isOpen={trackableEdit.open}
                onRequestClose={this.close}
                style={style2}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis" data-id="trackable-edit-update-title">
                        {title}
                    </span>
                    {node && node.mac_address
                    && (
                        <div className="grey-text" data-id="trackable-edit-update-tag-assoc">
                            {TRACKABLE_MODAL.EDIT.FORM.TAG_ASSOCIATION_FUNC(macToUpperCase(node.mac_address))}
                        </div>
                    )}
                    <NotificationMessage
                        show={_isMapVisible}
                        message={TRACKABLE_MODAL.EDIT.NOTIFY_MESSAGE}
                    />
                    <TrackableEditForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                        selectFloorplan={this.floorplanSelect}
                        unSelectFloorplan={this.floorplanUnSelect}
                        floorplans={floorplans}
                        sublocation_uid={sublocation_uid}
                        stationaryLeafletPosition={stationaryLeafletPosition}
                        isMapVisible={_isMapVisible}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = (state) => ({
    formState: state.form[NAME_OF_FORMS.TRACKABLE_EDIT],
    trackableEdit: getParsedTrackable(state),
    floorplans: sortByField(Floorplan.getAllFloorplans(state), 'name') || [],
    sublocations: Sublocation.getAllSublocations(state),
});

export default connect(mapStateToProps)(TrackableEditModal);
