import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import PropTypes from 'prop-types';

import { NAME_OF_FORMS, TRACKABLE_LOW_LATENCY_LINK_VALIDATE, COMPONENTS } from 'common';
import { closeCreateEditTrackableLLL, createEditTrackableLLL } from 'stores/actions';


let TrackableLowLatencyLinkValidationForm = (props) => {
    const {
        close, save, className, node,
    } = props;
    const message = node
        // Would you like to save your configuration anyway?
        ? TRACKABLE_LOW_LATENCY_LINK_VALIDATE.MESSAGES.HAVE_NODE.QUESTION
        // Would you like to continue?
        : TRACKABLE_LOW_LATENCY_LINK_VALIDATE.MESSAGES.HAVE_NO_NODE.QUESTION;
    return (
        <form className={className}>
            <div style={{ fontSize: '1.3em', marginTop: '10px' }} data-id="trackable-collision-validate-message">{message}</div>
            <div className="Form-Buttons row text-right">
                <button type="button" data-id="trackable-validate-save" onClick={save}>{COMPONENTS.BUTTONS.SAVE}</button>
                <button type="button" data-id="trackable-validate-cancel" onClick={close}>{COMPONENTS.BUTTONS.CANCEL}</button>
            </div>
        </form>
    );
};

TrackableLowLatencyLinkValidationForm.propTypes = {
    close: PropTypes.func,
    save: PropTypes.func,
    className: PropTypes.string,
    node: PropTypes.shape(),
};

TrackableLowLatencyLinkValidationForm.defaultProps = {
    close: () => {
    },
    save: () => {
    },
    className: '',
    node: {},
};

TrackableLowLatencyLinkValidationForm = reduxForm({
    form: NAME_OF_FORMS.TRACKABLE_LOW_LATENCY_LINK_VALIDATE,
})(TrackableLowLatencyLinkValidationForm);

class TrackableLowLatencyLinkValidationModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        trackableLowLatencyLinkValidation: PropTypes.shape({
            params: PropTypes.object,
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        trackableLowLatencyLinkValidation: {},
        style: {},
    };
    
    getSecondTitle = node => (node
    // Tag {mac_address} does not have the correct hardware version.
        ? TRACKABLE_LOW_LATENCY_LINK_VALIDATE.MESSAGES.HAVE_NODE.TITLE(node.mac_address || '')
    // Tag has a configuration that will not work with a trackable that is not assigned to a tag.
        : TRACKABLE_LOW_LATENCY_LINK_VALIDATE.MESSAGES.HAVE_NO_NODE.TITLE());

    close = () => {
        this.props.dispatch(closeCreateEditTrackableLLL());
    };
    
    save = () => {
        this.props.dispatch(createEditTrackableLLL(this.props.trackableLowLatencyLinkValidation.params));
    };
    
    render() {
        const { style, trackableLowLatencyLinkValidation } = this.props;
        const { params } = trackableLowLatencyLinkValidation;
        
        const { node } = params || {};
        const titleCommon = 'This Low Latency Link configuration will not work for this trackable.';
        const titleSecond = this.getSecondTitle(node);
        
        return (
            <Modal
                contentLabel="trackableLowLatencyLinkValidation"
                isOpen={trackableLowLatencyLinkValidation.open}
                onRequestClose={this.close}
                style={style}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header2" data-id="trackable-collision-validation-title">
                        {titleCommon}
                    </span>
                    <span style={{ fontSize: '1.3em' }}> {titleSecond}</span>
                    <TrackableLowLatencyLinkValidationForm
                        node={node}
                        className="Modal-Form"
                        close={this.close}
                        save={this.save}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    trackableLowLatencyLinkValidation: state.modals.trackableModals.trackableLowLatencyLinkValidation,
});

export default connect(mapStateToProps)(TrackableLowLatencyLinkValidationModal);
