import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { COMPONENTS } from 'common';
import { makeCopy } from 'utils/simpleUtils';
import { isTsBeforeDuration } from 'utils/timeUtils';
import { closeUserAccessControlEditModal, editUserAccessControl, closeUserAccessControlWarningModal, closeUserAccessControlEditCompanyScopeModal } from 'stores/actions';


class UserControlWarningModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        userAccessControlWarning: PropTypes.shape({
            role: PropTypes.string,
            userSessionTimeout: PropTypes.number,
            accountExpirationTimeout: PropTypes.number,
        }),
        users: PropTypes.shape({}),
        style: PropTypes.shape({}),
    };
    
    static defaultProps = {
        dispatch: () => {},
        userAccessControlWarning: {},
        users: {},
        style: {},
    };
    
    close = () => {
        this.props.dispatch(closeUserAccessControlWarningModal());
    };
    
    submit = () => {
        this.props.dispatch(editUserAccessControl(this.props.userAccessControlWarning.params));
        this.props.dispatch(closeUserAccessControlWarningModal());
        this.props.dispatch(closeUserAccessControlEditModal());
        this.props.dispatch(closeUserAccessControlEditCompanyScopeModal());
    };

    getAffectedUsers = () => {
        const accountExpirationTimeout = this.props.userAccessControlWarning?.params?.accountExpirationTimeout;
        const neverExpired = ['0', null, 0].includes(accountExpirationTimeout);
        const role = this.props.userAccessControlWarning?.params?.role;
        const users = Object.values(this.props.users);

        const affectedAccounts = [];
        for (const user of users) {
            const lastActivityTime = user.last_sign_in_at || user.updated_at;
            if (user.role === role && isTsBeforeDuration(lastActivityTime, accountExpirationTimeout) && !neverExpired) {
                affectedAccounts.push(user.email);
            }
        }
        return affectedAccounts;
    }
    
    render() {
        const { style, userAccessControlWarning } = this.props;
        const affectedAccounts = this.getAffectedUsers();
        let title = ``;
        if (affectedAccounts.length > 0) {
            title = `These changes will remove following accounts: ${affectedAccounts.join(', ')}. Please confirm your action.`;
        } else {
            title = 'These changes will affect account expiration policy. Please confirm your action.';
        }

        const currentStyle = makeCopy(style);
        currentStyle.content.width = '600px';

        return (
            <Modal
                contentLabel="userControlWarning"
                isOpen={userAccessControlWarning.open}
                onRequestClose={this.close}
                style={currentStyle}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis" data-id="user-access-control-warning-title">
                        {title}
                    </span>
                    <form className="Modal-Form">
                        <div className="Form-Buttons">
                            <button type="button" data-id="user-role-warning-save" onClick={this.submit}>{COMPONENTS.BUTTONS.SAVE}</button>
                            <button type="button" data-id="user-role-warning-cancel" onClick={this.close}>{COMPONENTS.BUTTONS.CANCEL}</button>
                        </div>
                    </form>
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    userAccessControlWarning: state.modals.userModals.userAccessControlWarning,
    users: state.entities.users.byUid,
});

export default connect(mapStateToProps)(UserControlWarningModal);
