import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import { injectIntl } from 'react-intl';

import { NAME_OF_FORMS, USER_ROLES, COMPONENTS, USERS_TAB } from 'common';
import { closeUserDetailsModal } from 'stores/actions/modalActions/userModalActions';
import { makeCopy } from 'utils/simpleUtils';


const parseUserType = (value, intl) => {
    switch (value) {
        case USER_ROLES.PROJECT_OPERATIONS_ADMIN:
            return USERS_TAB.USER_ROLES.PROJECT_OPERATIONS_ADMIN(intl);
        case USER_ROLES.PROJECT_SYSTEM_ADMIN:
            return USERS_TAB.USER_ROLES.PROJECT_SYSTEM_ADMIN(intl);
        case USER_ROLES.PROJECT_USER:
            return USERS_TAB.USER_ROLES.PROJECT_USER(intl);
        case USER_ROLES.PROJECT_MAINTAINER:
            return USERS_TAB.USER_ROLES.PROJECT_MAINTAINER(intl);
        case USER_ROLES.COMPANY_ADMIN:
            return USERS_TAB.USER_ROLES.COMPANY_ADMIN(intl);
        default:
            return null;
    }
};

let UserDetailsForm = (props) => {
    const { close, params, className, appContext, intl } = props;
    
    return (
        <form className={className}>
            <div className="Form-Line row">
                <div className="Form-Label col-md-3">{COMPONENTS.FIELDS.COMMON.NAME}</div>
                <div className="Form-Value col-md-9 multiple-lines-ellipsis" data-id="user-details-name">{params.name}</div>
            </div>
            <div className="Form-Line row">
                <div className="Form-Label col-md-3">{COMPONENTS.FIELDS.USER.EMAIL}</div>
                <div className="Form-Value col-md-9 multiple-lines-ellipsis" data-id="user-details-email">{params.email}</div>
            </div>
            {!appContext.project ||
            <section>
                <div className="Form-Line row">
                    <div className="Form-Label col-md-3">{COMPONENTS.FIELDS.USER.PHONE}</div>
                    <div
                        data-id="user-details-phone"
                        className="Form-Value col-md-9 multiple-lines-ellipsis"
                    >
                        {params.user_details ? params.user_details.phone_number : ''}
                    </div>
                </div>
                <div className="Form-Line row">
                    <div className="Form-Label col-md-3">{COMPONENTS.FIELDS.USER.USER_TYPE}</div>
                    <div className="Form-Value col-md-9 multiple-lines-ellipsis" data-id="user-details-user-type">{parseUserType(params.role, intl)}</div>
                </div>
            </section>
            }
            <div className="Form-Buttons OneBtn">
                <button type="button" data-id="user-details-close" onClick={close}>{COMPONENTS.BUTTONS.CLOSE}</button>
            </div>
        </form>
    );
};
UserDetailsForm.propTypes = {
    close: PropTypes.func,
    className: PropTypes.string,
    params: PropTypes.shape(),
    appContext: PropTypes.shape(),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

UserDetailsForm.defaultProps = {
    close: () => {
    },
    params: {},
    className: '',
    appContext: {
        project: {},
    },
    intl: {
        formatMessage: () => {},
    },
};

UserDetailsForm = reduxForm({
    form: NAME_OF_FORMS.USER_DETAILS,
})(UserDetailsForm);

const mapStateToForm = state => ({
    appContext: state.appContext,
});

UserDetailsForm = connect(mapStateToForm)(injectIntl(UserDetailsForm));

class UserDetailsModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        userDetails: PropTypes.shape({
            params: PropTypes.shape({
                name: PropTypes.string,
            }),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({}),
    };
    
    static defaultProps = {
        userDetails: {
            params: {
                name: '',
            },
            open: false,
        },
        dispatch: () => {
        },
        style: {},
    };
    
    close = () => {
        this.props.dispatch(closeUserDetailsModal());
    };
    
    render() {
        const style = makeCopy(this.props.style);
        delete style.width;
        const userName = this.props.userDetails.params ? this.props.userDetails.params.name : '';
        return (
            <Modal
                contentLabel="userDetails"
                isOpen={this.props.userDetails.open}
                onRequestClose={this.close}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis" data-id="user-details-title">
                        {COMPONENTS.FIELDS.COMMON.VIEW_INFORMATION_FUNC(userName)}
                    </span>
                    <UserDetailsForm
                        className="Modal-Form"
                        close={this.close}
                        params={this.props.userDetails.params}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    userDetails: state.modals.userModals.userDetails,
});

export default connect(mapStateToProps)(UserDetailsModal);
