import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { Field, formValueSelector, reduxForm, change } from 'redux-form';
import { injectIntl } from 'react-intl';
import * as api from 'api';
import has from 'lodash/has';

import RenderField from 'components/modals/RenderField';
import { makeCopy } from 'utils/simpleUtils';
import store from 'stores/LocationStore';
import { NAME_OF_FORMS, USER_ROLES, USER_EDIT_MODAL_SYSTEM_SCOPE, COMPONENTS, USER_EDIT_MODAL } from 'common';
import { closeUserEditModalSystemScope, editUserSystemScope, createUserSystemScope, restoreUserPassword } from 'stores/actions';
import { getValidatePasswordError } from './utils';


const companyUsersEmails = () => {
    const emails = [];
    store.getCompanyUsers().forEach((user) => {
        emails.push(user.email);
    });
    return emails;
};
const userValidation = email => api.validateUser({ email });

const asyncValidate = values => userValidation(values.email).then((result) => {
    if (!result.valid) {
        // eslint-disable-next-line
        throw { email: USER_EDIT_MODAL_SYSTEM_SCOPE.FORM.ERROR_EMAIL_EXIST };
    }
});

const validate = (values, props) => {
    let editContext = false;
    if (values.created_at) {
        editContext = true;
    }
    const errors = {};
    if (!values.email) {
        errors.email = COMPONENTS.VALIDATION.REQUIRED;
    } else if (!/^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,4}$/i.test(values.email)) {
        errors.email = USER_EDIT_MODAL_SYSTEM_SCOPE.FORM.ERROR_EMAIL_INVALID;
    } else if (!editContext && companyUsersEmails().indexOf(values.email) !== -1) {
        errors.email = USER_EDIT_MODAL_SYSTEM_SCOPE.FORM.ERROR_EMAIL_EXIST;
    }
    if (!values.first_name) {
        errors.first_name = COMPONENTS.VALIDATION.REQUIRED;
    }
    if (!values.last_name) {
        errors.last_name = COMPONENTS.VALIDATION.REQUIRED;
    }
    const passwordError = getValidatePasswordError(values.password, props.intl);
    if (passwordError) {
        errors.password = passwordError;
    }
    return errors;
};

const renderField = RenderField(3, 9);

let SystemUserEditForm = (props) => {
    const {
        close, submit, className, invalid, restorePassword, intl,
        isPasswordShown, uid, resetPasswordSent, dispatch, userEdit,
        submitSucceeded,
    } = props;
    const isEditMode = !!uid;
    return (
        <form className={className}>
            <div className="Form-Line row">
                <div htmlFor="name" className="Form-Label col-md-3">{USER_EDIT_MODAL_SYSTEM_SCOPE.FORM.USER_TYPE(intl)}</div>
                <div className="col-md-9" data-id="user-edit-system-user-type">
                    <Field
                        disabled
                        className="form-control input-sm "
                        name="role"
                        style={{ fontSize: '14px' }}
                        component="select"
                    >
                        <option
                            value={USER_ROLES.SYSTEM_ADMIN}
                        >
                            {USER_EDIT_MODAL_SYSTEM_SCOPE.FORM.USER_TYPE_SUPER_ADMIN(intl)}
                        </option>
                    </Field>
                </div>
            </div>
            
            <div className="Form-Line row">
                <Field
                    className="Form-Input"
                    name="email"
                    dataId="user-edit-system-email"
                    component={renderField}
                    label={`${COMPONENTS.FIELDS.USER.EMAIL_FUNC(intl)} *`}
                    type="email"
                />
            </div>
            
            {!isEditMode &&
            <div className="Form-Line row">
                <Field
                    className="Form-Input"
                    name="password"
                    dataId="user-edit-system-password"
                    component={renderField}
                    masked={false}
                    label={`${COMPONENTS.FIELDS.USER.PASSWORD_FUNC(intl)} *`}
                    props={{ disabled: isEditMode }}
                    type={isPasswordShown ? 'text' : 'password'}
                />
            </div>}
            
            {!isEditMode &&
            <div className="Form-Line row">
                <div className="col-md-3" />
                <div className="col-md-1 col-sm-1">
                    <Field
                        name="isPasswordShown"
                        id="password"
                        data-id="user-edit-system-show-password"
                        component="input"
                        type="checkbox"
                        style={{ marginTop: '0px' }}
                    />
                </div>
                <label className="no-select" htmlFor="password">
                    {COMPONENTS.FIELDS.USER.SHOW_PASSWORD}
                </label>
            </div>}
            
            <div className="Form-Line row">
                <Field
                    className="Form-Input"
                    name="first_name"
                    dataId="user-edit-system-first-name"
                    component={renderField}
                    label={COMPONENTS.FIELDS.USER.FIRST_NAME_FUNC(intl)}
                    type="text"
                />
            </div>
            <div className="Form-Line row">
                <Field
                    className="Form-Input"
                    name="last_name"
                    dataId="user-edit-system-last-name"
                    component={renderField}
                    label={COMPONENTS.FIELDS.USER.LAST_NAME_FUNC(intl)}
                    type="text"
                />
            </div>
            
            <div className="Form-Line row">
                <Field
                    className="Form-Input"
                    name="phone_number"
                    dataId="user-edit-system-phone"
                    component={renderField}
                    label={COMPONENTS.FIELDS.USER.PHONE_NUMBER_FUNC(intl)}
                    type="text"
                />
            </div>
            
            {!isEditMode &&
            <div className="Form-Line row">
                <div className="col-md-3" />
                <div className="col-md-1 col-sm-1" data-id="user-edit-system-send-notifcation">
                    <Field
                        name="send_notification"
                        id="send_notification"
                        component="input"
                        type="checkbox"
                        style={{ marginTop: 0 }}
                    />
                </div>
                <label className="no-select" htmlFor="send_notification">
                    {USER_EDIT_MODAL.NOTIFICATION_SEND}
                </label>
            </div>
            }
            
            <div className="Form-Buttons">
                {isEditMode &&
                    <button
                        type="button"
                        onClick={() => {
                            dispatch(change(NAME_OF_FORMS.USER_EDIT, 'resetPasswordSent', true));
                            restorePassword(userEdit.params.email);
                        }}
                        className="Form-Reset-Button"
                        data-id="user-edit-system-reset-password"
                    >
                        {COMPONENTS.FIELDS.USER.RESET_PASSWORD}
                    </button>
                }
                <button
                    type="button"
                    onClick={submit}
                    disabled={invalid || submitSucceeded}
                    data-id="user-edit-system-save"
                >
                    {COMPONENTS.BUTTONS.SAVE}
                </button>
                <button type="button" data-id="user-edit-system-cancel" onClick={close}>{COMPONENTS.BUTTONS.CANCEL}</button>
            </div>
            <div>
                {resetPasswordSent &&
                <span className="Notification">{USER_EDIT_MODAL.NOTIFICATION_WAS_SENT}</span>}
            </div>
        </form>
    );
};

SystemUserEditForm.propTypes = {
    userEdit: PropTypes.shape({
        params: PropTypes.shape({
            uid: PropTypes.string,
            email: PropTypes.string,
        }),
    }),
    dispatch: PropTypes.func,
    invalid: PropTypes.bool,
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    restorePassword: PropTypes.func,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    isPasswordShown: PropTypes.bool,
    uid: PropTypes.string,
    resetPasswordSent: PropTypes.bool,
    submitSucceeded: PropTypes.bool,
};

SystemUserEditForm.defaultProps = {
    userEdit: {
        params: {
            uid: '',
            email: '',
        },
    },
    dispatch: () => {},
    invalid: false,
    close: () => {
    },
    submit: () => {
    },
    restorePassword: () => {
    },
    className: '',
    intl: {
        formatMessage: () => {
        },
    },
    isPasswordShown: false,
    uid: '',
    resetPasswordSent: false,
    submitSucceeded: false,
};

SystemUserEditForm = reduxForm({
    form: NAME_OF_FORMS.USER_EDIT,
    validate,
    asyncValidate,
    asyncBlurFields: ['email'],
    shouldAsyncValidate: (params) => {
        if (!params.syncValidationPasses) {
            return false;
        }
        return params.trigger === 'blur';
    },
})(SystemUserEditForm);

const mapStateToForm = (state) => {
    const initialValues = state.modals.userModals.userEdit.params || {};

    if (!initialValues.phone_number && initialValues.user_details) {
        initialValues.phone_number = initialValues.user_details.phone_number;
    }
    initialValues.role = USER_ROLES.SYSTEM_ADMIN;
    const selector = formValueSelector(NAME_OF_FORMS.USER_EDIT);
    const isPasswordShown = selector(state, 'isPasswordShown');
    const resetPasswordSent = selector(state, 'resetPasswordSent');
    const uid = selector(state, 'uid');
    
    return {
        resetPasswordSent,
        isPasswordShown,
        uid,
        initialValues,
        userEdit: state.modals.userModals.userEdit,
    };
};
SystemUserEditForm = connect(mapStateToForm)(injectIntl(SystemUserEditForm));


class SystemUserEditModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        userEdit: PropTypes.shape({
            phone_number: PropTypes.string,
            user_details: PropTypes.shape({
                phone_number: PropTypes.string,
            }),
            params: PropTypes.shape({
                uid: PropTypes.string,
                email: PropTypes.string,
            }),
        }),
        style: PropTypes.shape({}),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        userEdit: {
            phone_number: '',
            user_details: {
                phone_number: '',
            },
            params: {
                uid: '',
                email: '',
            },
        },
        style: {},
    };
    
    componentDidUpdate() {
        if (has(this.props, 'userEdit.user_details') && !this.props.userEdit.phone_number) {
            this.props.userEdit.phone_number = this.props.userEdit.user_details.phone_number;
        }
        return null;
    }
    
    close = () => {
        this.props.dispatch(closeUserEditModalSystemScope());
    };
    
    submit = (values) => {
        if (store.getCurrentUser().email === this.props.userEdit.params.email) {
            store.setUserEmail(values.email);
            values.currentUser = true;
        }

        if (this.props.userEdit.params && this.props.userEdit.params.uid) {
            this.props.dispatch(editUserSystemScope(values));
        } else {
            this.props.dispatch(createUserSystemScope(values));
        }
        this.props.dispatch(closeUserEditModalSystemScope());
    };
    
    restorePassword = (email) => {
        this.props.dispatch(restoreUserPassword(email));
    };

    render() {
        const { style, userEdit } = this.props;
        
        const title = userEdit.params && userEdit.params.uid
            ? USER_EDIT_MODAL_SYSTEM_SCOPE.TITLE_EDIT_USER_FUNC(userEdit.params.name)
            : USER_EDIT_MODAL_SYSTEM_SCOPE.TITLE_ADD_NEW;
        const currentStyle = makeCopy(style);
        currentStyle.content.width = '600px';
        
        return (
            <Modal
                contentLabel="userEditSystem"
                isOpen={userEdit.openSystemScope}
                onRequestClose={this.close}
                style={currentStyle}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis" data-id="user-edit-system-title">
                        {title}
                    </span>
                    <SystemUserEditForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                        restorePassword={this.restorePassword}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    userEdit: state.modals.userModals.userEdit,
});

export default connect(mapStateToProps)(SystemUserEditModal);
