import { USER_EDIT_MODAL, COMPONENTS } from 'common/ui-labels';

export const getValidatePasswordError = (password, intl) => {
    /**
     * DEV-1201:
     a) Combination of >= 8 characters
     b) Include 3 of the 4 following character types:
         Upper Case
         Lower case
         Number
         Special Character (Unix, Microsoft or IBM)
     c) enforce current users to adapt passwords
     */
    if (!password) {
        return COMPONENTS.VALIDATION.REQUIRED_FUNC(intl);
    }
    const passwordLength = password.length;

    const upperCaseCount = password.replace(/[^A-Z]/g, '').length;
    const includeUpperCase = upperCaseCount ? 1 : 0;

    const lowerCaseCount = password.replace(/[^a-z]/g, '').length;
    const includeLowerCase = lowerCaseCount ? 1 : 0;

    const numberCount = password.replace(/[^0-9]/g, '').length;
    const includeNumber = numberCount ? 1 : 0;

    const specialSymbolCount = password.replace(/[^!@#$%^&*()+=_~`/<,.>]/g, '').length;
    const includeSpecialSymbol = specialSymbolCount ? 1 : 0;

    const characterTypes = 3;
    const includeAtLeastCharacterTypes = includeUpperCase + includeLowerCase + includeNumber + includeSpecialSymbol < characterTypes;

    if (passwordLength < 8) {
        return COMPONENTS.VALIDATION.MIN_LENGTH_FUNC(8);
    } else if (includeAtLeastCharacterTypes) {
        return USER_EDIT_MODAL.VALIDATION.AT_LEAST_CHARACTERS(intl);
    }
    return false;
};
