import React from 'react';
import PropTypes from 'prop-types';
import { filterSelectBoxOptions, sortByField } from 'utils';
import { change, Field } from 'redux-form';
import { NAME_OF_FORMS, ZONE_APPLY_TO } from 'common';
import { COMPONENTS, TRACKABLES_AND_GROUPS, COMMON_LABELS } from 'common/ui-labels';
import MultiSelectComponent from 'components/modals/MultiSelectComponent';


export function TrackablesGroupsForm({ intl, trackables, groups, trackables_groups_option, dispatch }) {
    const options = sortByField([...trackables, ...groups], 'name');

    return (
        <section>
            <div className="Form-Line row" style={{ textAlign: 'center', marginTop: '15px' }}>
                <div className="Form-Label col-md-6" style={{ fontSize: '1.2em' }}>{COMMON_LABELS.TRACKABLES_GROUPS}</div>
                <div className="col-md-6 text-left" data-id="zone-bulk-edit-trackables-groups">
                    <Field
                        name="trackables_groups_option"
                        component="input"
                        onChange={() => {
                            dispatch(change(NAME_OF_FORMS.ZONE_BULK_EDIT_ADMIN_PAGE, 'apply_to', ZONE_APPLY_TO.LIST));
                        }}
                        type="checkbox"
                    />
                </div>
            </div>
            <div className="Form-Line RPP-Group-advanced" style={{ textAlign: 'center', marginTop: '15px', display: trackables_groups_option ? 'block' : 'none' }}>
                <h4 className="RPP-Group-advanced-border-title">{TRACKABLES_AND_GROUPS.APPLY_TO}</h4>
                <div className="row Form-Line">
                    <div className="col-md-5">
                        <div className="row">
                            <div className="col-md-1">
                                <Field
                                    name="apply_to"
                                    data-cy="apply_to"
                                    component="input"
                                    style={{ marginTop: '3px', cursor: 'pointer' }}
                                    value={ZONE_APPLY_TO.LIST}
                                    type="radio"
                                />
                            </div>
                            <div
                                className="col-md-10 cursor-pointer"
                                onClick={() => {
                                    dispatch(change(NAME_OF_FORMS.ZONE_BULK_EDIT_ADMIN_PAGE, 'apply_to', ZONE_APPLY_TO.LIST));
                                }}
                            >
                                {COMMON_LABELS.APPLY_TO_ONLY}
                            </div>
                        </div>
                        <div className="row">
                            <div className="col-md-1 text-left">
                                <Field
                                    name="apply_to"
                                    data-cy="apply_to"
                                    component="input"
                                    style={{ marginTop: '3px', cursor: 'pointer' }}
                                    value={ZONE_APPLY_TO.ALL}
                                    type="radio"
                                />
                            </div>
                            <div
                                className="col-md-10 cursor-pointer"
                                onClick={() => {
                                    dispatch(change(NAME_OF_FORMS.ZONE_BULK_EDIT_ADMIN_PAGE, 'apply_to', ZONE_APPLY_TO.ALL));
                                }}
                            >
                                {COMMON_LABELS.APPLY_TO_EXCEPT}
                            </div>
                        </div>
                    </div>

                    <div className="col-md-7">
                        <Field
                            name="trackables_and_groups"
                            type="text"
                            label="Objective"
                            placeholder={COMPONENTS.SELECT_COMPONENT_PLACEHOLDER(intl)}
                            noResultsText={COMPONENTS.SELECT_COMPONENT_NO_RESULTS_TEXT}
                            options={options}
                            filterOptions={filterSelectBoxOptions}
                            scrollMenuIntoView
                            component={MultiSelectComponent}
                        />
                    </div>
                </div>
            </div>
        </section>
    );
}

TrackablesGroupsForm.propTypes = {
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
    trackables: PropTypes.arrayOf(PropTypes.shape({})),
    groups: PropTypes.arrayOf(PropTypes.shape({})),
    trackables_groups_option: PropTypes.bool,
    dispatch: PropTypes.func,
}

TrackablesGroupsForm.defaultProps = {
    intl: {
        formatMessage: () =>{},
    },
    trackables: [],
    groups: [],
    trackables_groups_option: false,
    dispatch: () => {},
}
