import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { ZONE_BULK_EDIT } from 'common/ui-labels';
import { editBulkZone, closeZoneEditBulkModal } from 'stores/actions';
import { makeCopy } from 'utils/simpleUtils';
import ZoneBulkEditSitePageForm from './ZoneBulkEditSitePageForm';


class ZoneBulkEditAdminPageModal extends Component {
    static propTypes = {
        dispatch: PropTypes.func,
        zoneEdit: PropTypes.shape({
            params: PropTypes.arrayOf(PropTypes.shape({})),
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({}),
    };
    
    static defaultProps = {
        dispatch: () => {},
        zoneEdit: {
            params: [],
            open: false,
        },
        style: {},
    };

    close = () => {
        this.props.dispatch(closeZoneEditBulkModal());
    };
    
    submit = (params) => {
        this.props.dispatch(editBulkZone(params));
    };
    
    render() {
        const { style } = this.props;
        const currentStyle = makeCopy(style);
        currentStyle.content.maxHeight = '90vh';

        return (
            <Modal
                contentLabel="zonesBulkEdit"
                isOpen={this.props.zoneEdit.open}
                onRequestClose={this.close}
                shouldCloseOnOverlayClick={false}
                style={style}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header multiple-lines-ellipsis" data-id="zone-bulk-edit-title">
                        {ZONE_BULK_EDIT.INFO_TITLE}
                    </span>
                    <span className="grey-text">
                        {ZONE_BULK_EDIT.UNDER_TITLE}
                    </span>
                    <ZoneBulkEditSitePageForm
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    zoneEdit: state.modals.zoneModals.zoneEditBulkAdminPage,
});

export default connect(mapStateToProps)(ZoneBulkEditAdminPageModal);
