import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { Field, reduxForm } from 'redux-form';
import PropTypes from 'prop-types';

import { makeCopy } from 'utils/simpleUtils';
import RenderSelectField from '../../components/modals/RenderSelectField';
import { NAME_OF_FORMS, ZONE_CHOOSE_AREA_ADMIN_PAGE_MODAL, COMPONENTS } from '../../common';
import { sortByField } from './../../utils';
import { closeZoneChooseAreaModal, closeZoneCreateAdminPageModal, chooseArea, openZoneChooseTypeModal } from '../../stores/actions';
import { Location, Sublocation } from '../../stores/classes';


const validate = (values) => {
    const errors = {};
    if (!values.location_uid) {
        errors.location_uid = ZONE_CHOOSE_AREA_ADMIN_PAGE_MODAL.ERRORS.LOCATION;
    }
    if (!values.sublocation_uid) {
        errors.sublocation_uid = ZONE_CHOOSE_AREA_ADMIN_PAGE_MODAL.ERRORS.SUBLOCATION;
    }
    return errors;
};

let ZoneChooseAreaForm = (props) => {
    const {
        invalid, close, className, locations, sublocations, formState, chooseZoneArea,
    } = props;
    
    const chooseAreaFormState = formState[NAME_OF_FORMS.ZONE_CHOOSE_AREA] || {};
    let selectedLocationUid;
    let selectedSublocationUid;
    
    if (chooseAreaFormState && chooseAreaFormState.values) {
        selectedLocationUid = chooseAreaFormState.values.location_uid;
        selectedSublocationUid = chooseAreaFormState.values.sublocation_uid;
    }
    
    return (
        <form className={className}>
            <div className="row Form-Line" style={{ textAlign: 'center' }}>
                <div className="col-md-5 col-sm-5 Form-Label">{ZONE_CHOOSE_AREA_ADMIN_PAGE_MODAL.CHOOSE_SITE}</div>
                <div className="col-md-7 col-sm-7">
                    <Field
                        className="form-control input-sm "
                        name="location_uid"
                        dataCy="location"
                        style={{ fontSize: '14px' }}
                        component={RenderSelectField}
                    >
                        <option value="" />
                        {
                            locations.map(location => (
                                <option key={location.uid} value={location.uid}>{location.name}</option>
                            ))
                        }
                        
                    </Field>
                </div>
            </div>
            <div className="row Form-Line" style={{ textAlign: 'center' }}>
                <div className="col-md-5 col-sm-5 Form-Label">{ZONE_CHOOSE_AREA_ADMIN_PAGE_MODAL.CHOOSE_AREA}</div>
                <div className="col-md-7 col-sm-7">
                    <Field
                        className="form-control input-sm "
                        name="sublocation_uid"
                        dataCy="sublocation"
                        style={{ fontSize: '14px' }}
                        component={RenderSelectField}
                    >
                        <option value="" />
                        {selectedLocationUid &&
                            sublocations
                                .filter(sublocation => sublocation.location_uid === selectedLocationUid)
                                .map(sublocation => (
                                    <option key={sublocation.uid} value={sublocation.uid}>{sublocation.name}</option>
                                ))
                        }
        
                    </Field>
                </div>
            </div>

            <div className="Form-Buttons">
                <button
                    type="button"
                    disabled={invalid}
                    data-id="zone-choose-next"
                    onClick={chooseZoneArea.bind(this, selectedSublocationUid, selectedLocationUid)}
                >
                    {COMPONENTS.BUTTONS.NEXT}
                </button>
                <button type="button" data-id="zone-choose-cancel" onClick={close}>{COMPONENTS.BUTTONS.CANCEL}</button>
            </div>
        </form>
    );
};

ZoneChooseAreaForm.propTypes = {
    close: PropTypes.func,
    invalid: PropTypes.bool,
    className: PropTypes.string,
    chooseZoneArea: PropTypes.func,
    formState: PropTypes.shape(),
    locations: PropTypes.arrayOf(PropTypes.shape()),
    sublocations: PropTypes.arrayOf(PropTypes.shape()),
};

ZoneChooseAreaForm.defaultProps = {
    close: () => {
    },
    chooseZoneArea: () => {
    },
    invalid: true,
    className: '',
    formState: {},
    locations: [],
    sublocations: [],
};

ZoneChooseAreaForm = reduxForm({
    form: NAME_OF_FORMS.ZONE_CHOOSE_AREA,
    validate,
})(ZoneChooseAreaForm);

const mapStateToForm = state => ({
    initialValues: state.modals.zoneModals.zoneChooseGeometry,
    formState: state.form,
});
ZoneChooseAreaForm = connect(mapStateToForm)(ZoneChooseAreaForm);


class ZoneChooseAreaAdminPageModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        style: PropTypes.shape({
            overlay: PropTypes.object,
            content: PropTypes.object,
        }),
        zoneChooseAreaAdminPage: PropTypes.shape({
            open: PropTypes.bool,
        }),
        sublocations: PropTypes.arrayOf(PropTypes.shape()),
        locations: PropTypes.arrayOf(PropTypes.shape()),
    };

    static defaultProps = {
        dispatch: () => {
        },
        style: {
            overlay: {},
            content: {},
        },
        zoneChooseAreaAdminPage: {
            open: false,
        },
        sublocations: [],
        locations: [],
    };

    close = () => {
        this.props.dispatch(closeZoneChooseAreaModal());
        this.props.dispatch(closeZoneCreateAdminPageModal());
    };
    
    chooseAreaModal = (sublocation_uid, location_uid) => {
        this.props.dispatch(chooseArea({ sublocation_uid, location_uid }));
        this.props.dispatch(closeZoneChooseAreaModal());
        this.props.dispatch(openZoneChooseTypeModal());
    };

    render() {
        const {
            style, zoneChooseAreaAdminPage, locations, sublocations,
        } = this.props;

        const customStyle = makeCopy(style);
        customStyle.content.width = 430;

        return (
            <Modal
                contentLabel="zoneChooseAreaAdminPage"
                isOpen={zoneChooseAreaAdminPage.open}
                onRequestClose={this.close}
                style={customStyle}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header" data-id="zone-add-title">
                        {COMPONENTS.FIELDS.ZONE.CREATE_NEW_ZONE}
                    </span>
                    <ZoneChooseAreaForm
                        className="Modal-Form"
                        close={this.close}
                        submit={this.submit}
                        chooseZoneArea={this.chooseAreaModal}
                        locations={locations}
                        sublocations={sublocations}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    zoneChooseAreaAdminPage: state.modals.zoneModals.zoneChooseAreaAdminPage,
    locations: sortByField(Location.getAllLocations(state), 'name'),
    sublocations: sortByField(Sublocation.getAllSublocations(state), 'name'),
});

export default connect(mapStateToProps)(ZoneChooseAreaAdminPageModal);
