import React from 'react';
import Modal from 'react-modal';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import deepcopy from 'deepcopy';
import { COMPONENTS, ZONE_CHOOSE_CREATION_MODE } from 'common/ui-labels';
import { closeZoneChooseCreationModeModal, openZoneChooseGeometryModal, openZoneCoordinatesModeModal, setCoordinatesRegimeAdminPageModal } from 'stores/actions/modalActions/zoneModalActions';
import { activateZoneEditCoordinatesMode, changeMode, startLiveMode } from 'stores/actions';
import { SITE_MODE } from 'common/constants';
import { makeCopy } from 'utils/simpleUtils';


function ZoneChooseCreationMode(props) {
    const style = deepcopy(props.style);

    const customStyle = makeCopy(style);
    customStyle.content.width = 390;

    return (
        <Modal
            isOpen={props.isOpen}
            shouldCloseOnOverlayClick={false}
            onRequestClose={() => {
                props.closeModal();
            }}
            style={customStyle}
        >
            <div className="RPP-Modal">
                <div className="Modal-Header" style={{ marginLeft: '10px' }}>
                    {COMPONENTS.FIELDS.ZONE.CREATE_NEW_ZONE}
                </div>
                <div className="Modal-Form">
                    <div className="Form-Confirmation-Margin">
                        {ZONE_CHOOSE_CREATION_MODE.SELECT_TOOL}
                    </div>
                    <div className="row" style={{ textAlign: 'center' }}>
                        <button
                            type="button"
                            style={{ padding: '20px', width: '170px', height: '150px', marginRight: '5px' }}
                            data-id="draw-mode"
                            onClick={() => {
                                props.chooseDrawMode(props.zone_type_name);
                            }}
                        >
                            <div>
                                <i className="fas fa-pencil-alt fa-3x" />
                            </div>
                            <div style={{ textAlign: 'center' }}>{ZONE_CHOOSE_CREATION_MODE.DRAW}</div>
                        </button>
                        <button
                            type="button"
                            style={{ padding: '20px', width: '170px', height: '150px', marginLeft: '5px' }}
                            data-id="coordinate-mode"
                            onClick={() => {
                                if (props.isAdminMode) {
                                    props.chooseCoordinateModeAdminPage();
                                } else {
                                    props.chooseCoordinateMode(props.zone_type_name);
                                }
                            }}
                        >
                            <div>
                                <i className="fa fa-plus fa-3x" aria-hidden="true" />
                            </div>
                            <div style={{ textAlign: 'center' }}>{ZONE_CHOOSE_CREATION_MODE.COORDINATES}</div>
                        </button>
                    </div>
            
                    <div className="Form-Buttons">
                        <button
                            type="button"
                            data-id="zone-add-cancel"
                            onClick={() => {
                                props.closeModal(props.isAdminMode);
                            }}
                        >{COMPONENTS.BUTTONS.CANCEL}
                        </button>
                    </div>
                </div>
            </div>
        </Modal>);
}


ZoneChooseCreationMode.propTypes = {
    isOpen: PropTypes.bool,
    isAdminMode: PropTypes.bool,
    closeModal: PropTypes.func,
    chooseDrawMode: PropTypes.func,
    chooseCoordinateMode: PropTypes.func,
    chooseCoordinateModeAdminPage: PropTypes.func,
    style: PropTypes.shape({}),
    zone_type_name: PropTypes.string,
};

ZoneChooseCreationMode.defaultProps = {
    isOpen: false,
    isAdminMode: false,
    closeModal: () => {},
    chooseDrawMode: () => {},
    chooseCoordinateMode: () => {},
    chooseCoordinateModeAdminPage: () => {},
    style: {},
    zone_type_name: null,
};

const mapDispatchToProps = dispatch => ({
    closeModal: (isAdminMode) => {
        if (!isAdminMode) {
            dispatch(startLiveMode());
        }
        dispatch(closeZoneChooseCreationModeModal());
    },
    chooseDrawMode: (zone_type_name) => {
        dispatch(closeZoneChooseCreationModeModal());
        dispatch(openZoneChooseGeometryModal({ zone_type_name }));
    },
    chooseCoordinateModeAdminPage: () => {
        dispatch(closeZoneChooseCreationModeModal());
        dispatch(setCoordinatesRegimeAdminPageModal());
    },
    chooseCoordinateMode: (zone_type_name) => {
        dispatch(closeZoneChooseCreationModeModal());
        dispatch(activateZoneEditCoordinatesMode());
        dispatch(openZoneCoordinatesModeModal({ zone_type_name }));
    
        dispatch(changeMode({
            name: SITE_MODE.EDIT_ZONE,
            onReturn: () => { },
        }));
    },
});

const mapStateToProps = state => ({
    isAdminMode: state.modals.zoneModals.zoneCreateAdminPage.open,
    isOpen: state.modals.zoneModals.zoneChooseCreationMode.open,
    zone_type_name: state.modals.zoneModals.zoneChooseCreationMode.zone_type_name,
});

export default connect(mapStateToProps, mapDispatchToProps)(ZoneChooseCreationMode);
