import React from 'react';
import Modal from 'react-modal';
import deepcopy from 'deepcopy';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { COMPONENTS, GEOMETRY_RESTRICTION_TYPES } from 'common';
import { closeZoneChooseGeometryModal, chooseZoneRectangleDrawRegime, chooseZonePolygonDrawRegime, startLiveMode } from 'stores/actions';
import ZoneChooseGeometryForm from './ZoneChooseGeometryForm';


class ZoneChooseGeometryModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        style: PropTypes.shape({
            overlay: PropTypes.shape({}),
            content: PropTypes.shape({}),
        }),
        isOpen: PropTypes.bool,
        isAdminMode: PropTypes.bool,
    };

    static defaultProps = {
        dispatch: () => {
        },
        style: {
            overlay: {},
            content: {},
        },
        isOpen: false,
        isAdminMode: false,
    };

    close = () => {
        // Subscribe to WS only if modal window was closed without proceeding zone creation procedure
        if (!this.props.isAdminMode) {
            this.props.dispatch(startLiveMode());
        }
        this.props.dispatch(closeZoneChooseGeometryModal());
    };
    
    addRectangle = (geometry_restriction = [GEOMETRY_RESTRICTION_TYPES.RECTANGLE]) => {
        this.props.dispatch(chooseZoneRectangleDrawRegime({ geometry_restriction }));
    };

    addPolygon = (geometry_restriction = [GEOMETRY_RESTRICTION_TYPES.POLYGON]) => {
        this.props.dispatch(chooseZonePolygonDrawRegime({ geometry_restriction }));
    };
    
    render() {
        const { style, isOpen } = this.props;

        const modifiedStyles = deepcopy(style);
        modifiedStyles.content.width = '406px';

        return (
            <Modal
                contentLabel="zoneDelete"
                shouldCloseOnOverlayClick={false}
                isOpen={isOpen}
                onRequestClose={this.close}
                style={modifiedStyles}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header" data-id="zone-add-title">
                        {COMPONENTS.FIELDS.ZONE.CREATE_NEW_ZONE}
                    </span>
                    <ZoneChooseGeometryForm
                        className="Modal-Form"
                        close={this.close}
                        addRectangle={this.addRectangle}
                        addPolygon={this.addPolygon}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    isOpen: state.modals.zoneModals.zoneChooseGeometry.isOpen,
    isAdminMode: state.modals.zoneModals.zoneCreateAdminPage.open,
});

export default connect(mapStateToProps)(ZoneChooseGeometryModal);
