import React, { Component } from 'react';
import Modal from 'react-modal';
import { Field, reduxForm } from 'redux-form';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { injectIntl } from 'react-intl';

import { getZoneTypeOptions } from 'utils';
import { makeCopy } from 'utils/simpleUtils';
import { NAME_OF_FORMS, COMPONENTS } from 'common';
import RenderSelectField from 'components/modals/RenderSelectField';
import { closeZoneSelectTypeModal, chooseZoneTypeOnCreate, stopLiveMode, startLiveMode } from 'stores/actions';


let ZoneChooseTypeSitePageForm = (props) => {
    const { close, submit, className, formState, zonePrototypes, intl } = props;
    const chooseTypeFormState = formState[NAME_OF_FORMS.ZONE_SELECT_TYPE] || {};
    let selectedZoneTypeName;
    if (chooseTypeFormState && chooseTypeFormState.values) {
        selectedZoneTypeName = chooseTypeFormState.values.zone_type_name;
    }
    
    return (
        <form className={className}>
            <div className="Form-Line row">
                <div className="Form-Label col-md-4 col-sm-4">
                    {COMPONENTS.FIELDS.ZONE.ZONE_TYPE} *
                </div>
                <div className="col-md-8 col-sm-8">
                    <Field
                        className="form-control input-sm "
                        name="zone_type_name"
                        style={{ fontSize: '14px' }}
                        dataId="zone-add-configuration-type"
                        component={RenderSelectField}
                    >
                        <option />
                        { getZoneTypeOptions(zonePrototypes, intl) }
                    </Field>
                </div>
            </div>

            <div className="Form-Buttons">
                <button
                    type="button"
                    onClick={submit}
                    data-id="zone-add-configuration-save"
                    disabled={!selectedZoneTypeName}
                >
                    {COMPONENTS.BUTTONS.NEXT}
                </button>
                <button
                    type="button"
                    data-cy="zone-add-configuration-cancel"
                    onClick={close}
                >
                    {COMPONENTS.BUTTONS.CANCEL}
                </button>
            </div>
        </form>
    );
};

ZoneChooseTypeSitePageForm.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    className: PropTypes.string,
    zonePrototypes: PropTypes.arrayOf(PropTypes.shape()),
    formState: PropTypes.shape(),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

ZoneChooseTypeSitePageForm.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    className: '',
    zonePrototypes: [],
    formState: {},
    intl: {
        formatMessage: () => {
        },
    },
};

ZoneChooseTypeSitePageForm = reduxForm({
    form: NAME_OF_FORMS.ZONE_SELECT_TYPE,
})(ZoneChooseTypeSitePageForm);

const mapStateToForm = state => ({
    initialValues: state.modals.zoneModals.zoneChooseTypeSitePage,
    formState: state.form,
    zonePrototypes: state.entities.zonesPrototypes,
});
ZoneChooseTypeSitePageForm = connect(mapStateToForm)(injectIntl(ZoneChooseTypeSitePageForm));


class ZoneChooseTypeSitePageModal extends Component {
    static propTypes = {
        dispatch: PropTypes.func,
        zonePrototypes: PropTypes.arrayOf(PropTypes.shape()),
        zoneChooseTypeSitePage: PropTypes.shape({
            open: PropTypes.bool,
        }),
        style: PropTypes.shape({
            overlay: PropTypes.shape({}),
            content: PropTypes.shape({}),
        }),
    };

    static defaultProps = {
        dispatch: () => {
        },
        zonePrototypes: [],
        zoneChooseTypeSitePage: {
            open: false,
        },
        style: {
            overlay: {},
            content: {},
        },
    };

    componentDidUpdate(prevProps) {
        if (this.props.zoneChooseTypeSitePage.open && this.props.zoneChooseTypeSitePage.open !== prevProps.zoneChooseTypeSitePage.open) {
            this.props.dispatch(stopLiveMode());
        }
    }

    close = () => {
        // Subscribe to WS only if modal window was closed without proceeding zone creation procedure
        // Next modal in chain is ZoneChooseCreationMode
        this.props.dispatch(startLiveMode());
        this.props.dispatch(closeZoneSelectTypeModal());
    };

    submit = (zone) => {
        const { zone_type_name } = zone;
        this.props.dispatch(closeZoneSelectTypeModal());
        this.props.dispatch(chooseZoneTypeOnCreate({ zone_type_name }));
    };

    render() {
        const style = makeCopy(this.props.style);
        style.content.width = 430;
    
        return (
            <Modal
                style={style}
                isOpen={this.props.zoneChooseTypeSitePage.open}
                onRequestClose={this.close}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header" data-id="zone-select-type-title">
                        {COMPONENTS.FIELDS.ZONE.ZONE_SELECT_TYPE_MODAL_TITLE}
                    </span>
                    <ZoneChooseTypeSitePageForm
                        zonePrototypes={this.props.zonePrototypes}
                        className="Modal-Form"
                        close={this.close}
                        onSubmit={this.submit}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    zoneChooseTypeSitePage: state.modals.zoneModals.zoneChooseTypeSitePage,
});

export default connect(mapStateToProps)(ZoneChooseTypeSitePageModal);
