import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import { COMPONENTS, EDIT_ZONE_MODE } from 'common/ui-labels';


function Buttons(props) {
    const {
        invalid,
        submit,
        createZoneFormState,
        close,
        isFinishButtonVisible,
        isFinishButtonDisabled,
        handleFinishClick,
    } = props;
    return (
        <Fragment>
            <div className="Form-Buttons">
                {
                    isFinishButtonVisible && <button
                        type="button"
                        className="Drawing-Button btn"
                        disabled={isFinishButtonDisabled}
                        onClick={() => {
                            handleFinishClick();
                        }}
                    >
                        {EDIT_ZONE_MODE.CLOSE_SHAPE}
                    </button>
                }
                <button
                    type="button"
                    disabled={invalid}
                    onClick={() => {
                        submit(createZoneFormState.values);
                    }}
                    data-id="zone-edit-ok"
                >
                    {COMPONENTS.BUTTONS.OK}
                </button>
                <button type="button" data-id="zone-edit-cancel" onClick={close}>{COMPONENTS.BUTTONS.CANCEL}</button>
            </div>
        </Fragment>
    );
}

Buttons.propTypes = {
    close: PropTypes.func,
    submit: PropTypes.func,
    invalid: PropTypes.bool,
    createZoneFormState: PropTypes.shape(),
    handleFinishClick: PropTypes.func,
    isFinishButtonVisible: PropTypes.bool,
    isFinishButtonDisabled: PropTypes.bool,
};

Buttons.defaultProps = {
    close: () => {
    },
    submit: () => {
    },
    invalid: true,
    createZoneFormState: {
        values: {
        },
    },
    handleFinishClick: () => {},
    isFinishButtonVisible: false,
    isFinishButtonDisabled: false,
};

export default Buttons;
