import React, { Fragment } from 'react';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';

import { getVerticesLimit } from 'utils/zoneUtils';
import VerticesList from 'modals/zone/ZoneCoordinatesEnterModal/VerticesList';
import { addVertexAdminPageModal, removeVertexAdminPageModal } from 'stores/actions';


function VerticesCoordinates(props) {
    if (!props.coordinateMode) {
        return (<Fragment />);
    }
    const verticesLimit = getVerticesLimit(props.currentProject);
    return (
        <div style={{ display: props.show ? 'block' : 'none' }}>
            <VerticesList
                verticesLimit={verticesLimit}
                addVertex={(vertex) => { 
                    props.addVertex(vertex);
                }}
                removeVertex={(index) => {
                    props.removeVertex(index);
                }}
                sublocation={props.sublocation}
            />
        </div>
    );
}

VerticesCoordinates.propTypes = {
    addVertex: PropTypes.func,
    removeVertex: PropTypes.func,
    sublocation: PropTypes.shape({}),
    currentProject: PropTypes.shape({}),
    coordinateMode: PropTypes.bool,
    show: PropTypes.bool,
};

VerticesCoordinates.defaultProps = {
    addVertex: () => {},
    removeVertex: () => {},
    sublocation: {},
    currentProject: {},
    coordinateMode: false,
    show: true,
};

const mapDispatchToProps = dispatch => ({
    addVertex: (position) => {
        dispatch(addVertexAdminPageModal(position));
    },
    removeVertex: (index) => {
        dispatch(removeVertexAdminPageModal(index));
    },
});

const mapStateToProps = state => ({
    coordinateMode: state.modals.zoneModals.zoneCreateAdminPage.coordinateMode,
    currentProject: state.appContext.project,
});

export default connect(mapStateToProps, mapDispatchToProps)(VerticesCoordinates);
