import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import { Field } from 'redux-form';
import RenderField from 'components/modals/RenderField';
import { STORAGE_KEY } from 'common/constants';
import store from 'stores/LocationStore';


const renderField = RenderField(5, 7, 'Form-Label-Average');
const required = value => (value || typeof value === 'number' ? undefined : 'Required');
const positive = value => (Number(value) > 0 ? undefined : 'Width should be positive');

function WidthControl(props) {
    const { geometry, show } = props;
    
    if (!show) {
        return (<Fragment />);
    }
    
    return (
        <div className="Form-Line">
            <div className="row" style={{ marginBottom: '5px' }}>
                <Field
                    className="Form-Input"
                    name="width"
                    dataCy="width-control"
                    disabled={geometry.zoneGeometryInDegrees.length === 0}
                    component={renderField}
                    onChange={(event) => {
                        const width = Number(event.target.value);
                        if (width > 0) {
                            store.setToLocalStorage(STORAGE_KEY.LAST_DIRECTIONAL_ZONE_WIDTH, width);
                        }
                    }}
                    label="Width (m):"
                    validate={[required, positive]}
                    type="number"
                />
            </div>
        </div>
    );
}

WidthControl.propTypes = {
    geometry: PropTypes.shape(),
    show: PropTypes.bool,
};

WidthControl.defaultProps = {
    geometry: {},
    show: false,
};

export default WidthControl;
