import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';

import { ZONE_EDIT_ADMIN_PAGE_MODAL, COMPONENTS } from 'common/ui-labels';
import NotificationMessage from 'components/NotificationMessage';
import {
    createAdminPageZone,
    siteViewClearMode,
    closeZoneCreateAdminPageModal,
    selectFloorplanCreateModal,
    unSelectFloorplanCreateModal,
    exitDrawRegime,
} from 'stores/actions';
import { handleLeafletDeltaZoom } from 'utils';
import { makeCopy } from 'utils/simpleUtils';
import ZoneCreateAdminPageForm from './ZoneCreateAdminPageForm';


class ZoneCreateAdminPageModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        style: PropTypes.shape({
            overlay: PropTypes.object,
            content: PropTypes.object,
        }),
        zoneCreateAdminPage: PropTypes.shape(),
        selectedFloorplanUid: PropTypes.string,
        showNotifyMessage: PropTypes.bool,
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        style: {
            overlay: {},
            content: {},
        },
        zoneCreateAdminPage: {},
        selectedFloorplanUid: '',
        showNotifyMessage: false,
    };
    
    constructor(props) {
        super(props);
        
        this.defaultState = {
            leaflet: null,
            zoom: 17,
        };
        
        this.state = this.defaultState;
    }
    
    componentDidUpdate(prevProps) {
        if (this.props.selectedFloorplanUid == null && this.props.selectedFloorplanUid !== prevProps.selectedFloorplanUid) {
            this.setState(this.defaultState);
        }
        
        if (prevProps.zoneCreateAdminPage.open && prevProps.zoneCreateAdminPage.open !== this.props.zoneCreateAdminPage.open) {
            this.props.dispatch(siteViewClearMode());
            this.setState(this.defaultState);
        }
        const zoneEdit = document.getElementsByClassName('zone-modal')[0];
        // eslint-disable-next-line
        if (zoneEdit && zoneEdit.__proto__.componentWillUnmount) { // remove handler for remove uncaught error
            // eslint-disable-next-line
            document.getElementsByClassName('zone-modal')[0].layers.__proto__.componentWillUnmount = null;
        }
    }
    
    onMove = (event) => {
        this.setState({
            // eslint-disable-next-line
            zoom: event.target._zoom,
        });
    };
    
    setLeafletToState = (leaflet) => {
        if (leaflet) {
            leaflet = handleLeafletDeltaZoom(leaflet);
            this.setState({
                leaflet,
            });
        }
    };
    
    close = () => {
        this.props.dispatch(siteViewClearMode());
        this.setState(this.defaultState);
        this.props.dispatch(exitDrawRegime());
        this.props.dispatch(closeZoneCreateAdminPageModal());
    };
    
    submit = (params) => {
        this.props.dispatch(createAdminPageZone(params));
    };
    
    floorplanSelect = (floorplan_uid) => {
        this.props.dispatch(selectFloorplanCreateModal(floorplan_uid));
    };
    
    floorplanUnSelect = () => {
        this.props.dispatch(unSelectFloorplanCreateModal());
        this.setState(this.defaultState);
    };
    
    render() {
        const {
            style, zoneCreateAdminPage, selectedFloorplanUid, showNotifyMessage, 
        } = this.props;
        const currentStyle = makeCopy(style);
        currentStyle.content.width = '85%';
        currentStyle.content.top = '50%';
        currentStyle.content.height = '85vh';
        
        const boundsForScale = this.state.leaflet ? this.state.leaflet.leafletElement.getBounds() : {};
    
        return (
            <Modal
                contentLabel="userDetails"
                isOpen={zoneCreateAdminPage.open}
                onRequestClose={this.close}
                style={currentStyle}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header" data-id="zone-edit-title">
                        {COMPONENTS.FIELDS.ZONE.CREATE_NEW_ZONE}
                    </span>
                    <NotificationMessage
                        show={showNotifyMessage}
                        message={ZONE_EDIT_ADMIN_PAGE_MODAL.NOTIFY_MESSAGE}
                    />
                    <ZoneCreateAdminPageForm
                        className="Modal-Form create-zone-form"
                        close={this.close}
                        onSubmit={this.submit}
                        selectFloorplan={this.floorplanSelect}
                        selectedFloorplanUid={selectedFloorplanUid}
                        unSelectFloorplan={this.floorplanUnSelect}
                        boundsForScale={boundsForScale}
                        onMove={this.onMove}
                        maxHeight="60vh"
                        zoom={this.state.zoom}
                        setLeafletToState={this.setLeafletToState}
                    />
                </div>
            </Modal>
        );
    }
}

const isNotifyActionShow = state => !!state.modals.zoneModals.zoneCreateAdminPage.zone_type_name;

const mapStateToProps = state => (
    {
        zoneCreateAdminPage: state.modals.zoneModals.zoneCreateAdminPage,
        selectedFloorplanUid: state.modals.zoneModals.zoneCreateAdminPage.floorplan_uid,
        showNotifyMessage: isNotifyActionShow(state),
    }
);

export default connect(mapStateToProps)(ZoneCreateAdminPageModal);
