import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { makeCopy } from 'utils/simpleUtils';
import { COMPONENTS } from 'common';
import { createSitePageZone, closeZoneAddConfigurationModal, clearZoneChooseGeometryModal, startLiveMode } from 'stores/actions';
import ZoneCreateSitePageForm from './ZoneCreateSitePageForm';


class ZoneCreateSitePageModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        style: PropTypes.shape({
            overlay: PropTypes.shape({}),
            content: PropTypes.shape({}),
        }),
        zoneCreateSitePage: PropTypes.shape({
            open: PropTypes.bool,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        style: {
            overlay: {},
            content: {},
        },
        zoneCreateSitePage: {
            open: false,
        },
    };

    close = () => {
        this.props.dispatch(closeZoneAddConfigurationModal());
        this.props.dispatch(clearZoneChooseGeometryModal());
        this.props.dispatch(startLiveMode());
    };

    submit = (params) => {
        this.props.dispatch(createSitePageZone(params));
        this.props.dispatch(startLiveMode());
    };
    
    render() {
        const { style } = this.props;
        const style2 = makeCopy(style);
        style2.content.width = '600px';

        return (
            <Modal
                contentLabel="zoneDelete"
                isOpen={this.props.zoneCreateSitePage.open}
                onRequestClose={this.close}
                style={style2}
            >
                <div className="RPP-Modal">
                    <span className="Modal-Header" data-id="zone-add-configuration-title">
                        {COMPONENTS.FIELDS.ZONE.CREATE_NEW_ZONE}
                    </span>
                    <ZoneCreateSitePageForm className="Modal-Form" close={this.close} onSubmit={this.submit} />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    zoneCreateSitePage: state.modals.zoneModals.zoneCreateSitePage,
});

export default connect(mapStateToProps)(ZoneCreateSitePageModal);

