import React from 'react';
import PropTypes from 'prop-types';
import store from 'stores/LocationStore';
import { COMPONENTS } from 'common/ui-labels';
import { zoneSeverityTextColor, isKeepOutZone, isKeepInZone, zoneFullActive, getZoneTypeName } from 'utils/zoneUtils';
import { zoneSeverityColor } from 'utils/simpleUtils';

function BasicFields({ zone, intl }) {
    const zoneTypeName = getZoneTypeName(store.getZonesPrototypes(), zone.zone_type_name, intl);
    const zoneStatus = zoneFullActive(zone) ? COMPONENTS.FIELDS.COMMON.ACTIVE : COMPONENTS.FIELDS.COMMON.INACTIVE;
    
    const alarmLevelStyle = {
        backgroundColor: zoneSeverityColor(zone.zone_alarm_level),
        textAlign: 'center',
        color: zoneSeverityTextColor(zone.zone_alarm_level),
    };
    const custom_info = zone.custom_info;

    const isKeepInKeepOutZone = isKeepOutZone(zone) || isKeepInZone(zone);
    return (
        <div>
            <div className="row Form-Line">
                <div className="col-md-5 Form-Label">{COMPONENTS.FIELDS.SITE.SITE}</div>
                <div className="col-md-7 Form-Value multiple-lines-ellipsis" data-id="zone-details-locations-name">{zone.location_name_display}</div>
            </div>
            <div className="row Form-Line">
                <div className="col-md-5 Form-Label">{COMPONENTS.FIELDS.SITE.AREA}</div>
                <div className="col-md-7 Form-Value multiple-lines-ellipsis" data-id="zone-details-sublocations-name">{zone.sublocation_name_display}</div>
            </div>
            <div className="row Form-Line">
                <div className="col-md-5 Form-Label">{COMPONENTS.FIELDS.ZONE.ZONE_TYPE}</div>
                <div className="col-md-7 Form-Value" data-id="zone-details-zone-type">{zoneTypeName}</div>
            </div>
            <div className="row Form-Line">
                <div className="col-md-5 Form-Label">{COMPONENTS.FIELDS.COMMON.NAME}</div>
                <div className="col-md-7 Form-Value multiple-lines-ellipsis" data-id="zone-details-site-name">{zone.name}</div>
            </div>
            <div className="row Form-Line">
                <div className="col-md-5 Form-Label">{COMPONENTS.FIELDS.COMMON.STATUS}</div>
                <div
                    className="col-md-7 Form-Value"
                    data-id="zone-details-site-status"
                    data-cy="zone-details-site-status"
                >
                    {zoneStatus}
                </div>
            </div>

            {custom_info &&
            <div className="Form-Line row">
                <div className="Form-Label col-md-5">{COMPONENTS.FIELDS.COMMON.CUSTOM_INFO}</div>
                <div
                    className="Form-Value col-md-7 multiple-lines-ellipsis"
                    data-id="group-details-params"
                    data-cy="group-custom-info"
                >
                    <textarea value={custom_info} readOnly className="RPP-Group-advanced-TextArea" />
                </div>
            </div>}

            {isKeepInKeepOutZone &&
                <div className="row Form-Line">
                    <div className="col-md-5 Form-Label">{COMPONENTS.FIELDS.ZONE.SEVERITY}</div>
                    <div className="col-md-7 Form-Value">
                        <div className="Zone-Details-Alarm" style={alarmLevelStyle} data-id="zone-details-alarm">{zone.zone_alarm_level}</div>
                    </div>
                </div>
            }
        </div>
    );
}

BasicFields.propTypes = {
    zone: PropTypes.shape({
        name: PropTypes.string,
        zone_alarm_level: PropTypes.number,
        sublocation_name_display: PropTypes.string,
        location_name_display: PropTypes.string,
        custom_info: PropTypes.string,
        zone_type_name: PropTypes.string,
    }),
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};
BasicFields.defaultProps = {
    zone: {
        name: '',
        zone_alarm_level: 0,
        sublocation_name_display: '',
        location_name_display: '',
        custom_info: '',
        zone_type_name: '',
    },
    intl: {
        formatMessage: () => {},
    },
};

export default BasicFields;
