import React from 'react';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import { injectIntl } from 'react-intl';
import PropTypes from 'prop-types';

import { zonePositions, showActivePeriod } from '../../../utils';
import { getZoneColor } from '../../../utils/simpleUtils';
import { NAME_OF_FORMS, DEFAULT_VALUES, COMPONENTS } from '../../../common';

import { getParsedGroups, getParsedTrackables } from '../../../stores/getters';

import BasicFields from './BasicFields';
import FloorplansAll from '../../../components/modals/forms/FloorplansAll';
import FloorplanSelected from '../../../components/modals/forms/zones/FloorplanSelected';
import ApplyTo from './ApplyTo';
import CustomZoneInfoOptions from './../../../components/modals/forms/zones/CustomZoneInfoOptions';
import { Sublocation, Floorplan, Zone } from '../../../stores/classes';
import { ZonePrototype } from '../../../stores/classes/Selectors';


const findFloorplansForZone = (zone, floorplans) => {
    let zoneFloorplans = [];
    if (zone.sublocation_uid) {
        zoneFloorplans = floorplans.filter(floorplan => floorplan.sublocation_uid === zone.sublocation_uid);
    }
    return zoneFloorplans;
};

const findZoneSublocation = (zone, sublocations, trackables) => {
    let zoneSublocation = {};
    if (zone.sublocation_uid) {
        sublocations.forEach((sublocation) => {
            if (sublocation.uid === zone.sublocation_uid) {
                zoneSublocation = sublocation;
            }
        });
    } else if (zone.trackable_object_uid) {
        trackables.forEach((trackable) => {
            if (trackable.uid === zone.trackable_object_uid && trackable.position && trackable.position.sl_uid) {
                // todo: remove this shits (and check for affects)
                zone.sublocation_uid = trackable.position.sl_uid;
                
                sublocations.forEach((sublocation) => {
                    if (sublocation.uid === trackable.position.sl_uid) {
                        // todo: remove this shits (and check for affects)
                        zone.sublocation_name_display = sublocation.name;
                        zoneSublocation = sublocation;
                    }
                });
            }
        });
    }
    return zoneSublocation;
};

let ZoneDetailsAdminPageForm = (props) => {
    const {
        close, selectFloorplan, unSelectFloorplan, params, className, direction,
        sublocations, floorplans, selectedFloorplan, groups, trackables, zone_display_name,
        boundsForScale, onMove, zoom, setLeafletToState, zonePrototype, intl, zones,
    } = props;
    
    const zoneSublocation = findZoneSublocation(params, sublocations, trackables);
    const floorplansList = selectedFloorplan ? [] : findFloorplansForZone(params, floorplans);
    const leafletClass = selectedFloorplan ? 'Zone-Details-Leaflet-Selected' : 'Zone-Details-Leaflet';
    const mapStyle = selectedFloorplan ? { height: '52vh' } : { height: '25vh' };
    
    const zone = {
        dashOpacity: 0.3,
        dashArray: params.active ? '' : '5 10',
        dashColor: 'black',
        dashWeight: 2,
        fillColor: getZoneColor(params),
        positions: zonePositions(params, zoneSublocation),
    };
    
    const {
        zone_exceptions = [], apply_to, zone_mode, schedule_start_time, schedule_stop_time, zone_exceptions_groups, user_params,
    } = params;
    
    return (
        <form className={className}>
            <div className="row">
                <div className="col-md-4" style={{ overflowY: 'auto', maxHeight: '60vh' }}>
                    <BasicFields
                        zone={params}
                        intl={intl}
                    />
                    <CustomZoneInfoOptions
                        zonePrototype={zonePrototype}
                        user_params={user_params}
                        zones={zones}
                    />
                    <ApplyTo
                        zone_display_name={zone_display_name}
                        apply_to={apply_to}
                        zone_exceptions_uids={zone_exceptions.concat(zone_exceptions_groups)}
                        groups={groups}
                        trackables={trackables}
                    />
                    <div className="row Form-Line">
                        <div className="col-md-5 Form-Label">{COMPONENTS.FIELDS.ZONE.ACTIVE_PERIOD}</div>
                        <div className="col-md-7 Form-Value" data-id="zone-details-site-status">
                            {showActivePeriod(zone_mode, schedule_start_time, schedule_stop_time)}
                        </div>
                    </div>
                </div>
                <div className="col-md-8">
                    <FloorplansAll
                        selectedFloorplan={selectedFloorplan}
                        unSelectFloorplan={unSelectFloorplan}
                        selectFloorplan={selectFloorplan}
                        zoneSublocation={zoneSublocation}
                        floorplansList={floorplansList}
                        leafletClass={leafletClass}
                        mapStyle={mapStyle}
                        zone={zone}
                        intl={intl}
                    />
                    <FloorplanSelected
                        intl={intl}
                        zoom={zoom}
                        zone={zone}
                        onMove={onMove}
                        mapStyle={mapStyle}
                        direction={direction}
                        leafletClass={leafletClass}
                        boundsForScale={boundsForScale}
                        zonePrototype={zonePrototype}
                        zoneSublocation={zoneSublocation}
                        selectFloorplan={selectFloorplan}
                        selectedFloorplan={selectedFloorplan}
                        unSelectFloorplan={unSelectFloorplan}
                        setLeafletToState={setLeafletToState}
                    />
                </div>
            </div>
            <div className="Form-Buttons">
                <button
                    type="button"
                    data-id="zone-details-close"
                    onClick={close}
                >
                    {COMPONENTS.BUTTONS.CLOSE}
                </button>
            </div>
        </form>
    );
};

ZoneDetailsAdminPageForm.propTypes = {
    close: PropTypes.func,
    selectFloorplan: PropTypes.func,
    unSelectFloorplan: PropTypes.func,
    params: PropTypes.shape({
        zone_alarm_level: PropTypes.number,
        sublocation_name_display: PropTypes.string,
        name: PropTypes.string,
        zone_geometry: PropTypes.shape({
            positions: PropTypes.array,
        }),
        active: PropTypes.bool,
        zone_type_name: PropTypes.string,
        zone_type: PropTypes.shape({
            name: PropTypes.string,
        }),
        default_allowed: PropTypes.bool,
        sublocation_uid: PropTypes.string,
        trackable_object_uid: PropTypes.oneOfType([
            PropTypes.string,
            PropTypes.instanceOf(undefined),
        ]),
    }),
    className: PropTypes.string,
    sublocations: PropTypes.arrayOf(PropTypes.object),
    zones: PropTypes.arrayOf(PropTypes.shape()),
    floorplans: PropTypes.arrayOf(PropTypes.object),
    zonePrototype: PropTypes.shape(),
    selectedFloorplan: PropTypes.shape(),
    zone_display_name: PropTypes.string,
    trackables: PropTypes.arrayOf(PropTypes.shape()),
    groups: PropTypes.arrayOf(PropTypes.shape()),
    boundsForScale: PropTypes.shape(),
    onMove: PropTypes.func,
    zoom: PropTypes.number,
    direction: PropTypes.number,
    setLeafletToState: PropTypes.func,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

ZoneDetailsAdminPageForm.defaultProps = {
    close: () => {
    },
    selectFloorplan: () => {
    },
    unSelectFloorplan: () => {
    },
    params: {
        zone_alarm_level: 1,
        sublocation_name_display: '',
        name: '',
        zone_geometry: {
            positions: [],
        },
        active: false,
        zone_type_name: '',
        zone_type: {
            name: '',
        },
        default_allowed: true,
        sublocation_uid: '',
        trackable_object_uid: '',
    },
    className: '',
    sublocations: [{}],
    zones: [],
    floorplans: [{}],
    zonePrototype: {},
    selectedFloorplan: {},
    direction: 0,
    zone_display_name: '',
    trackables: [{}],
    groups: [{}],
    boundsForScale: {},
    onMove: () => {
    },
    zoom: DEFAULT_VALUES.MAP_ZOOM.DEFAULT,
    setLeafletToState: () => {
    },
    intl: {
        formatMessage: () => {},
    },
};

ZoneDetailsAdminPageForm = reduxForm({
    form: NAME_OF_FORMS.ZONE_DETAILS,
})(ZoneDetailsAdminPageForm);

const mapStateToForm = (state) => {
    const { params } = state.modals.zoneModals.zoneDetailsAdminPage;
    const zone_type_id = params && params.zone_type_id;
    const direction = params && params.user_params && params.user_params.direction;
    const zonePrototype = ZonePrototype.getZonePrototypeById(zone_type_id);

    return {
        direction,
        zone_type_id,
        zonePrototype,
        appContext: state.appContext,
        groups: getParsedGroups(state),
        zones: Zone.getAllZonesArray(state),
        trackables: getParsedTrackables(state),
        zone_type_name: zonePrototype ? zonePrototype.zone_type.name : '',
        selectedFloorplan: state.modals.zoneModals.zoneDetailsAdminPage.floorplan,
        floorplans: Floorplan.getAllFloorplans(state) || [],
        sublocations: Sublocation.getAllSublocations(state) || [],
        zone_display_name: zonePrototype ? zonePrototype.zone_type.display_name : '',
    };
};

ZoneDetailsAdminPageForm = connect(mapStateToForm)(injectIntl(ZoneDetailsAdminPageForm));

export default ZoneDetailsAdminPageForm;
