import React from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';

import {
    editAdminPageZone,
    closeZoneEditAdminPageModal,
    selectFloorplanZoneEditPageModal,
    unSelectFloorplanZoneEditPageModal,
} from 'stores/actions';
import { makeCopy } from 'utils/simpleUtils';
import ZoneEditAdminPageForm from './ZoneEditAdminPageForm';


class ZoneEditAdminPageModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        zoneEdit: PropTypes.shape({
            params: PropTypes.shape({
                name: PropTypes.string,
            }),
            open: PropTypes.bool,
            floorplan: PropTypes.shape({}),
        }),
        style: PropTypes.shape(),
    };

    static defaultProps = {
        dispatch: () => {
        },
        zoneEdit: {
            params: {
                name: '',
            },
            open: false,
            floorplan: {},
        },
        style: {},
    };

    floorplanSelect = (floorplan) => {
        this.props.dispatch(selectFloorplanZoneEditPageModal(floorplan));
    };

    floorplanUnSelect = () => {
        this.props.dispatch(unSelectFloorplanZoneEditPageModal());
    };

    close = () => {
        this.props.dispatch(closeZoneEditAdminPageModal());
    };

    submit = (params) => {
        this.props.dispatch(editAdminPageZone(params));
    };

    render() {
        const { style } = this.props;

        const currentStyle = makeCopy(style);
        currentStyle.content.width = '85%';
        currentStyle.content.top = '50%';
        currentStyle.content.height = '80vh';

        const title = this.props.zoneEdit.params ? this.props.zoneEdit.params.name : ' ';
    
        return (
            <Modal
                contentLabel="userDetails"
                isOpen={this.props.zoneEdit.open}
                onRequestClose={this.close}
                style={currentStyle}
            >
                <div className="RPP-Modal">
                    <span
                        className="Modal-Header multiple-lines-ellipsis"
                        data-id="zone-edit-admin-page-title"
                    >
                        {title}
                    </span>
                    <ZoneEditAdminPageForm
                        close={this.close}
                        onSubmit={this.submit}
                        params={this.props.zoneEdit.params}
                        selectFloorplan={this.floorplanSelect}
                        selectedFloorplan={this.props.zoneEdit.floorplan}
                        unSelectFloorplan={this.floorplanUnSelect}
                        maxHeight="67vh"
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    zoneEdit: state.modals.zoneModals.zoneEditAdminPage,
});

export default connect(mapStateToProps)(ZoneEditAdminPageModal);
