import React from 'react';
import PropTypes from 'prop-types';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';

import { NAME_OF_FORMS } from '../../common/constants';
import { ZONE_NOTIFY_NO_CREATION_MODAL, COMPONENTS } from '../../common/ui-labels';
import { closeZoneNotifyNoCreationModal } from '../../stores/actions/index';

let ZoneNotifyNoCreationForm = (props) => {
    const { close, className } = props;
    return (
        <form className={className}>
            <div className="Form-Confirmation">
                {ZONE_NOTIFY_NO_CREATION_MODAL.FORM.CONFIRMATION}
            </div>
            <div className="Form-DeleteTitle">
                {ZONE_NOTIFY_NO_CREATION_MODAL.FORM.TITLE}
            </div>
            <div className="Form-Buttons">
                <button type="button" data-id="zone-notify-no-creation-ok" onClick={close}>{COMPONENTS.BUTTONS.OK}</button>
            </div>
        </form>
    );
};

ZoneNotifyNoCreationForm.propTypes = {
    close: PropTypes.func,
    className: PropTypes.string,
};

ZoneNotifyNoCreationForm.defaultProps = {
    close: () => {
    },
    className: '',
};

ZoneNotifyNoCreationForm = reduxForm({
    form: NAME_OF_FORMS.ZONE_NOTIFY_NO_CREATION,
})(ZoneNotifyNoCreationForm);

ZoneNotifyNoCreationForm = connect()(ZoneNotifyNoCreationForm);

class ZoneNotifyNoCreationModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        zoneNotifyNoCreation: PropTypes.shape({
            open: PropTypes.bool,
        }),
        style: PropTypes.shape(),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        zoneNotifyNoCreation: {
            open: false,
        },
        style: {},
    };
    
    close = () => {
        this.props.dispatch(closeZoneNotifyNoCreationModal());
    };
    
    render() {
        const { style } = this.props;
    
        return (
            <Modal
                contentLabel="nodeError"
                isOpen={this.props.zoneNotifyNoCreation.open}
                onRequestClose={this.close}
                style={style}
            >
                <div className="RPP-Modal">
                    <ZoneNotifyNoCreationForm
                        className="Modal-Form"
                        close={this.close}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    zoneNotifyNoCreation: state.modals.zoneModals.zoneNotifyNoCreation,
});

export default connect(mapStateToProps)(ZoneNotifyNoCreationModal);
