import React from 'react';
import Modal from 'react-modal';
import { connect } from 'react-redux';
import { reduxForm } from 'redux-form';
import PropTypes from 'prop-types';

import { NAME_OF_FORMS, ZONE_VERTICES_LIMIT_MODAL } from 'common';
import { closeZoneVerticesLimitModal } from 'stores/actions';
import { getVerticesLimit } from 'utils/zoneUtils';


let ZoneVerticesLimitForm = (props) => {
    const { className, finishDraw, close, undoDraw } = props;
    
    return (
        <form className={className}>
            <div className="Form-Buttons">
                <button
                    type="button"
                    data-id="zone-choose-next"
                    onClick={finishDraw}
                >
                    {ZONE_VERTICES_LIMIT_MODAL.YES_BUTTON}
                </button>
                <button type="button" data-id="zone-choose-undo" onClick={undoDraw}>{ZONE_VERTICES_LIMIT_MODAL.UNDO_DRAWING_BUTTON}</button>
                <button type="button" data-id="zone-choose-cancel" onClick={close}>{ZONE_VERTICES_LIMIT_MODAL.CANCEL_DRAWING_BUTTON}</button>
            </div>
        </form>
    );
};

ZoneVerticesLimitForm.propTypes = {
    close: PropTypes.func,
    className: PropTypes.string,
    finishDraw: PropTypes.func,
    undoDraw: PropTypes.func,
};

ZoneVerticesLimitForm.defaultProps = {
    close: () => {
    },
    finishDraw: () => {
    },
    undoDraw: () => {
    },
    className: '',
};

ZoneVerticesLimitForm = reduxForm({
    form: NAME_OF_FORMS.ZONE_VERTICES_LIMIT,
})(ZoneVerticesLimitForm);

const mapStateToForm = state => (
    {
        formState: state.form,
    }
);

ZoneVerticesLimitForm = connect(mapStateToForm)(ZoneVerticesLimitForm);


class ZoneVerticesLimitModal extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        currentProject: PropTypes.shape({}),
        style: PropTypes.shape({
            overlay: PropTypes.object,
            content: PropTypes.object,
        }),
        zoneVerticesLimit: PropTypes.shape({
            open: PropTypes.bool,
            finishDraw: PropTypes.func,
            cancelDraw: PropTypes.func,
        }),
    };

    static defaultProps = {
        dispatch: () => {
        },
        currentProject: null,
        style: {
            overlay: {},
            content: {},
        },
        zoneVerticesLimit: {
            open: false,
            finishDraw: () => { },
            cancelDraw: () => { },
        },
    };

    finishDraw = () => {
        const { zoneVerticesLimit } = this.props;
        if (typeof zoneVerticesLimit.finishDraw === 'function') {
            zoneVerticesLimit.finishDraw();
        }
        this.props.dispatch(closeZoneVerticesLimitModal());
    };
    
    undoDraw = () => {
        const { zoneVerticesLimit } = this.props;
        if (typeof zoneVerticesLimit.undoDraw === 'function') {
            zoneVerticesLimit.undoDraw();
        }
        this.props.dispatch(closeZoneVerticesLimitModal());
    };
    
    cancelDraw = () => {
        const { zoneVerticesLimit } = this.props;
        
        if (typeof zoneVerticesLimit.cancelDraw === 'function') {
            zoneVerticesLimit.cancelDraw();
        }
        this.props.dispatch(closeZoneVerticesLimitModal());
    };

    render() {
        const { style, zoneVerticesLimit, currentProject } = this.props;
        return (
            <Modal
                contentLabel="zoneVerticesLimit"
                isOpen={zoneVerticesLimit.open}
                onRequestClose={this.cancelDraw}
                style={style}
            >
                
                <div className="RPP-Modal">
                    <span className="Modal-Header" data-id="zone-vertices-limit-title">
                        {ZONE_VERTICES_LIMIT_MODAL.TITLE}
                    </span>
                    <div className="Modal-Header2" data-id="zone-vertices-limit-text">
                        {ZONE_VERTICES_LIMIT_MODAL.TEXT(getVerticesLimit(currentProject))}
                    </div>
                    <div className="Modal-Text-Big" data-id="zone-vertices-limit-question">
                        {ZONE_VERTICES_LIMIT_MODAL.QUESTION}
                    </div>
                    
                    <ZoneVerticesLimitForm
                        className="Modal-Form"
                        close={this.cancelDraw}
                        finishDraw={this.finishDraw}
                        undoDraw={this.undoDraw}
                    />
                </div>
            </Modal>
        );
    }
}

const mapStateToProps = state => ({
    zoneVerticesLimit: state.modals.zoneModals.zoneVerticesLimit,
    currentProject: state.appContext.project,
});

export default connect(mapStateToProps)(ZoneVerticesLimitModal);
