import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { Route, Switch } from 'react-router-dom';
import { push } from 'connected-react-router';
import { changeLastAdminPath, clearAdminPageSelectedItems } from 'stores/actions';
import { ROUTES } from 'common';
import { getLocalStorageValue } from 'utils';
import { STORAGE_KEY } from 'common/constants';
import admin_tabs from './tabs';


class AdminPageContent extends Component {
    static propTypes = {
        dispatch: PropTypes.func,
        currentPath: PropTypes.string,
        tabs: PropTypes.arrayOf(PropTypes.shape()),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        currentPath: '',
        tabs: [],
    };
    
    componentDidMount() {
        const { currentPath, tabs } = this.props;
        if (currentPath === ROUTES.ADMIN_ROUTE) {
            const paths = tabs.map(tab => tab.path);
            this.navigateToRoute(paths[0]);
        }
    }

    componentDidUpdate() {
        const { currentPath } = this.props;
        if (currentPath === ROUTES.ADMIN_ROUTE) {
            const lastPagePath = getLocalStorageValue(STORAGE_KEY.LAST_PAGE);
            this.navigateToRoute(lastPagePath);
        }
        return null;
    }

    componentWillUnmount() {
        this.props.dispatch(clearAdminPageSelectedItems());
    }
    
    navigateToRoute = (path) => {
        this.props.dispatch(changeLastAdminPath(path));
        this.props.dispatch(push(path));
    };
    
    render() {
        return (
            <div className="AppLayout-Admin Admin-Tabs row">
                <Switch>
                    {
                        this.props.tabs.map(tab => (
                            <Route
                                key={tab.path}
                                path={tab.path}
                                component={admin_tabs[tab.systemName]}
                            />
                        ))
                    }
                </Switch>
            </div>
        );
    }
}

const mapStateToProps = state => ({
    tabs: state.user.scope.pages.find(page => page.path === ROUTES.ADMIN_ROUTE).tabs,
    currentPath: state.router.location.pathname,
});

export default connect(mapStateToProps)(AdminPageContent);
