import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { injectIntl } from 'react-intl';

import { TABLES } from '../../../../common';
import { openAddNodeModal, openImportNodeModal, openDeleteNodeModal } from '../../../../stores/actions';

class TableButtons extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        setFilterItems: PropTypes.func,
        width: PropTypes.number,
        items: PropTypes.arrayOf(PropTypes.shape()),
        selectedItems: PropTypes.arrayOf(PropTypes.shape()),
        searchFields: PropTypes.arrayOf(PropTypes.string),
        intl: PropTypes.shape({
            formatMessage: PropTypes.func,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        setFilterItems: () => {
        },
        width: 1000,
        items: [],
        selectedItems: [],
        searchFields: [],
        intl: {
            formatMessage: () => {
            },
        },
    };
    
    constructor(props) {
        super(props);
        
        this.timeout = null;
    }

    createAddDeleteBtn = () => (
        <section className="Table">
            <i
                className="fas fa-trash-alt fa-lg table-action-icon"
                data-id="tags-remove-button"
                onClick={this.openMultiDeleteModal}
            />
            <i
                className="fas fa-file-upload fa-lg table-action-icon"
                data-id="tags-import-button"
                data-cy="tag-table-import-button"
                onClick={this.openImportModal}
            />
            <i
                className="fa fa-plus fa-lg table-action-icon"
                data-id="tags-plus-button"
                data-cy="tag-table-add-button"
                onClick={this.openAddModal}
            />
        </section>
    );
    
    createCustomSearchField = () => (
        <input
            type="text"
            className="form-control input-sm"
            data-cy="tag-table-search"
            placeholder={TABLES.SEARCH(this.props.intl)}
            onChange={(e) => {
                const value = e.target.value;
                const regex = new RegExp(value, 'i');
                clearTimeout(this.timeout);
                
                this.timeout = setTimeout(() => {
                    const filteredItems = [...this.props.items.values()]
                        .filter(item => this.props.searchFields.some(field => item[field].match(regex)));
                    this.props.setFilterItems(filteredItems, !!(value && value.length));
                }, 600);
            }}
        />
    );

    openMultiDeleteModal = () => {
        // const params = [];
        const params = this.props.selectedItems.reduce((memo, item) => {
            const node = this.props.items.find(node_x => node_x.uid === item.uid);
            if (node) {
                memo.push({
                    mac_address: node.mac_address,
                    uid: node.uid,
                });
            }
            return memo;
        }, []);
        if (params.length > 0) {
            this.props.dispatch(openDeleteNodeModal(params));
        }
    };

    openAddModal = () => {
        this.props.dispatch(openAddNodeModal());
    };

    openImportModal = () => {
        this.props.dispatch(openImportNodeModal());
    };

    render() {
        return (
            <div className="Table row row-head-box">
                <div className="col-md-8">{this.createAddDeleteBtn()}</div>
                <div className="col-md-4 text-right">{this.createCustomSearchField()}</div>
            </div>
        );
    }
}

export default connect()(injectIntl(TableButtons));
