import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { injectIntl } from 'react-intl';

import { TABLES } from '../../../../common';

class TableButtons extends React.Component {
    static propTypes = {
        setFilterItems: PropTypes.func,
        width: PropTypes.number,
        items: PropTypes.arrayOf(PropTypes.shape()),
        searchFields: PropTypes.arrayOf(PropTypes.string),
        intl: PropTypes.shape({
            formatMessage: PropTypes.func,
        }),
    };
    
    static defaultProps = {
        setFilterItems: () => {
        },
        width: 1000,
        items: [],
        searchFields: [],
        intl: {
            formatMessage: () => {
            },
        },
    };
    
    constructor(props) {
        super(props);
        
        this.timeout = null;
    }

    createCustomSearchField = () => (
        <input
            type="text"
            className="form-control input-sm"
            placeholder={TABLES.SEARCH(this.props.intl)}
            onChange={(e) => {
                const value = e.target.value;
                const regex = new RegExp(value, 'i');
                clearTimeout(this.timeout);
                
                this.timeout = setTimeout(() => {
                    const filteredItems = [...this.props.items.values()]
                        .filter(item => this.props.searchFields.some(field => item[field].match(regex)));
                    this.props.setFilterItems(filteredItems, !!(value && value.length));
                }, 600);
            }}
        />
    );

    render() {
        return (
            <div className="Table row row-head-box">
                <div className="col-md-8" />
                <div className="col-md-4 text-right">{this.createCustomSearchField()}</div>
            </div>
        );
    }
}

export default connect()(injectIntl(TableButtons));
