import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { injectIntl } from 'react-intl';
import { TABLES, ZONE_BULK_EDIT } from 'common/ui-labels';
import { openZoneChooseAreaModal, openZoneCreateAdminPageModal, openZoneDeleteModal, openZoneEditBulkModal } from 'stores/actions';

class TableButtons extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        setFilterItems: PropTypes.func,
        width: PropTypes.number,
        items: PropTypes.arrayOf(PropTypes.shape({})),
        selectedItems: PropTypes.arrayOf(PropTypes.shape({})),
        searchFields: PropTypes.arrayOf(PropTypes.string),
        intl: PropTypes.shape({
            formatMessage: PropTypes.func,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {},
        setFilterItems: () => {},
        width: 1000,
        items: [],
        selectedItems: [],
        searchFields: [],
        intl: {
            formatMessage: () => {
            },
        },
    };
    
    constructor(props) {
        super(props);
        
        this.timeout = null;
    }
    
    openMultiDeleteModal = () => {
        if (this.props.selectedItems.length) {
            this.props.dispatch(openZoneDeleteModal(this.props.selectedItems));
        }
    };
    
    openCreateModal = () => {
        this.props.dispatch(openZoneCreateAdminPageModal());
        this.props.dispatch(openZoneChooseAreaModal());
    };

    openBulkEditModal = () => {
        this.props.dispatch(openZoneEditBulkModal(this.props.selectedItems));
    };

    createAddDeleteBtn = () => {
        const disableBulkAction = this.props.selectedItems.length <= 1;
        return (
            <section className="Table">
                <i
                    className="fas fa-trash-alt fa-lg table-action-icon"
                    data-id="zones-button-trash"
                    onClick={this.openMultiDeleteModal}
                />
                <i
                    className="fa fa-plus fa-lg table-action-icon"
                    data-id="zones-button-plus"
                    onClick={this.openCreateModal}
                />
                <button
                    className={`unstyled-button ${disableBulkAction ? 'disabled' : ''}`}
                    data-id="zones-batch-edit-button table-action-icon"
                    onClick={this.openBulkEditModal}
                    disabled={disableBulkAction}
                    title={ZONE_BULK_EDIT.BUTTON_TITLE_FUNC(this.props.intl)}
                >
                    <i className="far fa-list-alt fa-lg table-action-icon" />
                </button>
            </section>)
    };
    
    createCustomSearchField = () => (
        <input
            type="text"
            data-cy="zone-table-search"
            className="form-control input-sm"
            placeholder={TABLES.SEARCH(this.props.intl)}
            onChange={(e) => {
                const { value } = e.target;
                const regex = new RegExp(value, 'i');
                clearTimeout(this.timeout);
                this.timeout = setTimeout(() => {
                    const filteredItems = [...this.props.items.values()]
                        .filter(item => this.props.searchFields.some(field => item[field].match(regex)));
                    this.props.setFilterItems(filteredItems, value);
                }, 600);
            }}
        />
    );

    render() {
        return (
            <div className="Table row row-head-box">
                <div className="col-md-8">{this.createAddDeleteBtn()}</div>
                <div className="col-md-4 text-right">{this.createCustomSearchField()}</div>
            </div>
        );
    }
}

export default connect()(injectIntl(TableButtons));
