import React, { useEffect, useState } from 'react';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import _IsEqual from 'lodash/isEqual';
import { minToMs, getTimeZoneOfProject } from 'utils/timeUtils';
import { getActiveShiftBySiteUid } from 'utils/utils';
import WidgetsContainer from './WidgetsContainer';
import PageHeader from './PageHeader';


const DashboardPageContent = (props) => {
    const { selectedSite, selectedArea, timeZone, locations, activityWidgetLoading, widgets } = props;
    const [activeShift, setActiveShift] = useState(null);
    const currentShift = selectedSite && getActiveShiftBySiteUid(selectedSite.uid, locations, timeZone);
    if (!_IsEqual(currentShift, activeShift)) {
        setActiveShift(currentShift);
    }

    useEffect(() => {
        const interval = setInterval(() => {
            const currentActiveShift = selectedSite && getActiveShiftBySiteUid(selectedSite.uid, locations, timeZone);
            if (!_IsEqual(currentActiveShift, activeShift)) {
                setActiveShift(currentActiveShift);
            }
        }, minToMs(1));
        return () => clearInterval(interval);
    }, [activeShift, selectedSite]);

    return (
        <div className="AppLayout-Dashboard">
            <PageHeader
                activeShift={activeShift}
                selectedSiteName={selectedSite ? selectedSite.name : undefined}
                selectedAreaName={selectedArea ? selectedArea.name : undefined}
                timeZone={timeZone}
            />
            <WidgetsContainer
                widgets={widgets}
                activityWidgetLoading={activityWidgetLoading}
                activeShift={activeShift}
            />
        </div>
    );
};

DashboardPageContent.propTypes = {
    locations: PropTypes.arrayOf(PropTypes.shape({})),
    timeZone: PropTypes.string,
    selectedSite: PropTypes.shape({}),
    selectedArea: PropTypes.shape({}),
    widgets: PropTypes.arrayOf(PropTypes.object),
    activityWidgetLoading: PropTypes.bool,
};

DashboardPageContent.defaultProps = {
    locations: [],
    timeZone: '',
    selectedSite: {},
    selectedArea: {},
    widgets: [{}],
    activityWidgetLoading: false,
};

const mapStateToProps = state => ({
    locations: state.entities.locations,
    widgets: state.dashboard.widgets,
    activityWidgetLoading: state.dashboard.activityWidgetLoading,
    timeZone: getTimeZoneOfProject(state.appContext.project),
    selectedSite: state.siteView.selectedLocation,
    selectedArea: state.siteView.selectedSublocation,
});

export default connect(mapStateToProps)(DashboardPageContent);
