import React from 'react';
import PropTypes from 'prop-types';
import { getDataForScaling, getTimeByFormatAndTimezone } from 'utils/timeUtils';


export default function AttendanceScaleHours(props) {
    const { start, end, width, timezone } = props;
    const { firstIntervalWidth, intervalWidth, lastIntervalWidth, fullHours, firstHour, lastHour } = getDataForScaling(start, end, width);

    return (
        <div className="time-line-scaling-wrapper">
            {
                !!firstIntervalWidth &&
                <div
                    className="time-line-scaling"
                    style={{ width: firstIntervalWidth, textOverflow: 'ellipsis', overflow: 'hidden' }}
                >
                    {getTimeByFormatAndTimezone(start, 'HH:mm', timezone)}
                </div>
            }
            {
                Array(fullHours).fill().map((el, index) => (
                    <div key={index} className="time-line-scaling" style={{ width: intervalWidth }}>
                        {getTimeByFormatAndTimezone(firstHour + (index * 3600000), 'HH:mm', timezone)}
                    </div>
                ))
            }
            {
                !!lastIntervalWidth &&
                <div
                    className="time-line-scaling"
                    style={{ width: lastIntervalWidth, textOverflow: 'ellipsis', overflow: 'hidden' }}
                >
                    {getTimeByFormatAndTimezone(lastHour, 'HH:mm', timezone)}
                </div>
            }
            {getTimeByFormatAndTimezone(end, 'HH:mm', timezone)}
        </div>);
}


AttendanceScaleHours.propTypes = {
    start: PropTypes.number,
    end: PropTypes.number,
    width: PropTypes.number,
    timezone: PropTypes.string,
};

AttendanceScaleHours.defaultProps = {
    start: 0,
    end: 0,
    width: 0,
    timezone: 'Etc/GMT',
};

