import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import DatePicker from 'antd/es/date-picker';
import { BootstrapTable, TableHeaderColumn } from 'react-bootstrap-table';
import { getActionFromDB } from '../../stores/actions';
import { DEFAULT_VALUES } from './../../common';
import { columnFormatter, mapFormatter } from './formatters';

const { RangePicker } = DatePicker;

class ActivitiesTab extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        data: PropTypes.arrayOf(PropTypes.shape()),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        data: [],
    };
    
    onOk = (value) => {
        const to = value[1].toDate().getTime();
        const from = value[0].toDate().getTime();
        
        this.props.dispatch(getActionFromDB({
            from,
            to,
        }));
    };
    
    formatCreatedBy = cell => <div style={{ overflowX: 'auto' }}>{cell && cell.email}</div>;
    
    render() {
        const { data } = this.props;
        
        return (
            <div className="AppLayout-Admin-Tab col-md-12">
                <h3 className="text-center AdminTab-Title"> ACTIONS IN DATABASE </h3>
                <h4 className="text-center AdminTab-Subtitle">
                    <RangePicker
                        showTime={{ format: 'HH:mm' }}
                        format="YYYY-MM-DD HH:mm"
                        placeholder={['Start Time', 'End Time']}
                        onOk={this.onOk}
                    />
                </h4>
                
                <hr />
                <BootstrapTable
                    data={data}
                    bodyStyle={{ overflowX: 'auto' }}
                    bodyContainerClass="Admin-BootstrapTable"
                    pagination
                    condensed
                    striped
                    search
                    hover
                >
                    <TableHeaderColumn
                        dataField="id"
                        searchable={false}
                        hidden
                        isKey
                    >
                        ID
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="created_at"
                        width="180"
                        headerAlign="center"
                        dataSort
                    >
                        Created at
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="created_by"
                        dataFormat={this.formatCreatedBy}
                        width="200"
                        dataAlign="center"
                        headerAlign="center"
                        dataSort
                    >
                        Created by
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="action"
                        dataAlign="center"
                        width="130"
                        headerAlign="center"
                    >
                        Action
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="object"
                        width="130"
                        dataFormat={columnFormatter}
                        headerAlign="center"
                        dataAlign="center"
                    >
                        Object
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="plist"
                        dataFormat={mapFormatter}
                        headerAlign="center"
                    >
                        Plist
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="project_uid"
                        width="130"
                        dataFormat={columnFormatter}
                        headerAlign="center"
                        dataAlign="center"
                    >
                        Project UID
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="company_uid"
                        width="130"
                        dataFormat={columnFormatter}
                        headerAlign="center"
                        dataAlign="center"
                    >
                        Company UID
                    </TableHeaderColumn>
                </BootstrapTable>
            </div>
        );
    }
}

const mapStateToProps = state => ({
    data: state.loggerPage.actions ? state.loggerPage.actions : DEFAULT_VALUES.empty_array,
});

export default connect(mapStateToProps)(ActivitiesTab);
