import React from 'react';
import moment from 'moment';
import * as api from 'api';
import DatePicker from 'antd/es/date-picker';
import { BootstrapTable, TableHeaderColumn } from 'react-bootstrap-table';

class LogsTab extends React.Component {
    state = {
        logs: [],
    };
    
    selectMonth = (date) => {
        api.getLoggerFileContent(date.valueOf())
            .then((data) => {
                let rows = data.data.split('\n');
                const rxp = /\[.*?\]/g;
                if (rows && Array.isArray(rows)) {
                    rows = rows.map((row, index) => {
                        let matches = row.match(rxp);
                        let from = 0;
                        if (matches && Array.isArray(matches)) {
                            from = (matches[0] ? matches[0].length : 0) + (matches[1] ? matches[1].length : 0) + 1;
                        } else {
                            matches = ['', ''];
                        }
                        return {
                            id: index,
                            date: matches[0],
                            level: matches[1],
                            description: row.substr(from, row.length),
                        };
                    });
                } else {
                    rows = [];
                }
                
                this.setState({ logs: rows });
            });
    };
    
    render() {
        const dateFormat = 'YYYY/MM/DD';
        const now = moment();
        
        return (
            <div className="AppLayout-Admin-Tab col-md-12">
                <h3 className="text-center AdminTab-Title"> LOGS FROM LOG FILE </h3>
                <h4 className="text-center AdminTab-Subtitle">
                    <DatePicker
                        onChange={this.selectMonth}
                        defaultValue={now}
                        format={dateFormat}
                    />
                </h4>
                
                <hr />
                <BootstrapTable
                    data={this.state.logs}
                    bodyStyle={{ overflow: 'auto' }}
                    bodyContainerClass="Admin-BootstrapTable"
                    pagination
                    condensed
                    striped
                    search
                    hover
                >
                    <TableHeaderColumn
                        dataField="id"
                        searchable={false}
                        hidden
                        isKey
                    >
                        ID
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="date"
                        width="200"
                        headerAlign="center"
                        dataSort
                    >
                        Date
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="level"
                        width="100"
                        dataAlign="center"
                        headerAlign="center"
                    >
                        Log level
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="description"
                        headerAlign="center"
                    >
                        Description
                    </TableHeaderColumn>
                </BootstrapTable>
            </div>
        );
    }
}

export default LogsTab;
