import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';

import { getMessageProcessorState } from '../../stores/actions';
import MessageProcessorGeneralMapTable from './MessageProcessorGeneralMapTable';

const SIDE = {
    LEFT: 'left',
    RIGHT: 'right',
};

const customColumnsForMaps = {
    scheduleMap: [],
    zonesMap: [],
    objectMap: [{
        dataField: 'name',
        width: '150',
        display: 'Name',
    }],
    associationsAddressMap: [{
        dataField: 'trob_uid',
        width: '150',
        display: 'Object uid',
    }],
    sublocationsMap: [{
        dataField: 'name',
        width: '150',
        display: 'Name',
    }, {
        dataField: 'uid',
        width: '150',
        display: 'Uid',
    }],
    locationsMap: [{
        dataField: 'name',
        width: '150',
        display: 'Name',
    }, {
        dataField: 'uid',
        width: '150',
        display: 'Uid',
    }],
    nodesMap: [{
        dataField: 'name',
        width: '150',
        display: 'Name',
    }],
};

const customPropTypes = PropTypes.shape({
    dataField: PropTypes.string,
    width: PropTypes.string,
    display: PropTypes.string,
});

class MessageProcessorTab extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        messageProcessor: PropTypes.shape({
            get: PropTypes.func,
            scheduleMap: PropTypes.arrayOf(PropTypes.shape({})),
            zonesMap: PropTypes.arrayOf(PropTypes.shape({})),
            objectMap: PropTypes.arrayOf(PropTypes.shape({})),
            associationsAddressMap: PropTypes.arrayOf(PropTypes.shape({})),
            sublocationsMap: PropTypes.arrayOf(PropTypes.shape({})),
            locationsMap: PropTypes.arrayOf(PropTypes.shape({})),
            nodesMap: PropTypes.arrayOf(PropTypes.shape({})),
        }),
        mpSnapshotsTimes: PropTypes.arrayOf(PropTypes.string),
        columns: PropTypes.shape({
            scheduleMap: PropTypes.arrayOf(customPropTypes),
            zonesMap: PropTypes.arrayOf(PropTypes.shape(customPropTypes)),
            objectMap: PropTypes.arrayOf(PropTypes.shape(customPropTypes)),
            associationsAddressMap: PropTypes.arrayOf(PropTypes.shape(customPropTypes)),
            sublocationsMap: PropTypes.arrayOf(PropTypes.shape(customPropTypes)),
            locationsMap: PropTypes.arrayOf(PropTypes.shape(customPropTypes)),
            nodesMap: PropTypes.arrayOf(PropTypes.shape(customPropTypes)),
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        messageProcessor: new Map(),
        mpSnapshotsTimes: [],
        columns: [],
    };
    
    constructor(props) {
        super(props);
        
        this.state = {
            // selected Maps key in each side
            right: '',
            left: '',
            
            // side keys
            rightKeys: [],
            leftKeys: [],
    
            // selected Map
            rightMap: [],
            leftMap: [],
    
            // selected Date
            leftSelectedDate: '',
            rightSelectedDate: '',
        };
    }
    
    /**
     *
     * @param side {string} see SIDE const
     * @param e {object} select event
     */
    onSelectSideDate = (side, e) => {
        const selectedDate = e.target.value;
        const currentDateMaps = this.props.messageProcessor.get(selectedDate);
        if (currentDateMaps) {
            const maps = currentDateMaps[selectedDate];
            this.setState({
                [`${side}Keys`]: Object.keys(currentDateMaps),
                [`${side}SelectedMap`]: maps,
                [`${side}SelectedDate`]: selectedDate,
            });
        }
    };
    
    /**
     *
     * @param side {string} see SIDE const
     * @param mapName
     */
    onChangedSideMap = (side, mapName) => {
        const currentDateMaps = this.props.messageProcessor.get(this.state[`${side}SelectedDate`]);
        if (currentDateMaps) {
            const maps = currentDateMaps[mapName];
            this.setState({
                [`${side}`]: mapName,
                [`${side}SelectedMap`]: maps,
            });
        }
    };
    
    getMessageProcessorStateClass = () => {
        this.props.dispatch(getMessageProcessorState());
    };
    
    /**
     *
     * @param mpSnapshotsTimes {string} timestamp
     * @param side {string} see SIDE const
     */
    renderSelectDateList = (mpSnapshotsTimes, side) => (
        <select
            className="form-control input-sm"
            onChange={this.onSelectSideDate.bind(this, side)}
        >
            <option />
            {mpSnapshotsTimes.map((time, index) => (
                <option key={index} value={time}>{time}</option>
            ))}
        </select>
    );
    
    /**
     *
     * @param mpKeys
     * @param side {string} see SIDE const
     */
    renderMapsButtons = (mpKeys, side) => (
        mpKeys.map((mapName, idx) => (
            <button
                key={idx}
                className={this.state[side] === mapName ? 'Control-Button-Selected' : 'Control-Button'}
                onClick={this.onChangedSideMap.bind(this, side, mapName)}
            >
                {mapName}
            </button>
        ))
    );

    render() {
        const { mpSnapshotsTimes, columns } = this.props;
        const {
            rightSelectedMap, leftSelectedMap,
            rightKeys, leftKeys,
            right, left,
        } = this.state;
    
        return (
            <div className="AppLayout-Logger-Tab col-md-12">
                <div className="row" style={{ marginBottom: '10px' }}>
                    <div className="col-md-4 text-center">
                        {this.renderSelectDateList(mpSnapshotsTimes, SIDE.LEFT)}
                    </div>
                    <div className="col-md-4 text-center">
                        <button className="Control-Button" onClick={this.getMessageProcessorStateClass}>
                            GET MESSAGE PROCESSOR STATE
                        </button>
                    </div>
                    <div className="col-md-4 text-center">
                        {this.renderSelectDateList(mpSnapshotsTimes, SIDE.RIGHT)}
                    </div>
                </div>
                
                <div className="row" style={{ marginBottom: '10px' }}>
                    <div className="col-md-6 text-center">
                        {this.renderMapsButtons(leftKeys, SIDE.LEFT)}
                    </div>
                    
                    <div className="col-md-6 text-center">
                        {this.renderMapsButtons(rightKeys, SIDE.RIGHT)}
                    </div>
                </div>
                
                <div className="col-md-6">
                    <MessageProcessorGeneralMapTable
                        title={left}
                        data={leftSelectedMap}
                        columns={columns[left] || []}
                    />
                </div>
                
                <div className="col-md-6">
                    <MessageProcessorGeneralMapTable
                        title={right}
                        data={rightSelectedMap}
                        columns={columns[right] || []}
                    />
                </div>
            </div>
        );
    }
}

const mapStateToProps = (state) => {
    const { messageProcessorState } = state.loggerPage;
    
    const mpSnapshotsTimes = messageProcessorState ? [...messageProcessorState.keys()] : [];
    
    return {
        messageProcessor: messageProcessorState,
        columns: customColumnsForMaps,
        mpSnapshotsTimes,
    };
};

export default connect(mapStateToProps)(MessageProcessorTab);
