import React from 'react';
import PropTypes from 'prop-types';
import { REPORTS_SIDE_BAR, REPORTS_SELECTOR } from 'common/ui-labels';
import { SERVER_REPORT_TYPES } from 'common/constants';
import ReportsLoader from 'components/ReportsLoader';
import AttendanceTable from './AttendanceTable';
import ReportMenu from '../ReportMenu';


function Attendance(props) {
    return (
        <div className="AppLayout-Selector">
            <ReportMenu
                title={REPORTS_SIDE_BAR.ATTENDANCE}
                subTitle={REPORTS_SELECTOR.ATTENDANCE_DESCRIPTION}
                type={SERVER_REPORT_TYPES.ATTENDANCE}
                isReady={props.status === 100}
                reportListLoading={props.reportListLoading}
                reports={props.reports}
                timezone={props.timezone}
                options={props.options}
                report_uid={props.report_uid}
            />
            {props.showProgress && <ReportsLoader status={props.status} />}
            {!props.showProgress && <div className="report-content row">
                <div className="col-lg-12 col-md-12">
                    <div style={{ textAlign: 'right', marginBottom: 5 }} />
                    <AttendanceTable status={props.status} />

                </div>
            </div>}
        </div>
    );
}

Attendance.propTypes = {
    showProgress: PropTypes.bool,
    status: PropTypes.number,
    reportListLoading: PropTypes.bool,
    timezone: PropTypes.string,
    report_uid: PropTypes.string,
    options: PropTypes.shape({}),
    reports: PropTypes.arrayOf(PropTypes.shape({})),
};

Attendance.defaultProps = {
    showProgress: false,
    status: 0,
    reportListLoading: false,
    timezone: 'Etc/GMT',
    report_uid: '',
    options: {},
    reports: [],
};

export default Attendance;
