import React from 'react';
import PropTypes from 'prop-types';
import moment from 'moment-timezone';
import { injectIntl } from 'react-intl';
import { connect } from 'react-redux';
import DatePicker from 'antd/es/date-picker';

import { setReportDate } from 'stores/actions/reportsActions/generalReportActions';
import { REPORTS_SELECTOR } from 'common/ui-labels';
import ExportButton from './ExportButton';
import Filter from './Filter';


class ActionBar extends React.Component {
    handleDateSelect = (date, dateString) => {
        const from = moment.tz(dateString, this.props.timezone).startOf('day').toISOString();
        const to = moment.tz(dateString, this.props.timezone).endOf('day').toISOString();
        
        this.props.dispatch(setReportDate({ from, to, selectedDay: dateString }, this.props.type));
    }
    
    render() {
        const { isDataReady, options, intl } = this.props;
        const selectedDay = (options && options.selectedDay) ? moment.tz(options.selectedDay, this.props.timezone) : null;

        return (
            <div className="reports-actionbar row-margin-bottom">
                <div className="report-actions row" style={{ marginBottom: 10 }}>
                    <div className="align-left align-actions col-sm-12 col-md-6 col-lg-5">
                        <DatePicker
                            allowClear={false}
                            onChange={this.handleDateSelect}
                            className="reports-actionbar-item date-picker"
                            placeholder={REPORTS_SELECTOR.SELECT_DAY(intl)}
                            defaultValue={selectedDay}
                        />
                        <div className="filter">
                            <Filter reportType={this.props.type} />
                        </div>
                    </div>
                    <div className="align-right">
                        <div className="col-md-6 col-sm-6 col-lg-6">
                            <ExportButton isDataReady={isDataReady} type={this.props.type} />
                        </div>
                    </div>
                </div>
            </div>
        );
    }
}

ActionBar.propTypes = {
    isDataReady: PropTypes.bool,
    timezone: PropTypes.string,
    options: PropTypes.shape({}),
    type: PropTypes.string,
    dispatch: PropTypes.func,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func,
    }),
};

ActionBar.defaultProps = {
    isDataReady: false,
    timezone: 'Etc/GMT',
    options: null,
    type: '',
    dispatch: () => {},
    intl: {
        formatMessage: () => {
        },
    },
};

export default connect()(injectIntl(ActionBar));
