import React, { Component, Fragment } from 'react';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import Select from 'react-select';
import _isEqual from 'lodash/isEqual';
import 'react-select/dist/react-select.css';
import { getReportsAdvancedFilterSelectAction } from 'stores/actions/reportsActions/generalReportActions';
import { getReportFilterOptions, filterSelectBoxOptions } from 'utils';


class AdvancedSelect extends Component {
    shouldComponentUpdate(nextProps) {
        const values_change = !_isEqual(nextProps.values, this.props.values);
        const options_change = !_isEqual(nextProps.options, this.props.options);
        const disabled_change = !_isEqual(nextProps.disabled, this.props.disabled);
        const loading_change = !_isEqual(nextProps.isLoading, this.props.isLoading);
        return values_change || options_change || disabled_change || loading_change;
    }
    
    componentDidUpdate(prevProps) {
        if (!prevProps.isLoading && this.props.isLoading) {
            this.onChange(null);
        }
    }
    
    onChange = (result) => {
        const { reportType, param_name } = this.props;
        const params = {};
        if (Array.isArray(result)) {
            params[param_name] = result.map(x => x.value);
        } else if (result) {
            params[param_name] = [result.value];
        } else {
            params[param_name] = null;
        }
        
        this.props.dispatch(getReportsAdvancedFilterSelectAction(reportType, params));
    };
    
    render() {
        const { options, label, placeholder, disabled, values, singleSelect, isLoading } = this.props;
        return (
            <Fragment>
                {
                    label && <div className="select-label-text">{label}</div>
                }
                <Select
                    isLoading={isLoading}
                    options={options}
                    filterOptions={filterSelectBoxOptions}
                    className="menu-outer-top"
                    multi={!singleSelect}
                    placeholder={placeholder}
                    value={singleSelect ? values[0] : values}
                    disabled={disabled || isLoading}
                    onChange={this.onChange}
                />
            </Fragment>
        );
    }
}

AdvancedSelect.propTypes = {
    options: PropTypes.arrayOf(PropTypes.shape()),
    values: PropTypes.arrayOf(PropTypes.shape()),
    label: PropTypes.string,
    param_name: PropTypes.string,
    placeholder: PropTypes.string,
    reportType: PropTypes.string,
    disabled: PropTypes.bool,
    singleSelect: PropTypes.bool,
    isLoading: PropTypes.bool,
    dispatch: PropTypes.func,
};

AdvancedSelect.defaultProps = {
    options: [],
    values: [],
    label: '',
    param_name: '',
    placeholder: '',
    reportType: '',
    disabled: false,
    isLoading: false,
    singleSelect: false,
    dispatch: () => {},
};

const mapStateToProps = (state, { reportType, param_name, options, singleSelect }) => {
    const report = getReportFilterOptions(state, reportType);
    const values = report[param_name] || [];
    return {
        singleSelect,
        values: values.map(value => options.find(option => option.value === value)),
    };
};

export default connect(mapStateToProps)(AdvancedSelect);
