import React, { useState } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import Menu from '@material-ui/core/Menu/index';
import MenuItem from '@material-ui/core/MenuItem/index';
import { REPORT_BUTTON, COMPONENTS } from 'common/ui-labels';
import { getReportCsv } from 'stores/actions/reportsActions/generalReportActions';
import { getReportParams } from 'utils';


function ExportButton(props) {
    const [isMenuOpened, setMenuOpen] = useState(null);
    return (
        <section>
            {
                <button
                    className="reports-actionbar-item action-button"
                    onClick={(event) => {
                        setMenuOpen(event.currentTarget);
                    }}
                    disabled={!props.isDataReady}
                >
                    <i className="fas fa-file-download" />
                    <span className="button-text-label">{COMPONENTS.BUTTONS.FULL_REPORT}</span>
                </button>
            }
            <Menu
                className="pdf-export-menu"
                anchorEl={isMenuOpened}
                open={Boolean(isMenuOpened)}
                onClose={() => {
                    setMenuOpen(null);
                }}
            >
                <MenuItem onClick={() => {
                    setMenuOpen(null);
                    props.dispatch(getReportCsv(props.data, props.report, props.project, props.company_name, props.type, props.userEmail));
                }}
                >
                    <span>{REPORT_BUTTON.EXPORT_CSV}</span>
                </MenuItem>
            </Menu>
        </section>
    );
}

ExportButton.propTypes = {
    isDataReady: PropTypes.bool,
    data: PropTypes.arrayOf(PropTypes.shape({})),
    report: PropTypes.shape({}),
    project: PropTypes.shape({}),
    company_name: PropTypes.string,
    type: PropTypes.string,
    userEmail: PropTypes.string,
    dispatch: PropTypes.func,
};

ExportButton.defaultProps = {
    isDataReady: false,
    data: [],
    report: null,
    project: null,
    company_name: '',
    type: '',
    userEmail: '',
    dispatch: () => {},
};

const mapStateToProps = (state, props) => {
    const reportInStore = getReportParams(state, props.type);
    return ({
        userEmail: state.user.onBehalf ? state.user.onBehalf.email : state.user.email,
        data: reportInStore.tableData,
        report: reportInStore.report,
        locations: state.entities.locations,
        project: state.appContext.project,
        company_name: state.appContext.company.name,
    });
};

export default connect(mapStateToProps)(ExportButton);
