import React from 'react';
import PropTypes from 'prop-types';
import { REPORTS_SIDE_BAR, SERVER_REPORT_TYPES, REPORTS_SELECTOR } from 'common';
import ReportsLoader from 'components/ReportsLoader';
import ReportMenu from 'pages/reports/ReportMenu';
import ZoneActivityTable from 'pages/reports/ZoneActivity/ZoneActivityTable';


function ZoneActivity(props) {
    return (
        <div className="AppLayout-Selector">
            <ReportMenu
                title={REPORTS_SIDE_BAR.ZONE_ACTIVITY}
                subTitle={REPORTS_SELECTOR.INFO_ZONE_DISCRIPTION}
                type={SERVER_REPORT_TYPES.ZONE_ACTIVITY_REPORT}
                isReady={props.status === 100}
                reportListLoading={props.reportListLoading}
                reports={props.reports}
                timezone={props.timezone}
                options={props.options}
                report_uid={props.report_uid}
            />
            {props.showProgress && <ReportsLoader status={props.status} />}
            {!props.showProgress && <div className="report-content row">
                <div className="col-lg-12 col-md-12">
                    <div style={{ textAlign: 'right', marginBottom: 5 }} />
                    <ZoneActivityTable status={props.status} />
                </div>
            </div>}
        </div>
    );
}

ZoneActivity.propTypes = {
    showProgress: PropTypes.bool,
    status: PropTypes.number,
    reportListLoading: PropTypes.bool,
    timezone: PropTypes.string,
    report_uid: PropTypes.string,
    options: PropTypes.shape({}),
    reports: PropTypes.arrayOf(PropTypes.shape({})),
};

ZoneActivity.defaultProps = {
    showProgress: false,
    status: 0,
    reportListLoading: false,
    timezone: 'Etc/GMT',
    report_uid: '',
    options: {},
    reports: [],
};
export default ZoneActivity;
