import React from 'react';
import { connect } from 'react-redux';
import deepcopy from 'deepcopy';
import { LayerGroup } from 'react-leaflet';
import LeafletHeatmap from 'components/leaflet/LeafletHeatmap';
import { heatmapBoundsTranslate } from 'utils/formatters';


class LeafletHeatmapContainer extends LayerGroup {
    render() {
        const { heatmaps, sublocation } = this.props;
        
        return (
            <div>
                {
                    heatmaps.map((heatmap) => {
                        const heatmapCopy = deepcopy(heatmap);
                        heatmapCopy.output.bounds = heatmapBoundsTranslate(heatmapCopy.output.bounds, sublocation);
                        return (<LeafletHeatmap
                            key={heatmapCopy.uid}
                            {...heatmapCopy.output}
                        />);
                    })
                }
            </div>
        );
    }
}

const mapStateToProps = state => ({
    heatmaps: state.heatmap.currentHeatmaps,
    sublocation: state.siteView.selectedSublocation,
});

export default connect(mapStateToProps)(LeafletHeatmapContainer);
