import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';

import { changeOpeningSideBar } from 'stores/actions/siteViewActions';
import { siteViewChangeSelectedItems, wsSubscribe, wsUnsubscribe } from 'stores/actions';
import { WS_CHANNELS } from 'worker/common/constants';
import SiteView from './SiteView';
import RightSideBar from './RightSideBar';


class SitePageContent extends Component {
    static propTypes = {
        dispatch: PropTypes.func,
        zoneTableRowElements: PropTypes.arrayOf(PropTypes.shape({})),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        zoneTableRowElements: [],
    };

    componentDidMount() {
        this.props.dispatch(wsSubscribe([WS_CHANNELS.POS]));
    }

    componentWillUnmount() {
        this.props.dispatch(wsUnsubscribe([WS_CHANNELS.POS]));
    }

    openCloseSideBar = () => {
        this.props.dispatch(changeOpeningSideBar());
    };

    ensureSelectedZoneInTableVisible = (zoneElement) => {
        const alignToTop = true;
        if (zoneElement) {
            zoneElement.scrollIntoView(alignToTop);
        }
    };

    handleSiteViewZoneSelection = (zone) => {
        const { zoneTableRowElements } = this.props;
        this.props.dispatch(siteViewChangeSelectedItems(zone));
        this.ensureSelectedZoneInTableVisible(zoneTableRowElements[zone.uid]);
    };

    render() {
        const { zoneTableRowElements, isOpenSideBar } = this.props;

        return (
            <div className="AppLayout-SiteView">
                <SiteView handleSiteViewZoneSelection={this.handleSiteViewZoneSelection} />
                
                <RightSideBar zoneTableRowElements={zoneTableRowElements} isOpenSideBar={isOpenSideBar} />

                <button 
                    onClick={this.openCloseSideBar}
                    className="SiteView-SideBarControl"
                    data-cy="toggle-right-sidebar-button"
                    data-collapsed={!isOpenSideBar}
                >
                    <i className="fa fa-bars" />
                </button>
            </div>
        );
    }
}

const mapStateToProps = state => ({
    isOpenSideBar: state.siteView.isOpenSideBar,
});

export default connect(mapStateToProps)(SitePageContent);
