import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';

import { reduxForm, Field } from 'redux-form';

import { getSpaghetti } from 'stores/actions';
import RenderRangeSlider from 'components/modals/RenderRangeSlider';
import { getTimeZoneOfProject, getTimeZoneOffsetByProject, getTimeByFormatAndTimezone } from 'utils/timeUtils';

class SiteViewSpaghettiDiagramControls extends Component {
    static propTypes = {
        spaghettiId: PropTypes.string,
        isReady: PropTypes.bool,
    };

    static defaultProps = {
        spaghettiId: '',
        isReady: false,
    };

    constructor(props) {
        super(props);

        this.from = null;
        this.to = null;
    }

    onTimeframeDragEnd = ([displayFrom, displayTo]) => {
        const { spaghettiId } = this.props;
        getSpaghetti({ displayFrom, displayTo, spaghettiId });
    };

    render() {
        const { isReady } = this.props;

        return (
            <div>
                {
                    isReady && <SiteViewSpaghettiDiagramControlsForm
                        onTimeframeDragEnd={this.onTimeframeDragEnd}
                        onSubmit={this.handleSubmit}
                    />
                }
            </div>
        );
    }
}

const mapStateToProps = (state) => {
    const { spaghetti: { byId, spaghettiId, isSpaghettiDiagramShowing } } = state;

    return {
        spaghettiId,
        isReady: byId && byId[spaghettiId] && isSpaghettiDiagramShowing,
    };
};

let SiteViewSpaghettiDiagramControlsForm = (props) => {
    const {
        handleSubmit, timeframe, onTimeframeDragEnd, timeZone, isSpaghettiShowing,
    } = props;

    const displayTimeFormat = 'MM/DD h:mm:ss a';
    const getDisplayTime = date => getTimeByFormatAndTimezone(date, displayTimeFormat, timeZone);

    return (
        <form onSubmit={handleSubmit}>
            {
                isSpaghettiShowing && timeframe && <div className="slider-wrapper timeframe-slider">
                    <Field
                        name="timeframe"
                        component={RenderRangeSlider}
                        min={timeframe.spaghettiFrom}
                        max={timeframe.spaghettiTo}
                        valueLabelFormat={value => getTimeByFormatAndTimezone(value, displayTimeFormat, timeZone)}
                        onTimeframeDragEnd={onTimeframeDragEnd}
                    />
                    <div className="ProgressBarWithTime-Time">
                        <div className="ProgressBarWithTime-Time-elem ProgressBarWithTime-Time-start">
                            {getDisplayTime(timeframe.spaghettiFrom)}
                        </div>

                        <div className="ProgressBarWithTime-Time-elem ProgressBarWithTime-Time-finish">
                            {getDisplayTime(timeframe.spaghettiTo)}
                        </div>
                    </div>
                </div>
            }
        </form>
    );
};

SiteViewSpaghettiDiagramControlsForm.propTypes = {
    handleSubmit: PropTypes.func,
    onTimeframeDragEnd: PropTypes.func,
    timeframe: PropTypes.shape({
        spaghettiFrom: PropTypes.number,
        spaghettiTo: PropTypes.number,
    }),
    timeZone: PropTypes.string,
    isSpaghettiShowing: PropTypes.bool,
};

SiteViewSpaghettiDiagramControlsForm.defaultProps = {
    handleSubmit: () => {},
    onTimeframeDragEnd: () => {},
    timeframe: {
        spaghettiFrom: 0,
        spaghettiTo: 0,
    },
    timeZone: 'Etc/GMT',
    isSpaghettiShowing: false,
};

SiteViewSpaghettiDiagramControlsForm = reduxForm({
    form: 'SiteViewSpaghettiDiagramControls',
    enableReinitialize: true,
})(SiteViewSpaghettiDiagramControlsForm);

const mapStateToForm = (state) => {
    const { spaghetti: { byId, spaghettiId, isSpaghettiDiagramShowing } } = state;
    const { timeframe } = byId[spaghettiId];

    const isSpaghettiReady = byId[spaghettiId] && byId[spaghettiId].ready;
    const isSpaghettiShowing = isSpaghettiReady && isSpaghettiDiagramShowing;

    const { project } = state.appContext;
    const timeZone = getTimeZoneOfProject(project);
    const timeZoneOffset = getTimeZoneOffsetByProject(project);

    return (timeframe) ? {
        initialValues: {
            timeframe: [timeframe.spaghettiFrom, timeframe.spaghettiTo],
        },
        timeframe,
        timeZone,
        timeZoneOffset,
        isSpaghettiShowing,
    } : {};
};

SiteViewSpaghettiDiagramControlsForm = connect(mapStateToForm)(SiteViewSpaghettiDiagramControlsForm);

export default connect(mapStateToProps)(SiteViewSpaghettiDiagramControls);
