import React, { useEffect } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { injectIntl } from 'react-intl';
import { TABLES, SITE_TRACKABLES_TABLE, STORAGE_KEY } from 'common';
import { handleUnresponsiveFilter } from 'stores/actions';
import store from 'stores/LocationStore';

function UnresponsiveControl(props) {
    const { showUnresponsive, dispatch, intl } = props;
    const showHideUnresponsive = () => {
        store.setToLocalStorage(STORAGE_KEY.SHOW_UNRESPONSIVE_TRACKABLES, !showUnresponsive);
        dispatch(handleUnresponsiveFilter(!showUnresponsive));
    };
    return (
        <div style={{ fontSize: '0.85em', display: 'flex' }}>
            <div style={{ display: 'flex', alignItems: 'center' }}>
                <input
                    type="checkbox"
                    id="show-unresponsive"
                    defaultChecked={showUnresponsive}
                    onClick={() => showHideUnresponsive()}
                />
                <label style={{ margin: '5px 0 0 5px' }} htmlFor="show-unresponsive">
                    {SITE_TRACKABLES_TABLE.TEXT.SHOW_UNRESPONSIVE(intl)}
                </label>
            </div>
        </div>
    );
}

UnresponsiveControl.propTypes = {
    intl: PropTypes.shape({ formatMessage: PropTypes.func }),
    showUnresponsive: PropTypes.bool,
    dispatch: PropTypes.func,
};
UnresponsiveControl.defaultProps = {
    intl: { formatMessage: () => { } },
    showUnresponsive: true,
    dispatch: () => {},
};

function SearchField(props) {
    let timeout;
    useEffect(() => () => {
        if (timeout) clearTimeout(timeout);
    }, []);
    const { intl, items, searchFields, setFilterItems } = props;

    return (
        <input
            type="text"
            data-cy="trackable-table-search"
            className="form-control input-sm"
            style={{ width: '100%' }}
            placeholder={TABLES.SEARCH(intl)}
            onChange={(e) => {
                const { value } = e.target;
                const regex = new RegExp(value, 'i');
                clearTimeout(timeout);
                timeout = setTimeout(() => {
                    const filteredItems = items
                        .filter(item => searchFields.some(field => (item[field] && item[field].match(regex))));
                    setFilterItems(filteredItems, value);
                }, 600);
            }}
        />
    );
}

SearchField.propTypes = {
    intl: PropTypes.shape({ formatMessage: PropTypes.func }),
    items: PropTypes.arrayOf(PropTypes.shape({})),
    searchFields: PropTypes.arrayOf(PropTypes.string),
    setFilterItems: PropTypes.func,
};
SearchField.defaultProps = {
    intl: { formatMessage: () => { } },
    items: [],
    searchFields: [],
    setFilterItems: () => {},
};

function TableButtons(props) {
    const { dispatch, intl, items, searchFields, setFilterItems, showUnresponsive } = props;
    return (
        <div className="Table row" style={{ marginBottom: '10px' }}>
            <div className="col-md-7">
                <UnresponsiveControl
                    intl={intl}
                    showUnresponsive={showUnresponsive}
                    dispatch={dispatch}
                />
            </div>
            <div className="col-md-5 text-right">
                <SearchField
                    intl={intl}
                    items={items}
                    searchFields={searchFields}
                    setFilterItems={setFilterItems}
                />
            </div>
        </div>
    );
}

TableButtons.propTypes = {
    intl: PropTypes.shape({ formatMessage: PropTypes.func }),
    showUnresponsive: PropTypes.bool,
    dispatch: PropTypes.func,
    items: PropTypes.arrayOf(PropTypes.shape({})),
    searchFields: PropTypes.arrayOf(PropTypes.string),
    setFilterItems: PropTypes.func,
};

TableButtons.defaultProps = {
    dispatch: () => {},
    setFilterItems: () => {},
    items: [],
    showUnresponsive: false,
    searchFields: [],
    intl: { formatMessage: () => {} },
};

export default connect()(injectIntl(TableButtons));
