import React, { Fragment, Component } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { injectIntl } from 'react-intl';
import { SortDirection, AutoSizer } from 'react-virtualized';
import { getTrackablesBySublocation } from 'utils';
import store from 'stores/LocationStore';
import { STORAGE_KEY } from 'common';
import VirtualTable from './VirtualTable';

class TrackablesTable extends Component {
    static propTypes = {
        dispatch: PropTypes.func,
        height: PropTypes.number,
        showUnresponsive: PropTypes.bool,
        trackables: PropTypes.shape(),
        selectedItems: PropTypes.arrayOf(PropTypes.shape({})),
    };

    static defaultProps = {
        dispatch: () => {},
        height: 0,
        showUnresponsive: true,
        trackables: [],
        selectedItems: [],
    };

    constructor(props) {
        super(props);

        this.state = {
            containerWidth: 0,
            containerHeight: 0,
        };
    }

    render() {
        const { trackables, selectedItems, dispatch, showUnresponsive } = this.props;
        const { containerWidth, containerHeight } = this.state;
        const trackablesCount = trackables.size;

        return (
            <div style={{ height: this.props.height }}>
                <AutoSizer
                    onResize={({ height, width }) => {
                        this.setState({
                            containerWidth: width,
                            containerHeight: height,
                        });
                    }}
                >
                    {({ height, width }) => (
                        <Fragment>
                            <VirtualTable
                                defaultSortName="name"
                                defaultSortOrder={SortDirection.ASC}
                                tableSize={{
                                    width: containerWidth,
                                    height: containerHeight,
                                    headerHeight: 32,
                                    rowHeight: 32,
                                }}
                                allItems={trackables}
                                totalCount={trackablesCount}
                                selectedItems={selectedItems}
                                showUnresponsive={showUnresponsive}
                                dispatch={dispatch}
                            />
                        </Fragment>
                    )}
                </AutoSizer>
            </div>
        );
    }
}

const getFormattedTrackablesForTrackablesTable = (intl, zones, groups, nodes, state, showUnresponsive, isPlaybackOpen) => (
    getTrackablesBySublocation(state)
        .reduce((memo, trackable) => {
            const tko = trackable.formattedTrackableForSitePage(intl, zones, groups, nodes);
            if (!showUnresponsive) {
                if (tko.isResponsive(isPlaybackOpen)) {
                    memo.set(trackable.uid, tko);
                }
            } else {
                memo.set(trackable.uid, tko);
            }
            return memo;
        }, new Map())
);
const isShowUnresponsive = () => {
    let showUnresponsive = store.getFromLocalStorage(STORAGE_KEY.SHOW_UNRESPONSIVE_TRACKABLES);
    if (showUnresponsive === null) {
        store.setToLocalStorage(STORAGE_KEY.SHOW_UNRESPONSIVE_TRACKABLES, true);
        showUnresponsive = true;
    }
    return showUnresponsive;
};

const mapStateToProps = (state, { intl }) => {
    const isPlaybackOpen = !!(state.playback && state.playback.isOpenPlayBackControl);
    const zonesList = Object.values(state.entities.zones.byUid);
    const groups = state.entities.groups.byUid;
    const nodes = state.entities.nodes.byMac;
    const showUnresponsive = isShowUnresponsive();
    const trackables = getFormattedTrackablesForTrackablesTable(intl, zonesList, groups, nodes, state, showUnresponsive, isPlaybackOpen);
    const selectedItems = state.siteViewFilter.objectFilter.selectedTrackables.filter(uid => trackables.get(uid));

    return {
        trackables,
        selectedItems,
        isPlaybackOpen,
        showUnresponsive,
        height: state.siteView.height,
    };
};

export default injectIntl(connect(mapStateToProps)(injectIntl(TrackablesTable)));
