import React, { useEffect } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { injectIntl } from 'react-intl';
import { TABLES } from 'common';
import { userHasFullAccess } from 'utils';
import { openZoneNotifyNoCreationModal, openZoneSelectTypeModal } from 'stores/actions';

function AddButton(props) {
    const { currentUser, isZoneCreationDisabled, isOpenPlayBackControl, dispatch } = props;
    if (!userHasFullAccess(currentUser)) return null;
    
    const zoneSelectTypeModal = () => {
        if (isOpenPlayBackControl) {
            dispatch(openZoneNotifyNoCreationModal());
        } else {
            dispatch(openZoneSelectTypeModal());
        }
    };
    
    return (
        <section>
            <button
                className="site-view-table-button"
                onClick={() => zoneSelectTypeModal()}
                data-id="site-view-tab-zones-plus-button"
                data-info="actions-section"
                disabled={isZoneCreationDisabled}
            >
                <i className="fa fa-plus fa-lg table-action-icon" />
            </button>
        </section>
    );
}

AddButton.propTypes = {
    currentUser: PropTypes.shape({}),
    isZoneCreationDisabled: PropTypes.bool,
    isOpenPlayBackControl: PropTypes.bool,
    dispatch: PropTypes.func,
};
AddButton.defaultProps = {
    currentUser: null,
    isZoneCreationDisabled: false,
    isOpenPlayBackControl: false,
    dispatch: () => {},
};

function SearchField(props) {
    let timeout;
    useEffect(() => () => {
        if (timeout) clearTimeout(timeout);
    }, []);
    const { intl, items, searchFields, setFilterItems } = props;

    return (
        <input
            type="text"
            data-cy="zone-table-search"
            className="form-control input-sm"
            style={{ width: '100%' }}
            placeholder={TABLES.SEARCH(intl)}
            onChange={(e) => {
                const { value } = e.target;
                const regex = new RegExp(value, 'i');
                clearTimeout(timeout);
                timeout = setTimeout(() => {
                    const filteredItems = items
                        .filter(item => searchFields.some(field => (item[field] && item[field].match(regex))));
                    setFilterItems(filteredItems, value);
                }, 600);
            }}
        />
    );
}

SearchField.propTypes = {
    intl: PropTypes.shape({ formatMessage: PropTypes.func }),
    items: PropTypes.arrayOf(PropTypes.shape({})),
    searchFields: PropTypes.arrayOf(PropTypes.string),
    setFilterItems: PropTypes.func,
};
SearchField.defaultProps = {
    intl: { formatMessage: () => { } },
    items: [],
    searchFields: [],
    setFilterItems: () => {},
};

function TableButtons(props) {
    const { dispatch, intl, items, searchFields, setFilterItems, currentUser, isZoneCreationDisabled, isOpenPlayBackControl } = props;
    return (
        <div className="Table row" style={{ marginBottom: '10px' }}>
            <div className="col-md-7">
                <AddButton
                    currentUser={currentUser}
                    isZoneCreationDisabled={isZoneCreationDisabled}
                    isOpenPlayBackControl={isOpenPlayBackControl}
                    dispatch={dispatch}
                />
            </div>
            <div className="col-md-5 text-right">
                <SearchField
                    intl={intl}
                    items={items}
                    searchFields={searchFields}
                    setFilterItems={setFilterItems}
                />
            </div>
        </div>
    );
}

TableButtons.propTypes = {
    intl: PropTypes.shape({ formatMessage: PropTypes.func }),
    dispatch: PropTypes.func,
    items: PropTypes.arrayOf(PropTypes.shape({})),
    searchFields: PropTypes.arrayOf(PropTypes.string),
    setFilterItems: PropTypes.func,
    currentUser: PropTypes.shape({}),
    isZoneCreationDisabled: PropTypes.bool,
    isOpenPlayBackControl: PropTypes.bool,
};

TableButtons.defaultProps = {
    dispatch: () => {},
    setFilterItems: () => {},
    items: [],
    searchFields: [],
    intl: { formatMessage: () => {} },
    currentUser: null,
    isZoneCreationDisabled: false,
    isOpenPlayBackControl: false,
};

export default connect()(injectIntl(TableButtons));
