import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { BootstrapTable, TableHeaderColumn } from 'react-bootstrap-table';
import { getActiveConnectionStatus } from 'stores/actions';
import { SHM_ACTIVE_CONNECTION_TABLE, TABLES } from 'common/ui-labels';
import { TIME } from 'common/constants';


class SHMActiveConnectionTable extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        connections: PropTypes.arrayOf(PropTypes.shape()),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        connections: [],
    };
    
    constructor(props) {
        super(props);
        this.interval = null;
    }
    
    componentDidMount() {
        this.interval = setInterval(() => {
            this.props.dispatch(getActiveConnectionStatus());
        }, TIME.SERVER_STATUS_UPDATE_INTERVAL);
    }
    
    componentWillUnmount() {
        clearInterval(this.interval);
    }
    
    trClassFormat = (row) => {
        if (row.percentUsed > 80) {
            return 'redText';
        }
        return '';
    };
    
    render() {
        const { connections } = this.props;
    
        const options = {
            noDataText: (TABLES.NO_DATA_TO_DISPLAY),
        };
        
        return (
            <div className="SHM-Server active-connections-table">
                <h3 className="text-center AdminTab-Title">{SHM_ACTIVE_CONNECTION_TABLE.TITLE}</h3>
                
                <BootstrapTable
                    condensed
                    options={options}
                    data={connections}
                    trClassName={this.trClassFormat}
                    hover
                    striped
                    bodyContainerClass="BootstrapTable"
                >
                    <TableHeaderColumn
                        dataField="port"
                        tdAttr={{ 'data-id': 'shm-connection-port' }}
                        dataAlign="center"
                        dataSort
                        headerAlign="center"
                    >
                        {SHM_ACTIVE_CONNECTION_TABLE.TABLE.PORT_COLUMN}
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="key"
                        hidden
                        isKey
                    />
                    <TableHeaderColumn
                        dataField="ip_connected"
                        tdAttr={{ 'data-id': 'shm-connection-ip_connected' }}
                        dataAlign="center"
                        headerAlign="center"
                    >
                        {SHM_ACTIVE_CONNECTION_TABLE.TABLE.IP_COLUMN}
                    </TableHeaderColumn>
                </BootstrapTable>
            </div>
        );
    }
}

const mapStateToProps = state => ({
    connections: state.SHM.connections,
});

export default connect(mapStateToProps)(SHMActiveConnectionTable);
