import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { BootstrapTable, TableHeaderColumn } from 'react-bootstrap-table';
import { getUptimeStatus } from 'stores/actions';
import { SHM_UPTIME_TABLE, TABLES, COMPONENTS } from 'common/ui-labels';
import { TIME } from 'common/constants';

class SHMUptimeTable extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        uptime: PropTypes.arrayOf(PropTypes.shape()),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        uptime: [],
    };
    
    constructor(props) {
        super(props);
        this.interval = null;
    }
    
    componentDidMount() {
        setTimeout(() => {
            this.interval = setInterval(() => {
                this.props.dispatch(getUptimeStatus());
            }, TIME.SERVER_STATUS_UPDATE_INTERVAL);
        }, 1000);
    }
    
    componentWillUnmount() {
        clearInterval(this.interval);
    }
    
    trClassFormat = (row) => {
        if (row.percentUsed > 80) {
            return 'redText';
        }
        return '';
    };

    combineChildModules = (cell, row, dataField) => {
        const r = [row[dataField]];
        for (let i = 0; i < row.children.length; i += 1) {
            r.push(`<span>${row.children[i][dataField] || ''}</span>`);
        }
        return r.join('</br>');
    };
    
    render() {
        const options = {
            noDataText: (TABLES.NO_DATA_TO_DISPLAY),
        };

        return (
            <div className="SHM-Server uptime-table">
                <h3 className="text-center AdminTab-Title">{SHM_UPTIME_TABLE.TITLE}</h3>
                
                <BootstrapTable
                    condensed
                    data={this.props.uptime}
                    trClassName={this.trClassFormat}
                    options={options}
                    hover
                    striped
                    bodyContainerClass="BootstrapTable"
                >
                    <TableHeaderColumn
                        dataField="category"
                        tdAttr={{ 'data-id': 'shm-uptime-category' }}
                        dataAlign="center"
                        headerAlign="center"
                        dataFormat={(cell, row) => {
                            if (row.children) {
                                return this.combineChildModules(cell, row, 'category');
                            }
                            return cell;
                        }}
                        isKey
                    >
                        {COMPONENTS.FIELDS.NODE.CATEGORY}
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="version"
                        tdAttr={{ 'data-id': 'shm-uptime-version' }}
                        dataAlign="center"
                        headerAlign="center"
                        dataFormat={(cell, row) => {
                            if (row.children) {
                                return this.combineChildModules(cell, row, 'version');
                            }
                            return cell;
                        }}
                    >
                        <span className="text-capitalize">{SHM_UPTIME_TABLE.TABLE.VERSION_COLUMN}</span>
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="status"
                        tdAttr={{ 'data-id': 'shm-uptime-status' }}
                        dataAlign="center"
                        headerAlign="center"
                        dataFormat={(cell, row) => {
                            if (row.children) {
                                return this.combineChildModules(cell, row, 'status');
                            }
                            return cell;
                        }}
                    >
                        {COMPONENTS.FIELDS.COMMON.STATUS}
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="seconds"
                        tdAttr={{ 'data-id': 'shm-uptime-seconds' }}
                        dataSort
                        dataAlign="center"
                        headerAlign="center"
                        dataFormat={(cell, row) => {
                            if (row.children) {
                                return this.combineChildModules(cell, row, 'uptime');
                            }
                            return row.uptime;
                        }}
                    >
                        {SHM_UPTIME_TABLE.TITLE}
                    </TableHeaderColumn>
                </BootstrapTable>
            </div>
        );
    }
}

const mapStateToProps = state => ({
    uptime: state.SHM.uptime,
});

export default connect(mapStateToProps)(SHMUptimeTable);
