import React from 'react';
import { injectIntl } from 'react-intl';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { BootstrapTable, TableHeaderColumn } from 'react-bootstrap-table';

import { getServerStatus } from 'stores/actions';
import { SHM_SERVER, TABLES, TIME, COMPONENTS } from 'common';

class SHMUsageTable extends React.Component {
    static propTypes = {
        dispatch: PropTypes.func,
        serverStatus: PropTypes.shape({}),
        intl: PropTypes.shape({
            formatMessage: PropTypes.func,
        }),
    };
    
    static defaultProps = {
        dispatch: () => {
        },
        serverStatus: {},
        intl: {
            formatMessage: () => {
            },
        },
    };
    
    constructor(props) {
        super(props);
        this.interval = null;
    }
    
    componentDidMount() {
        this.interval = setInterval(() => {
            this.props.dispatch(getServerStatus());
        }, TIME.SERVER_STATUS_UPDATE_INTERVAL);
    }
    
    componentWillUnmount() {
        clearInterval(this.interval);
    }
    
    trClassFormat = (row) => {
        if (row.percentUsed > 80) {
            return 'redText';
        }
        return '';
    };
    
    dataFormat = serverStatus => Object.keys(serverStatus).map((param) => {
        const elem = serverStatus[param];
        let name;
        let used;
        let capacity;
        let percentUsed;
        
        if (param === 'cpu') {
            name = SHM_SERVER.CATEGORY.CPU_USAGE(this.props.intl);
            used = `${elem.usage_ghz} GHz`;
            capacity = `${elem.total_ghz} GHz`;
            percentUsed = elem.usage_percentage;
        } else if (param === 'disk') {
            name = SHM_SERVER.CATEGORY.DISK_USAGE(this.props.intl);
            used = `${elem.usage_gb} Gb`;
            capacity = `${elem.total_gb} Gb`;
            percentUsed = elem.usage_percentage;
        } else if (param === 'memory') {
            name = SHM_SERVER.CATEGORY.MEMORY_USAGE(this.props.intl);
            used = `${elem.usage_gb} Gb`;
            capacity = `${elem.total_gb} Gb`;
            percentUsed = elem.usage_percentage;
        }
        
        return {
            key: param,
            name,
            used,
            capacity,
            percentUsed,
        };
    });
    
    render() {
        const { serverStatus } = this.props;
        const data = this.dataFormat(serverStatus);
        const options = {
            noDataText: (TABLES.NO_DATA_TO_DISPLAY),
        };
        
        return (
            <div className="SHM-Server usage-table">
                <h3 className="text-center AdminTab-Title">{SHM_SERVER.TITLE}</h3>
                
                <BootstrapTable
                    condensed
                    data={data}
                    options={options}
                    trClassName={this.trClassFormat}
                    hover
                    striped
                    bodyContainerClass="BootstrapTable"
                >
                    <TableHeaderColumn
                        dataField="name"
                        tdAttr={{ 'data-id': 'shm-usage-name' }}
                        dataAlign="center"
                        dataSort
                        headerAlign="center"
                    >
                        {COMPONENTS.FIELDS.NODE.CATEGORY}
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="key"
                        hidden
                        isKey
                    />
                    <TableHeaderColumn
                        dataField="used"
                        tdAttr={{ 'data-id': 'shm-usage-used' }}
                        dataAlign="center"
                        headerAlign="center"
                    >
                        {SHM_SERVER.TABLE.USED_COLUMN}
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="capacity"
                        tdAttr={{ 'data-id': 'shm-usage-capacity' }}
                        dataAlign="center"
                        headerAlign="center"
                    >
                        {SHM_SERVER.TABLE.CAPACITY_COLUMN}
                    </TableHeaderColumn>
                    <TableHeaderColumn
                        dataField="percentUsed"
                        tdAttr={{ 'data-id': 'shm-usage-percentUsed' }}
                        dataAlign="center"
                        dataFormat={cell => `${cell}%`}
                        headerAlign="center"
                    >
                        {SHM_SERVER.TABLE.PERCENT_USED_COLUMN}
                    </TableHeaderColumn>
                </BootstrapTable>
            </div>
        );
    }
}

const mapStateToProps = state => ({ serverStatus: state.SHM.serverStatus });

export default connect(mapStateToProps)(injectIntl(SHMUsageTable));
