import * as api from 'api';
import { ACTIONS } from 'common/constants';
import { errorHandler, errorHandlerGetRequest } from 'stores/actions/errorHandlerActions';


export const loadTrackableAssociations = () => async (dispatch) => {
    try {
        const trackableAssociations = await api.loadTrackableAssociations();
        dispatch({
            type: ACTIONS.TRACKABLES_ASSOCIATION_SET,
            params: trackableAssociations,
        });
    } catch (err) {
        console.error(err);
        errorHandlerGetRequest(err, dispatch);
    }
};

export const createTrackableAssociations = ({ mac_address, trackable_uid }) => async (dispatch, getState) => {
    try {
        const association = await api.createTrackableAssociations({ mac_address, obj_uid: trackable_uid });
        if (!getState().worker.isWebSocketOn) {
            dispatch({
                type: ACTIONS.TRACKABLES_ASSOCIATION_CREATE,
                params: association,
            });
        }
    } catch (err) {
        console.error(err);
        errorHandler(err, dispatch);
    }
};


export const closeTrackableAssociations = ({ mac_address, obj_uid }) =>
    (dispatch, getState) => api.closeTrackableAssociations({ mac_address, obj_uid })
        .then((association) => {
            const { worker, appContext } = getState();
            worker.isWebSocketOn && !appContext.project ?
                Promise.resolve(1)
                :
                dispatch({
                    type: ACTIONS.TRACKABLES_ASSOCIATION_CLOSE,
                    params: association,
                });
        })
        .catch((err) => {
            console.error(err);
            errorHandler(err, dispatch);
        });
