import { setProjectUidToHeader, removeProjectFromHeader } from 'api';
import { ACTIONS, getCurrentUserScope, USER_SCOPE_KEYS, SAGA_ACTIONS, USER_ROLES } from 'common';
import { userHasPrivileges } from 'utils';
import { loadAlarms } from 'stores/actions/entityActions/alarmActions';
import {
    loadTrackables,
    loadCompanyTrackables,
    loadTrackableTemplates,
} from 'stores/actions/entityActions/trackablesActions';
import { openProjectsSettingsModal } from 'stores/actions/modalActions/authActions';
import { loadSubscribers, loadSystemNotificationSubscribers } from 'stores/actions/entityActions/subscriberActions';
import { getServerStatus, getActiveConnectionStatus, getUptimeStatus } from 'stores/actions/SHMActions';
import { loadUsers, loadHelperLink, loadMonitorLink, loadUserRoles } from 'stores/actions/entityActions/usersActions';
import { loadCompanies } from 'stores/actions/entityActions/companyActions';
import { loadGroups } from 'stores/actions/entityActions/groupActions';
import { loadZonesPrototypes, loadZones } from 'stores/actions/entityActions/zoneActions';
import { loadProjects } from 'stores/actions/entityActions/projectActions';
import { loadNodes } from 'stores/actions/entityActions/nodeActions';
import { loadTrackableAssociations } from 'stores/actions/entityActions/associationActions';
import { loadSublocations } from 'stores/actions/entityActions/sublocationActions';
import { loadLocations } from 'stores/actions/entityActions/locationActions';
import { loadFloorplans } from 'stores/actions/entityActions/floorplanActions';
import { loadWinAnchors } from 'stores/actions/entityActions/winAnchorActions';
import { loadNotifications, loadNotificationTypesList } from 'stores/actions/entityActions/notificationActions';

export * from './alarmActions';
export * from './companyActions';
export * from './projectActions';
export * from './usersActions';
export * from './trackablesActions';
export * from './groupActions';
export * from './nodeActions';
export * from './zoneActions';
export * from './associationActions';
export * from './locationActions';
export * from './sublocationActions';
export * from './floorplanActions';
export * from './winAnchorActions';
export * from './messageActions';
export * from './notificationActions';
export * from './subscriberActions';

export const reloadLastContext = access => (
    {
        type: SAGA_ACTIONS.SAGA_RELOAD_LAST_CONTEXT,
        params: { access },
    });

const openFirstCompanyAdminModal = () => (dispatch, getState) => {
    const projects = getState().entities.projects;
    const projectsWithoutOffset = (projects && projects.length) ? projects.filter(project => (!project.user_params || !project.user_params.timezone)) : [];
    if (projectsWithoutOffset.length) {
        dispatch(openProjectsSettingsModal(projectsWithoutOffset));
    }
};

export const entitiesAreLoaded = params => ({ 
    type: ACTIONS.ENTITIES_LOADED, 
    params,
});


export const loadEntities = access => async (dispatch, getState) => {
    dispatch(entitiesAreLoaded(false));
    const { currentRole } = access;
    const currentProject = getState().appContext.project;
    const currentScope = getCurrentUserScope(currentRole);

    switch (currentScope) {
        case USER_SCOPE_KEYS.SYSTEM_SCOPE:
            await Promise.all([
                dispatch(loadCompanies()),
            ]);
            break;
        case USER_SCOPE_KEYS.COMPANY_SCOPE:
            await Promise.all([
                dispatch(loadProjects()),
                dispatch(loadNodes()),
                dispatch(loadCompanyTrackables()),
                dispatch(loadTrackableAssociations()),
            ]);
            dispatch(openFirstCompanyAdminModal());
            break;
        case USER_SCOPE_KEYS.PROJECT_SCOPE:
        default:
            // should not load access data for simple user;
            dispatch(getServerStatus());
            dispatch(getUptimeStatus());

            await Promise.all([
                dispatch(loadNotifications()),
                dispatch(loadNotificationTypesList()),
                dispatch(loadSubscribers()),
                dispatch(loadSystemNotificationSubscribers()),
                dispatch(loadAlarms()),
                dispatch(loadGroups()),
                dispatch(loadTrackables()),
                dispatch(loadTrackableAssociations()),
                dispatch(loadZones()),
                dispatch(loadZonesPrototypes()),
                dispatch(loadLocations()),
                dispatch(loadSublocations()),
                dispatch(loadFloorplans()),
                dispatch(getActiveConnectionStatus()),
                dispatch(loadMonitorLink()),
                dispatch(loadTrackableTemplates()),
            ]);
            if (userHasPrivileges(access.currentRole, USER_ROLES.PROJECT_MAINTAINER)) {
                await dispatch(loadWinAnchors());
            }
            // Load all nodes for project scope
            removeProjectFromHeader();
            await dispatch(loadNodes());
            setProjectUidToHeader(currentProject && currentProject.uid);
    }

    dispatch(loadUsers());
    dispatch(loadUserRoles());
    dispatch(loadHelperLink());
    dispatch(reloadLastContext(access));

    // All entities are loaded
    dispatch(entitiesAreLoaded(true));
};
