import * as api from 'api';
import { ACTIONS } from 'common/constants';
import { errorHandler, errorHandlerGetRequest } from 'stores/actions/errorHandlerActions';
import { cronFromStartEndTime } from 'utils/timeUtils';
import Shift from 'stores/classes/Shift';


export const loadLocations = () => dispatch => new Promise((resolve) => {
    api.getLocations()
        .then((locations) => {
            dispatch({
                type: ACTIONS.LOCATIONS_SET,
                params: locations,
            });
            resolve();
        })
        .catch((err) => {
            resolve();
            errorHandlerGetRequest(err, dispatch);
        });
});

export const prepareLocationShifts = (shift) => {
    const { start, end } = cronFromStartEndTime(shift);

    return new Shift({
        name: shift.name,
        start,
        end,
        expected_person: shift.expected_person,
        expected_vehicles: shift.expected_vehicles,
        expected_others: shift.expected_others,
        active: shift.active,
    });
};

export const prepareLocationShiftForClient = (shift, location) => {
    const shiftForClient = prepareLocationShifts(shift);

    return shiftForClient.formattedForClient(location);
};

export const locationShiftDelete = ({ uids, locations }) => async (dispatch) => {
    for (let i = 0; i < locations.length; i += 1) {
        const shift = locations[i].shift.reduce((memo, _shift) => {
            if (!uids.includes(_shift.uid)) {
                memo.push(prepareLocationShifts(_shift));
            }
            return memo;
        }, []);
        const updatedLocation = { ...locations[i], shift };
        
        await api.updateLocation(updatedLocation)
            .catch((err) => {
                errorHandler(err, dispatch);
            });
    }
};

export const locationShiftUpdate = params => (dispatch, getState) => {
    const { locations } = getState().entities;
    const location = locations.find(loc => loc.uid === params.location_uid);
    
    const updatedShift = location.shift.find(_shift => _shift.uid === params.uid);
    if (updatedShift) {
        location.shift = location.shift.map((_shift) => {
            if (_shift.uid === updatedShift.uid) {
                return params;
            }
            return _shift;
        });
    } else {
        location.shift.push(prepareLocationShiftForClient(params, location));
    }
    
    const updatedLocation = { ...location, shift: location.shift.map(shift => prepareLocationShifts(shift)) };

    return api.updateLocation(updatedLocation)
        .catch((err) => {
            console.error(err);
            errorHandler(err, dispatch);
        });
};
