import * as api from 'api';
import { ACTIONS } from 'common/constants';
import { errorHandlerGetRequest } from 'stores/actions/errorHandlerActions';


export const loadNotifications = () => async dispatch => new Promise(async (resolve) => {
    try {
        const notifications = await api.getNotifications();

        dispatch({
            type: ACTIONS.NOTIFICATIONS_SET,
            params: notifications,
        });
        resolve();
    } catch (err) {
        errorHandlerGetRequest(err, dispatch);
        resolve();
    }
});

export const loadNotificationTypesList = () => async dispatch => new Promise(async (resolve) => {
    try {
        const notificationList = await api.getNotificationTypesList();

        dispatch({
            type: ACTIONS.NOTIFICATION_TYPES_LIST_SET,
            params: notificationList,
        });
        resolve();
    } catch (err) {
        errorHandlerGetRequest(err, dispatch);
        resolve();
    }
});

export const createNotification = params => async (dispatch, getState) => {
    try {
        const node = await api.createNotification(params);

        if (!getState().worker.isWebSocketOn) {
            await dispatch({
                type: ACTIONS.NOTIFICATION_CREATE,
                params: node,
            });
        }
    } catch (err) {
        errorHandlerGetRequest(err, dispatch);
        console.warn(err);
    }
};

export const updateNotification = params => async (dispatch, getState) => {
    try {
        const node = await api.updateNotification(params);
        if (!getState().worker.isWebSocketOn) {
            await dispatch({
                type: ACTIONS.NOTIFICATION_UPDATE,
                params: node,
            });
        }
    } catch (err) {
        errorHandlerGetRequest(err, dispatch);
        console.warn(err);
    }
};

export const deleteNotification = params => async (dispatch, getState) => {
    try {
        const node = await api.deleteNotification(params);
        if (!getState().worker.isWebSocketOn) {
            await dispatch({
                type: ACTIONS.NOTIFICATION_DELETE,
                params: node,
            });
        }
    } catch (err) {
        errorHandlerGetRequest(err, dispatch);
        console.warn(err);
    }
};
