import { push } from 'connected-react-router';
import { ACTIONS, ERROR_MESSAGES, HTTP_STATUS, MODAL_ACTIONS } from 'common/constants';
import { openErrorModal } from 'stores/actions/modalActions/commonModalActions';
import { LocationStoreMethods } from 'utils/browserStorage';
import { clearStoreData } from 'stores/actions/commonActions';


function handleLockedError(dispatch) {
    console.warn(ERROR_MESSAGES.ACCOUNT_DISABLED_PREFIX);
    
    LocationStoreMethods.clearUserParamsFromStorage();
    dispatch(clearStoreData());
    dispatch({ type: ACTIONS.USER_LOGOUT });
    dispatch(push('/'));
    
    dispatch(openErrorModal({
        message: 'The user was disabled.  Please contact your administrator for more details.',
        title: `${ERROR_MESSAGES.ACCOUNT_DISABLED_PREFIX}.`,
    }));
}

function handleGeneralError(dispatch) {
    dispatch({
        type: MODAL_ACTIONS.MODAL_OPEN_GENERAL_ERROR,
        params: { title: 'Error', message: 'Requested data is unavailable now' },
    });
}

function handleAuthError(dispatch) {
    console.warn(ERROR_MESSAGES.TOKEN_EXPIRED);
    
    LocationStoreMethods.clearUserParamsFromStorage();
    dispatch(clearStoreData());
    dispatch({ type: ACTIONS.USER_LOGOUT });
    dispatch(push('/'));
}

function handleManyRequestError(dispatch, method) {
    const isGetRequest = method === 'GET';
    const errMessage = isGetRequest ? 'We cannot reach the page at this time. Please try again later.' :
        'This action could not be completed because the server could not be reached at this time. Please try again later.';
    dispatch(openErrorModal({
        message: errMessage,
        title: 'Server is busy. Too many requests.',
        onCloseRedirect: isGetRequest,
    }));
}

export const errorHandler = (err, dispatch, method = '') => {
    if (!dispatch) {
        console.error('No dispatch import');
        return;
    }
    const status = err.response && err.response.status;
    const message = err.response && err.response.data && err.response.data.message;
    if (status === HTTP_STATUS.LOCKED && message && message.startsWith(ERROR_MESSAGES.ACCOUNT_DISABLED_PREFIX)) {
        handleLockedError(dispatch);
        return;
    }

    if (status === HTTP_STATUS.UNAUTHORIZED_ERROR && ERROR_MESSAGES.TOKEN_EXPIRED === message) {
        handleAuthError(dispatch);
        return;
    }
    
    if (status === HTTP_STATUS.TOO_MANY_REQUESTS) {
        handleManyRequestError(dispatch, method);
        return;
    }
    
    console.error(err);
    if (status !== HTTP_STATUS.UNPROCESSABLE && status !== HTTP_STATUS.UNAUTHORIZED_ERROR) {
        handleGeneralError(dispatch);
    }
};

export const errorHandlerGetRequest = (err, dispatch) => {
    errorHandler(err, dispatch, 'GET');
};
