import * as api from 'api';
import { ACTIONS, STORAGE_KEY } from 'common/constants';
import { openErrorModal } from 'stores/actions/modalActions/commonModalActions';
import { clearSpaghettiDiagram } from 'stores/actions/commonActions';
import { RECENT_HEATMAP } from 'common/ui-labels';
import { getSessionStorageValue, LocationStoreMethods, _getHostName } from 'utils/browserStorage';
import { errorHandler } from 'stores/actions/errorHandlerActions';
import { startLiveMode } from 'stores/actions/workerActions';
import { clearPlayback } from './playbackActions';


export const changeHeatmapParams = params => (dispatch, getState) => {
    const { user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;
    
    if (params.completedHeatmaps) {
        LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_CREATED_HEATMAPS, params.completedHeatmaps, userEmail, projectUid);
    }
    
    dispatch({
        type: ACTIONS.HEATMAP_CHANGE_PARAMS,
        params,
    });
};

export const heatmapRequestSend = () => ({
    type: ACTIONS.HEATMAP_REQUEST_SEND,
});

export const heatmapRequestReceive = () => ({
    type: ACTIONS.HEATMAP_REQUEST_RECEIVE,
});

export const getHeatmap = uid => api.getReport(uid).then(data => data);

const getRecentHeatmapName = (selectedPeriodInHours, isCustomInterval, intl) => ((isCustomInterval)
    ? RECENT_HEATMAP.NAME.CUSTOM_INTERVAL(intl)
    : RECENT_HEATMAP.NAME.LAST_HOURS(intl, selectedPeriodInHours));

export const createHeatmap = (params, intl) => (dispatch, getState) => {
    if (!params.start || !params.end || !params.uids) return;

    if (getState().playback.isOpenPlayBackControl || getState().spaghetti.spaghettiId) {
        dispatch(clearPlayback());
    }

    if (getState().spaghetti.spaghettiId) {
        dispatch(clearSpaghettiDiagram());
        dispatch(startLiveMode());
    }

    params.start /= 1000;
    params.end /= 1000;
    dispatch(heatmapRequestSend());

    api.createHeatmap(params)
        .then((res) => {
            const interval = setInterval(() => {
                getHeatmap(res.uid)
                    .then((data) => {
                        if (data.output && !~getState().heatmap.completedHeatmaps.findIndex(heatmap => heatmap.uid === data.uid)) {
                            data.output.url = api.getHeatmapUrl(_getHostName(), data.uid);

                            if (getState().siteView.selectedSublocation) {
                                data.relatedSublocationUid = getState().siteView.selectedSublocation.uid;
                            }

                            data.input.names = params.names;
                            dispatch(heatmapRequestReceive());

                            const { isCustomInterval, selectedPeriodInHours } = params;

                            const name = getRecentHeatmapName(selectedPeriodInHours, isCustomInterval, intl);

                            dispatch(changeHeatmapParams({
                                completedHeatmaps: [...getState().heatmap.completedHeatmaps, { ...data, isCustomInterval, selectedPeriodInHours, name }],
                                currentHeatmaps: [...getState().heatmap.currentHeatmaps, data],
                            }));

                            clearInterval(interval);
                        }
                        if (data.error) {
                            dispatch(heatmapRequestReceive());
                            dispatch(openErrorModal({
                                title: RECENT_HEATMAP.ERROR.TITLE(intl),
                                message: RECENT_HEATMAP.ERROR.HEATMAP_ERROR_MESSAGE(intl),
                            }));
                            clearInterval(interval);
                        }
                    });
            }, 2000);
        })
        .catch((err) => {
            dispatch(heatmapRequestReceive());
            errorHandler(err, dispatch);
        });
};

// clear currentHeatmaps
export const clearHeatmap = () => ({
    type: ACTIONS.HEATMAP_CLEAR,
});
