import moment from 'moment';
import * as api from 'api';
import { ACTIONS, STORAGE_KEY } from 'common/constants';
import { getSessionStorageValue, LocationStoreMethods } from 'utils/browserStorage';
import { errorHandler, errorHandlerGetRequest } from 'stores/actions/errorHandlerActions';


export const changeLastLoggerPath = lastPath => (dispatch, getState) => {
    const { user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;
    
    LocationStoreMethods.setToLocalStorage(STORAGE_KEY.LAST_LOGGER_PATH, lastPath, userEmail, projectUid);
    dispatch({
        type: ACTIONS.LOGGER_PAGE_CHANGE_LAST_PATH,
        params: {
            lastPath,
        },
    });
};

export const getActionFromDB = options => async (dispatch) => {
    const defaultTo = moment().toDate().getTime();
    const defaultFrom = moment().add(-1, 'day').toDate().getTime();

    const { data } = await api.getLoggerAction({
        from: options.from ? options.from : defaultFrom,
        to: options.to ? options.to : defaultTo,
    })
        .catch((err) => { errorHandlerGetRequest(err, dispatch); });

    dispatch({
        type: ACTIONS.LOGGER_GET_ACTIONS_FROM_DB,
        params: {
            from: (data && data.from) ? data.from : 0,
            to: (data && data.to) ? data.to : 0,
            data: (data && data.data) ? data.data : [],
        },
    });
};

export const getMessageProcessorState = () => async (dispatch) => {
    const messageProcessorMaps = await api.getMessageProcessorState()
        .catch((err) => { errorHandlerGetRequest(err, dispatch); });

    dispatch({
        type: ACTIONS.LOGGER_GET_MESSAGE_PROCESSOR_MAP,
        params: messageProcessorMaps,
    });
};

export const getServerLoggerDebuggerState = () => async (dispatch) => {
    const serverLoggerMaps = await api.getServerLoggerState()
        .catch((err) => { errorHandlerGetRequest(err, dispatch); });
    dispatch({
        type: ACTIONS.LOGGER_PAGE_GET_LOGGER_STATUS,
        params: serverLoggerMaps,
    });
};

export const getUpdateValueDebuggerState = value => async (dispatch) => {
    dispatch({
        type: ACTIONS.LOGGER_PAGE_UPDATE_VALUE,
        params: value,
    });
};
export const getUpdateKeyDebuggerState = value => async (dispatch) => {
    dispatch({
        type: ACTIONS.LOGGER_PAGE_UPDATE_KEY,
        params: value,
    });
};

export const postDebuggerState = (key, value) => async (dispatch) => {
    api.postServerLoggerState(key, value).catch((err) => { errorHandler(err, dispatch); });
    dispatch(getServerLoggerDebuggerState());
};

export const deleteDebuggerState = () => async (dispatch) => {
    api.deleteServerLoggerState().catch((err) => { errorHandler(err, dispatch); });
    dispatch(getServerLoggerDebuggerState());
};
