import { MODAL_ACTIONS, SITE_MODE, STORAGE_KEY } from 'common/constants';
import { getSessionStorageValue, LocationStoreMethods } from 'utils/browserStorage';
import { changeMode } from 'stores/actions/siteViewActions';
import { activateZoneEditCoordinatesMode, deactivateZoneEditCoordinatesMode } from 'stores/actions/siteViewZoneEditCoordinatesActions';
import { exitDrawRegime } from 'stores/actions/entityActions/zoneActions';


export const openZoneDeleteModal = row => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_DELETE,
    params: row,
});

export const openZoneCreateAdminPageModal = () => (dispatch, getState) => {
    const { user, appContext } = getState();
    const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const projectUid = (appContext.project && appContext.project.uid) || null;
    
    dispatch({
        type: MODAL_ACTIONS.MODAL_OPEN_ZONE_CREATE_ADMIN_PAGE,
        params: LocationStoreMethods.getFromLocalStorage(STORAGE_KEY.LAST_DIRECTIONAL_ZONE_WIDTH, userEmail, projectUid),
    });
};

export const closeZoneCreateAdminPageModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_CREATE_ADMIN_PAGE,
});

export const openZoneChooseAreaModal = () => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_CHOOSE_AREA,
});

export const closeZoneChooseAreaModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_CHOOSE_AREA,
});

export const openZoneChooseTypeModal = () => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_CHOOSE_TYPE,
});

export const closeZoneChooseTypeModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_CHOOSE_TYPE,
});

export const chooseArea = params => ({
    type: MODAL_ACTIONS.MODAL_CHOOSE_AREA_ZONE_CREATE_ADMIN_PAGE,
    params,
});

export const chooseZoneType = params => ({
    type: MODAL_ACTIONS.MODAL_CHOOSE_TYPE_ZONE_CREATE_ADMIN_PAGE,
    params,
});

export const selectFloorplanCreateModal = floorplan => ({
    type: MODAL_ACTIONS.MODAL_SELECT_FLOORPLAN_CREATE_ADMIN_PAGE,
    params: floorplan,
});

export const saveOptionsZoneCreateModal = params => ({
    type: MODAL_ACTIONS.MODAL_SAVE_OPTIONS_ZONE_CREATE_ADMIN_PAGE,
    params,
});

export const unSelectFloorplanCreateModal = () => ({
    type: MODAL_ACTIONS.MODAL_UNSELECT_FLOORPLAN_CREATE_ADMIN_PAGE,
});

export const setZoneCreateAdminModal = zone => ({
    type: MODAL_ACTIONS.MODAL_SET_ZONE_CREATE_ADMIN_PAGE,
    params: zone,
});

export const setCoordinatesRegimeAdminPageModal = () => ({
    type: MODAL_ACTIONS.MODAL_SET_COORDINATES_REGIME_CREATE_ADMIN_PAGE,
});

export const clearCoordinatesRegimeAdminPageModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLEAR_COORDINATES_REGIME_CREATE_ADMIN_PAGE,
});

export const addVertexAdminPageModal = vertex => ({
    type: MODAL_ACTIONS.MODAL_ADD_VERTEX_ZONE_CREATE_ADMIN_PAGE,
    params: vertex,
});

export const removeVertexAdminPageModal = index => ({
    type: MODAL_ACTIONS.MODAL_REMOVE_VERTEX_ZONE_CREATE_ADMIN_PAGE,
    params: index,
});

export const clearGeometryAdminPageModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLEAR_GEOMETRY_ZONE_CREATE_ADMIN_PAGE,
});

export const closeZoneDeleteModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_DELETE,
});

export const openZoneDetailsModal = row => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_DETAILS,
    params: row,
});

export const closeZoneDetailsModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_DETAILS,
});

export const openZoneDetailsSitePageModal = row => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_DETAILS_SITE_PAGE,
    params: row,
});

export const closeZoneDetailsSitePageModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_DETAILS_SITE_PAGE,
});

export const openZoneEditGeoSitePageModal = row => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_EDIT_GEO_SITE_PAGE,
    params: row,
});

export const openZoneEditGeoSitePage = (zone) => (dispatch) => {
    dispatch(openZoneEditGeoSitePageModal(zone));
    dispatch(changeMode({ name: SITE_MODE.EDIT_ZONE, onReturn: () => { } }));
    dispatch(activateZoneEditCoordinatesMode());
};

export const closeZoneEditGeoSitePage = () => (dispatch) => {
    dispatch(exitDrawRegime());
    dispatch(deactivateZoneEditCoordinatesMode());
    dispatch(closeZoneEditGeoSitePageModal());
};

export const closeZoneEditGeoSitePageModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_EDIT_GEO_SITE_PAGE,
});

export const openZoneEditSitePageModal = row => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_EDIT_SITE_PAGE,
    params: row,
});

export const openZoneEditAdminPageModal = row => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_EDIT_ADMIN_PAGE,
    params: row,
});

export const closeZoneEditSitePageModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_EDIT_SITE_PAGE,
});

export const closeZoneEditAdminPageModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_EDIT_ADMIN_PAGE,
});

export const selectOneZoneDetailsModal = floorplan => ({
    type: MODAL_ACTIONS.MODAL_SELECT_ZONE_FLOORPLAN_DETAILS,
    params: floorplan,
});

export const unSelectOneZoneDetailsModal = () => ({
    type: MODAL_ACTIONS.MODAL_UNSELECT_ZONE_FLOORPLAN_DETAILS,
});

export const selectFloorplanZoneEditPageModal = floorplan => ({
    type: MODAL_ACTIONS.MODAL_SELECT_FLOORPLAN_ZONE_EDIT_ADMIN_PAGE,
    params: floorplan,
});

export const unSelectFloorplanZoneEditPageModal = () => ({
    type: MODAL_ACTIONS.MODAL_UNSELECT_FLOORPLAN_ZONE_EDIT_ADMIN_PAGE,
});

export const openZoneChooseGeometryModal = params => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_CHOOSE_GEOMETRY,
    params,
});

export const clearZoneChooseGeometryModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLEAR_ZONE_CHOOSE_GEOMETRY,
});

export const closeZoneChooseGeometryModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_CHOOSE_GEOMETRY,
});

export const openZoneAddConfigurationModal = data => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_CONFIGURATION_ADD,
    params: data,
});

export const openZoneSelectTypeModal = () => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_SELECT_TYPE,
});

export const closeZoneSelectTypeModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_SELECT_TYPE,
});

export const closeZoneAddConfigurationModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_CONFIGURATION_ADD,
});

export const openZoneNotifyNoCreationModal = () => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_NOTIFY_NO_CREATION,
});

export const closeZoneNotifyNoCreationModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_NOTIFY_NO_CREATION,
});

export const finishDrawingPolygon = () => ({
    type: MODAL_ACTIONS.MODAL_ZONE_POLYGON_STOP_CREATE,
});

export const openZoneVerticesLimitModal = handlers => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_VERTICES_LIMIT,
    params: handlers,
});

export const closeZoneVerticesLimitModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_VERTICES_LIMIT,
});

export const openZoneChooseCreationModeModal = params => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_CHOOSE_CREATION_MODE,
    params,
});

export const closeZoneChooseCreationModeModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_CHOOSE_CREATION_MODE,
});

export const openZoneCoordinatesModeModal = params => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_COORDINATES_REGIME,
    params,
});

export const closeZoneCoordinatesModeModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_COORDINATES_REGIME,
});

export const openZoneEditBulkModal = params => ({
    type: MODAL_ACTIONS.MODAL_OPEN_ZONE_EDIT_BULK_ADMIN_PAGE,
    params,
});

export const closeZoneEditBulkModal = () => ({
    type: MODAL_ACTIONS.MODAL_CLOSE_ZONE_EDIT_BULK_SITE_PAGE,
});

export const saveZonesBulkModal = () => ({
    type: MODAL_ACTIONS.MODAL_IN_PROGRESS_ZONE_EDIT_BULK_ADMIN_PAGE,
});
