import { NEAR_MISS_WORKER_METHODS } from 'near-miss-event/common/constants';
import * as storage from 'utils/browserStorage';
import { tryParse } from 'utils/simpleUtils';
import { getTimeByFormatAndTimezone, getTimeZoneOfProject } from 'utils/timeUtils';
import { download } from 'utils/htmlUtils';
import { ACTIONS, STORAGE_KEY } from 'common/constants';
import NearMissEventWorker from 'near-miss-event/near-miss-event.worker.js'; // handled by plugin worker-loader in webpack config


let nearMissWorker;

const runNearMissWorker = () => (dispatch) => {
    nearMissWorker = new NearMissEventWorker();
    nearMissWorker.postMessage({
        method: NEAR_MISS_WORKER_METHODS.INIT_NEAR_MISS,
    });
    
    nearMissWorker.onmessage = (message) => {
        const { type, params } = message.data;
        
        dispatch({ type, params });
    };
};

export const generateNearMissEventReport = params => (dispatch, getState) => {
    if (!nearMissWorker) {
        dispatch(runNearMissWorker());
    }
    const { appContext } = getState();
    const email = storage.getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
    const token = storage.getSessionStorageValue(STORAGE_KEY.USER_TOKEN);
    const project = tryParse(storage.getSessionStorageValue(STORAGE_KEY.CURRENT_PROJECT));
    const hostname = storage._getHostName(appContext);
    
    const nearMissEventsParams = { ...params };
    nearMissEventsParams.email = email;
    nearMissEventsParams.token = token;
    nearMissEventsParams.project_uid = project.uid;
    nearMissEventsParams.timeZone = getTimeZoneOfProject(project);
    nearMissEventsParams.hostname = hostname;
    
    nearMissWorker.postMessage({
        method: NEAR_MISS_WORKER_METHODS.GENERATE_NEAR_MISS,
        params: nearMissEventsParams,
    });
};

export const getNearMissEventsCsv = (events, options, project, company_name) => {
    const timezone = getTimeZoneOfProject(project);
    const fields = ['timestamp', 'distance (mm)', 'object_one_uid', 'object_one_name', 'object_one_category',
        'object_one_driver_uid', 'object_one_driver_name', 'object_one_x (mm)', 'object_one_y (mm)', 'object_two_uid', 'object_two_name',
        'object_two_category', 'object_two_driver_uid', 'object_two_driver_name', 'object_two_x (mm)', 'object_two_y (mm)'];
    const reportNameRow = '#Near Miss Events\n';
    const companyRow = `#Company: ${company_name}\n`;
    const projectRow = `#Project: ${project.name}\n`;
    const from = `#Start: ${new Date(options.displayFrom).toISOString()}\n`;
    const to = `#End: ${new Date(options.displayTo).toISOString()}\n`;
    
    let result = `${reportNameRow}${companyRow}${projectRow}${from}${to}\n${fields.join(',')}\n`;
    
    for (let i = 0; i < events.length; i += 1) {
        const event = events[i];
        const isoTime = new Date(event.timestampUtc).toISOString();
        result += `${isoTime},${event.distance}`;
        result += event.trackables.reduce((memo, tko, index) => {
            memo += `,${tko.uid},${tko.name || ''},${tko.category},${tko.driver_uid || ''},${tko.driver_name || ''},${tko.x},${tko.y}`;
            if (index === event.trackables.length - 1) {
                memo += '\n';
            }
            return memo;
        }, '');
    }
    
    const start = getTimeByFormatAndTimezone(options.displayFrom, 'MM/DD/YYYY-HH:mm', timezone);
    const end = getTimeByFormatAndTimezone(options.displayTo, 'MM/DD/YYYY-HH:mm', timezone);
    const file_name = `${start}_${end}_near_miss.csv`;
    
    download(file_name, result);
};


export const changeNearMissDisplayTimeFrame = params => ({
    type: ACTIONS.NEAR_MISS_REPORT_CHANGE_DISPLAY_TIME_FRAME,
    params,
});

export const openNearMissEventPopup = params => ({
    type: ACTIONS.OPEN_NEAR_MISS_EVENT_MARKER_POPUP,
    params,
});

export const getNearMissEventsForTimeframe = (params) => {
    nearMissWorker.postMessage({
        method: NEAR_MISS_WORKER_METHODS.GET_NEAR_MISS_DATA,
        params,
    });
};
