import { ACTIONS, CLIENT_REPORT_TYPES, SERVER_REPORT_TYPES } from 'common/constants';
import { getAttendanceReport, getAttendanceReportsListAction, getAttendanceReportCsv } from 'stores/actions/reportsActions/attendanceReportActions';
import { getAlarmsReportsListAction, getAlarmsReport, getAlarmsReportCsv } from 'stores/actions/reportsActions/alarmsReportActions';
import { getZoneActivityReportsListAction, getZoneActivityReport, getZoneActivityReportCsv } from 'stores/actions/reportsActions/zoneActivityReportActions';
import { getDistanceReportsListAction, getDistanceReport, getDistanceReportCsv } from 'stores/actions/reportsActions/distanceReportActions';
import { createPwsReport, getPwsReportCsv } from 'stores/actions/reportsActions/pwsReportActions';


export const getReportsList = (params, type) => async (dispatch) => {
    switch (type) {
        case SERVER_REPORT_TYPES.ATTENDANCE: {
            await dispatch(getAttendanceReportsListAction(params, type));
            break;
        }
        case SERVER_REPORT_TYPES.ALARMS_REPORT: {
            await dispatch(getAlarmsReportsListAction(params, type));
            break;
        }
        case SERVER_REPORT_TYPES.ZONE_ACTIVITY_REPORT: {
            await dispatch(getZoneActivityReportsListAction(params, type));
            break;
        }
        case SERVER_REPORT_TYPES.TRACKABLE_DISTANCE_REPORT: {
            await dispatch(getDistanceReportsListAction(params, type));
            break;
        }
        default: {
            return null;
        }
    }
};

export const createReport = (params, type) => async (dispatch) => {
    switch (type) {
        case SERVER_REPORT_TYPES.PWS_REPORT: {
            await dispatch(createPwsReport(params));
            break;
        }
        default: {
            return null;
        }
    }
};

export const loadReport = (type) => {
    switch (type) {
        case SERVER_REPORT_TYPES.ATTENDANCE: {
            return {
                type: ACTIONS.LOADING_ATTENDANCE_REPORT,
            };
        }
        case SERVER_REPORT_TYPES.ALARMS_REPORT: {
            return {
                type: ACTIONS.LOADING_ALARMS_REPORT,
            };
        }
        case SERVER_REPORT_TYPES.ZONE_ACTIVITY_REPORT: {
            return {
                type: ACTIONS.LOADING_ZONE_ACTIVITY_REPORT,
            };
        }
        case SERVER_REPORT_TYPES.TRACKABLE_DISTANCE_REPORT: {
            return {
                type: ACTIONS.LOADING_DISTANCE_REPORT,
            };
        }
        default: {
            return null;
        }
    }
};

export const loadReportList = (type) => {
    switch (type) {
        case SERVER_REPORT_TYPES.ATTENDANCE: {
            return {
                type: ACTIONS.LOADING_ATTENDANCE_REPORT_LIST,
            };
        }
        case SERVER_REPORT_TYPES.ALARMS_REPORT: {
            return {
                type: ACTIONS.LOADING_ALARMS_REPORT_LIST,
            };
        }
        case SERVER_REPORT_TYPES.ZONE_ACTIVITY_REPORT: {
            return {
                type: ACTIONS.LOADING_ZONE_ACTIVITY_REPORT_LIST,
            };
        }
        case SERVER_REPORT_TYPES.TRACKABLE_DISTANCE_REPORT: {
            return {
                type: ACTIONS.LOADING_DISTANCE_REPORT_LIST,
            };
        }
        default: {
            return null;
        }
    }
};

export const getReport = (params, type) => async (dispatch) => {
    switch (type) {
        case SERVER_REPORT_TYPES.ATTENDANCE: {
            await dispatch(getAttendanceReport(params));
            break;
        }
        case SERVER_REPORT_TYPES.ALARMS_REPORT: {
            await dispatch(getAlarmsReport(params));
            break;
        }
        case SERVER_REPORT_TYPES.ZONE_ACTIVITY_REPORT: {
            await dispatch(getZoneActivityReport(params));
            break;
        }
        case SERVER_REPORT_TYPES.TRACKABLE_DISTANCE_REPORT: {
            await dispatch(getDistanceReport(params));
            break;
        }
        default: {
            return null;
        }
    }
    return undefined;
};

export const clearReport = type => (dispatch) => {
    switch (type) {
        case SERVER_REPORT_TYPES.ATTENDANCE: {
            dispatch({ type: ACTIONS.CLEAR_ATTENDANCE_REPORT });
            break;
        }
        case SERVER_REPORT_TYPES.ALARMS_REPORT: {
            dispatch({ type: ACTIONS.CLEAR_ALARMS_REPORT });
            break;
        }
        case SERVER_REPORT_TYPES.ZONE_ACTIVITY_REPORT: {
            dispatch({ type: ACTIONS.CLEAR_ZONE_ACTIVITY_REPORT });
            break;
        }
        case SERVER_REPORT_TYPES.TRACKABLE_DISTANCE_REPORT: {
            dispatch({ type: ACTIONS.CLEAR_DISTANCE_REPORT });
            break;
        }
        default: {
            return null;
        }
    }
    return undefined;
};

export const getReportCsv = (data, report, project, companyName, type, userEmail) => (dispatch) => {
    switch (type) {
        case SERVER_REPORT_TYPES.ATTENDANCE: {
            getAttendanceReportCsv(data, report, project, companyName, userEmail);
            break;
        }
        case SERVER_REPORT_TYPES.PWS_REPORT: {
            dispatch(getPwsReportCsv(report));
            break;
        }
        case SERVER_REPORT_TYPES.ALARMS_REPORT: {
            getAlarmsReportCsv(report, project, companyName, userEmail);
            break;
        }
        case SERVER_REPORT_TYPES.ZONE_ACTIVITY_REPORT: {
            getZoneActivityReportCsv(report, project, companyName, userEmail);
            break;
        }
        case SERVER_REPORT_TYPES.TRACKABLE_DISTANCE_REPORT: {
            getDistanceReportCsv(data, report, project, companyName, userEmail);
            break;
        }
        default: {
            return null;
        }
    }
};

export const setReportDate = (params, type) => {
    switch (type) {
        case SERVER_REPORT_TYPES.PWS_REPORT: {
            return {
                type: ACTIONS.TIME_SELECT_PWS_REPORT,
                params,
            };
        }
        case SERVER_REPORT_TYPES.ATTENDANCE: {
            return {
                type: ACTIONS.SET_ATTENDANCE_REPORT_DATE,
                params,
            };
        }
        case SERVER_REPORT_TYPES.ALARMS_REPORT: {
            return {
                type: ACTIONS.SET_ALARMS_REPORT_DATE,
                params,
            };
        }
        case SERVER_REPORT_TYPES.ZONE_ACTIVITY_REPORT: {
            return {
                type: ACTIONS.SET_ZONE_ACTIVITY_REPORT_DATE,
                params,
            };
        }
        case SERVER_REPORT_TYPES.TRACKABLE_DISTANCE_REPORT: {
            return {
                type: ACTIONS.SET_DISTANCE_REPORT_DATE,
                params,
            };
        }
        default: {
            return null;
        }
    }
};

export const getReportsAdvancedFilterSelectAction = (reportType, params) => {
    let type;
    switch (reportType) {
        case CLIENT_REPORT_TYPES.ZONE_ACTIVITY_REPORT: {
            type = ACTIONS.ADVANCED_SELECT_ZONE_ACTIVITY_REPORT;
            break;
        }
        case CLIENT_REPORT_TYPES.TRACKABLE_DISTANCE_REPORT: {
            type = ACTIONS.ADVANCED_SELECT_TRACKABLE_DISTANCE_REPORT;
            break;
        }
        case CLIENT_REPORT_TYPES.PWS_REPORT: {
            type = ACTIONS.ADVANCED_SELECT_PWS_REPORT;
            break;
        }
        case CLIENT_REPORT_TYPES.ATTENDANCE: {
            type = ACTIONS.ADVANCED_SELECT_ATTENDANCE_REPORT;
            break;
        }
        case CLIENT_REPORT_TYPES.ALARMS_REPORT: {
            type = ACTIONS.ADVANCED_SELECT_ALARMS_REPORT;
            break;
        }
        default:
            return {};
    }
    
    return { type, params };
};
