import { WORKER_METHODS } from 'worker/common/constants';
import { ACTIONS } from 'common/constants';
import { LocationStoreMethods } from 'utils/browserStorage';
import SpaghettiWorker from 'spaghetti/spaghetti.worker.js'; // handled by plugin worker-loader in webpack config


let spaghettiWorker;

const runSpaghettiWorker = () => (dispatch) => {
    spaghettiWorker = new SpaghettiWorker();
    
    spaghettiWorker.postMessage({
        method: WORKER_METHODS.SPAGHETTI_INIT,
    });
    
    spaghettiWorker.onmessage = (message) => {
        const { type, params } = message.data;
        
        dispatch({ type, params });
    };
};

export const generateSpaghetti = params => (dispatch) => {
    if (!spaghettiWorker) {
        dispatch(runSpaghettiWorker());
    }
    const { email, token, project, hostname } = LocationStoreMethods.getParamsFromStorage();
    const spaghettiParams = { ...params };
    spaghettiParams.email = email;
    spaghettiParams.token = token;
    spaghettiParams.project_uid = project.uid;
    spaghettiParams.hostname = hostname;
    
    spaghettiWorker.postMessage({
        method: WORKER_METHODS.SPAGHETTI_GENERATE,
        params: spaghettiParams,
    });
};

export const getSpaghetti = (params) => {
    spaghettiWorker.postMessage({
        method: WORKER_METHODS.GET_SPAGHETTI_DATA,
        params,
    });
};

export const clearSpaghettiDiagramParams = () => ({ type: ACTIONS.CLEAR_SPAGHETTI_DIAGRAM });

export const stopSpaghettiWorker = () => (dispatch) => {
    if (spaghettiWorker) {
        spaghettiWorker.terminate();
        spaghettiWorker = undefined;
    } else {
        console.warn('Spaghetti not running');
    }
    dispatch(clearSpaghettiDiagramParams());
};

export const setFilteredTrailUids = params => ({
    type: ACTIONS.FILTERED_SPAGHETTI_DIAGRAM_TRAILS,
    params,
});

export const changeSpaghettiViewMode = params => ({
    type: ACTIONS.SPAGHETTI_DIAGRAM_CHANGE_VIEW_MODE,
    params,
});

export const selectIdleTimeMarker = params => ({
    type: ACTIONS.SELECT_IDLE_TIME_MARKER,
    params,
});
