import { SITE_ALARMS_TABLE } from 'common/ui-labels';
import { ALARM_NAMES, ALARM_TYPES, ALARM_ID_NAME } from 'common/constants';
import { getFullDateByTz } from 'utils/timeUtils';


export default class Alarm {
    constructor(alarm) {
        this.acknowledged = alarm.acknowledged;
        this.acknowledged_by = alarm.acknowledged_by;
        this.alarm_name = alarm.alarm_name || ALARM_ID_NAME[alarm.alarm_type_id];
        this.alarm_type_id = alarm.alarm_type_id;
        this.created_at = alarm.created_at;
        this.hysteresis_count = alarm.hysteresis_count;
        this.mac_address = alarm.mac_address;
        this.obj_uid = alarm.obj_uid;
        this.state = alarm.state;
        this.ts = alarm.ts;
        this.uid = alarm.uid;
        this.updated_at = alarm.updated_at;
        this.x = alarm.x;
        this.y = alarm.y;
        this.z = alarm.z;
        this.zone_uid = alarm.zone_uid;
        this.sublocation_uid = alarm.sublocation_uid;
        if (alarm.alarm_name === ALARM_NAMES.PWS_SAFETY || alarm.alarm_type_id === ALARM_TYPES.PWS_SAFETY) {
            const info = alarm.additional_info || {};
            this.additional_info = { ...info, text: `${info.contact_name} is in proximity` };
        } else if (alarm.alarm_name === ALARM_NAMES.UNCERTIFIED_OPERATION || alarm.alarm_type_id === ALARM_TYPES.UNCERTIFIED_OPERATION) {
            const info = alarm.additional_info || {};
            this.additional_info = { ...info, text: 'Uncertified operation' };
        } else {
            this.additional_info = alarm.additional_info;
        }
    }
    
    getProperties() {
        return { ...this };
    }
    
    getAlarmInfo = (zoneMap, timeZone, intl) => {
        const zone = zoneMap[this.zone_uid];
        let msg = '';
        
        if (zone && intl) {
            const displayName = zone.zone_type;
            msg = `${displayName.name === 'keep_out'
                ? SITE_ALARMS_TABLE.TEXT.ENTER_KEEP_OUT_FUNC(intl)
                : SITE_ALARMS_TABLE.TEXT.LEAVE_KEEP_IN_FUNC(intl)
            } ${SITE_ALARMS_TABLE.TEXT.ZONE_FUNC(intl)} ${zone.name}`;
        }
        if (this.created_at && timeZone) {
            return `\n${getFullDateByTz(this.created_at, timeZone)}\n${msg}`;
        }
        
        return `\n\n\n${msg}`;
    };
    
    static getAllAlarms(state) {
        const isPlaybackOpen = (state.playback && state.playback.isOpenPlayBackControl);
        if (isPlaybackOpen) {
            return state.playback.alarms;
        }
        return state.entities.alarms;
    }
}
