import { getNodeSwVersion } from 'utils/formatters';
import { TIME } from 'common/constants';

export default class Node {
    constructor(node) {
        this.uid = node.uid;
        this.name = node.name || '';
        this.project_uid = node.project_uid || null;
        this.company_uid = node.company_uid || null;
        this.users = node.users || [];
        this.mac_address = node.mac_address || '';
        this.parent_mac_address = node.parent_mac_address || '';
        this.bridge_mac_address = node.bridge_mac_address || '';
        this.last_heard = node.last_heard || '';
        this.announce = node.announce || {};
        this.node_type = node.node_type || '';
        this.uwb_trx_config = node.uwb_trx_config || '';
        this.periferial_info = node.periferial_info || {};
        this.created_at = node.created_at || '';
        this.updated_at = node.updated_at || '';
        this.current_system_timestamp = node.current_system_timestamp || '';
        this.status = node.status || null;
    
        // Properties has only in client side
        this.battery = node.battery || null;
        this.sw_version = node.sw_version || null;
        this.hw_info = node.hw_info || null;
        this.charging = node.charging || null;
    }
    
    getProperties() {
        return { ...this };
    }

    formattedNode(currentProject, associationsMap, trackablesMap) {
        const node = this.getProperties();
        node.trackable_name = ''; // for table search
        node.ownership = 'Claim'; // for table search
        node.mac_address = node.mac_address ? node.mac_address.toUpperCase() : null;
        node.firmware_version = getNodeSwVersion(node);

        const obj_uid = associationsMap.byMac[node.mac_address];
        const trackable = obj_uid ? trackablesMap[obj_uid] : null;
    
        node.trackable_association = obj_uid ? 'Yes' : 'No'; // for table search
        node.trackable_name = trackable ? trackable.name : '';
        
        if (!this.company_uid) {
            node.project_uid = null;
        }
        
        if (this.project_uid === currentProject.uid) {
            node.ownership = 'Release'; // for table search
            node.project_name = currentProject.name;
        }
        // for table search
        return node;
    }
    
    isUnresponsive(interval = TIME.HEARTBEAT_UPDATE_INTERVAL) {
        if (!this.last_heard) return true;
    
        const COUNT_FOR_CHECK_LOSTING = 4;
        const timeLost = interval * COUNT_FOR_CHECK_LOSTING;
        const now = new Date();
        const lastHeard = new Date(this.last_heard);
    
        return (now - lastHeard) > timeLost;
    }

    formattedNodeWithoutLastHeard() {
        const props = this.getProperties();
        delete props.last_heard;
        return new Node(props);
    }

    static getAllNodes(state) {
        return state.entities.nodes.byMac;
    }
    
    static getAllNodesArray(state) {
        return Object.values(Node.getAllNodes(state));
    }
}
