import { lengthToDegree,  } from 'utils/simpleUtils';
import { degreeToLength,  } from 'utils/formatters';
import LeafletPosition from './LeafletPosition';

export default class Position {
    constructor(position, sublocation = {}) {
        const offset = {
            x: sublocation.offset_x || 0,
            y: sublocation.offset_y || 0,
        };
        
        if (!isNaN(position.lat) && !isNaN(position.lng)) {
            this.position = new LeafletPosition(position.lat, position.lng, offset).latlng;
        } else if (Array.isArray(position)) {
            this.position = new LeafletPosition(position[0], position[1], offset).latlng;
        } else if (!isNaN(position.x) && !isNaN(position.y)) {
            this.position = new LeafletPosition(lengthToDegree(position.y / 100), lengthToDegree(position.x / 100), offset).latlng;
        } else {
            this.position = position;
        }
    }

    getProperties() {
        return { ...this };
    }
    
    get latlng() {
        return [this.position.lat, this.position.lng];
    }

    get xy() {
        return [this.x, this.y];
    }
    
    get latlngObj() {
        return {
            lat: this.position.lat,
            lng: this.position.lng,
        };
    }
    
    get lat() {
        return this.position.lat;
    }
    
    get lng() {
        return this.position.lng;
    }

    get x() {
        return degreeToLength(this.position.lng * 100);
    }

    get y() {
        return degreeToLength(this.position.lat * 100);
    }
}
