import moment from 'moment';
import Cron from 'cron-converter';
import { getUID } from 'utils/utils';


export default class Shift {
    constructor(shift) {
        this.name = shift.name;
        this.start = shift.start;
        this.end = shift.end;
        this.expected_person = shift.expected_person || null;
        this.expected_vehicles = shift.expected_vehicles || null;
        this.expected_others = shift.expected_others || null;
        this.active = shift.active || false;
    }

    static get uid() {
        Shift._counter = (Shift._counter || 0) + 1;


        return Shift._counter;
    }

    getProperties() {
        return { ...this };
    }

    formattedForClient(relatedLocation) {
        const { name, start, end, expected_person, expected_vehicles, expected_others, active } = this;
        const timeFormat = 'HH:mm';
        const cronInstance = new Cron().fromString(start);
        const schedule = cronInstance.schedule(moment());
        const startTimeString = schedule.next().format(timeFormat);
        const start_time = moment(startTimeString, timeFormat);
        const weekdays = cronInstance.toArray()[4];
        
        cronInstance.fromString(end);
        const endTimeString = schedule.next().format(timeFormat);
        const end_time = moment(endTimeString, timeFormat);

        return {
            uid: getUID(),
            location_uid: relatedLocation.uid,
            location_name: relatedLocation.name,
            name,
            start,
            end,
            start_time,
            end_time,
            weekdays,
            expected_person,
            expected_vehicles,
            expected_others,
            active,
        };
    }
}
