import { getTimeByFormatAndTimezone } from 'utils/timeUtils';


export default class SpaghettiMarker {
    constructor(startPoint, endPoint, checkPoint, trackableName, color, timeZone) {
        this.startPoint = startPoint;
        this.endPoint = endPoint;
        this.checkPoint = checkPoint;
        this.trackableName = trackableName;
        this.timeZone = timeZone;
        this.color = color;
        this.alpha = (Math.atan((this.endPoint.lat - this.startPoint.lat) / (this.endPoint.lng - this.startPoint.lng)) * 180) / Math.PI;
        this.pos = {
            lat: this.getMarkerLat(),
            lng: this.getMarkerLng(),
        };
    }
    
    getMarkerLat() {
        const alphaAbs = Math.abs(this.alpha);
        if ((alphaAbs > 45 && alphaAbs < 135) || (alphaAbs > 135 && alphaAbs < 225)) {
            return this.checkPoint.lat;
        }
        return this.startPoint.lat + (Math.tan((this.alpha * Math.PI) / 180) * (this.checkPoint.lng - this.startPoint.lng));
    }
    
    getMarkerLng() {
        const alphaAbs = Math.abs(this.alpha);
        if ((alphaAbs > 45 && alphaAbs < 135) || (alphaAbs > 135 && alphaAbs < 225)) {
            return this.startPoint.lng + ((this.checkPoint.lat - this.startPoint.lat) / Math.tan((this.alpha * Math.PI) / 180));
        }
        return this.checkPoint.lng;
    }
    
    getMarkerOptions() {
        const startDistance = this.startPoint.distance;
        const endDistance = this.endPoint.distance;
        const startTs = this.startPoint.ts;
        const endTs = this.endPoint.ts;
    
        const totalLength = Math.hypot(this.startPoint.lng - this.endPoint.lng, this.startPoint.lat - this.endPoint.lat);
        const lengthFromStart = Math.hypot(this.pos.lng - this.startPoint.lng, this.pos.lat - this.startPoint.lat);
        
        const weightCoefficient = lengthFromStart / totalLength;
    
        const distance = Math.round((((endDistance - startDistance) * weightCoefficient) + startDistance) * 100) / 100;
        const ts = Math.round(((endTs - startTs) * weightCoefficient) + startTs);
    
        return { distance, ts };
    }
    
    getMarker() {
        const { ts, distance } = this.getMarkerOptions();
        return {
            ts,
            distance,
            pos: this.pos,
            trackableName: this.trackableName,
            time: getTimeByFormatAndTimezone(ts, undefined, this.timeZone),
            color: this.color,
        };
    }
}
