import Trackable from 'stores/classes/Trackable';
import _isEmpty from 'lodash/isEmpty';
import { FILTER } from 'common/constants';
import { getNodeByMacFromMap } from 'utils/utils';


export default class TrackableFilterHandle {
    constructor(trackable, nodes, filtersObject, isPlaybackOpen) {
        this.isPlaybackOpen = isPlaybackOpen;
        this.trackable = new Trackable(trackable);
        this.nodesMap = { ...nodes };
        this.filter = {
            selectedTrackables: filtersObject.selectedTrackables,
            showStationary: filtersObject.showStationary,
            selectedGroups: filtersObject.selectedGroups,
            showInactive: filtersObject.showInactive,
            inactivityValue: filtersObject.inactivityValue,
        };
    }
    
    get _visibleAsGroupMember() {
        const trackableHasNoGroup = !this.trackable.groups || _isEmpty(this.trackable.groups);
        const showTrackablesWithoutGroup = !!this.filter.selectedGroups.find(x => x === FILTER.NA);
    
        if (trackableHasNoGroup && showTrackablesWithoutGroup) {
            return true;
        }
    
        const tkoGroups = (this.trackable.paired ? this.trackable.pairedGroups : this.trackable.groups) || [];
        
        return this.filter.selectedGroups.find(uid => tkoGroups.find(groupUid => groupUid === uid));
    }
    
    get _isShowByDuration() {
        const now = Date.now();
        const mac_address = this.trackable.node && this.trackable.node.mac_address;
        const node = getNodeByMacFromMap(this.nodesMap, mac_address);
        const duration = now - new Date(node.last_heard).getTime();
    
        return duration <= this.filter.inactivityValue;
    }
    
    get _visibleAsUnresponsive() {
        if (this.isPlaybackOpen) {
            return true;
        }
        const { showInactive, inactivityValue } = this.filter;
        if (!this.trackable.isResponsive() && !showInactive) {
            return false;
        }
    
        const showInactiveByDuration = showInactive && inactivityValue;
    
        if (!this.trackable.isResponsive() && showInactiveByDuration) {
            return this._isShowByDuration;
        }
    
        return true;
    }
    
    get _visibleAsStationary() {
        if (this.trackable.stationary) {
            return this.filter.showStationary;
        }
        return true;
    }
    
    get _visibleAsSelected() {
        return this.filter.selectedTrackables.includes(this.trackable.uid);
    }
    
    get isVisible() {
        return this._visibleAsGroupMember && this._visibleAsUnresponsive && this._visibleAsStationary && this._visibleAsSelected;
    }
}
