import _isEmpty from 'lodash/isEmpty';

import { formatDbNameToHumanReadable } from 'utils/htmlUtils';
import { CUSTOM_ZONE_TYPE } from 'common/constants';


export default class ZonePrototype {
    constructor(zonePrototype) {
        this.company_uid = zonePrototype.company_uid;
        this.created_at = zonePrototype.created_at;
        this.project_uid = zonePrototype.project_uid;
        this.removed_at = zonePrototype.removed_at;
        this.updated_at = zonePrototype.updated_at;
        this.variables = zonePrototype.variables;
        this.zone_geometry_restriction = zonePrototype.zone_geometry_restriction;
        this.zone_type = zonePrototype.zone_type;
        this.zone_type_id = zonePrototype.zone_type_id;
    }
    
    getProperties() {
        return { ...this };
    }
    
    isZoneTypeIdEqualTo(zone_type_id) {
        if ((typeof this.zone_type_id === 'number') && (typeof zone_type_id === 'number')) {
            return this.zone_type_id === zone_type_id;
        }
        return undefined;
    }
    
    isZoneTypeNameEqualTo(name) {
        if (this.zone_type && (typeof this.zone_type.name === 'string') && (typeof name === 'string')) {
            return this.zone_type.name === name;
        }
        return undefined;
    }
    
    allowCoordinateMode() {
        return _isEmpty(this.zone_geometry_restriction);
    }
    
    getZoneColorProps() {
        const colorProps = {
            color: '#808080',
            fillOpacity: 0.2,
        };
        if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.BOUNDARY_IN.name)) {
            colorProps.color = 'green';
            colorProps.fillOpacity = 0.5;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.BOUNDARY_OUT.name)) {
            colorProps.color = 'red';
            colorProps.fillOpacity = 0.5;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.STOP_NO_ALERT.name)) {
            colorProps.color = '#ee5c12';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.SLOW.name)) {
            colorProps.color = '#0b7ac1';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.SPECIAL_CUSTOM.name)) {
            colorProps.color = '#51fd91';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.MUTE.name)) {
            colorProps.color = '#bbc10b';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.WIRE_REQUIRED.name)) {
            colorProps.color = '#ff0000';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.HEIGHT_RESTRICTION.name)) {
            colorProps.color = '#52eccc';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.EXIT_RESTRICTION.name)) {
            colorProps.color = '#d27676';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.SPEED_RESTRICTION.name)) {
            colorProps.color = '#04136d';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.MAXIMUM_OCCUPANCY.name)) {
            colorProps.color = '#4b5707';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.ACTION_REQUIRED_ZONE.name)) {
            colorProps.color = '#333b0b';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.CUSTOM_ZONE_A.name)) {
            colorProps.color = '#ff83d9';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.CUSTOM_ZONE_B.name)) {
            colorProps.color = '#e251b8';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.CUSTOM_ZONE_C.name)) {
            colorProps.color = '#d11be7';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.CUSTOM_ZONE_D.name)) {
            colorProps.color = '#9c5ba3';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.CUSTOM_ZONE_E.name)) {
            colorProps.color = '#991ea5';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.CUSTOM_ZONE_F.name)) {
            colorProps.color = '#9970a3';
            colorProps.fillOpacity = 0.7;
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.CUSTOM_ZONE_G.name)) {
            colorProps.color = '#7c427f';
            colorProps.fillOpacity = 0.7;
        }

        return colorProps;
    }
    
    isBoundaryZone() {
        return (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.BOUNDARY_IN.name) || this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.BOUNDARY_OUT.name));
    }
    
    getModalInfoCustomOptions(user_params, zones = [], intl) {
        return this.variables.map((variable) => {
            const { label, name } = variable;
            let value = user_params[name];
            if (this.isBoundaryZone()) {
                const zone = zones.find(_zone => _zone.zone_id === value);
                value = zone ? zone.name : 'None';
            }
            return {
                label: formatDbNameToHumanReadable(intl, name, label),
                value,
            };
        });
    }
    
    getEditModalCustomOptions(zone_id, zones) {
        if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.BOUNDARY_IN.name)) {
            return zones.reduce((memo, _zone) => {
                if (_zone.zone_type_name === CUSTOM_ZONE_TYPE.BOUNDARY_OUT.name && (!_zone.user_params.coupled || zone_id === _zone.user_params.coupled)) {
                    memo.push({
                        value: _zone.zone_id,
                        label: _zone.name,
                    });
                }
                return memo;
            }, []);
        } else if (this.isZoneTypeNameEqualTo(CUSTOM_ZONE_TYPE.BOUNDARY_OUT.name)) {
            return zones.reduce((memo, _zone) => {
                if (_zone.zone_type_name === CUSTOM_ZONE_TYPE.BOUNDARY_IN.name && (!_zone.user_params.coupled || zone_id === _zone.user_params.coupled)) {
                    memo.push({
                        value: _zone.zone_id,
                        label: _zone.name,
                    });
                }
                return memo;
            }, []);
        }
        return [];
    }
    
    static getAllZonePrototypes(state) {
        return state.entities.zonesPrototypes;
    }
}
