import { createSelector } from 'reselect';
import { addValueLabelToValue } from 'utils';
import { Trackable, Group, Node, Zone } from 'stores/classes';
import * as Selectors from 'stores/classes/Selectors';


const getGroups = state => Group.getAllGroupsArray(state).map(group => (addValueLabelToValue({ uid: group.uid, name: group.name })));
const getZonesForSelector = state => Zone.getAllZonesArray(state).map(zone => ({
    name: zone.name,
    uid: zone.uid,
    label: zone.name,
    value: zone.uid,
    sublocation_uid: zone.sublocation_uid,
    zone_type_name: zone.zone_type_name,
    zone_id: zone.zone_id,
    user_params: zone.user_params,
}));

const getStaticZonesForSelector = state => Zone.getAllZonesArray(state).reduce((memo, zone) => {
    if (!zone.dynamic) {
        memo.push({
            name: zone.name,
            uid: zone.uid,
            label: zone.name,
            value: zone.uid,
            sublocation_uid: zone.sublocation_uid,
            zone_type_name: zone.zone_type_name,
            zone_id: zone.zone_id,
            user_params: zone.user_params,
        });
    }
    return memo;
}, [])

const getTrackablesForSelector = state => Trackable.getAllTrackablesArray(state).map(trackable => trackable.formattedTrackablesValueLabel());


export const getTrackables = state => Trackable.getAllTrackablesArray(state).map(trackable => trackable.formattedTrackableWithoutPosition());

export const getAdminTrackables = (state) => {
    const tkoMap = new Map();
    const trackables = Trackable.getAllTrackables(state);
    const zones = Selectors.Zone.getZoneArray(state);
    const associations = Selectors.Association.getAssociations(state);
    const nodes = Selectors.Node.getNodesMap(state);
    const groups = Selectors.Group.getGroupsMap(state);
    
    for (const uid in trackables) {
        if (trackables[uid] && typeof trackables[uid].formattedTrackableForAdminPage === 'function') {
            tkoMap.set(uid, trackables[uid].formattedTrackableForAdminPage(zones, associations, nodes, groups));
        }
    }
    return tkoMap;
};

export const getNodes = state => Node.getAllNodesArray(state).map(node => node.formattedNodeWithoutLastHeard());

// createSelector
export const getParsedTrackables = createSelector([getTrackablesForSelector], items => items);
export const getParsedGroups = createSelector([getGroups], items => items);
export const getParsedZones = createSelector([getZonesForSelector], items => items);
export const getParsedStaticZones = createSelector([getStaticZonesForSelector], items => items);
