import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS, MODAL_ACTIONS } from 'common/constants';

const initialState = {
    selectedItems: [],
    projectSelect: null,
    lastPath: null,
    canEditShift: true,
};

const adminPage = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.RELOAD_CONTEXT:
            return {
                ...state,
                lastPath: initialState.lastPath,
            };
        case ACTIONS.ADMIN_PAGE_SAVE_LAST_PATH:
            return {
                ...state,
                lastPath: action.params.lastPath,
            };
        case ACTIONS.ADMIN_PAGE_CHANGE_SELECTED_ITEMS: {
            let selectedItems = [];
            
            const isExist = state.selectedItems.find((item) => item.uid === action.params.uid);
            
            if (isExist) {
                state.selectedItems.forEach((item) => {
                    if (item.uid !== action.params.uid) {
                        selectedItems.push(item);
                    }
                });
            } else {
                selectedItems = [...state.selectedItems, action.params];
            }
            
            return {
                ...state,
                selectedItems,
            };
        }
        case ACTIONS.ADMIN_PAGE_SELECT_ITEMS: {
            let selectedItems = state.selectedItems;
            
            action.params.forEach((item) => {
                selectedItems = selectedItems.filter((selectedItem) => item.uid !== selectedItem.uid);
            });
            
            selectedItems = [...action.params, ...selectedItems];
            
            return {
                ...state,
                selectedItems,
            };
        }
        case ACTIONS.ADMIN_PAGE_UNSELECT_ITEMS: {
            const selectedItems = [];
            
            state.selectedItems.forEach((item) => {
                const alreadyExist = action.params.find((unselectItem) => unselectItem.uid === item.uid);
                
                if (!alreadyExist) {
                    selectedItems.push(item);
                }
            });
            
            return {
                ...state,
                selectedItems,
            };
        }
        case NOTIFY_ACTIONS.NODE_DELETED:
        case NOTIFY_ACTIONS.ZONE_DELETED:
        case NOTIFY_ACTIONS.GROUP_DELETED:
        case NOTIFY_ACTIONS.TRACKABLE_OBJECT_DELETED: {
            const { uid } = action.params;
            const selectedItems = state.selectedItems.filter((item) => item.uid !== uid);
            return {
                ...state,
                selectedItems,
            };
        }
        case ACTIONS.ADMIN_PAGE_CLEAR_SELECTED_ITEMS: {
            return {
                ...state,
                selectedItems: [],
            };
        }
        case ACTIONS.PROJECT_SELECT:
            if (state.projectSelect && state.projectSelect.uid === action.params.uid) {
                return {
                    ...state,
                    projectSelect: null,
                };
            }
            
            return {
                ...state,
                projectSelect: action.params,
            };
        case ACTIONS.ADMIN_PAGE_CLEAR:
            return { ...initialState };
        case NOTIFY_ACTIONS.LOCATION_UPDATED: {
            return {
                ...state,
                canEditShift: true,
            };
        }
        case MODAL_ACTIONS.EDIT_SHIFT_DISABLE: {
            return {
                ...state,
                canEditShift: false,
            };
        }
        default:
            return state;
    }
};

export default adminPage;
