import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import Floorplan from 'stores/classes/Floorplan';
import { getNotifyParams } from 'utils/storeUtils';

const initialState = [];

const floorplans = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.FLOORPLANS_SET:
            return action.params.map(floorplan => new Floorplan(floorplan));
        case ACTIONS.FLOORPLANS_CLEAR:
            return [...initialState];
        case NOTIFY_ACTIONS.FLOORPLAN_CREATED:
        case ACTIONS.FLOORPLAN_CREATE: {
            const newState = [...state];
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.push(new Floorplan(param));
            });
            return newState;
        }
        case NOTIFY_ACTIONS.FLOORPLAN_UPDATED:
        case ACTIONS.FLOORPLAN_UPDATE: {
            const params = getNotifyParams(action);
            return state.map((floorplan) => {
                const param = params.find(_param => _param.uid === floorplan.uid);
                if (param) {
                    return new Floorplan(param);
                }
                return floorplan;
            });
        }
        case NOTIFY_ACTIONS.FLOORPLAN_DELETED:
        case ACTIONS.FLOORPLAN_DELETE: {
            const params = getNotifyParams(action);
            return state.filter((floorplan) => {
                const param = params.find(_param => _param.uid === floorplan.uid);
                return !param;
            });
        }
        default:
            return state;
    }
};

export default floorplans;
