import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import Group from 'stores/classes/Group';
import { getNotifyParams } from 'utils/storeUtils';

const initialState = {
    byUid: {},
};

function makeStateCopy(state) {
    return {
        byUid: { ...state.byUid },
    };
}

const groups = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.GROUPS_SET: {
            const newState = { byUid: {} };
            action.params.forEach((group) => {
                newState.byUid[group.uid] = new Group(group);
            });
            return newState;
        }
        case ACTIONS.GROUPS_CLEAR:
            return { ...initialState };
        case NOTIFY_ACTIONS.GROUP_CREATED:
        case ACTIONS.GROUP_CREATE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.byUid[param.uid] = new Group(param);
            });
            return newState;
        }
        case NOTIFY_ACTIONS.GROUP_UPDATED:
        case ACTIONS.GROUP_UPDATE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.byUid[param.uid] = new Group(param);
            });
            return newState;
        }
        case NOTIFY_ACTIONS.GROUP_DELETED:
        case ACTIONS.GROUP_DELETE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                delete newState.byUid[param.uid];
            });
            return newState;
        }
        default:
            return state;
    }
};

export default groups;
