import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import Location from 'stores/classes/Location';
import { getNotifyParams } from 'utils/storeUtils';

const initialState = [];

const locations = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.LOCATIONS_SET:
            return action.params.map(location => new Location(location));
        case ACTIONS.LOCATIONS_CLEAR:
            return [...initialState];
        case NOTIFY_ACTIONS.LOCATION_CREATED:
        case ACTIONS.LOCATION_CREATE: {
            const newState = [...state];
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.push(new Location(param));
            });
            return newState;
        }
        case NOTIFY_ACTIONS.LOCATION_UPDATED:
        case ACTIONS.LOCATION_UPDATE: {
            const params = getNotifyParams(action);
            return state.map((location) => {
                const param = params.find(_param => _param.uid === location.uid);
                if (param) {
                    return new Location(param);
                }
                return location;
            });
        }
        case NOTIFY_ACTIONS.LOCATION_DELETED:
        case ACTIONS.LOCATION_DELETE: {
            const params = getNotifyParams(action);
            return state.filter((location) => {
                const param = params.find(_param => _param.uid === location.uid);
                return !param;
            });
        }
        default:
            return state;
    }
};

export default locations;
