import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import Notification from 'stores/classes/Notification';
import { getNotifyParams } from 'utils/storeUtils';

/**
 * @typedef notification {Array}
 * @params uid {string}
 * @params name {string}
 * @params zone_severity_level {number}
 * @params email {boolean}
 * @params phone {boolean}
 */
const initialState = [];

const notifications = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.NOTIFICATIONS_SET:
            return action.params.map(notification => new Notification(notification));
        case ACTIONS.NOTIFICATIONS_CLEAR:
            return initialState;
        case ACTIONS.NOTIFICATION_CREATE:
        case NOTIFY_ACTIONS.NOTIFICATION_CREATED: {
            const newState = [...state];
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.push(new Notification(param));
            });
            return newState;
        }
        case ACTIONS.NOTIFICATION_UPDATE:
        case NOTIFY_ACTIONS.NOTIFICATION_UPDATED: {
            const params = getNotifyParams(action);
            return state.map((notification) => {
                const param = params.find(_param => _param.uid === notification.uid);
                if (param) {
                    return new Notification(param);
                }
                return notification;
            });
        }
        case ACTIONS.NOTIFICATION_DELETE:
        case NOTIFY_ACTIONS.NOTIFICATION_DELETED: {
            const params = getNotifyParams(action);
            return state.filter((notification) => {
                const param = params.find(_param => _param.uid === notification.uid);
                return !param;
            });
        }
        default:
            return state;
    }
};

export default notifications;
