import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import Sublocation from 'stores/classes/Sublocation';
import { getNotifyParams } from 'utils/storeUtils';

const initialState = [];

const sublocations = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.SUBLOCATIONS_SET:
            return action.params.map(sublocation => new Sublocation(sublocation));
        case ACTIONS.SUBLOCATIONS_CLEAR:
            return [...initialState];
        case NOTIFY_ACTIONS.SUBLOCATION_CREATED:
        case ACTIONS.SUBLOCATION_CREATE: {
            const params = getNotifyParams(action);
            const newState = [...state];
            params.forEach((param) => {
                newState.push(new Sublocation(param));
            });
            return newState;
        }
        case NOTIFY_ACTIONS.SUBLOCATION_UPDATED:
        case ACTIONS.SUBLOCATION_UPDATE: {
            const params = getNotifyParams(action);
            // todo: change O(N^2) to O(N)
            return state.map((sublocation) => {
                const param = params.find(_param => _param.uid === sublocation.uid);
                if (param) {
                    return new Sublocation(param);
                }
                return sublocation;
            });
        }
        case NOTIFY_ACTIONS.SUBLOCATION_DELETED:
        case ACTIONS.SUBLOCATION_DELETE: {
            const params = getNotifyParams(action);
            // todo: change O(N^2) to O(N)
            return state.filter((sublocation) => {
                const param = params.find(_param => _param.uid === sublocation.uid);
                return !param;
            });
        }
        default:
            return state;
    }
};

export default sublocations;
