import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import Subscriber from 'stores/classes/Subscriber';
import { getNotifyParams } from 'utils/storeUtils';

/**
 * @typedef Subscriber {Array}
 * @params uid {string}
 * @params name {string}
 * @params notification {Array<string>} Notification uid list
 * @params email {string}
 * @params phone {string}
 */
const initialState = [];

const subscribers = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.SUBSCRIBERS_SET:
            return action.params.map(subscriber => new Subscriber(subscriber));
        case ACTIONS.SUBSCRIBERS_CLEAR:
            return [...initialState];
        case NOTIFY_ACTIONS.SUBSCRIBER_CREATED:
        case ACTIONS.SUBSCRIBER_CREATE: {
            const newState = [...state];
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.push(new Subscriber(param));
            });
            return newState;
        }
        case NOTIFY_ACTIONS.SUBSCRIBER_UPDATED:
        case ACTIONS.SUBSCRIBER_UPDATE: {
            const params = getNotifyParams(action);
            return state.map((subscriber) => {
                const param = params.find(_param => _param.uid === subscriber.uid);
                if (param) {
                    return new Subscriber(param);
                }
                return subscriber;
            });
        }
        case NOTIFY_ACTIONS.SUBSCRIBER_DELETED:
        case ACTIONS.SUBSCRIBER_DELETE: {
            const params = getNotifyParams(action);
            return state.filter((subscriber) => {
                const param = params.find(_param => _param.uid === subscriber.uid);
                return !param;
            });
        }
        default:
            return state;
    }
};

export default subscribers;
