import { NOTIFY_ACTIONS, WS_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import { mergeTrackablesAndPositions } from 'utils/simpleUtils';
import { getNotifyParams } from 'utils/storeUtils';
import Trackable from 'stores/classes/Trackable';


const initialState = {
    byUid: {},
    allUids: [],
};


function makeStateCopy(state) {
    return {
        byUid: { ...state.byUid },
        allUids: [...state.allUids],
    };
}

const trackables = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.TRACKABLES_SET: {
            const newState = { byUid: {}, allUids: [] };
            action.params.forEach((to) => {
                newState.byUid[to.uid] = new Trackable({
                    ...to,
                    default_height: to.default_height / 1000,
                });
                newState.allUids.push(to.uid);
            });
            return newState;
        }
        case ACTIONS.TRACKABLES_CLEAR:
            return { ...initialState };
        case NOTIFY_ACTIONS.TRACKABLE_OBJECT_UPDATED:
        case ACTIONS.TRACKABLE_UPDATE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);

            params.forEach((param) => {
                const updatedTrackable = {
                    ...param,
                    default_height: param.default_height / 1000,
                };

                const trackable = newState.byUid[updatedTrackable.uid];

                if (trackable && trackable.position && !updatedTrackable.position) {
                    updatedTrackable.position = trackable.position;
                }

                newState.byUid[updatedTrackable.uid] = new Trackable(updatedTrackable);
            });
            
            return newState;
        }
        case NOTIFY_ACTIONS.TRACKABLE_OBJECT_CREATED:
        case ACTIONS.TRACKABLE_CREATE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);

            params.forEach((param) => {
                newState.byUid[param.uid] = new Trackable({
                    ...param,
                    default_height: param.default_height / 1000,
                });
                newState.allUids.push(param.uid);
            });

            return newState;
        }
        case NOTIFY_ACTIONS.TRACKABLE_OBJECT_ASSOCIATION_CREATED:
        case ACTIONS.TRACKABLES_ASSOCIATION_CREATE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);

            params.forEach((param) => {
                const trackable = newState.byUid[param.obj_uid];

                if (trackable) {
                    newState.byUid[trackable.uid] = new Trackable({
                        ...trackable,
                        node: {
                            mac_address: param.mac_address,
                        },
                    });
                }
            });
            return newState;
        }
        case NOTIFY_ACTIONS.TRACKABLE_OBJECT_ASSOCIATION_UPDATED:
        case ACTIONS.TRACKABLES_ASSOCIATION_CLOSE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);

            params.forEach((param) => {
                const trackable = newState.byUid[param.obj_uid];
                if (trackable) {
                    newState.byUid[param.obj_uid] = new Trackable({
                        ...trackable.getProperties(),
                        node: null,
                    });
                }
            });
            return newState;
        }
        case NOTIFY_ACTIONS.TRACKABLE_OBJECT_DELETED:
        case ACTIONS.TRACKABLE_DELETE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);

            params.forEach((param) => {
                delete newState.byUid[param.uid];
                newState.allUids = newState.allUids.filter(uid => uid !== param.uid);
            });

            return newState;
        }
        case WS_ACTIONS.POSITIONS:
            if (action.params.length > 0) {
                const newState = makeStateCopy(state);
                return mergeTrackablesAndPositions(newState, action.params, Trackable);
            }
            return state;
        default:
            return state;
    }
};

export default trackables;
