import { NOTIFY_ACTIONS } from 'worker';
import { ACTIONS } from 'common/constants';
import User from 'stores/classes/User';
import { getNotifyParams } from 'utils/storeUtils';

const initialState = {
    byUid: {},
};

function makeStateCopy(state) {
    return {
        byUid: { ...state.byUid },
    };
}

const users = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.USERS_SET: {
            const newState = { byUid: {} };
            action.params.forEach((user) => {
                newState.byUid[user.uid] = new User(user);
            });
            return newState;
        }
        case ACTIONS.USERS_CLEAR:
            return { ...initialState };
        case NOTIFY_ACTIONS.PROJECT_USER_ACCESS_UPDATED:
        case ACTIONS.USERS_UPDATE_PROJECT_ACCESS: {
            const newState = makeStateCopy(state);
            /**
             * First from projects/access
             * Second from WS PROJECT_USER_ACCESS
             * @type {Array<{
             *      email: String;
             *      project_uid: String;
             *      user_role: String;
             *      user_uid : String;
             *  }|{
             *     admin: boolean,
             *     email: String,
             *     first_name: String,
             *     last_name: String,
             *     priv: number,
             *     project_uid: String,
             *     uid: String,
             *     updated_at: String
             * }>}
             * @example {
             *     admin : false
             *     email: "dlukin+poa22@redpointpositioning.com"
             *     first_name:"111"
             *     last_name:"111"
             *     priv:5
             *     project_uid:"MpCgTxqWR9mKNvO3vVS1SA"
             *     uid:"3xPqyi6tQmWb9_Tu7uTqhg"
             *     updated_at:"2024-03-29T10:46:06.000Z"
             * }
             * @example {
             *     "user_uid":"_Ve-rCEqRwqyh88JmZpZQQ",
             *     "user_role":"project_system_admin",
             *     "project_uid":"MpCgTxqWR9mKNvO3vVS1SA",
             *     "email":"psa_psa_e2e_smoke@test.com",
             *     "isCurrentProject":true
             * }
             */
            const params = getNotifyParams(action);
            params.forEach((param) => {
                const user = newState.byUid[param.user_uid || param.uid];
                if (user) {
                    newState.byUid[param.user_uid || param.uid] = new User({ ...user.getProperties(), project_uid: param.project_uid, user_role: param.user_role });
                }
            });
            return newState;
        }
        case NOTIFY_ACTIONS.PROJECT_DELETED:
        case ACTIONS.PROJECTS_DELETE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);

            params.forEach((param) => {
                const { uid: deletedProjectUid } = param;
                const usersArray = Object.values(newState.byUid);
                usersArray.forEach((user) => {
                    if (user.project_uid && user.project_uid === deletedProjectUid) {
                        const userEntity = newState.byUid[user.uid];
                        delete userEntity.project_uid;
                    }
                });
            });
            return newState;
        }
        case NOTIFY_ACTIONS.USER_DELETED:
        case ACTIONS.USERS_DELETE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                delete newState.byUid[param.uid];
            });
            return newState;
        }
        case NOTIFY_ACTIONS.USER_UPDATED:
        case ACTIONS.USERS_UPDATE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.byUid[param.uid] = new User(param);
            });
            return newState;
        }
        case NOTIFY_ACTIONS.USER_CREATED:
        case ACTIONS.USERS_CREATE: {
            const newState = makeStateCopy(state);
            const params = getNotifyParams(action);
            params.forEach((param) => {
                newState.byUid[param.uid] = new User(param);
            });
            return newState;
        }
        default:
            return state;
    }
};

export default users;
