import { ACTIONS, MODAL_ACTIONS, DEFAULT_VALUES } from 'common/constants';
import { NOTIFY_ACTIONS } from 'worker';


export const initialState = {
    leaflet: {
        zoom: DEFAULT_VALUES.MAP_ZOOM.DEFAULT,
    },
    layerFilter: {
        isOpenViewFilter: false,
        isOpenZoneFilter: false,
        
        isShowingAllZones: true,
        isShowingAlarmZones: true,
        isShowingInfoZones: true,
        isShowingCustomZones: true,
        isShowingInactiveZones: true,

        isShowingActiveZonesOnly: true,
        isShowingInactiveZonesOnly: true,
        isShowingActiveAlarmZones: true,
        isShowingInactiveAlarmZones: true,
        isShowingActiveInfoZones: true,
        isShowingInactiveInfoZones: true,

        isShowingGrid1m: false,
        isShowingGrid5m: false,
        isShowingTrackableLabels: true,
        isShowingZoneLabels: true,
        isShowingAnchors: true,
        isShowingScale: true,
    },
    objectFilter: {
        isOpenObjectFilter: false, // high level filter
    
        isOpenGroupFilter: false, // mid level group filter
        showGroups: true,
        selectedGroups: [],
        selectedTrackables: [],
        
        isOpenInactiveFilter: false, // mid level inactivity filter
        showInactive: true,
        inactivityValue: null,
        
        showStationary: true,
        showAnchor: true,
        showBridges: true,
    },
};

const siteViewFilter = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.SITE_VIEW_SET_INITIAL_GROUPS_FILTER: {
            initialState.objectFilter.selectedGroups = action.params.selectedGroups;
            return { ...state };
        }
        
        case ACTIONS.SITE_VIEW_SET_GROUPS_FILTER: {
            return {
                ...state,
                objectFilter: {
                    ...state.objectFilter,
                    ...action.params,
                },
            };
        }
        case ACTIONS.RELOAD_CONTEXT: {
            const { lastStateOfLeaflet, lastStateOfLayerFilter, lastStateOfObjectFilter } = action.params;
            return {
                ...state,
                leaflet: {
                    ...state.leaflet,
                    ...lastStateOfLeaflet,
                },
                layerFilter: {
                    ...state.layerFilter,
                    ...lastStateOfLayerFilter,
                },
                objectFilter: {
                    ...state.objectFilter,
                    ...lastStateOfObjectFilter,
                    selectedTrackables: [...state.objectFilter.selectedTrackables],
                    isOpenObjectFilter: false,
                    isOpenGroupFilter: false,
                    isOpenInactiveFilter: false,
                },
            };
        }
        
        case ACTIONS.SITE_VIEW_LEAFLET_SET_PARAMS: {
            return {
                ...state,
                leaflet: {
                    ...state.leaflet,
                    ...action.params,
                },
            };
        }
    
        case ACTIONS.SITE_VIEW_LAYER_FILTER: {
            return {
                ...state,
                layerFilter: {
                    ...state.layerFilter,
                    ...action.params,
                },
            };
        }
        
        case ACTIONS.SITE_VIEW_CHANGE_OPENING_FILTER: {
            return {
                ...state,
                objectFilter: {
                    ...state.objectFilter,
                    ...action.params,
                },
            };
        }
        
        case ACTIONS.SITE_VIEW_CHANGE_GROUP_FILTER: {
            return {
                ...state,
                objectFilter: {
                    ...state.objectFilter,
                    ...action.params,
                },
            };
        }
        
        case ACTIONS.SITE_VIEW_CHANGE_FILTER: {
            return {
                ...state,
                objectFilter: {
                    ...state.objectFilter,
                    ...action.params,
                },
            };
        }
        
        case ACTIONS.SITE_VIEW_CHANGE_UNRESPONSIVE_FILTER: {
            return {
                ...state,
                objectFilter: {
                    ...state.objectFilter,
                    ...action.params,
                },
            };
        }
        
        case ACTIONS.TRACKABLES_SET: {
            return {
                ...state,
                objectFilter: {
                    ...state.objectFilter,
                    selectedTrackables: action.params.map(tko => tko.uid),
                },
            };
        }

        case NOTIFY_ACTIONS.TRACKABLE_OBJECT_ASSOCIATION_CREATED: {
            const { selectedTrackables } = state.objectFilter;
            selectedTrackables.push(action.params.obj_uid);

            return {
                ...state,
                objectFilter: {
                    ...state.objectFilter,
                    selectedTrackables,
                },
            };
        }

        case MODAL_ACTIONS.PLAYBACK_SELECT_TRACKABLES_CHANGE: {
            const selectedTrackables = [...state.objectFilter.selectedTrackables];
            if (action.params) {
                action.params.selectedTrackables.forEach((trackable) => {
                    if (!selectedTrackables.includes(trackable.uid)) {
                        selectedTrackables.push(trackable.uid);
                    }
                });
            }

            return {
                ...state,
                objectFilter: {
                    ...state.objectFilter,
                    selectedTrackables,
                },
            };
        }

        case ACTIONS.SITE_VIEW_FILTER_UNSELECT_TRACKABLES: {
            const selectedTrackables = [...state.objectFilter.selectedTrackables].filter(uid => !action.params.includes(uid));
            return {
                ...state,
                objectFilter: {
                    ...state.objectFilter,
                    selectedTrackables,
                },
            };
        }
        
        case ACTIONS.SITE_VIEW_FILTER_SELECT_TRACKABLES: {
            const selectedTrackables = [...state.objectFilter.selectedTrackables];
            action.params.forEach((uid) => {
                if (!selectedTrackables.includes(uid)) {
                    selectedTrackables.push(uid);
                }
            });

            return {
                ...state,
                objectFilter: {
                    ...state.objectFilter,
                    selectedTrackables,
                },
            };
        }
        
        default:
            return state;
    }
};

export default siteViewFilter;
