import { NOTIFY_ACTIONS } from 'worker';
import { setTokenToHeader, removeProjectFromHeader } from 'api';
import { ACTIONS, STORAGE_KEY } from 'common/constants';
import { getNotifyParams } from 'utils/storeUtils';
import * as storage from 'utils/browserStorage';

const initialState = {
    logged: false,
    email: '',
    token: '',
    access: {},
    scope: {
        pages: [],
        navButtons: [],
    },
};

const user = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.USER_LOGIN: {
            return {
                ...state,
                logged: true,
                ...action.params,
            };
        }
        case ACTIONS.USER_LOGOUT: {
            removeProjectFromHeader();
            return {
                ...initialState,
            };
        }
        case NOTIFY_ACTIONS.USER_DELETED: {
            const params = getNotifyParams(action);
            const newState = { ...state };
            params.forEach((param) => {
                newState.logged = param.deletedUserEmail !== newState.email;
            });
            return newState;
        }
        case ACTIONS.UPDATE_CURRENT_USER: {
            return {
                ...state,
                ...action.params,
            };
        }
        case NOTIFY_ACTIONS.UPDATE_TOKEN: {
            const params = getNotifyParams(action);
            const newState = { ...state };
            params.forEach((param) => {
                storage.setSessionStorageKeyValue(STORAGE_KEY.USER_TOKEN, param.token);
                setTokenToHeader(param.token);
                newState.token = param.token;
            });
            return newState;
        }
        default: {
            return state;
        }
    }
};

export default user;
