import * as api from 'api';
import { fork, takeEvery, call, put } from 'redux-saga/effects';
import { HTTP_STATUS, SAGA_ACTIONS } from 'common/constants';
import { openErrorModal } from 'stores/actions/modalActions/commonModalActions';
import errorHandler from 'stores/sagas/commonSaga';


export function* handleGroupTrackable(trackableUid, groups) {
    try {
        yield call(api.replaceTrackableGroups, { uid: trackableUid }, groups, false);
    } catch (error) {
        const status = error.response && error.response.status;
        if (status === HTTP_STATUS.UNPROCESSABLE && error.response.data) {
            yield put(openErrorModal({ message: error.response.data, title: 'Error assigning groups to trackable' }));
        }
        console.error(error);
        yield put(openErrorModal({ message: error.response, title: 'Error assigning trackable(s) to a group' }));
        yield call(errorHandler, error);
    }
}


export function* bulkEditGroup(action) {
    const { trackables, groupUid } = action.params;

    for (let i = 0; i < trackables.length; i += 1) {
        const groupList = [...trackables[i].groups];
        groupList.push(groupUid);

        yield call(handleGroupTrackable, trackables[i].uid, groupList);
    }
}

function* watchBulkEditGroup() {
    yield takeEvery(SAGA_ACTIONS.SAGA_GROUPS_BULK_EDIT, bulkEditGroup);
}

export default function* groupBulkEditSaga() {
    return yield fork(watchBulkEditGroup);
}
