import { select, call, put, takeEvery, fork } from 'redux-saga/effects';
import * as api from 'api';

import { replaceTrackableGroups } from 'stores/sagas/trackable/trackableSagas';
import { closeGroupDeleteModal } from 'stores/actions/modalActions/groupModalActions';
import { groupsMap, trackablesList } from 'stores/sagas/selectors';
import errorHandler from 'stores/sagas/commonSaga';
import { filterTrackables } from 'utils/utils';
import { makeCopy } from 'utils/simpleUtils';
import { ACTIONS, SAGA_ACTIONS } from 'common/constants';


export function* deleteSingleGroup(uid) {
    try {
        yield call(api.deleteGroup, uid);
        yield put({ type: ACTIONS.GROUP_DELETE, params: { uid } });
    } catch (err) {
        yield call(errorHandler, err);
    }
}

export function* updateTrackableGroup(_trackable, group) {
    if (!group) {
        return;
    }
    const trackable = makeCopy(_trackable);
    const groups = yield select(groupsMap);
    const index = trackable.groups.findIndex(uid => group.uid === uid);
    
    if (index >= 0) {
        trackable.groupList = trackable.groups.filter(x => x !== group.uid).map(x => groups[x]);
        yield call(replaceTrackableGroups, trackable);
    }
}

function* detachTrackableGroup(group) {
    const trackables = yield select(trackablesList);
    const filteredTrackables = yield call(filterTrackables, trackables, group);
    for (let i = 0; i < filteredTrackables.length; i += 1) {
        yield call(updateTrackableGroup, filteredTrackables[i], group);
    }
}

export function* deleteGroups(action) {
    if (action.params.uid) {
        yield call(deleteSingleGroup, action.params.uid);
    } else {
        for (let i = 0; i < action.params.length; i += 1) {
            yield call(deleteSingleGroup, action.params[i].uid);
        }
    }
    yield put(closeGroupDeleteModal());
}


function* watchDeleteGroups() {
    yield takeEvery(SAGA_ACTIONS.SAGA_GROUPS_DELETE, deleteGroups);
}

export function* groupsDeleteSaga() {
    return yield fork(watchDeleteGroups);
}
