import { fork, takeEvery, call, put } from 'redux-saga/effects';
import * as api from 'api';
import errorHandler from 'stores/sagas/commonSaga';
import { ACTIONS, HTTP_STATUS, SAGA_ACTIONS } from 'common/constants';
import { formatGroup } from 'common/formatters/groupFormatters';
import { openErrorModal } from 'stores/actions/modalActions/commonModalActions';


export function* editGroup(action) {
    try {
        const { group } = yield call(formatGroup, action.params);
        const _group = yield call(api.updateGroup, group);
        yield put({ type: ACTIONS.GROUP_UPDATE, params: _group });
    } catch (error) {
        yield call(errorHandler, error);

        const status = error.response && error.response.status;
        if (status === HTTP_STATUS.UNPROCESSABLE && error.response.data) {
            yield put(openErrorModal({ message: error.response.data, title: 'Group update error' }));
        }
        if (status === HTTP_STATUS.LOCKED || status === HTTP_STATUS.LOCKED) {
            const message = `${error.response.data.message} Try again later.`;
            yield put(openErrorModal({ message, title: 'Server locked' }));
        }
    }
}

function* watchEditGroup() {
    yield takeEvery(SAGA_ACTIONS.SAGA_GROUPS_EDIT, editGroup);
}

export default function* groupEditSaga() {
    return yield fork(watchEditGroup);
}
