import { select, call, put, takeEvery, all, fork } from 'redux-saga/effects';
import * as api from 'api';
import { ACTIONS, FILTER, SAGA_ACTIONS, STORAGE_KEY } from 'common/constants';
import errorHandler from 'stores/sagas/commonSaga';
import { getSessionStorageValue, LocationStoreMethods } from 'utils/browserStorage';
import { initialState } from 'stores/reducers/siteViewFilter';
import { applicationContext, currentUser } from '../selectors';


export function* getGroups() {
    try {
        const groups = yield call(api.getGroups);
        const appContext = yield select(applicationContext);
        const user = yield select(currentUser);
        const userEmail = user.email || getSessionStorageValue(STORAGE_KEY.USER_EMAIL);
        const projectUid = (appContext.project && appContext.project.uid) || null;
        yield put({ type: ACTIONS.GROUPS_SET, params: groups });
        
        const lastStateOfObjectFilter = yield call(LocationStoreMethods.getFromLocalStorage, STORAGE_KEY.LAST_STATE_OF_OBJECT_FILTER, userEmail, projectUid);
        const objectFilter = lastStateOfObjectFilter || { ...initialState.objectFilter };
        if (!lastStateOfObjectFilter) {
            const selectedGroups = groups.map(x => x.uid).concat(FILTER.NA);
            yield put({ type: ACTIONS.SITE_VIEW_SET_INITIAL_GROUPS_FILTER, params: { selectedGroups } });
            objectFilter.selectedGroups = selectedGroups;
            yield call(LocationStoreMethods.setToLocalStorage, STORAGE_KEY.LAST_STATE_OF_OBJECT_FILTER, objectFilter, userEmail, projectUid);
        }
        yield put({ type: ACTIONS.SITE_VIEW_SET_GROUPS_FILTER, params: { objectFilter } });
    } catch (err) {
        yield call(errorHandler, err);
    }
}

function* watchLoadGroups() {
    yield takeEvery(SAGA_ACTIONS.SAGA_GROUPS_LOAD, getGroups);
}

export function* groupsSagas() {
    return yield all([
        fork(watchLoadGroups),
    ]);
}
