import { lengthToDegree } from '../../js/utils/simpleUtils';
import { getTimeByFormatAndTimezone } from '../../js/utils/timeUtils';


export default class NearMissEvent {
    constructor(event, sublocation, timezone = 'Etc/Gmt', id) {
        this.id = id;
        this.distance = event.distance;
        this.duration = event.duration; // in seconds
        this.timestampUtc = (event.ts * 1000) + event.ms;
        this.type = event.type;
        this.trackables = event.trackables.reduce((memo, trackable) => {
            memo[trackable.uid] = { ...trackable };
            memo[trackable.uid].x = trackable.x - sublocation.offset_x;
            memo[trackable.uid].y = trackable.y - sublocation.offset_y;
            return memo;
        }, {});
        this.sublocation = sublocation;
        this.timezone = timezone;
        this.pos = {
            x: (event.trackables[0].x + event.trackables[1].x) / 2,
            y: (event.trackables[0].y + event.trackables[1].y) / 2,
        };
    }
    
    get position() {
        return {
            lng: lengthToDegree((this.pos.x - this.sublocation.offset_x) / 100),
            lat: lengthToDegree((this.pos.y - this.sublocation.offset_y) / 100),
        };
    }
    
    addTrackablesInfo(trackablesMap) {
        for (const key in this.trackables) {
            const driver_uid = this.trackables[key].driver_uid;
            this.trackables[key].name = trackablesMap[key].name || '';
            this.trackables[key].driver_name = (driver_uid && trackablesMap[driver_uid]) ? trackablesMap[driver_uid].name : '';
            this.trackables[key].category = trackablesMap[key] ? trackablesMap[key].category : '';
        }
    }
    
    get data() {
        const trackables = Object.values(this.trackables);
        const name = `${trackables[0].name}/${trackables[1].name}`;
        return {
            id: this.id,
            distance: this.distance,
            duration: this.duration,
            timestampUtc: this.timestampUtc,
            time: getTimeByFormatAndTimezone(this.timestampUtc, 'MM/DD/YYYY hh:mm:ss a', this.timezone),
            clearTime: getTimeByFormatAndTimezone((this.timestampUtc + (this.duration * 1000)), 'MM/DD/YYYY hh:mm:ss a', this.timezone),
            position: this.position,
            trackables,
            name,
        };
    }
    
    get marker() {
        return {
            value: this.timestampUtc,
            id: this.id,
        };
    }
}
