import PlaybackNotifyMethods from './PlaybackNotifyMethods';


export default class PlaybackDataMethods extends PlaybackNotifyMethods {
    _addPositionToPlayback = (data) => {
        const posTime = (data.ts * 1000) + data.ms;
        const keyTs = this._getHistoryMapKeyTime(posTime);
        const playbackKeyValue = this.historyPos.get(keyTs);
        
        if (playbackKeyValue) {
            if (playbackKeyValue.pos) {
                playbackKeyValue.pos.set(`pos_${data.dev_id}`, data);
            } else {
                const innerObject = new Map();
                innerObject.set(`pos_${data.dev_id}`, data);
                playbackKeyValue.pos = innerObject;
            }
        } else {
            const innerObject = new Map();
            innerObject.set(`pos_${data.dev_id}`, data);
            this.historyPos.set(
                keyTs,
                { pos: innerObject },
            );
        }
        this.maxPosTs = this.maxPosTs < keyTs ? keyTs : this.maxPosTs;
    };
    
    _addInitialPositionToPlayback = (data) => {
        this.initialPos.set(`initial_pos_${data.dev_id}`, data);
    };
    
    _addAlarmToPlayback = (data) => {
        const alarmTime = Math.floor(data.ts / 1000) * 1000;
        const keyTs = this._getHistoryMapKeyTime(alarmTime);
        const playbackKeyValue = this.historyPos.get(keyTs);

        if (playbackKeyValue) {
            if (playbackKeyValue.alarm) {
                playbackKeyValue.alarm.set(`alarm_${data.uid}_${data.state}`, data);
            } else {
                const innerObject = new Map();
                innerObject.set(`alarm_${data.uid}_${data.state}`, data);
                playbackKeyValue.alarm = innerObject;
            }
        } else {
            const innerObject = new Map();
            innerObject.set(`alarm_${data.uid}_${data.state}`, data);
            this.historyPos.set(
                keyTs,
                { alarm: innerObject },
            );
        }
        this.maxAlarmTs = (this.maxAlarmTs < keyTs && data.state.toUpperCase() === 'SET') ? keyTs : this.maxAlarmTs;
    };
    
    _handleLastPositionMessage = (data) => {
        if (!data.playTo) {
            console.warn('[PlaybackHandler] Receive done message without playTo field');
            return;
        }
        const playTo = Math.floor(data.playTo / 1000) * 1000;
        this.maxPosTs = this.maxPosTs < playTo ? playTo : this.maxPosTs;
        
        // Add empty record for request of playback playTo time
        if (!this.historyPos.has(playTo)) {
            this.historyPos.set(playTo, {
                pos: new Map(),
                alarm: new Map(),
            });
        }
    };
    
    _handleLastAlarmMessage = (data) => {
        if (!data.playTo) {
            console.warn('[PlaybackHandler] Receive done message without playTo field');
            return;
        }
        const playTo = Math.floor(data.playTo / 1000) * 1000;
        this.maxAlarmTs = this.maxAlarmTs < playTo ? playTo : this.maxAlarmTs;
        
        // Add empty record for request of playback playTo time
        if (!this.historyPos.has(playTo)) {
            this.historyPos.set(playTo, {
                pos: new Map(),
                alarm: new Map(),
            });
        }
    };
    
    _handleReceivedPosition = (data) => {
        if (data.error) {
            this._rejectPlayback();
        } else if (data.message === 'done') {
            this._handleLastPositionMessage(data);
            this.receivedAllPositions = true;
            this._checkPlaybackState();
        } else if (!data.ts || typeof data.ms !== 'number' || !data.dev_id) {
            console.warn('[PlaybackHandler]: Receive data without ts/ms or dev_id:', data);
        } else {
            this._addPositionToPlayback(data);
        }
    };
    
    _handleReceivedInitialPosition = (data) => {
        if (data.error) {
            this._rejectPlayback();
        } else if (data.message === 'done') {
            this.receivedInitialPositions = true;
            this._sendInitialPositionsToClient(this.initialPos.values());
            this._checkPlaybackState();
        } else if (!data.ts || typeof data.ms !== 'number' || !data.dev_id) {
            console.warn('[PlaybackHandler]: Receive data without ts/ms or dev_id:', data);
        } else {
            this._addInitialPositionToPlayback(data);
        }
    };
    
    _handleReceivedAlarm = (data) => {
        if (data.error) {
            this._rejectPlayback();
        } else if (data.message === 'done') {
            this._handleLastAlarmMessage(data);
            this.receivedAllAlarms = true;
            this._checkPlaybackState();
        } else if (!data.obj_uid || !data.uid) {
            console.warn('[PlaybackHandler]: Receive data without obj_uid/uid :', data);
        } else {
            this._decomposeAndHandleAlarm(data);
        }
    };
    
    _decomposeAndHandleAlarm = (alarm) => {
        const alarmSetTime = alarm.ts ? new Date(alarm.ts).getTime() : new Date(alarm.created_at).getTime();
        const alarmClearTime = new Date(alarm.updated_at).getTime();
        
        // Every alarm should be added with state 0 (SET)
        this._addAlarmToPlayback({ ...alarm, ts: alarmSetTime, state: 'SET' });
        const isAlarmClosedInPlaybackPeriod = ((alarm.state.toUpperCase() === 'CLEAR') && (alarmClearTime < this.finishTs));
        
        if (isAlarmClosedInPlaybackPeriod) {
            this._addAlarmToPlayback({ ...alarm, ts: alarmClearTime, state: 'CLEAR' });
        }
    };
}
