import { getUID } from 'worker/utils';
import { SPAGHETTI_DEFAULTS } from 'worker/common/constants';
import { SpaghettiTrackable, DisplayedTrackable } from './SpaghettiTrackable';
import SpaghettiPositionMethods from './SpaghettiPositionMethods';


export default class SpaghettiHandler extends SpaghettiPositionMethods {
    constructor() {
        super();
        this.indle_time = SPAGHETTI_DEFAULTS.IDLE_TIME;
        this.minimalFilteredDistance = SPAGHETTI_DEFAULTS.MINIMAL_DISTANCE; // in mm
        this.spaghetti = {};
        this.break_down_time = 10 * 1000;
        this.break_down_ditance = 1500;
    }
    
    generateSpaghetti = (params) => {
        const spaghettiId = getUID();
        this.configureSpaghettiOptions(params, spaghettiId);
        
        const spaghettiOptions = {
            timeframe: {
                displayFrom: params.displayFrom,
                displayTo: params.displayTo,
                spaghettiFrom: params.spaghettiFrom,
                spaghettiTo: params.spaghettiTo,
            },
            sublocation_uid: params.sublocation.uid,
        };
        
        this.sendSpaghettiParamsToClient(spaghettiId, spaghettiOptions);
        this.requestServerData(params, spaghettiId);
    };
    
    configureSpaghettiOptions = (params, spaghettiId) => {
        this.spaghetti[spaghettiId] = {
            displayFrom: params.displayFrom,
            displayTo: params.displayTo,
            spaghettiFrom: params.spaghettiFrom,
            spaghettiTo: params.spaghettiTo,
            sublocation: params.sublocation,
            trackables: {},
        };
        
        params.trackables.forEach((trackable, index) => {
            const color = SPAGHETTI_DEFAULTS.TRAIL_COLORS[index] || 'black';
            this.spaghetti[spaghettiId].trackables[trackable.uid] = new SpaghettiTrackable(trackable, color);
        });
    };
    
    requestSpaghettiFromWorker = (params) => {
        const displayFrom = params.displayFrom || this.spaghetti[params.spaghettiId].displayFrom;
        const displayTo = params.displayTo || this.spaghetti[params.spaghettiId].displayTo;
        
        this.getSpaghettiForTimeFrame(displayFrom, displayTo, params.spaghettiId);
    };

    getSpaghettiForTimeFrame = (displayFrom, displayTo, spaghettiId) => {
        const trackables = {};
        const timeframe = {
            displayTo,
            displayFrom,
            spaghettiTo: this.spaghetti[spaghettiId].spaghettiTo,
            spaghettiFrom: this.spaghetti[spaghettiId].spaghettiFrom,
        };
        for (const uid in this.spaghetti[spaghettiId].trackables) {
            if (uid) {
                const trackable = this.spaghetti[spaghettiId].trackables[uid];
                trackables[uid] = new DisplayedTrackable(trackable, timeframe).data;
            }
        }
    
        this.sendDataToClient({ trackables, spaghettiId, timeframe });
    };
}
