import BaseHandlers from './BaseHandlers';
import { posMapToList, hbMapToList } from '../utils';
import { WS_ACTIONS, NOTIFY_ACTIONS, OBJECT_TYPE } from '../common/constants';
import { TIMINGS } from '../../../js/common/constants';


function setProjectCompanyUidToObjectData(params, listOfObjects) {
    if (listOfObjects.indexOf(params.object) !== -1) {
        if (!params.plist.project_uid) {
            params.plist.project_uid = params.project_uid ? params.project_uid : null;
        }
        if (!params.plist.company_uid) {
            params.plist.company_uid = params.company_uid ? params.company_uid : null;
        }
    }
    return params;
}

class WSNotifyHandlers extends BaseHandlers {
    startUpdateInterval = () => {
        this.posSendInterval = setInterval(() => {
            if (this.positions.size > 0 && this.clientReceivedPos) {
                const positions = posMapToList(this.positions);
                this.positions.clear();
                self.postMessage({ type: WS_ACTIONS.POSITIONS, params: positions });
                this.clientReceivedPos = false;
            }

            if (this.alarms.length > 0) {
                self.postMessage({ type: NOTIFY_ACTIONS.ALARMS, params: this.alarms });
                this.alarms = [];
            }
        }, TIMINGS.SEND_POSITION_INTERVAL);

        this.notifySendInterval = setInterval(() => {
            if (this.heartbeats.size > 0) {
                const hbs = hbMapToList(this.heartbeats);
                this.heartbeats.clear();
                self.postMessage({ type: NOTIFY_ACTIONS.HBS, params: hbs });
            }
            if (this.notifies.size > 0) {
                this.notifies.forEach((params, type, notifies) => {
                    self.postMessage({ type, params });
                    notifies.delete(type);
                });
            }
        }, TIMINGS.SEND_NOTIFY_INTERVAL);
    };

    handleNotify = (action) => {
        const notify = this.notifies.get(action.type);
        if (!notify) {
            this.notifies.set(action.type, [action.params]);
        } else {
            notify.push(action.params);
        }
    }

    stopUpdateInterval = () => {
        clearInterval(this.posSendInterval);
        clearInterval(this.notifySendInterval);
    };
    handleNotNormalSituation = (data) => {
        if (data && data.plist && data.plist.user && data.plist.company) {
            if (data.object === OBJECT_TYPE.COMPANY_OBJECT) return data.plist.company;
            if (data.object === OBJECT_TYPE.USER_OBJECT) return data.plist.user;
        }

        return data.plist;
    };
    handleNotifyMessage = (parameters) => {
        const { data, subscription } = parameters;
        let type;
        let params;
        switch (subscription) {
            case 'pos':
            case '#pos':
                this.positions.set(data.dev_id, data);
                break;
            case 'alarm':
            case '#alarm':
                this.alarms.push(data);
                break;
            case 'notify':
            case '#notify':
                if (data.action && data.object) {
                    type = `${data.object.toUpperCase()}_${data.action.toUpperCase()}`;
                    // params = data.action === 'HB' ? data : this.handleNotNormalSituation(data.plist);
                    if (data.action === NOTIFY_ACTIONS.HB) {
                        params = data;
                        type = NOTIFY_ACTIONS.HB;
                    } else {
                        params = this.handleNotNormalSituation(data);
                    }

                    setProjectCompanyUidToObjectData(data, [OBJECT_TYPE.NODE]);
                } else if (data.object) {
                    type = data.object.toUpperCase();
                    if (data.token) {
                        params = { token: data.token };
                    }
                } else if (data.action) {
                    if (data.action === NOTIFY_ACTIONS.HB) {
                        params = data;
                        type = NOTIFY_ACTIONS.HB;
                    }
                } else {
                    type = OBJECT_TYPE.TYPE_OF_NO_HANDLER_ACTION;
                }
                if (type !== OBJECT_TYPE.TYPE_OF_NO_HANDLER_ACTION) {
                    if (type === NOTIFY_ACTIONS.HB) {
                        this.heartbeats.set(params.dev_id, params);
                    } else {
                        this.handleNotify({ type, params });
                    }
                } else {
                    console.warn('[NotifyHandlers] No handlers for action like this ', data);
                }
                break;
            default:
                console.warn('[NotifyHandlers] Notify from ws did not handled ', params);
        }
    };

    constructor() {
        super();
        this.heartbeats = new Map();
        this.positions = new Map();
        this.notifies = new Map();
        this.alarms = [];
        this.posSendInterval = null;
        this.notifySendInterval = null;
        this.clientReceivedPos = true;
    }
}

export default WSNotifyHandlers;
