#!/usr/bin/env bash
set -x #echo on

PROJECT=rtls-frontend

RPM_DESCRIPTION="Redpoint Positioning RTLS SiteWise"
RPM_MAINTAINER=help@redpointpositioning.com
RPP_VENDOR="Redpoint Positioning, Inc."

PROJECT_HOME=${WORKSPACE}

export PATH=/usr/local/bin:/usr/local/rbenv/shims:$PATH

VERSION="$( client/sys-services/rtls-get-version.sh )"
RELEASE="$( client/sys-services/rtls-get-release.sh )"
FILE="$( client/sys-services/rtls-get-file-name.sh )"

echo "PROJECT_HOME:       ${PROJECT_HOME}"
echo "BUILDING ON BRANCH: ${BRANCH_NAME}"
echo "VERSION:            ${VERSION}"
echo "RELEASE:            ${RELEASE}"
echo "FILE:               ${FILE}"

rm -f "${PROJECT_HOME}"/*.deb
rm -f "${PROJECT_HOME}"/*.rpm
[ -d "${PROJECT_HOME}"/releases ] && rm -f "${PROJECT_HOME}"/releases/*

fpm -s dir -t deb -f \
  --description "${RPM_DESCRIPTION}" \
  --maintainer "${RPM_MAINTAINER}" \
  --vendor "${RPP_VENDOR}" \
  --license "Proprietary" \
  --provides "rtls-frontend" \
  --exclude ".git" \
  --exclude "**/**/__tests__/*" \
  --exclude "**/**/__tests__" \
  --exclude "client/addons/dummy" \
  --exclude "client/addons/dummy/*" \
  --exclude "client/addons/vehicle_certification" \
  --exclude "client/addons/vehicle_certification/*" \
  --exclude "client/addons/vehicle_certification.js" \
  --exclude "client/addons/zone_manager" \
  --exclude "client/addons/zone_manager/*" \
  --exclude "client/addons/zone_manager.js" \
  --exclude "client/addons/.gitkeep" \
  --prefix /usr/rtls/rtls-frontend \
  --deb-group rtls \
  --deb-user rtls \
  --before-remove client/sys-services/pre-uninstall.sh \
  --before-install client/sys-services/pre-install.sh \
  --after-install client/sys-services/post-install.sh \
  --before-upgrade client/sys-services/pre-update.sh \
  --after-upgrade client/sys-services/post-update.sh \
  --depends "nodejs (>= 20.5.1)" \
  --name "${PROJECT}" \
  --version "${VERSION}" \
  --iteration "${RELEASE}" \
  --package "${PROJECT_HOME}" \
  ./client
